#
# spec file for package ovmf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%undefine _build_create_debug
%global openssl_version 3.4.1
%global softfloat_version b64af41c3276f
%if 0%{?suse_version} < 1599
%bcond_with build_riscv64
%else
%bcond_without build_riscv64
%endif

Name:           ovmf
Version:        202502
Release:        3.1
Summary:        Open Virtual Machine Firmware
License:        BSD-2-Clause-Patent
Group:          System/Emulators/PC
URL:            https://github.com/tianocore/edk2
Source0:        edk2-edk2-stable%{version}.tar.gz
Source1:        https://www.openssl.org/source/old/3.0/openssl-%{openssl_version}.tar.gz
Source111:      https://www.openssl.org/source/old/3.0/openssl-%{openssl_version}.tar.gz.asc
Source112:      openssl.keyring
Source113:      openssl.keyring.README
Source114:      descriptors.tar.xz.README
Source2:        README
Source3:        SLES-UEFI-CA-Certificate-2048.crt
Source4:        openSUSE-UEFI-CA-Certificate-2048.crt

Source7:        descriptors.tar.xz
# oniguruma: https://github.com/kkos/oniguruma,  "src" directory only
Source8:        oniguruma-v6.9.4_mark1-src.tar.xz
# public-mipi-sys-t: https://github.com/MIPI-Alliance/public-mipi-sys-t
Source9:        public-mipi-sys-t-1.1-edk2.tar.gz
# mbedtls: https://github.com/Mbed-TLS/mbedtls
Source10:       mbedtls-3.3.0.tar.gz
# brotli: https://github.com/google/brotli
Source11:       brotli-f4153a09f87cbb9c826d8fc12c74642bb2d879ea.tar.gz
# libspdm: https://github.com/DMTF/libspdm.git
Source12:       libspdm-50924a4c8145fc721e17208f55814d2b38766fe6.tar.gz
# pylibfdt: https://github.com/devicetree-org/pylibfdt
Source13:       pylibfdt-cfff805481bdea27f900c32698171286542b8d3c.tar.gz
Source100:      %{name}-rpmlintrc
Source101:      gdb_uefi.py.in
Patch1:         %{name}-gdb-symbols.patch
Patch2:         %{name}-pie.patch
Patch3:         %{name}-disable-ia32-firmware-piepic.patch
Patch6:         %{name}-ignore-spurious-GCC-12-warning.patch
# Bug 1205978 - Got Page-Fault exception when VM is booting with edk2-stable202211 ovmf
Patch7:         %{name}-Revert-OvmfPkg-PlatformInitLib-dynamic-mmio-window-s.patch
# Bug 1207095 - ASSERT [ArmCpuDxe] /home/abuild/rpmbuild/BUILD/edk2-edk2-stable202211/ArmPkg/Library/DefaultExceptionHandlerLib/AArch64/DefaultExceptionHandler.c(333): ((BOOLEAN)(0==1))
Patch8:         %{name}-Revert-ArmVirtPkg-make-EFI_LOADER_DATA-non-executabl.patch
# Bug 1205613 - L3: win 2k22 UEFI xen VMs cannot boot in xen after upgrade
Patch9:         %{name}-Revert-OvmfPkg-OvmfXen-Set-PcdFSBClock.patch
# Bug 1236009 - Build failure on Leap 15.5/15.6 due to unsupported GCC flag -mstack-protector-guard for aarch64 cross-compiler
Patch10:        %{name}-Revert-Add-Stack-Cookie-Support-to-MSVC-and-GCC.patch
%ifarch x86_64
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} <= 150700
Patch11:        %{name}-BaseTools-Using-gcc12-for-building-image.patch
%endif
%endif
Patch12:        %{name}-Increase-FVMAIN-Size-for-Compatibility-with-2MB-Size.patch
# Bug 1240420 - UEFI boot breaks: X64 Exception Type - 0E(#PF - Page-Fault) CPU Apic ID - 00000000
Patch13:        %{name}-UefiCpuPkg-Disable-EFI-memory-attributes-protocol.patch

BuildRequires:  bc
BuildRequires:  cross-arm-binutils
BuildRequires:  cross-arm-gcc%{gcc_version}
BuildRequires:  dosfstools
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
%ifarch x86_64
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} <= 150700
BuildRequires:  gcc12
BuildRequires:  gcc12-c++
%endif
%endif
BuildRequires:  iasl
BuildRequires:  libbpf1
BuildRequires:  libuuid-devel
BuildRequires:  mkisofs
BuildRequires:  mtools
BuildRequires:  nasm
BuildRequires:  openssl
BuildRequires:  python3
BuildRequires:  unzip
BuildRequires:  virt-firmware
%ifnarch aarch64
BuildRequires:  cross-aarch64-binutils
BuildRequires:  cross-aarch64-gcc%{gcc_version}
%endif
%ifnarch x86_64
BuildRequires:  cross-x86_64-binutils
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} <= 150700
BuildRequires:  cross-x86_64-gcc12
%else
BuildRequires:  cross-x86_64-gcc%{gcc_version}
%endif
%endif
%ifnarch riscv64
%if %{with build_riscv64}
BuildRequires:  cross-riscv64-binutils
BuildRequires:  cross-riscv64-gcc%{gcc_version}
%endif
%endif
# Only build on the architectures with
#  1. cross-compilers, 2. iasl
ExclusiveArch:  x86_64 aarch64 riscv64

%description
The Open Virtual Machine Firmware (OVMF) project aims to support
firmware for Virtual Machines using the edk2 code base.

%package tools
Summary:        The BaseTools from edk2
Group:          System/Emulators/PC

%description tools
The Open Virtual Machine Firmware (OVMF) project aims to support
firmware for Virtual Machines using the edk2 code base.

This package contains the tools from edk2.

%package -n qemu-ovmf-ia32
Summary:        Open Virtual Machine Firmware - QEMU rom images (IA32)
Group:          System/Emulators/PC
Requires:       qemu
BuildArch:      noarch

%description -n qemu-ovmf-ia32
The Open Virtual Machine Firmware (OVMF) project aims to support
firmware for Virtual Machines using the edk2 code base.

This package contains UEFI rom images for exercising UEFI secure
boot in a qemu environment (IA32)

%package -n qemu-ovmf-x86_64
Summary:        Open Virtual Machine Firmware - QEMU rom images (x86_64)
Group:          System/Emulators/PC
Requires:       qemu
BuildArch:      noarch

%description -n qemu-ovmf-x86_64
The Open Virtual Machine Firmware (OVMF) project aims to support
firmware for Virtual Machines using the edk2 code base.

This package contains UEFI rom images for exercising UEFI secure
boot in a qemu environment (x86_64)

%ifarch x86_64
%package -n qemu-ovmf-x86_64-debug
Summary:        Open Virtual Machine Firmware - debug symbols (x86_64)
Group:          Development/Sources
Requires:       qemu

%description -n qemu-ovmf-x86_64-debug
The Open Virtual Machine Firmware (OVMF) project aims to support
firmware for Virtual Machines using the edk2 code base.

This package contains the debug symbols for UEFI rom images (x86_64)
%endif

%package -n qemu-uefi-aarch64
Summary:        UEFI QEMU rom image (AArch64)
Group:          System/Emulators/PC
BuildArch:      noarch

%description -n qemu-uefi-aarch64
This package contains the UEFI rom image (AArch64) for QEMU cortex-a57
virt board.

%package -n qemu-uefi-aarch32
Summary:        UEFI QEMU rom image (AArch32)
Group:          System/Emulators/PC
BuildArch:      noarch

%description -n qemu-uefi-aarch32
This package contains the UEFI rom image (AArch32) for QEMU cortex-a15
virt board.

%if %{with build_riscv64}
%package -n qemu-uefi-riscv64
Summary:        UEFI QEMU rom image (RISC-V 64)
Group:          System/Emulators/PC
BuildArch:      noarch

%description -n qemu-uefi-riscv64
This package contains the UEFI rom image (RISC-V 64) for QEMU
virt board.
%endif

%prep
%setup -q -n edk2-edk2-stable%{version}

# bsc#973038 Remove the packages we don't need to avoid any potential
# license issue.
PKG_TO_REMOVE="EmulatorPkg"
rm -rf $PKG_TO_REMOVE

%autopatch -p1

# add openssl
pushd CryptoPkg/Library/OpensslLib/openssl
tar -xf %{SOURCE1} --strip 1
popd

# prepare the firmware descriptors for qemu
tar -xf %{SOURCE7}

# add oniguruma
pushd MdeModulePkg/Universal/RegularExpressionDxe/oniguruma
tar -xf %{SOURCE8} --strip 1
popd

# add public-mipi-sys-t
pushd MdePkg/Library/MipiSysTLib/mipisyst
tar -xf %{SOURCE9} --strip 1
popd

# add mbedtls
pushd CryptoPkg/Library/MbedTlsLib/mbedtls
tar -xf %{SOURCE10} --strip 1
popd

# add brotli
pushd BaseTools/Source/C/BrotliCompress/brotli
tar -xf %{SOURCE11} --strip 1
popd
pushd MdeModulePkg/Library/BrotliCustomDecompressLib/brotli
tar -xf %{SOURCE11} --strip 1
popd

# add libspdm
pushd SecurityPkg/DeviceSecurity/SpdmLib/libspdm
tar -xf %{SOURCE12} --strip 1
popd

# add libfdt
pushd MdePkg/Library/BaseFdtLib/libfdt
tar -xf %{SOURCE13} --strip 1
popd

%build

# Enable python3 build
export PYTHON3_ENABLE=TRUE
export PYTHON_COMMAND=python3

# For some reason ARM still uses TPM2_CONFIG_ENABLE
OVMF_FLAGS=" \
	-D TPM2_ENABLE \
	-D TPM2_CONFIG_ENABLE \
	-D NETWORK_IP6_ENABLE \
	-D NETWORK_HTTP_BOOT_ENABLE \
"

%if 0%{?suse_version} > 1320
TOOL_CHAIN=GCC5
%else
echo `gcc -dumpversion`
TOOL_CHAIN=GCC$(gcc -dumpversion|sed 's/\([0-9]\)\.\([0-9]\).*/\1\2/')
%endif

# Flavors for x86
FLAVORS_X86=("ovmf-ia32")
BUILD_OPTIONS_X86=" \
	$OVMF_FLAGS \
	-D FD_SIZE_2MB \
	-D SECURE_BOOT_ENABLE \
	-D BUILD_SHELL=FALSE \
	-a IA32 \
	-p OvmfPkg/OvmfPkgIa32.dsc \
	-b DEBUG \
	-t $TOOL_CHAIN \
"

# Flavors for x86_64: 2MB, 4MB, 4MB+SMM and AMD SEV
FLAVORS_X64=("ovmf-x86_64" "ovmf-x86_64-4m" "ovmf-x86_64-smm" "ovmf-x86_64-sev")
# Flavors will NOT enroll default kek/db keys
FLAVORS_X64_SKIP_SB_KEY=("ovmf-x86_64-sev")
# Flavors only support unified image (no separate *-code/-vars files)
FLAVORS_X64_UNIFIED_ONLY=("")
BUILD_OPTIONS_X64=" \
	$OVMF_FLAGS \
	-D BUILD_SHELL=FALSE \
	-a X64 \
	-b DEBUG \
	-t $TOOL_CHAIN \
"

# Flavors for aarch64
FLAVORS_AA64=("aavmf-aarch64")
BUILD_OPTIONS_AA64=" \
	$OVMF_FLAGS \
	-D SECURE_BOOT_ENABLE \
	-D NETWORK_TLS_ENABLE \
	-a AARCH64 \
	-p ArmVirtPkg/ArmVirtQemu.dsc \
	-b DEBUG \
	-t $TOOL_CHAIN \
"

# Flavors for arm
FLAVORS_AA32=("aavmf-aarch32")
BUILD_OPTIONS_AA32=" \
	-a ARM \
	-p ArmVirtPkg/ArmVirtQemu.dsc \
	-b DEBUG \
	-t $TOOL_CHAIN \
"
%if %{with build_riscv64}
# Flavors for riscv
FLAVORS_RV64=("riscv")
BUILD_OPTIONS_RV64=" \
	$OVMF_FLAGS \
	-D SECURE_BOOT_ENABLE \
	-a RISCV64 \
	-p OvmfPkg/RiscVVirt/RiscVVirtQemu.dsc \
	-b DEBUG \
	-t $TOOL_CHAIN \
"
%endif

# Build BaseTools
%ifarch x86_64
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} <= 150700
echo "gcc_version="`gcc -dumpversion`
export CC=gcc-12
export CXX=g++-12
%endif
	make -C BaseTools
%endif
%ifarch aarch64
	ARCH=AARCH64 make -C BaseTools
%endif
%ifarch riscv64
	ARCH=RISCV64 make -C BaseTools
%endif

# Import the build functions
source ./edksetup.sh

### Build x86 UEFI Images ###
%ifnarch %{ix86} x86_64
# Assign the cross-compiler prefix
export ${TOOL_CHAIN}_BIN="x86_64-suse-linux-"
%endif
build $BUILD_OPTIONS_X86

cp Build/OvmfIa32/DEBUG_*/FV/OVMF.fd ovmf-ia32.bin
cp Build/OvmfIa32/DEBUG_*/FV/OVMF_CODE.fd ovmf-ia32-code.bin
cp Build/OvmfIa32/DEBUG_*/FV/OVMF_VARS.fd ovmf-ia32-vars.bin

# Remove the temporary build files to reduce the disk usage (bsc#1178244)
rm -rf Build/OvmfIa32/

### Build x86_64 UEFI Images ###
%ifarch x86_64
collect_x86_64_debug_files()
{
	local target="$1"
	local out_dir="debug/$target"
	local abs_path="`pwd`/$out_dir/"
	local source_path="`pwd`"
	local gdb_src_path="%{_prefix}/src/debug/ovmf-x86_64"

	# copy the debug symbols
	mkdir -p $out_dir
	pushd Build/OvmfX64/DEBUG_GCC*/X64/
	find . -mindepth 2 -type f -name "*.debug" -print0 | sort -z | xargs -i -0 cp --parents -a {} $abs_path
	cp --parents -a DebugPkg/GdbSyms/GdbSyms/DEBUG/GdbSyms.dll $abs_path
	build_path=`pwd`
	popd

	# Change the path in the python gdb script
	sed "s:__BUILD_PATH__:$build_path:;s:__SOURCE_PATH__:$source_path:;s:__GDB_SRC_PATH__:$gdb_src_path:;s/__FLAVOR__/$target/" \
	  %{SOURCE101} > gdb_uefi-$target.py
}
%endif

declare -A EXTRA_FLAGS_X64
EXTRA_FLAGS_X64=(
	[ovmf-x86_64]="-p OvmfPkg/OvmfPkgX64.dsc -D FD_SIZE_2MB -D SECURE_BOOT_ENABLE"
	[ovmf-x86_64-4m]="-p OvmfPkg/OvmfPkgX64.dsc -D FD_SIZE_4MB -D NETWORK_TLS_ENABLE -D SECURE_BOOT_ENABLE"
	[ovmf-x86_64-smm]="-a IA32 -p OvmfPkg/OvmfPkgIa32X64.dsc -D FD_SIZE_4MB -D NETWORK_TLS_ENABLE -D SMM_REQUIRE -D SECURE_BOOT_ENABLE"
	[ovmf-x86_64-sev]="-p OvmfPkg/OvmfPkgX64.dsc -D FD_SIZE_4MB -D NETWORK_TLS_ENABLE"
)
declare -A OUTDIR_X64
OUTDIR_X64=(
	[ovmf-x86_64]="OvmfX64"
	[ovmf-x86_64-4m]="OvmfX64"
	[ovmf-x86_64-smm]="Ovmf3264"
	[ovmf-x86_64-sev]="OvmfX64"
)

%ifnarch x86_64
# Assign the cross-compiler prefix
export ${TOOL_CHAIN}_BIN="x86_64-suse-linux-"
%endif
for flavor in ${FLAVORS_X64[@]}; do
	build $BUILD_OPTIONS_X64 ${EXTRA_FLAGS_X64[$flavor]}
	cp Build/${OUTDIR_X64[$flavor]}/DEBUG_*/FV/OVMF.fd      $flavor.bin
	cp Build/${OUTDIR_X64[$flavor]}/DEBUG_*/FV/OVMF_CODE.fd $flavor-code.bin
	cp Build/${OUTDIR_X64[$flavor]}/DEBUG_*/FV/OVMF_VARS.fd $flavor-vars.bin

%ifarch x86_64
	collect_x86_64_debug_files $flavor
%endif
done

# remove -code/-vars files for unfied only flavors
for flavor in ${FLAVORS_X64_UNIFIED_ONLY[@]}; do
	rm $flavor-code.bin
	rm $flavor-vars.bin
done

%ifarch x86_64
# Collect the source
mkdir -p source/ovmf-x86_64
#   TODO get the source list from debug files
src_list=`find Build/OvmfX64/DEBUG_GCC*/X64/ -mindepth 1 -maxdepth 1 -type d -print0 | sort -z | xargs -0 -i basename {}`
find $src_list \( -name "*.c" -o -name "*.h" \) -type f -print0 | sort -z | xargs -0 -i cp --parents -a {} source/ovmf-x86_64
find source/ovmf-x86_64 -name *.c -type f -exec chmod 0644 {} \;
%endif

# The extra TDX flavor for x86_64
BUILD_OPTION_X64_TDX=" \
	-p OvmfPkg/IntelTdx/IntelTdxX64.dsc \
	-a X64 \
	-b DEBUG \
	-t $TOOL_CHAIN \
"

build $BUILD_OPTION_X64_TDX
cp Build/IntelTdx/DEBUG_*/FV/OVMF.fd ovmf-x86_64-tdx.bin
cp Build/IntelTdx/DEBUG_*/FV/OVMF_CODE.fd ovmf-x86_64-tdx-code.bin
cp Build/IntelTdx/DEBUG_*/FV/OVMF_VARS.fd ovmf-x86_64-tdx-vars.bin

# Remove the temporary build files to reduce the disk usage (bsc#1178244)
rm -rf Build/IntelTdx/

# The extra Xen flavor for x86_64
BUILD_OPTION_X64_XEN=" \
	-p OvmfPkg/OvmfXen.dsc \
	-a X64 \
	-b DEBUG \
	-t $TOOL_CHAIN \
"
#  Build the 2MB Xen flavor
build $BUILD_OPTION_X64_XEN -D FD_SIZE_2MB
cp Build/OvmfXen/DEBUG_*/FV/OVMF.fd ovmf-x86_64-xen.bin
#  Build the 4MB Xen flavor
build $BUILD_OPTION_X64_XEN -D FD_SIZE_4MB
cp Build/OvmfXen/DEBUG_*/FV/OVMF.fd ovmf-x86_64-xen-4m.bin

# Remove the temporary build files to reduce the disk usage (bsc#1178244)
rm -rf Build/OvmfX64/ Build/Ovmf3264/ Build/OvmfXen/

# Build with keys done later (shared between archs)

### Build AARCH64 UEFI Images ###
%ifnarch aarch64
# Assign the cross-compiler prefix
export ${TOOL_CHAIN}_AARCH64_PREFIX="aarch64-suse-linux-"
%endif
# Build the UEFI image without keys
build $BUILD_OPTIONS_AA64

cp Build/ArmVirtQemu-AARCH64/DEBUG_GCC*/FV/QEMU_EFI.fd qemu-uefi-aarch64.bin
cp Build/ArmVirtQemu-AARCH64/DEBUG_GCC*/FV/QEMU_EFI.fd aavmf-aarch64-code.bin
truncate -s 64M aavmf-aarch64-code.bin
cp Build/ArmVirtQemu-AARCH64/DEBUG_GCC*/FV/QEMU_VARS.fd aavmf-aarch64-vars.bin
truncate -s 64M aavmf-aarch64-vars.bin

# Remove the temporary build files to reduce the disk usage (bsc#1178244)
rm -rf Build/ArmVirtQemu-AARCH64/

# Build with keys done later (shared between archs)

### Build AARCH32 UEFI Images ###
%ifnarch armv7hl
# Assign the cross-compiler prefix
export ${TOOL_CHAIN}_ARM_PREFIX="arm-suse-linux-gnueabi-"
%endif
# Build the UEFI image
build $BUILD_OPTIONS_AA32

cp Build/ArmVirtQemu-ARM/DEBUG_GCC*/FV/QEMU_EFI.fd qemu-uefi-aarch32.bin
cp Build/ArmVirtQemu-ARM/DEBUG_GCC*/FV/QEMU_EFI.fd aavmf-aarch32-code.bin
truncate -s 64M aavmf-aarch32-code.bin
cp Build/ArmVirtQemu-ARM/DEBUG_GCC*/FV/QEMU_VARS.fd aavmf-aarch32-vars.bin
truncate -s 64M aavmf-aarch32-vars.bin

# Remove the temporary build files to reduce the disk usage (bsc#1178244)
rm -rf Build/ArmVirtQemu-ARM/

### Build RISCV64 UEFI Images ###
%if %{with build_riscv64}
%ifnarch riscv64
# Assign the cross-compiler prefix
export ${TOOL_CHAIN}_RISCV64_PREFIX="riscv64-suse-linux-"
%endif
# Build the UEFI image without keys
build $BUILD_OPTIONS_RV64

cp Build/RiscVVirtQemu/DEBUG_GCC*/FV/RISCV_VIRT_CODE.fd ovmf-riscv64-code.bin
truncate -s 32M ovmf-riscv64-code.bin
cp Build/RiscVVirtQemu/DEBUG_GCC*/FV/RISCV_VIRT_VARS.fd ovmf-riscv64-vars.bin
truncate -s 32M ovmf-riscv64-vars.bin

# Remove the temporary build files to reduce the disk usage (bsc#1178244)
rm -rf Build/RiscVVirtQemu/

%endif

### Build the variable store templates ###

# Default key sources: ms suse opensuse
KEY_SOURCES=(ms suse opensuse)
#   Add 'devel' if necessary
if [ -e %{_sourcedir}/_projectcert.crt ]; then
	prjissuer=$(openssl x509 -in %{_sourcedir}/_projectcert.crt -noout -issuer_hash)
	opensusesubject=$(openssl x509 -in %{SOURCE4} -noout -subject_hash)
	slessubject=$(openssl x509 -in %{SOURCE3} -noout -subject_hash)
	if [ "$prjissuer" != "$opensusesubject" -a "$prjissuer" != "$slessubject" ]; then
		KEY_SOURCES+=(devel)
	fi
fi

# Assign the default PK/KEK
declare -A PKKEK
PKKEK=(
	[ms]=%{SOURCE3}
	[suse]=%{SOURCE3}
	[opensuse]=%{SOURCE4}
	[devel]=%{_sourcedir}/_projectcert.crt
)

generate_sb_var_templates()
{
	local ARCH=$1

	# We only build the variable templates for X64 and AARCH64
	if [ "$ARCH" == "X64" ]; then
		FLAVORS=${FLAVORS_X64[@]}
		# some flavors should NOT enroll default keys
		for skip in ${FLAVORS_X64_SKIP_SB_KEY[@]}; do
   			FLAVORS=("${FLAVORS[@]/$skip}")
		done
	elif [ "$ARCH" == "AARCH64" ]; then
		FLAVORS=${FLAVORS_AA64[@]}
	fi

	# Generate the varstore templates
	for flavor in ${FLAVORS[@]}; do
		for key in ${KEY_SOURCES[@]}; do
			ln "${flavor}-code.bin" "${flavor}-${key}-code.bin"

			if [ "$key" == "ms" ]; then
				virt-fw-vars --secure-boot --enroll-cert "${PKKEK[$key]}" -i "${flavor}-vars.bin" -o "${flavor}-${key}-vars.bin"
			else
				# GUID of EnrollDefaultKeys.efi, already used by virt-fw-vars for PK and KEK
				virt-fw-vars --secure-boot --enroll-cert "${PKKEK[$key]}" -i "${flavor}-vars.bin" -o "${flavor}-${key}-vars.bin" \
					     --no-microsoft --microsoft-kek none --add-db a0baa8a3-041d-48a8-bc87-c36d121b5e3d "${PKKEK[$key]}"
			fi
		done
	done

	if [ "$ARCH" == "X64" ]; then
		# Generate the unified firmware with preloaded keys for
		# backward compatibility. (bsc#1159793)
		for flavor in ${FLAVORS[@]}; do
			for key in ${KEY_SOURCES[@]}; do
				cat "${flavor}-${key}-vars.bin" "${flavor}-code.bin" > "${flavor}-${key}.bin"
			done
		done
	fi
}

# Generate the variable stores with default Secure Boot keys
generate_sb_var_templates X64
generate_sb_var_templates AARCH64

# Rename the x86_64 4MB firmware
#  We use ovmf-x86_64-$key-4m instead of ovmf-x86_64-4m-$key in the
#  version < stable201905. Rename the 4MB firmware files for backward
#  compatibility.
for key in ${KEY_SOURCES[@]}; do
	rename "4m-$key" "$key-4m" *"4m-$key"*.bin
done

%install
cp %{SOURCE2} README

sed -i s/'\r'// License.txt

# Install BaseTools
install -d %{buildroot}/%{_bindir}
install -m 0755 --strip BaseTools/Source/C/bin/EfiRom %{buildroot}/%{_bindir}

# Replace @DATADIR@ in the firmware descriptors
sed -i "s:@DATADIR@:%{_datadir}/qemu:" descriptors/*.json

tr -d '\r' < OvmfPkg/License.txt > License-ovmf.txt

install -m 0644 -D ovmf-*.bin -t %{buildroot}/%{_datadir}/qemu/
install -m 0644 -D qemu-uefi-*.bin -t %{buildroot}/%{_datadir}/qemu/
install -m 0644 -D aavmf-*.bin -t %{buildroot}/%{_datadir}/qemu/
install -m 0644 -D descriptors/*.json \
	-t %{buildroot}/%{_datadir}/qemu/firmware

%fdupes %{buildroot}/%{_datadir}/qemu/

%ifarch x86_64
# Install debug symbols, gdb-uefi.py
install -d %{buildroot}/%{_datadir}/ovmf-x86_64/
install -m 0644 gdb_uefi-*.py %{buildroot}/%{_datadir}/ovmf-x86_64/
mkdir -p %{buildroot}%{_prefix}/lib/debug
mv debug/ovmf-x86_64* %{buildroot}%{_prefix}/lib/debug
%fdupes %{buildroot}%{_prefix}/lib/debug/ovmf-x86_64*
mkdir -p %{buildroot}%{_prefix}/src/debug
mv source/ovmf-x86_64* %{buildroot}%{_prefix}/src/debug
%fdupes -s %{buildroot}%{_prefix}/src/debug/ovmf-x86_64
%endif

%if %{without build_riscv64}
rm %{buildroot}%{_datadir}/qemu/firmware/*-riscv64*.json
%endif

%files
%doc README

%files tools
%doc BaseTools/UserManuals/EfiRom_Utility_Man_Page.rtf
%{_bindir}/EfiRom

%files -n qemu-ovmf-ia32
%license License.txt License-ovmf.txt
%dir %{_datadir}/qemu/
%{_datadir}/qemu/ovmf-ia32*.bin
%dir %{_datadir}/qemu/firmware
%{_datadir}/qemu/firmware/*-ia32*.json

%files -n qemu-ovmf-x86_64
%license License.txt License-ovmf.txt
%dir %{_datadir}/qemu/
%{_datadir}/qemu/ovmf-x86_64*.bin
%dir %{_datadir}/qemu/firmware
%{_datadir}/qemu/firmware/*-x86_64*.json

%ifarch x86_64
%files -n qemu-ovmf-x86_64-debug
%{_datadir}/ovmf-x86_64/
%dir %{_prefix}/lib/debug/
%{_prefix}/lib/debug/ovmf-x86_64*
%dir %{_prefix}/src/debug/
%{_prefix}/src/debug/ovmf-x86_64*
%endif

%files -n qemu-uefi-aarch64
%license License.txt
%dir %{_datadir}/qemu/
%{_datadir}/qemu/qemu-uefi-aarch64*.bin
%{_datadir}/qemu/aavmf-aarch64-*code.bin
%{_datadir}/qemu/aavmf-aarch64-*vars.bin
%dir %{_datadir}/qemu/firmware
%{_datadir}/qemu/firmware/*-aarch64*.json

%files -n qemu-uefi-aarch32
%license License.txt
%dir %{_datadir}/qemu/
%{_datadir}/qemu/qemu-uefi-aarch32.bin
%{_datadir}/qemu/aavmf-aarch32-code.bin
%{_datadir}/qemu/aavmf-aarch32-vars.bin
%dir %{_datadir}/qemu/firmware
%{_datadir}/qemu/firmware/*-aarch32*.json

%if %{with build_riscv64}
%files -n qemu-uefi-riscv64
%license License.txt
%dir %{_datadir}/qemu/
%{_datadir}/qemu/ovmf-riscv64-code.bin
%{_datadir}/qemu/ovmf-riscv64-vars.bin
%dir %{_datadir}/qemu/firmware
%{_datadir}/qemu/firmware/*-riscv64*.json
%endif

%changelog
* Mon Apr 28 2025 YI HSIN Lyu <richard.lyu@suse.com>
- Add TDX flavor OVMF using Config-B (OvmfPkg/IntelTdx/IntelTdxX64.dsc).
  Full TDX functionality has been supported with Config-B.
- Config-A (OvmfPkg/OvmfPkgX64.dsc) will be proposed for switching
  from Config-B once TDX upstream support becomes more complete and integration is
  more mature.
- Below is the difference between Config-A and Config-B.
  - Config-A:
  - Merge the basic TDVF feature to existing OvmfPkgX64.dsc. (Align with existing SEV)
  - Threat model: VMM is NOT out of TCB. (We don't make things worse)
  - The OvmfPkgX64.dsc includes SEV/TDX/normal OVMF basic boot capability. The final binary can run on SEV/TDX/normal OVMF.
  - No changes to existing OvmfPkgX64 image layout.
  - No need to remove features if they exist today.
  - PEI phase is NOT skipped in either TD or Non-TD.
  - RTMR based measurement (CC_MEASUREMENT) is supported as an optional requirement.
  - External inputs from Host VMM are measured, such as TdHob, CFV.
  - Other external inputs are measured, such as FW_CFG data, os loader, initrd, etc.
  - Config-B:
  - Add a standalone IntelTdxX64.dsc to a TDX specific directory (OvmfPkg/IntelTdx) for a full feature TDVF.(Align with existing SEV)
  - Threat model: VMM is out of TCB. (We need necessary change to prevent attack from VMM)
  - IntelTdxX64.dsc includes TDX/normal OVMF basic boot capability. The final binary can run on TDX/normal OVMF.
  - It might eventually merge with AmdSev.dsc, but NOT at this point of time. And we don't know when it will happen. We need sync with AMD in the community after both of us think the solutions are mature to merge.
  - RTMR based measurement (CC_MEASUREMENT) is supported as a mandatory requirement.
  - External inputs from Host VMM are measured, such as TdHob, CFV.
  - Other external inputs are measured, such as FW_CFG data, os loader, initrd, etc.
  - PEI phase is skipped to remove unnecessary attack surface.
  - DXE FV is split into 2 FVs (DXEFV & NCCFV) to remove the unnecessary attack surface in a TD guest..
  - When launching a TD guest, only drivers in DXEFV are loaded.
  - When launching a Non-TD guest, dirvers in both DXEFV and NCCFV are loaded.
* Thu Apr  3 2025 Joey Lee <jlee@suse.com>
- Using old ovmf-Revert-Add-Stack-Cookie-Support-to-MSVC-and-GCC.patch
  to replace ovmf-Remove-unsupported-GCC-flag-mstack-protector-guard.patch
  because the new patch causes that smm ovmf can not boot success.
  (bsc#1240300)
  - guest OS: openSUSE Tumbleweed, Windows 11
- Added ovmf-UefiCpuPkg-Disable-EFI-memory-attributes-protocol.patch
  to disable EFI memory attributes protocol at this moment. It causes
  old shim 15.8 boot fail on SLE12-SP5. (bsc#1240771)
* Wed Mar  5 2025 Richard Lyu <richard.lyu@suse.com>
- Update to edk2-stable202502
  - New Features & Bug Fixes (https://github.com/tianocore/edk2/releases):
  - DynamicTablesPkg: Adds X64 support to SRAT table generator
  - DynamicTablesPkg: Generates X64 MADT and CPU SSDT Topology Table
  - Add RNG PPI
  - Update to openssl-3.4.x
  - Update CI to VS2022
  - Produce EFI memory attribute protocol
  - UefiCpuPkg: Add TdxMeasurementLib
  - DxeRngLib: GetRandomNumber spurious success
  - SecurityPkg: Update libspdm
  - OvmfPkg: Use the OvmfPkg version of CcProbeLib
  - ShellPkg: Fix bug #3080, OOB, minor UefiShellLib fixes
  - MdePkg: Fix overflow issue in PeCoffLoaderRelocateImageForRuntime
  - Add Dynamic Stack Cookie Support to IA32/X64/AARCH64
  - Patches (git log --oneline --date-order edk2-stable202411..edk2-stable202502):
    fbe0805b20 MdeModulePkg/HiiDatabaseDxe: Remove buffer error for string default.
    0192f2d7cb MdeModulePkg/UsbBusPei: Improve PEI USB enumeration
    bc664d1830 Revert "FatPkg: Validate Reserved FAT Entries on Volume Open"
    523dbb6d59 ArmPkg: ArmFfaStandaloneMmLib: Fix non-FFA path
    96cf70951f MdePkg/DynamicStackCookieEntryPointLib: Drop execute-in-place versions
    5c3dcef94c MdePkg/DynamicStackCookieEntryPointLib: Remove unused files
    23007f7ae2 UefiPayloadPkg: Add StackCheckLib to fix FIT build issue
    7308568dd6 StandaloneMmPkg StandaloneMmCoreMemoryAllocationLib: Rename gMmst
    0d61f52fe3 Add MockVariablePolicyHelperLib
    2b3ea9334f DynamicTablesPkg: Adds X64 support to SRAT table generator
    1f1182c396 ArmVirtPkg: ArmVirtQemu: Add Custom Stack Cookies
    861b91d975 ArmVirtPkg: Add RNDR Support to QEMU
    30547859f2 OvmfPkg: OvmfIA32X64: Add Custom Stack Cookie Checking
    6d741357c2 OvmfPkg: Add RDRAND Support To QEMU
    e6b6aa90d4 MdePkg: Add Dynamic Stack Cookie Support
    efbf5ed08c MdePkg: Move StackCheckLibStaticInit to StackCheckLib
    db03bf1d9d StandaloneMmPkg: Consume X64 StandaloneMmCoreEntryPoint From MdePkg
    885bcca649 MdePkg: Add StandaloneMmCoreEntryPoint for X64
    e63cdeebb8 MdePkg: Add StackCheckLib Library Class
    d9715c133f MdePkg: Centralize RNDR Register Definition
    5c02a64823 Maintainers.txt: adding Ard and Michael to stewards team
    1cb349e4bb IntelFsp2WrapperPkg: Remove inactive maintainer email
    edf1450f3e SecurityPkg: Add RngPei
    bcab6996a0 MdePkg: Add PeiRngLib
    de5c1198c1 MdePkg: Add Random Number Generator (RNG) PPI
    7518b93f77 MdePkg: Split RNG protocol definitions
    15e225d06a Maintainers.txt: add myself as PrmPkg maintainer
    258f2d1563 ReadMe.rst: reflect bugzilla migration
    f7cf6ce299 License-History.txt: Reflect bugzilla migration
    fe5c2df49e SignedCapsulePkg: make Doxygen interpret ASCII art as verbatim text
    259e1f04c6 BaseTools: Add @verbatim as allowed Doxygen tag
    0664c4e3b9 UefiPayloadPkg: Revert 4KB alignment of CLANGDWARF build
    cd87106d26 BaseTools: Add /DRIVER to CLANGPDB link flags
    074f61e4c6 MdePkg/IndustryStandard: add definitions for CXL CEDT
    62b0698309 BaseTools/AutoGen: GenMake response file quotes strings
    15a7d311a8 BaseTools/tools_def: Remove no-warn-rwx-segments linker options
    f2b42c83dd BaseTools/Scripts/GccBase.lds: Use separate R-W and RW- ELF segments
    e5d95c786b BaseTools/Scripts: Merge GCC and Clang ELF linker scripts
    f5d585b46b BaseTools/Scripts/ClangBase.lds: Move .entry into .text section
    7fd3c89ff4 UefiPayloadPkg: Update Elf segment/section syncup process
    d844a7eab5 BaseTools/tools_def: Use no-warn-rwx-segments only for GCC5
    09d4e6f7c7 MdePkg: Add Hot pluggable resource attribute
    4ec3539e34 MdePkg: Add UEFI 2.11 specification macro
    2e6359a088 MdePkg: Add Confidential Computing Extension for RISC-V AP-TEE
    12ceee664a MdePkg: Add HotPlug Memory Attribute
    62cd7d338b ArmPkg: Retire ArmDisassemblerLib
    fbe19844e0 Revert "ArmVirtPkg/ArmVirtQemu: Reduce MMIO region mapped by default"
    4dd8b9e0f7 ArmVirtPkg: turn off debug logging for VirtioSerialDxe
    c1ab2d6397 Maintainers: update my email address
    e063f8b8a5 BaseTools/Pccts: set C standard
    c0796335d3 MdePkg/BaseFdtLib: fix build with gcc 15
    7742247d1c MdePkg: Add SM3 crypto algorithm GUID definition
    d949ed05d4 Devcontainer: Use latest Fedora 40 image
    31abbed237 .github/codeql.yml: Drop ArmPkg IA32 and X64 from build matrix
    87f14322da ArmVirtPkg: Drop reference to ArmDisassemblerLib
    ef80dd8fad ArmPkg: Stop using ArmDisassemblerLib
    74376f0b72 ArmPkg,ArmPkg/ArmExceptionLib: drop vector relocation variant/support
    43233ff9f8 ArmVirtPkg/ArmVirtQemu: Reduce MMIO region mapped by default
    c558a3b18b ArmPkg/ArmGicDxe: Map GIC MMIO regions before use
    3c4c7a0fc9 ArmPkg/ArmGicDxe: Remove pointless passing around of MMIO addresses
    e68e784649 ArmPkg/ArmGicDxe: Avoid pointless repeated iteration over GIC frames
    387fcf4fa1 ArmPkg/ArmGicDxe: Replace CpuArch registration event with DEPEX
    fb7497cbf9 ArmPkg/CpuDxe: Replace DEPEX on h/w protocol with event notification
    0422dd0669 ArmPkg/CpuDxe: Remove rudimentary vector handoff logic
    e5b56d6ef9 ArmPkg/CpuDxe: Use STATIC linkage where possible
    afdae789cd ArmPkg/CpuDxe: Fix error handling in driver initialization
    b64f735867 Maintainers.txt: Update EmulatorPkg maintainers
    2cb8bf6c69 UnitTestFrameworkPkg: Fix false positives from address sanitizer
    3600675368 MdePkg/BasePeCoffLib: Remove DEBUG() statements from runtime code
    254937f0bc ShellPkg: fix warnings about uninitialized variable
    755d4b9397 OvmfPkg: fix warning about uninitialized variable
    ceb87029c5 SecurityPkg/RngDxe: fix warning about uninitialized variable
    c58501aa1a MdeModulePkg: NvmExpressDxe: fix warning about uninitialized variable
    0f12a5f722 MdeModulePkg: fix warning about uninitialized variable
    a5cb67fb8d MdeModulePkg: PeiMain: fix warning about uninitialized variable
    bba72ffbe1 OvmfPkg/QemuKernelLoaderFsDxe: use SIZE_OF_EFI_FILE_INFO
    df84bb5eda Resolved Coverity Issues in Http Dxe
    428cd8a46f MdePkg: Fix Clang Build Error
    18984b68fe OvmfPkg: make legacy direct kernel loader code nx clean
    6d2143f685 BaseTools: Fix NoneType parent reference in FMMT operations
    8c1e786e50 OvmfPkg/XenPvBlkDxe: Update disk size calculation
    3cf7a644eb OvmfPkg/IndustryStandard/Xen: Update io/blkif.h
    7c5ec51175 MdeModulePkg PeiMain: Remove return for PeiCoreBuildHobHandoffInfoTable()
    d35899b6d2 UnitTestFrameworkPkg: Add SafeIntLib to Common Includes
    6278bbb898 MdePkg: Use SafeIntLib to handle overflow
    aedcaa3df8 MdePkg: Fix overflow issue in PeCoffLoaderRelocateImageForRuntime
    b3bfb8f22d UefiPayloadPkg: Add 4KB align to CLANGDWARF build.
    e356b0f6fd EmulatorPkg PlatformBm: Fix duplicate BootManagerMenuApp boot option issue
    0df3729ad6 ShellPkg Http.c: Remove extra `\n` when using `-m` param
    1f19c3d6ee OvmfPkg/GenericQemuLoadImageLib: fix cmdline + initrd handling
    b873e8b8e3 OvmfPkg/QemuKernelLoaderFsDxe: root directory name should be ""
    9f28d48d2f Maintainers.txt: Add Star as UefiCpuPkg reviewer
    38c17825ad UefiCpuPkg LocalApicLib: Correct typo LINT0 to LINT1
    99cbb63652 OvmfPkg/OvmfXen: use PeiPcdLib for PEI_CORE
    33309733e4 command drvcfg ASSERT REF: https://github.com/tianocore/edk2/issues/10626
    eda58c143c DynamicTablesPkg: Adds X64 FACS generator library
    feb8d49834 OvmfPkg/RiscVVirtQemu.dsc: enable VGA support
    a36fb60053 Maintainers.txt: Remove myself from some reviewer role
    81802056c8 EmulatorPkg: Move magic page to first allocation
    54c1460dd0 RedfishPkg/RedfishHttpDxe: report failure via status code
    3ba6f7d966 Maintainers.txt: add myself as UefiPayloadPkg maintainer
    14cb48b0a0 BaseTools: Break Build on Linker Warnings
    4613eb6abc EmulatorPkg: Fix IA32 MSVC Linker Warnings
    81ba76f7df PrmPkg: Clarify Architecture Support
    336e7e06eb UefiCpuPkg/CpuMpPei: Add LoongArch64 support
    7bc51fc68e UefiCpuPkg/CpuMpPei: Split CpuMpPei.c to two files
    f6afd87663 UefiCpuPkg/PiSmmCpuDxeSmm: SmmWaitForApArrival first sync check
    cbfae3e8a9 EmulatorPkg: Fix Source Level Debug on Windows
    58766a4729 FatPkg: Validate Reserved FAT Entries on Volume Open
    35232f165c OvmfPkg: document opt/org.tianocore/EnableLegacyLoader option
    1549bf11cc OvmfPkg/X86QemuLoadImageLib: make legacy loader configurable.
    4b507b4966 OvmfPkg/GenericQemuLoadImageLib: support booting via shim
    3da39f2cb6 OvmfPkg/X86QemuLoadImageLib: support booting via shim
    c45051450e OvmfPkg/QemuKernelLoaderFsDxe: don't quit when named blobs are present
    46ae4e4b95 OvmfPkg/QemuKernelLoaderFsDxe: accept absolute paths
    1111e9fe70 OvmfPkg/QemuKernelLoaderFsDxe: drop bogus assert
    adf385ecab OvmfPkg/QemuKernelLoaderFsDxe: allow longer file names
    20df7c42bd OvmfPkg/QemuKernelLoaderFsDxe: add support for named blobs
    459f5ffa24 OvmfPkg/QemuKernelLoaderFsDxe: rework direct kernel boot filesystem
    139cbb266b BaseTools/Plugin/HostBasedUnitTestRunner: Set ASAN env vars
    e78fb8a366 UnitTestFrameworkPkg/MemoryAllocationLibPosix: Add allocate below address
    5f97d5391e UnitTestFrameworkPkg/UnitTestLib: Reduce sanitizer false positive
    1c73f0e71d UnitTestFrameworkPkg: Add failing unit tests cases for sanitizer
    de06288019 UnitTestFrameworkPkg: Use /MTd and enable Address Sanitizers
    8d0e23d998 BaseTools/Conf: Simplify VS20xx HOST_APPLICATION builds
    ca4e19ccc2 UnitTestFraworkPkg: Enable DEBUG_CLEAR_MEMORY in host tests
    30b10dcdd0 UnitTestFrameworkPkg/UnitTestLib: Implement Free*() services
    182dbe79a0 UnitTestFrameworkPkg/MemoryAllocationLibPosix: Add DEBUG_CLEAR_MEMORY()
    f9a0e54953 OvmfPkg/OvmfDisplayPcds.dsc.inc: set SetupConOut too
    df35307196 OvmfPkg/OvmfDisplayPcds.dsc.inc: set SetupVideoResolution too
    fde034447f OvmfPkg/PlatformDxe: set SetupVideoResolution too
    b4536e36c4 OvmfPkg/VirtioGpuDxe: set SetupVideoResolution too
    1d2558af76 OvmfPkg/QemuVideoDxe: set SetupVideoResolution too
    2f5db44fdd ArmVirtPkg/ArmVirtQemu.dsc: use OvmfDisplayPcds.dsc.inc
    2b72a70cd1 OvmfPkg/RiscVVirtQemu.dsc: use OvmfDisplayPcds.dsc.inc
    787450af9c OvmfPkg/OvmfXen.dsc: use OvmfDisplayPcds.dsc.inc
    c3427ae439 OvmfPkg: move display pcds to OvmfDisplayPcds.dsc.inc include file
    2091e449f1 StandaloneMmPkg: Introduce a PCD to disable shadow boot FV
    2d2642f483 ArmPkg/ArmGicDxe: Use EOImode 0x0 on GICv3
    81e2cd329e ArmPkg/ArmGic: Rename directory to ArmGicDxe
    9d1a9b426e ArmPkg/ArmGic: Implement GICv3+ version of GIC driver
    86119ff79e ArmPkg/ArmGic: Implement GICv2-only version of GIC driver
    0bb40c79be ArmPkg: Retire ArmGicLib implementations
    c9e38d1afb ArmPkg/ArmGic: Incorporate v3 code from ArmGicLib
    eaa60a6b10 ArmPkg/ArmGic: Retire ArmGicArchLib
    34ab9197a5 DynamicTablesPkg/SsdtSerialPortFixupLib: Switch to ArmGicLib.h
    9bf20991b4 ArmPkg/ArmGic: Move some GIC defines into ArmGicLib.h
    e663b79f74 ArmVirtPkg: Convert ArmVirtGicArchLib to NULL class library
    8edd5fd6d3 ArmPkg/ArmGic: Move GICv3 sysreg check into ArmGicDxe
    84eed1ef2a ArmPkg/ArmGic: Move GICv2 specific EOI/ACK routines into v2 driver
    337a99af10 ArmPkg/ArmGic: Move remaining shared code into ArmGicDxe
    298d8c436a ArmPkg/ArmGic: Drop declarations for non-existent functions
    2ab362f313 ArmPkg/ArmGic: Disentangle ArmGicEnableDistributor () versions
    4e874fcf09 ArmPkg/ArmGic: Disentangle v2 and v3 versions of IRQ en/disable APIs
    a4928a0cfc ArmPkg/ArmGic: Remove ArmGicEndOfInterrupt () API
    aad4dd9aac ArmPkg/ArmGic: Remove ArmGicSendSgiTo () API
    ec5bb8f953 ArmPkg/ArmGic: drop ArmGicEnableInterruptInterface from ArmGicLib
    555bbc6643 ArmPkg/ArmGic: Drop GICv2 legacy support
    ea2f6c68ee MdePkg/Base: Don't error out on missing compiler CPP macros
    f0c87b9ef4 StandaloneMmPkg: move core entry point lib and cpu driver to ArmPkg
    b370eab898 StandaloneMmPkg: introduce StandaloneMmExtractGuidedSectionLib
    6dd5375820 StandaloneMmPkg: remove per-cpu feature on StandaloneMm
    6c62f40df3 StandaloneMmPkg: Move sanity check for comm buffer to entrypoint
    7340a4b63a StandaloneMmPkg: Apply embedded stack in StandaloneMmEntryPoint
    6975494655 ArmPkg: Add StandaloneMm stack size Pcd
    6016c522c6 StandaloneMmCore: Change log level when mCommunicationBuffer is NULL
    1bebc97b81 ArmPkg/MmCommunication: add helper function converting smc return
    8f3c157e04 AmrPkg/MmCommunication: move Mmcommunicate.h to common include
    73b2831879 ArmPkg/MmCommunicationPei: Mmcommunication via FF-A
    9f9a3de9e4 ArmPkg/MmCommunicationDxe: Mmcommunication via FF-A
    1c963008e8 StandaloneMm/Library: Apply FF-A v1.2 in StandaloneMm
    4ca452cf91 ArmPkg/Library: Update StandaloneMmuLib with FF-A v1.2 with page granulirty
    401699c326 ArmPkg: Add ArmFfaLib used in StandaloneMm
    166c3b2eb7 ArmPkg: Add ArmFfaLib used in PEIM
    5d1b38dd07 ArmPkg: Add ArmFfaLib used in Dxe driver
    18948c4a6a ArmPkg: Add ArmFfaLib.h
    30ecebe015 ArmPkg: Remove PcdFfaEnabled
    843f4fd60d ArmPkg: Add FF-A related dynamic Pcd and Guid
    79875fdde0 ArmPkg: Add FF-A partition information header
    d1d690f363 ArmPkg/IndustryStandard: Introduce ArmFfaBootInfo.h
    173af697dd ArmPkg/IndustryStandard: Update ArmFfaSvc.h
    a5212d3db7 StandaloneMm/Library: Apply transfer list boot protocol in StandaloneMm
    54e394b4a2 ArmPkg/StandaloneMmMmuLib: Introduce a SPM_MM status helper fucntion
    c56856f068 ArmPkg/IndustryStandard: Change naming convention in ArmMmSvc.h
    31fcaf1fc0 StandaloneMm/Library: Remove Hob creation on Arm CoreHob Library
    fbeab84945 ArmPkg/Library: Introduce ArmTransferListLib
    6087382c62 StandaloneMmPkg: Introduce PI_MM_CPU_DRIVER_EP protocol.
    62127dfbc7 StandaloneMmPkg: Simplify returning event complete values
    1301e0b47e MdePkg: Add manageability status code defined in PI 1.9 Spec.
    89d413731d NetworkPkg/SnpDxe: Shutdown SnpDxe on BeforeExitBootServices Event.
    c1548908c9 NetworkPkg: UefiPxeBcDxe: Fix error packet detection
    cb672a8eb1 ArmVirtPkg: Use OvmfPkg/Include/*/Shell*.inc
    076ef39ba2 OvmfPkg: Use OvmfPkg/Include/*/Shell*.inc throughout
    7d958e55a4 ArmVirtPkg/CI: Copy shell to virtual drive
    e8de471660 ArmVirtPkg: Include no network components with -D NETWORK_ENABLE=0
    9a21320361 OvmfPkg: Include no network components with -D NETWORK_ENABLE=0
    b24ad97e53 Add VS Code GitHub issues notebook
    f07b03ea90 IntelFsp2Pkg/IntelFsp2Pkg.dec: add a GUID defined in FSP EAS
    8b2256fbf2 MdePkg/Include: Use _Static_assert for clang and GNUC
    aae044a130 EmbeddedPkg: CodeQL Fixes.
    d6f828b384 OvmfPkg/MicroVM: use PeiPcdLib for PEI_CORE
    ac9a6eed02 BaseTools: build_rule.template generate a different dll for wholearchive.
    f35d3a5bd3 MdeModulePkg: Make noisy log DEBUG_VERBOSE
    f2a8bb9dfb CloudHv: Disable PcdFirstTimeWakeUpAPsBySipi
    cbe8a09dba MdeModulePkg/HiiDatabaseDxe: Add string question load default support.
    7c1562f03c CryptoPkg: Add HMAC algorithms for signature/keymgmt
    8b87eb9dfb OvmfPkg: Use the OvmfPkg version of CcProbeLib
    d51baa02a6 OvmfPkg: Update with TdxMeasurementLib
    6f73428d06 OvmfPkg: Implement TdxMeasurementLib
    d97f530413 UefiCpuPkg: Add NULL TdxMeasurementLib instance
    94bfc6f0cb UefiCpuPkg: Add TdxMeasurementLib.h
    8c180acf1d StandaloneMmPkg/MmIpl: Correct FV HOB check founction
    3c8f47bf21 EmulatorPkg/Win/Host: Use safe function _vsnprintf_s()
    4218026bd6 CryptoPkg/BaseCryptLib: Fix mktime() coding style issue
    96390bb8a5 UefiCpuPkg: Update return status to follow spec
    efaa102d00 UefiCpuPkg: Produce EFI memory attributes protocol
    aaf0846fa2 ArmPkg: remove ArmGicAcknowledgeInterrupt function.
    11cffd9c3f CryptoPkg/BaseCryptLibMbedTls : Add strncpy() support to SecCryptLib
    c0533b7e22 OvmfPkg/SmmCpuPlatformHookLibQemu: Define IsCpuSyncAlwaysNeeded
    a8363bce36 Add SmmCpuPlatformHookLib IsCpuSyncAlwaysNeeded interface
    21cbba1bb3 StandaloneMmPkg: Call PeCoffLoaderUnloadImage When Unloading Image
    9bb11cad9d EmbeddedPkg: Remove misleading error message in FindNextMemoryNodeReg
    107981f3f0 StandaloneMmPkg: Assert if dispatcher fails memory allocation
    3ac092cf72 BaseTools: Clean up os.path.normcase and os.path.normpath usage
    8593eca048 ShellPkg: AcpiView: TPM2 parser for Arm FF-A
    14f5e9b098 ShellPkg: AcpiView: TPM2 Parser
    7216013b36 MdePkg: Tpm2Acpi.h: Add defines for TPM2 ACPI table revision 5
    1a23fe7472 MdeModulePkg: Update AtaPassThru to UEFI 2.10A
    114b54e3fb MdePkg: Update AtaPassThru header to UEFI 2.10A
    bb129c6a82 SignedCapsulePkg: Clarify return status of Fmp Protocol GetImage()
    768adcd9c1 FmpDevicePkg: Clarify return status of FMP Protocol GetImage()
    e4d74bb592 MdePkg: Add UEFI Specification macros
    a872cc18e0 MdePkg: Clarify return status of FMP Protocol GetImage()
    9144bb940a MdePkg: Update Default IP TTL
    42a141800c BaseTools: Skip directories with code extensions in the name
    7e03c40659 MdePkg: Update BASE_CR macro in Base.h for a Coverity error
    f6e19abd97 OvmfPkg/VirtioSerialDxe: respond CONSOLE_PORT with PORT_OPEN
    dca265a8ca RedfishPkg/RedfishPlatformConfigDxe: check attribute max. and min. value
    a7cc0014d2 FatPkg: CI: Add PrEval entry
    62de957185 CryptoPkg: Add sleep() function to BaseCryptLibMbedTls
    070eadb550 NetworkPkg/UefiPxeBcDxe: Bugfix for pxe driver
    a2263cb201 UefiPayloadpkg Add Missing part back
    105a62d3ac UefiPayloadPkg ：Update RetrieveMultiSegmentInfoFromHob
    fc140c5eae OvmfPkg: Enable virtio keyboard driver for Ia32x64 OVMF platform
    ce4317b4c8 OvmfPkg: Enable virtio keyboard driver for X64 OVMF platform
    573057cb1d ArmVirtPkg: Enable virtio keyboard driver for ARM OVMF platform
    8bc9f5a2bc OvmfPkg: Virtio based keyboard driver implementation
    0eea7b9c02 OvmfPkg: Add virtio keyboard device hooks
    0986082d7e Redfish/HiiUtilityLib Fix incorrect type assignment
    9e6537469d MdePkg: UefiDevicePathLib: Add Display Only format for Hard Drive.
    f39b121066 UefiPayloadPkg: Align base address for ACPI region
    da6504e5cc IntelFsp2WrapperPkg: Save FspHobListPtr right after FspMemoryInit exits
    1cc78814cd Remove dependancy on re.T
    e8c7b14da0 UefiPayloadPkg: Set PixelsPerScanLine property in GraphicInfo HOB
    c52dddf1eb ArmPkg: Update Generic Watchdog PCD Type
    4971459ab2 OvmfPkg: add new shell runtime config option to documentation.
    597342b212 OvmfPkg/PlatformBootManagerLib: Optimize PlatformRegisterFvBootOption
    abbd05992d OvmfPkg/PlatformBootManagerLib: Introduce FileIsInFv function.
    103aed83a7 OvmfPkg/PlatformBootManagerLib: Introduce support for fw_cfg for UEFI Shell
    07bb226542 OvmfPkg: Add a runtime switch for PlatformRegisterFvBootOption
    b8f3199595 OvmfPkg/LoongArch: Enabling some base libraries
    2ece0790f7 UefiCpuPkg: Add dump interrupt type on LoongArch64
    0fdffb71df UefiCpuPkg: Adjust the exception handler logic on LoongArch64
    fbbf4206c1 MdeModulePkg/XhciDxe: Non-zero start/stop values in XhcGetElapsedTicks
    896930edc9 .github: Add issue automation workflows
    3c8016b302 BaseTools: Support custom library build for base tools on Linux ARM
    74bf7f55c1 BaseTools: Adding cross compilation of BaseTool for Windows ARM/ARM64
    4b2f964749 BaseTools: Adding support of building BaseTool on Windows ARM/ARM64
    79a64e73f7 StandaloneMmPkg/Core: Support to dispatch multiple standalone MM FVs
    40df344b54 .github: Add GitHub issue templates
    124ed0f6d8 IntelFsp2Pkg : Add FSP-I arch config PPI
    1d1e0474d7 IntelFsp2WrapperPkg/FspiWrapperPeim : Support FSP-I measurement
    df1726a65e IntelFsp2WrapperPkg/FspiWrapperPeim : Support API mode
    4ffa8810af IntelFsp2Pkg : Add fsp status code for fspsmm init
    e374edc180 IntelFsp2WrapperPkg/FspiWrapperPeim : Support dispatch mode
    6fd8533b62 IntelFsp2WrapperPkg/FspiWrapperPeim : FSP-I wrapper PEIM entrypoint
    816a02cb3b StandaloneMmPkg/MmIpl : Add MM core fv location PPI support
    47cb080ca4 StandaloneMmPkg : Add MM core fv location PPI
    8279e49aae StandaloneMmPkg/MmIpl : Check if  MM FV HOB was built
    e8ce6c5189 UefiPkg/PiSmmCpuDxeSmm: Set SmmProfile Variable only for DXE SMM
    4af5849556 UefiPayloadPkg: Fix the issue detected by Uncrustify
    c5811ef1b3 UefiPayloadPkg: Enhance universal payload build
    72b65146bf UefiPayloadPkg: Enhance Universal payload serial port node
    7e7492fa12 .pytool/EccCheck: Open files in utf-8
    260d36484d .pytool/LicenseCheck: Open files in utf-8
    b8602d8fee NetworkPkg/WifiConnectionManagerDxe: Keep Setup page on no Wi-Fi module
    d1fccbf494 EmulatorPkg: spurious failure in WriteBlocks on X64
    30c8a73850 SecurityPkg/SecureBootConfigDxe: Enhance help in Delete Signature page
    2c07ab6256 Maintainers.txt: Add myself as ShellPkg reviewer
    9ef348350a OvmfPkg: document runtime config options
    924780f2cc UefiCpuPkg: x86 CpuDxe: Allocate AP Exception Stack Below 4GB
    cef65b2e93 MdePkg BootManagerPolicy.h: Define GUID for connecting storage devices.
    b38180effe ShellPkg/AcpiView: RAS2 Parser - check validity of PCC Count
    35216819b5 SourceLevelDebugPkg DxeDebugAgent: Handle additional initialize cases.
    17e67d26d9 MdeModulePkg DxeMain: Add late initialization for Debug Agent.
    e99d532fd7 ShellPkg/UefiShellLib: Accept "0 " as valid numeric string
    d63d5884d7 ShellPkg/UefiShellLib: Only write value if successful conversion
    f34a945a80 ShellPkg/UefiShellLib: Simplify check for empty string
    e11a912aa3 ShellPkg/UefiShellLib: Correct check for empty string
    ef3a1ef397 ShellPkg/UefiShellLib: Prevent out-of-bounds access
    7936ffa1e6 MdePkg/Ufs.h: Update to UFS 4.0
    59cfc13139 MdeModulePkg/Bus/Ufs: Use IndustryStandard headers
    29ebe5ee5a MdePkg/IndustryStandard: Add UFS definitions
    89b527df17 CryptoPkg: revert BUFSIZ macro definition from commit 456dd8b99f00
    1a440d9638 Retrieve the USB class specific data from the configuration descriptor
    c7354e9c84 OvmfPkg: Add minimum Python version for CI badge
    4274bcf146 EmulatorPkg: Add minimum Python version for CI badge
    ff003faabe ReadMe.rst: Add minimum Python version badge
    c1eb477e06 OvmfPkg/TdxDxe: Clear GPR Mask for RBX
    3022bab164 OvmfPkg: Remove macro MAX_LOONGARCH_EXCEPTION
    9537f8ce67 UefiCpuPkg: Remove macro MAX_LOONGARCH_EXCEPTION
    3c8e10c8b3 MdePkg: Synchronize UEFI2.11 LoongArch64 DebugSupportLib definition
    03783393e1 MdePkg: Allows loading X64 and ARM64 OPROM images on LoongArch64
    25ce25ecce ArmPkg: DefaultExceptionHandlerLib: Update function input bitwidth
    e8b7d7a238 ArmPkg: ArmExceptionLib: Fixing exception vector and type casting
    b689c387e2 ArmPkg: ArmLib: Update function to match header file
    6539b693d1 MdePkg: ArmLib: Return UINT32 for ArmCacheWritebackGranule
    9d0f3dd35d ArmPkg: ArmArchTimerLib: Update operations to be 64 bit wide
    77d32b1796 ArmPkg: TimerDxe: Use 64bit operation for timer ticks
    957fcbe7a3 ArmPkg: ArmGic: Cast CpuTarget to UINT32 for legacy GIC
    95972f966e DynamicTablesPkg: Correct parser for X64 architecture objects
    cf8241facc MdePkg: Add Google Mock Library for SafeIntLib
    232003ce5a MdePkg: Update StatusCodeDataTypeId.h
    e02c7848af MdeModulePkg SmbiosMeasurementDxe: Release TableAddress after use
    58c7517228 MdeModulePkg DriverHealthManagerDxe: Display HealthStatus as TextTwo
    f8f29a4a6a BaseTools: fix spelling error
    74ac8cc0e8 BaseTools: Typo fixes
    aca75d3c08 BaseTools: Update alignment for entry seg for Clang
    1bb10a479f MdeModulePkg/BrotliCustomDecompressLib: Make the library buildable
    1c5c951ec3 Update CI to VS2022
    bcbb709959 BaseTools: Add VS2022 XIPFLAGS
    f1e014a5ca BaseTools: Add /WHOLEARCHIVE for VS2022 Builds
    4c7c90254f Maintainers.txt: Add VS Code PR Dashboard maintainer
    2941f4b57f PullRequests.github-issues: Add PR notebook
    d55d4e22f4 OvmfPkg: Update PlatformPei.inf with TdxHelperLib
    1f55e175f4 OvmfPkg: Update OvmfPkgX64.dsc to support TdTcg2Pei
    9f9657e7da OvmfPkg: Update OvmfTpmLibs.dsc.inc to add PeiTpmMeasurementLib.inf
    7689c0d9fa OvmfPkg/TdTcg2Pei: Add TdTcg2Pei to install gEdkiiCcPpi
    bdf3c917e3 OvmfPkg/TdTcg2Dxe: Update with TdxHelperLib
    b6b1fdb073 OvmfPkg/TdxHelperLib: Refactor for new APIs
    cc0ec8ebae OvmfPkgX64: Add BaseCryptLib definition in PEIM
    b2df9a89ba SecurityPkg/PeiTpmMeasurementLib: Support CC Measurement
    3b07a2fb52 SecurityPkg/Ppi: Add gEdkiiCcPpi for CC Measurement in PEI phase
    481c43308b MdePkg: Add new PCDs for IPMI Serial
    5b760ca087 MdePkg/IndustryStandard: Add definitions for IPMI Serial
    e53cf2412a ShellPkg/UefiShellLevel2CommandsLib: Add helper for reset -fwui option
    694cc9f100 UefiPayloadPkg: Update ReadUnaligned64 in ACPI parsing
    ddb4ea681b UefiPayloadPkg: Update FDT parser logic for unaligned data access
    2d6d03056a UefiPayloadPkg: Add AARCH64 support on FdtParserLib
    f0424ec80e OvmfPkg: disable iscsi by default
    645988d9b3 OvmfPkg: add PcdEntryPointOverrideDefaultValue
    9ca29831f6 OvmfPkg: add fw_cfg option for usb storage
    f9335bcb7c OvmfPkg: add fw_cfg option for iscsi support
    b9cb18206a OvmfPkg: add fw_cfg option for virtio-net support
    5be587067a OvmfPkg: move USB drivers to new UsbComponents.dsc.inc
    b3b3cfab7e OvmfPkg: move VirtioNet to NetworkComponents.dsc.inc
    35706d43c5 NetworkPkg: PXE boot option build flag
    087a47688c OvmfPkg: PXE boot option build flag
    9e0c46efb0 ArmVirtPkg: PXE boot option build flag
    f6422011e5 MdeModulePkg/PlatformDriOverrideDxe: fix HiiOpCodeHandle leak
    1b283cf437 MdeModulePkg/UiApp: fix HiiOpCodeHandle leak
    e8cfc7beba NetworkPkg/IScsiDxe: fix HiiOpCodeHandle leak
    b1cdfc556f SecurityPkg/OpalPassword: fix HiiOpCodeHandle leak on error path
    fd9501f582 DxeRngLib: GetRandomNumber spurious success
    bbcdc0b7d9 MdePkg: Improve comments on DebugLib PCDs
    5b2d55533b BaseTools: Improve error messages from UefiCapsuleHeader.py
    e508c6c08a MdeModulePkg/DxeIplPeim: Free scratch buffer after FV extraction
    73570d8ab6 openssl: disable visual studio warning #4189
    99e18f2327 CryptoPkg: CI: update OpensslGen file list
    8c5dcecd24 CryptoPkg: gcc needs 4k section alignment too
    9895fe25ac CryptoPkg/BaseCryptLib: add next parameter to SHA3_squeeze
    a801363249 CryptoPkg: add openssl/providers/fips/include to includes
    005f4c6b5e openssl: add more stubs for openssl 3.2.x
    53cea8efd1 openssl: adapt stubs to openssl 3.2.x
    8f6c2ccc45 openssl: update generated files
    e584e865f8 openssl: update submodule to 3.4.0
    333e9638ad MdeModulePkg/Bus/Pci: Fix Descriptor Misalignment in USB Config Handling
    e8668d2dee MdeModulePkg/DxeCore: Call BeforeExitBootServices event group only once
    47e28a6d44 ArmVirtPkg/ArmPlatformLibQemu: Enable early ID map on EL2+VHE
    793f4d2662 Maintainers.txt: Add a new R for LoongArch64
    47ef197873 BaseTools: Coverage: Detect lcov version
    2940708eb2 NetworkPkg/DxeNetLib: drop GLOBAL_REMOVE_IF_UNREFERENCED
    d31fd8bcb7 MdePkg/DxeRngLib: drop GLOBAL_REMOVE_IF_UNREFERENCED
    061bccff3a DynamicTablesPkg: Update link to iASL in Readme.md
    210a76e917 Remove Ray from maintainer list of FatPkg
    775d6cd7ed OvmfPkg/QemuFwCfgDxeLib: use PcdConfidentialComputingGuestAttr
    194cdc1700 SecurityPkg: remove unused `EfiSig` variable in SecureBootFetchData
    dfab971e91 SecurityPkg: Improve formatting of msg when GetVariable fails
    61c714285f BaseTools: Coverage: make lcov v2.0 work
    29859cbc28 CI: Use latest Fedora 40 image for Linux jobs
    0f9dbb4abf Maintainers.txt: Add myself as FatPkg Maintainer
    745cab5aad DynamicTablesPkg: Fix BDF format for PCI initiators
    bff50932c1 OvmfPkg: Update links to Intel & MS ACPI compilers in README
    da1084ccf4 MdePkg/Include/IndustryStandard: Address C++ keyword collisions
    e6a886fdfc SecurityPkg/Library/TpmCommandLib: Change xor to xor_
    05ac9a58f5 MdePkg/Include/IndustryStandard: Add operator_ and xor_ field names
    1e079360cd PrmPkg: Update link to ACPICA in Readme.md
    9112fb0ecc MdeModulePkg/HiiDatabase: Return default value for BIT VarStore as UNIT32
    9a9bcacbe0 UefiCpuPkg/CpuMmuLib: Adjust default memory attributes on LoongArch
    9098efdf0d EmulatorPkg: BlockIo2 APIs do not signal event
    5158b598f7 DynamicTablesPkg: Adds X64 support for CPU SSDT generator
    e89ff68110 DynamicTablesPkg: Add X64 MADT table generator
    24d835a131 OvmfPkg/Library/HardwareInfoLib: Fix memory allocation for a root bridge
    4928851899 ArmVirtPkg: Report an error if NETWORK_TLS_ENABLE is TRUE on ARM
    3781ad107d OvmfPkg/QemuVideoDxe: Clean up Non-Used PCDs
    9c4542a064 OvmfPkg: Rerun dispatcher after initializing virtio-rng
    3ee2ceb6fa FatPkg/EnhancedFatDxe: Add comments around StrSize() checks
    bf32c2d61f ArmPkg/SemihostFs: StrSize() cannot return 0
    d90bf1f973 EmbeddedPkg: reduce "Found ACPI table" messages from ERROR to INFO
    b78b4da1fb ArmPlatformPkg: Allow up to 5 Secure Boot DB certs
    ae8ab7190c ArmVirtPkg/ArmVirtKvmTool: Use PSCI/SMCCC conduit from FDT
    f9f4164af9 ArmVirtPkg: Rename ArmVirtQemuMonitorLib to ArmVirtMonitorLib
    91171b6b94 ArmVirtPkg/PrePi: Don't clear HCR_EL2 fields when setting TGE
    f60a839480 ArmPkg/ArmMmuLib: Add support for EL2&0 translation regime
    e80b17d21a ArmPkg/ArmMmuLib: Ignore EL3 in RELEASE code
    31ff325228 ArmPkg/ArmLib: Use VHE alternatives for timer system registers
    c2827283a8 MdePkg/AArch64: Add some missing MMU related constants
    a25eb7557f SignedCapsulePkg: Drop ARM support
    6f0e977165 Drop git submodule for Berkeley softfloat library
    31ea376b58 ArmPkg: Remove ArmSoftFloatLib implementation
    e54794bcc6 Remove all ArmSoftFloatLib library class resolutions
    98f4d35aae RedfishPkg: Drop ARM support
    f73f7b2318 CryptoPkg/OpensslLib: Drop dependency on ArmSoftFloatLib
    a4c50dd3e8 .github: Handle deleted GitHub accounts
    7eff71fe69 SecurityPkg: Update libspdm
    c15bd99342 SecurityPkg/Tcg2Config: Set TPM2.0 for default of Attempt TPM Device
    468b3d9589 UefiCpuPkg/PiSmmCpuDxeSmm:Check resource HOB range before mapping
    065df32de3 CryptoPkg: Apply gettimeofday() solution to BaseCryptLibMbedTls
    8c8e05db24 OvmfPkg/PlatformInitLib: enable x2apic mode if needed
    800205678f ShellPkg: Fix check on OldArgv in UpdateArgcArgv()
    6142f0a8a5 OvmfPkg/EmuVariableFvbRuntimeDxe: Issue NV vars initializitation message
    d502cc7702 OvmfPkg/PlatformInitLib: Retry NV vars FV check as shared
    52fa7e78d2 OvmfPkg/PlatformPei: Move NV vars init to after SEV-SNP memory acceptance
    f0d2bc3ab2 OvmfPkg/QemuFlashFvbServicesRuntimeDxe: Do not use flash with SEV-SNP
    a6f1433e95 DynamicTablesPkg/ArmGicCParser: Parse VGIC interrupt for all CPUs
    0d129450c2 NetworkPkg: Restore TPL Before Return
    f3bc6013d2 MdeModulePkg HobPrintLib: Add Guid to Guids section.
    edb312d5d0 MdePkg/BaseRngLib: Remove global variable for RDRAND state update
    4d3cf37ff0 MdePkg/SmmPciExpressLib: Ensure gBS variable for the constructor
  - Remove berkeley-softfloat-3-b64af41c3276f.tar.xz because of commit "31ea376b58 ArmPkg: Remove ArmSoftFloatLib implementation"
  - Remove ovmf-Revert-Add-Stack-Cookie-Support-to-MSVC-and-GCC.patch (modified as ovmf-Remove-unsupported-GCC-flag-mstack-protector-guard.patch to minimize impact)
  - Add ovmf-Remove-unsupported-GCC-flag-mstack-protector-guard.patch
  - Add ovmf-Increase-FVMAIN-Size-for-Compatibility-with-2MB-Size.patch
  - Update openssl library to 3.4
* Tue Jan 14 2025 Richard Lyu <richard.lyu@suse.com>
- Update to edk2-stable202411
  - Features (https://github.com/tianocore/edk2/releases):
  - MdeModulePkg: Added PPI support in UFS PEI driver
  - DynamicTablesPkg: Adds SPMI table generator
  - MdeModulePkg: PeiMain: Add Delayed Dispatch PPI Implementation
  - UefiPayloadPkg: Add Secure Boot support
  - MdeModulePkg/TerminalDxe: Add VTUTF8 to Putty function key map
  - DynamicTablesPkg: Adds ACPI HPET table generator
  - Update Openssl 3.0.15
  - DynamicTablesPkg: Adds WSMT generator for X64
  - Enable UPL support for RISC-V
  - Patches (git log --oneline --date-order edk2-stable202408..edk2-stable202411):
    0f3867fa6e UefiPayloadPkg/UefiPayloadEntry: Fix PT protection in 5 level paging
    c28721484d MedModulePkg/DxeIplPeim: Fix pagetable protection region in 5 level paging
    13fad60156 UefiCpuPkg: Fix unchecked returns and potential integer overflows
    843f0c129e Maintainers.txt: Update M and R for UefiCpuPkg and StandaloneMmPkg
    fe1272dc57 NetworkPkg/DxeNetLib: make mSecureHashAlgorithms static
    cd681f5f6a MdePkg/DxeRngLib: make mSecureHashAlgorithms static
    d1c8a88e3b Maintainers.txt: update Leif's email address
    cb87aada97 ArmPlatformPkg: Honour RES1 fields in CPTR_EL2
    1bd09ad193 MdePkg: Define AARCH64_CPTR_RES1 and AARCH64_CPTR_DEFAULT
    ef35863880 ArmPlatformPkg,MdePkg: Rename AARCH64 CPACR_CP_FULL_ACCESS
    6f07aeb49c ArmPlatformPkg: Document that we don't support HCR_EL2.E2H being set
    3299c36ba1 EmulatorPkg WinThunk: Use Win32 API to get Performance Frequency and Count
    e12a8d83fa FatPkg/FatPei: Simplify the GPT Header Check
    ef4f3aa3f7 MdePkg: MdeLibs.dsc.inc: Apwhich are merged to edk2-stable202408:e public Architectural MSRs from MdePkg
    5a73776156 UefiCpuPkg: Use public Architectural MSRs from MdePkg
    961a9e1d76 MdePkg: Added definition of AMD specific public MSRs
    b904377d0d EmbeddedPkg/PrePiHobLib: Remove Non-RT Types from Mem Type Info HOB
    d1372720a8 ArmVirtPkg/MemoryInitPei: Remove Non-RT Types from Mem Type Info HOB
    7da3dcd45d ArmPlatformPkg/MemoryInitPei: Remove Non-RT Types from Mem Type Info HOB
    d8984e86c7 ArmVirtPkg: mark fixed network PCDs
    2ffd6d2e82 OvmfPkg: mark fixed network PCDs
    fc9f06de6f NetworkPkg: mark fixed network PCDs
    9cab9905af ArmVirtPkg: use NetworkDynamicPcds include file
    7ccda1a0b3 OvmfPkg: use NetworkDynamicPcds include file
    1db5895c39 NetworkPkg: introduce include file for dynamic PCDs
    599c8309a5 NetworkPkg/Dhcp6Dxe: Fix sanitizer issues
    171335e34e UefiCpuPkg/MtrrLib: Fix unit test read overflow
    fadf4f377e MdePkg/Test/DevicePathLib: Remove FreePool(NULL)
    d5600f4f5a CryptoPkg/BaseCryptLib: Fix serial number read overrun
    12e1b1f8ef UefiCpuPkg/SecCore: Consume PcdMaxMappingAddressBeforeTempRamExit
    e1b09dfca4 UefiCpuPkg/UefiCpuPkg.dec: Add PcdMaxMappingAddressBeforeTempRamExit
    836942fbad StandaloneMmPkg/MemLib: remove unnecessary check
    da8fd23dbb StandaloneMmPkg/Core: Check Resource HOB and Mmram ranges
    3adb507175 StandaloneMmPkg/Core: add a new InitializeMmHobList()
    d24bb10b1d StandaloneMmPkg/MemLib: Check if the non-MMRAM buffer is valid
    025cec183d StandaloneMmPkg/MemLib: Add an internal header file
    b19f1311d6 StandaloneMmPkg/Core: Remove unneeded check
    734406184f StandaloneMmPkg/MmIpl: Optimize hob pointer check flow
    6f17fe30bf CryptoPkg: Added MM_STANDALONE support in CryptoPkg.
    ccbe6f5030 CryptoPkg: Increase ScratchMemory buffer for openssl 3.0.15
    95d8a1c255 UnitTestFrameworkPkg: Use TianoCore mirror of subhook submodule
    47ba459fc1 CryptoPkg: Updated the missed architectures.
    03d8907321 UefiCpuPkg: Remove AMD 32-bit SMRAM save state map
    b7735a087a MdePkg: CodeQL Fixes.
    a9901a7748 MdeModulePkg: SataControllerSupported checks DevicePath Protocol
    d13f31c3fe UefiPayloadPkg ：ACPI memory node
    60c6486f79 UefiPayloadPkg：Add SMBIOS node.
    de19273e89 UefiPayloadPkg: Modify PCI root reg .
    aac5b3eca3 StandaloneMmPkg/MmIpl: Max physical address bits if disable 5 page level
    79ad703b55 ArmPlatformPkg: CodeQL Fixes.
    7327089f63 ArmVirtPkg: KvmTool: Fix clang linker error
    b72d3495ee MdePkg: Add Google Mock Library for PostCodeLib
    fc6a8bb131 Maintainers: Revert "Remove Ard Biesheuvel from all packages"
    004232c6af UefiCpuPkg/MmUnblockMemoryLib: Check if buffer range is valid
    acce74762b MdeModulePkg: Adding support for authenticated variable storage data format
    56dfab9a8a StandaloneMmPkg/Core: Shadow Standalone BFV into MMRAM
    11d4edc7c6 UefiCpuPkg/PiSmmCpuDxeSmm: Fix extraneous parentheses
    8d74a37944 StandaloneMmPkg/Core: RUpdate openssl library to 3.0.15a in-place option
    8af71632d6 DynamicTablesPkg: Drop the unnecessary comparision of UINT8 max value
    9e56b4373b EmbeddedPkg: Add MDEPKG_NDEBUG to RELEASE build
    8f04804593 EmbeddedPkg: Remove non-needed MDEPKG_NDEBUG dependent code
    051ef932bd BaseTools/GenFw X64: Detect GOTCPRELX relaxations applied by LLD
    9c557575a1 MdePkg/Include/Guid: Fix EFI_CXL_COMPONENT_EVENT_LOG in Cper.h
    4ab8c3cf99 ShellPkg: Updated Type 4 Info as per Smbios 3.8.0
    9dc7fb819c MdePkg: Updated Type 4 Info as per Smbios 3.8.0
    ad522d9609 DynamicTablesPkg: Update X64 FADT XPm1aEvtBlk
    11bd2fa072 Update CI config following CompilerIntrinsicsLib move from ArmPkg
    cb1db8b9b9 DynamicTablesPkg: Update creator id for WSMT table
    7b3969c951 MdeModulePkg UsbNetwork: Use USB class definition from MdePkg
    e2ab098e65 ShellPkg/SmbiosView: Correct wrong length offset usage in SMBIOS Type4
    a19f50bb95 MdePkg/Include/Guid: Rename CXL definitions in Cper.h
    8f84eb0e76 BaseTools: Remove -Wno-unneeded-internal-declaration from CLANGDWARF
    ae83c6b7fd MdePkg: Fix null macros for XCODE5 and CLANG
    6e197a8ba5 MdePkg: Add Google Test Library and Protocol
    866abb2338 MdeModulePkg: Replace rwhich are merged to edk2-stable202408: missing CXL definitions to Cper.h
    79598f34fa MdeModulePkg: PeiMain: Updated dispatcher for delayed dispatch
    d64d1e195c MdeModulePkg: PeiMain: Introduce implementation of delayed dispatch
    b3f36e151d MdePkg: Update Delayed Dispatch PPI as per PI 1.8 A Spec
    e19cc32bce edksetup.sh: Fix the Issue of PYTHON_COMMAND Un-Configurable
    b7342074a6 UnitTestFrameworkPkg: VS2022 Support on UnitTest.
    1b19ccfdfa Add USB Association Descriptor definitions
    d44b82270b ArmPkg: CodeQL Fixes.
    a232e0cd2f UefiCpuPkg/PiSmmCpuDxeSmm: Save and restore CR2 only if SmiProfile enable
    92c1274467 MdePkg: Describe storage location of config tables as per PI 1.7 A spec
    caec6089cf MdePkg: Clarify EFI_MM_SX_DISPATCH_PROTOCOL.Register() as per PI 1.7 A spec
    c80f456ef4 MdePkg: Define PI Specification Version Macro
    b3efbda166 NetworkPkg/HttpBootDxe: Report download error when resume attempts fail
    081cf576a2 DynamicTablesPkg: Update FADT fixed feature flags validation
    21767dcf4e RedfishPkg/RedfishCredentialDxe: Fix 'too many arguments' error
    fcd9570c8d UefiCpuPkg/PiSmmCpuDxeSmm: Consume SmmCpuPlatformHookBeforeMmiHandler func
    e34460c8b2 OvmfPkg/Library: Impl SmmCpuPlatformHookBeforeMmiHandler func
    7d4da670ea UefiCpuPkg: Add SmmCpuPlatformHookBeforeMmiHandler
    2351165f1b UefiCpuPkg/PiSmmCpuDxeSmm: Clarification for BSP & APs Sync Flow
    d2a41d1a7a Maintainers.txt: Update GitHub username for myself
    0bae161fed UefiCpuPkg/MpLib: Remove NotifyOnS3SmmInitDonePpi
    6f17bd5eaf UefiCpuPkg/S3: Skip CR3 modification in S3Resume for 64-bit PEI
    da1c6dd62a UefiPayloadPkg: Add Secure Boot support
    7bac0a940e BaseTools/SetupGit.py: Fix invalid choice 'edk2-test'
    fd619ec460 BaseTools/CodeQl: Give preference to Plugin settings
    06da7daab1 FmpDevicePkg/FmpDependencyLib: Fix potential overflow in loop
    550c38a299 UefiPayloadPkg : Roll back the sequence of gEfiEndOfPeiSignalPpiGuid.
    2ee050d1d5 UnitTestFrameworkPkg: UnitTestLib: Support Failure Strings of 512 Chars
    d99045f392 MdePkg: DebugLib: Check Signature in CR in Release Builds
    77c070b1a7 EmulatorPkg: Add Signature to Graphics Structure
    596773f5e3 DynamicTablesPkg: AmlLib: Fix CodeQL Issue
    80d9b44491 Maintainers.txt: Add myself as UefiPayloadPkg maintainer
    8cce048d48 DynamicTablesPkg: Correct _PSD package format
    54469a6918 ShellPkg: Fix Optional Data rewriting with bcfg
    b21cf3bd5b ShellPkg: ShellLevel2StripQuotes: Strip consecutive quotes
    df884297fd ShellPkg/AcpiView: RASF Parser
    c82bf392c5 ShellPkg/AcpiView: RAS2 Parser - Remove unused define
    91d806917f OvmfPkg: RiscV64: build BaseRiscVFpuLib
    f8c738577f UefiCpuPkg: RiscV64: initialize FPU
    28dd588ca8 MdePkg/BaseLib: RISC-V: Add FPU CSR constants
    7123940665 MdePkg: MdeLibs.dsc.inc: Introduce CUSTOM_STACK_CHECK_LIB Macro
    2fdc39d09d MdeModulePkg/UefiBootManagerLib: Build proper SD/MMC boot descriptions
    f962adc8a0 DynamicTablesPkg: Adds SPMI table generator
    0958b762fb MdePkg/IndustryStandard: Adds SPMI macros
    d2e8118461 StandaloneMmPkg: CodeQL Fixes.
    e73ec56942 MdePkg: Improving readability of CVE patch for PeCoffLoaderRelocateImage
    cac73c45c4 ArmVirtPkg/ArmVirtQemu: avoid unnecessary use of $(ARCH) conditional
    3297be20bb Maintainers.txt: add Leif Lindholm as additional BaseFdtLib maintainer
    eac33b88f4 Maintainers.txt: add all files in BaseFdtLib to component
    9a1d54665c MdePkg: add various additional functions to BaseFdtLib
    450a001c09 MdePkg: export additional Property functions from BaseFdtLib
    5bad560935 MdePkg: export FdtAddressCells/FdtSizeCells from BaseFdtLib
    9ba11ee131 MdePkg: export FdtOpenInto/FdtPack from BaseFdtLib
    9dc9a4bae6 MdePkg: export some additional macros from BaseFdtLib
    0cc9963cc9 MdePkg: align BaseFdtLib function prototypes
    8292296893 MdePkg: add FdtStrerror wrapper to BaseFdtLib
    8040fdbb8b MdePkg: consistently use "Property" in BaseFdtLib
    bf7dbf6380 MdePkg,UefiPayloadPkg: improve BaseFdtLib memreserve helper style
    4f4673846f .github/GitHub.py: Update bot in redundant comment check
    c95233b852 MdePkg: Fix overflow issue in BasePeCoffLib
    517019a553 .gitignore: Ignore Python venv files
    a6b472131e IntelFsp2Pkg : Refactor BaseFspCommonLib to reduce binary size
    21e1fc5400 BaseTools: LinuxGcc5ToolChain: Run for GCC Toolchain
    10783187dd .pytool/UncrustifyCheck: Show errors in output
    48b5815d77 RedfishPkg/Include: add common RedfishPkg header file.
    8b295e0aad NetworkPkg/Dhcp6Dxe: Fix extraneous parentheses
    e548e1cd73 CryptoPkg: Fix unused variable in CryptX509.c
    90fb3c6cfc CryptoPkg/OpensslLib: Fix build on XCODE5
    95292a0f24 MdeModulePkg/VariablePolicyLib: Fix extraneous parentheses
    0aa93aecb7 MdePkg: Fix DEBUG_CODE and PERF_CODE macros for XCODE5
    cc47e82703 BaseTools: Fix redefinition of UINT8_MAX in Decompress.c on XCODE5
    ded3ae2cf4 ArmPkg: drop FdtLib resolution from .dsc
    0693c66f76 EmbeddedPkg: add missing BaseLib/BaseMemoryLib declarations
    dab548a51b ArmVirtPkg: add QemuVirtMemInfoLib missing dependency/includes
    fe93b3745f DynamicTablesPkg/FdtHwInfoParserLib: add missing resolutions/includes
    3ed4f43f83 CryptoPkg: Update generated files based on openssl 3.0.15
    c13f9de56d CryptoPkg: Update openssl submodule to 3.0.15
    2936b7d162 ArmVirtPkg: Correct PcdDxeNxMemoryProtectionPolicy comment
    39462fcd99 openssl: add Library/OpensslLib/openssl to includes, drop e_os.h hack
    67c303cb5f CrtLibSupport: add intptr_t
    c371460cb4 CrtLibSupport: add timezone
    0ec54d8d0c CrtLibSupport: add mktime()
    af73d37741 CrtLibSupport: factor out EFI_TIME -> time_t calculation to new function
    ebf7daa583 CrtLibSupport: fix gettimeofday()
    609c7e8679 CrtLibSupport: add sleep()
    b8122cc9d8 ShellPkg: add missing linefeed in reset message
    a131839a3d FatPkg: Improvements to Fat to Fix File Corruption
    3ef6a71ed1 FatPkg: Check BlockIo Device Has Supported BlockSize
    4c3bffaeb3 UefiPayloadPkg: Enhance ReadMe.md for ELF and FIT
    1a89c690a1 CryptoPkg/OpensslLib: Create SM3-only version of the library
    1815f35b87 CryptoPkg: Add unit testcase for SM3
    89309fee81 CryptoPkg/MbedTls CLANGDWARF: Replace outdated CLANG3x references
    6820004b3e BaseTools: Fix multiple 'invalid escape sequence' warnings in tests
    0354e89fc9 UefiPayloadPkg: Add LOCKBOX_SUPPORT in UPL and set it as FALSE in default
    14bfcc4021 UefiPayloadPkg: Align relocation item with spec
    222e2854fe BaseTools: Update RETURN_ERROR Macro in BaseTypes.h
    c358009352 Set PcdSerialClockRate from SerialPortInfo in UefiPayloadEntry
    3a3b12cbda UefiCpuPkg/MtrrLib: MtrrLibIsMtrrSupported always return FALSE in TD-Guest
    ff8a7d101f Maintainers.txt: Add Sami Mujawar as maintainer for Arm modules
    5901f19a87 DynamicTablesPkg: Adds ACPI SSDT HPET table generator
    fada1cea46 DynamicTablesPkg: Adds ACPI HPET table generator
    21e8a85653 MdeModulePkg/TerminalDxe: Add VTUTF8 to Putty function key map
    170fa8ecd4 BaseTools/tools_def ARM: Disable stack protector with CLANGDWARF
    779642283a Maintainers: Remove Ard Biesheuvel from all packages
    b0d1cb59c7 UefiCpuPkg/AmdSmmCpuFeaturesLib: Skip SMBASE configuration
    670e263419 UefiPayloadPkg: Move FADT check to consumer coode.
    7843c8da06 RedfishPkg/Include: move protocol version definition to protocol header
    be36ddb234 ArmPkg: Avoid building ArmCrashDumpDxe on ARM
    73dbb68006 NetworkPkg/HttpBootDxe: Correctly uninstall HttpBootCallbackProtocol
    1f32b5a30e UefiPayloadPkg: Handle simple reserved ranges from DT
    043045cd6e MdePkg: Add reserved mem fdt helpers
    099aff9137 UefiPayloadPkg: Add support for Root bridge parser
    c511663cfa UefiPayloadPkg: Add support for Special Purpose memory
    5cd9e7ce87 UefiPayloadPkg: Remove unnecessary ACPI checks
    7fdb360046 UefiPayloadPkg: Enable RiscV64 entry point to UPL
    1f4ae34f13 UniversalPayload: Add RISC-V support for UPL PCDs
    9fff9912fd UefiPayloadPkg: Parse fdt and create smbios table
    4d35077048 UefiPayloadPkg: Bugfix: Do not parse NULL nodes
    ed665ef38c UefiPayloadPkg: Handle ordering issue with option node
    121af960e2 OvmfPkg/CpuHotplugSmm: delay SMM exit
    ec18fa81d3 OvmfPkg: Use TdInfo instead of fw_cfg to get cpu count in TDVF
    262ab6259f OvmfPkg/RiscVVirtQemu: Remove non-needed !include line
    273f43cec9 MdePkg/DxeRngLib: Add gEfiRngAlgorithmArmRndr to the secure algorithms
    5ed8f64647 MdePkg/DxeRngLib: Use PcdEnforceSecureRngAlgorithms for default algorithm
    c04c4534c4 MdePkg/DxeRngLib: Refactor Rng algorithm selection
    bc02b255a8 MdePkg: Move PcdEnforceSecureRngAlgorithms from NetworkPkg
    5c8bdb190f MdePkg DebugLib: Enable FILE NAME as DEBUG ASSERT for GCC12
    69139e39bc NetworkPkg/HttpBootDxe: Resume an interrupted boot file download.
    5262108822 MdePkg/Http11.h: Add HTTP header definitions.
    964c22b8ea MdeModulePkg: Fix buffer overflow in MergeMemoryMap
    a9b38305b6 MdePkg: Remove Old Stack Check Lib Implementation
    f53f029122 BaseTools: Add Stack Cookie Support to MSVC and GCC IA32/X64/ARM/AARCH64
    cac0955658 BaseTools: Update Stack Cookie Logic
    5e07b97094 UnitTestFrameworkPkg: Add StackCheckLib
    17744fc9ce UefiPayloadPkg: Add StackCheckLib
    dfc397133b UefiCpuPkg: Add StackCheckLib
    7b4b1d2bd3 StandaloneMmPkg: Add StackCheckLib
    d7a0a7ae4a SourceLevelDebugPkg: Add StackCheckLib
    2e8fb6b406 ShellPkg: Add StackCheckLib
    ce347727a0 SignedCapsulePkg: Add StackCheckLibNull
    7ca87dcc6a SecurityPkg: Add StackCheckLibNull
    78d5d27470 RedfishPkg: Add StackCheckLibNull
    e4c3c3eb65 PrmPkg: Add StackCheckLibNull
    a275f10186 PcAtChipsetPkg: Add StackCheckLib
    538b10f157 OvmfPkg: Add StackCheckLibNull
    fefd017851 NetworkPkg: Add StackCheckLib
    000b61eff8 MdeModulePkg: Add StackCheckLib
    847561eb53 IntelFsp2WrapperPkg: Add StackCheckLib
    254e4cfa8c IntelFsp2Pkg: Add StackCheckLibNull
    715a695c3d FmpDevicePkg: Add StackCheckLibNull
    6f0ba20471 FatPkg: Add StackCheckLibNull
    ae5953dea0 EmulatorPkg: Add StackCheckLibNull
    e7c0ad3661 EmbeddedPkg: Add StackCheckLibNull
    8c21bc7157 DynamicTablesPkg: Add StackCheckLibNull
    c9320adf22 CryptoPkg: Add StackCheckLib
    02e6c73a99 ArmVirtPkg: Add Null Stack Check Lib
    acab6dbf87 ArmPlatformPkg: Add Null Stack Check Lib
    d1faaa8eae ArmPkg: Remove Deprecated Stack Check Lib
    5000568969 MdePkg: Create Stack Check Lib
    ac43bbacde MdePkg: Create Stack Check Null Libs
    3a9da5f329 MdePkg: Add Stack Cookie Interrupt Vector PCD
    26c3818011 UnitTestFrameworkPkg: Move common includes to their own file
    837bb62661 NetworkPkg: PxeBcDhcp6GoogleTest: Fix Stack Smashing Unit Test
    6706fe6e23 ArmPkg/ArmLib: Drop set/way Dcache operations
    bec02ea9de MdePkg/ArmLib: Drop routines that maintain the entire D-cache
    bb403511d4 ArmVirtPkg: Fix unable to build with -D NETWORK_ENABLE=0
    14d7ae94bc OvmfPkg: Fix unable to build OVMF with -D NETWORK_ENABLE=0
    af60615f0e NetworkPkg: Fix unable to build OVMF with -D NETWORK_ENABLE=0
    8f74b95a21 MdePkg: Move CompilerIntrinsicsLib from ArmPkg
    734e71f428 MdePkg: Move AsmMacroIoLib*.h from ArmPkg
    656665d289 ArmPkg: CompilerIntrinsicsLib: Use AsmMacroIoLibV8.h for AARCH64 ASM
    fe6b6feca7 OvmfPkg/LoongArchVirt: Modify loongarch uefi firmware size
    1197fb3383 ShellPkg/AcpiView: RAS2 Parser
    dfc242c2dd MdePkg/Acpi65.h: Add RAS2 table defs and signature as in ACPI 6.5
    babccb841d MdeModulePkg: Enable Data Terminal at end of serial
    bacee5113e MdePkg/IpmiNetFnGroupExtension.h: Enforce structure alignment
    e41e728c16 Refactor SetMemWrapper to reduce binary size
    03c8ec6ce2 MdeModulePkg/DxeCapsuleLibFmp: Check BootService Status to Use ESRT Cache
    dadd8c7a95 MdeModulePkg/DxeCapsuleLibFmp: Change the Event Notify to Cache ESRT Table
    f2557032d6 NetworkPkg/MnpDxe: Convert TX buffer allocation messages to DEBUG_VERBOSE
    589304e67f Support Report Status Code in the UefiPxe driver.
    58b4bf7b7e StandaloneMmPkg/MmIpl: Correct unblocked memory regions attribute
    14c9ba1a2c IntelFsp2Pkg: Support FSP API to save and restore page table
    9a4088777f .pytool/EccCheck: Trim leading path to modified directory
    1328938560 MdeModulePkg/VariableRuntimeDxe: Fix VariablePolicyProtocol PRODUCES
    b1ce2e1b67 ArmPkg/ArmPsciMpServices: GetProcessorInfo copies incorrect structure
    61f9695f20 BaseTools: Remove Pip BaseTools
    3885a3edad NetworkPkg/DxeNetLib: Update misleading comment
    e5715711a4 OvmfPkg/QemuFwCfgS3Lib: Disable S3 detection in TDVF
    043615ae8b MdePkg/BaseLib: Add NULL version Tdx functions for other architectures
    b437b5ca4c UefiCpuPkg/PiSmmCpuDxeSmm: Remove RestrictedMemoryAccess check for MM CPU
    b4820f2d65 UefiCpuPkg/PiSmmCpuDxeSmm: Clean mCpuSmmRestrictedMemoryAccess
    633a755d99 UefiCpuPkg/PiSmmCpuDxeSmm: Update IfReadOnlyPageTableNeeded
    4f6614fc18 UefiCpuPkg/PiSmmCpuDxeSmm: Correct SetPageTableAttributes func usage
    f6eb069e17 UefiCpuPkg/PiSmmCpuDxeSmm: Deadloop if PFAddr is not supported by system
    c8ce84d067 UefiCpuPkg/PiSmmCpuDxeSmm: Always save and restore CR2
    897284d47d UefiCpuPkg/PiSmmCpuDxeSmm: Fix IsSmmCommBufferForbiddenAddress check
    c047353a12 UefiCpuPkg/PiSmmCpuDxeSmm: Avoid to access MCA_CAP if CPU does not support
    253b3d678a MdeModulePkg/Core/Pei: Add error handling for Section Length
    9dabe005f0 MdePkg/IndustryStandard: Add definitions for IPMI Boot Progress Code
    bfb33c0e09 BaseTools: Disable MSVC volatileMetadata for VS2019 and VS2022 for X64
    013d51771a EmbeddedPkg/PrePiHobLib: Fix SetBootMode return value
    1204de7b50 EmbeddedPkg/PrePiHobLib: Align Doxygen comment between code and header
    3151798123 ShellPkg: Acpiview: Add GICC field parsing
    f0dc9e1504 MdeModulePkg: UefiBootManagerLib: Update assert condition
    03bc4252fb XhciDxe: Fail the start of malfunctioning XHCI controllers
    7b9f2018d1 RedfishPkg: PlatformHostInterfaceBmcUsbNicLib: use credential protocol
    7acd8c9bd2 RedfishPkg: PlatformHostInterfaceBmcUsbNicLib: fix compilation warning
    c9a59facd8 RedfishPkg: RedfishDiscoverDxe: fix compilation warning
    2ddce71142 EmulatorPkg: fix X64 Unix/Host segfault with GCC toolchain profile
    99d60cbd39 ArmVirtPkg ARM: Move to MbedTls for crypto
    1240a722f8 SecurityPkg: Tcg2Acpi: Remove _DSM Memory Clear and _PTS
    a4245b265d SecurityPkg: Tcg2Smm: Remove Memory Clear SMI Handler
    559affab2e MdeModulePkg: Fix redundant call to RestoreTpl()
    b17ac09cc4 MdeModulePkg: Add extra RestoreTpl() call in DiskIo
    afba5358c8 ArmVirtPkg: Resolve RngLib via RngDxe for TRNG support
    8504d2be17 MdeModulePkg/FaultTolerantWriteDxe: Fix buffer overrun issue
    1a89d9887f MdePkg:Update Return Error Macro in Base.h
    5bb4f9694a OvmfPkg/PlatformPei: Build gCcEventEntryHobGuid at First
    d997d3c62f OvmfPkg: Use TdHob instead of e820tables to get memory info in TDVF
    e48acc0fa9 ShellPkg/SmbiosView: Add new Socket Type for SMBIOS Type4
    aebe9625c9 MdePkg/SmBios.h: Add new Processor Upgrade definition for SMBIOS Type4
    7f505d377b MdePkg/SmBios.h: Add new Socket Type for SMBIOS Type4
    72cf76868c NetworkPkg/WifiConnectionManagerDxe: Fix Connection Manager HII errors
    cb9bdf3753 SecurityPkg: Optimization by moving PeiServicesLocatePpi outside loop
    a859f4fc03 MdePkg: Fix a buffer overread.
    909849be87 pip-requirements.txt: Bump versions of several packages and fix URL
    f0f14aac3d FatPkg/EnhancedFatDxe: Downgrade debug level for no media found
    5b6ec1a7f4 UefiPayloadPkg/UefiPayloadPkg.ci.yaml: Add PrEval CI config
    d214d75be0 UefiCpuPkg/UefiCpuPkg.ci.yaml: Add PrEval CI config
    6e727ed9dd StandaloneMmPkg/StandaloneMmPkg.ci.yaml: Add PrEval CI config
    7c10472983 SourceLevelDebugPkg/SourceLevelDebugPkg.ci.yaml: Add PrEval CI config
    abf21d76e7 SignedCapsulePkg/SignedCapsulePkg.ci.yaml: Add PrEval CI config
    0cfed09674 ShellPkg/ShellPkg.ci.yaml: Add PrEval CI config
    6ead9a8b80 SecurityPkg/SecurityPkg.ci.yaml: Add PrEval CI config
    89bad0726c PcAtChipsetPkg/PcAtChipsetPkg.ci.yaml: Add PrEval CI config
    ea5581186e NetworkPkg/NetworkPkg.ci.yaml: Add PrEval CI config
    c79487605a EmulatorPkg/EmulatorPkg.ci.yaml: Add PrEval CI config
    2ccf94d37b ArmPlatformPkg/ArmPlatformPkg.ci.yaml: Add PrEval CI config
    715200ea60 ArmPkg/ArmPkg.ci.yaml: Add PrEval CI config
    814470b834 NetworkPkg/SnpDxe: return error for unsupported parameter
    82c5cacd13 NetworkPkg: DxeHttpLib: Use HTTP error 429
    829f773e5c MdePkg: Add HTTP error 429
    eaf78e43f2 MdeModulePkg: Enable VarCheckHiiLibStandaloneMm.
    df58def118 MdeModulePkg: Add VarCheckHiiLibStandaloneMm.
    02f6774803 MdeModulePkg: Move DUMP_VAR_CHECK_HII in common file
    45cf57ce79 MdeModulePkg: Relocate VarCheckHiiInternalDumpHex, VarCheckHiiQuestion
    3956f4e392 MdeModulePkg: Wrap SetVariableCheckHandlerHii as a common API
    db43a80c10 MdeModulePkg: Rename VarCheckHiiLibNullClass as VarCheckHiiLib.
    5718c9b06f MdeModulePkg: Modified BuildVarCheckHiiBin parameter to IN OUT.
    ee1e163a2f MdeModulePkg: Enable VarCheckHiiLibMmDependency
    6b3ac9cbf8 MdeModulePkg: Add VarCheckHiiLibMmDependency library.
    4aea90ea53 MdeModulePkg: Relocation of mVarCheckHiiBin declaration
    238ccc5944 DynamicTablesPkg: Adds generic ACPI Creator ID
    5dafa13d62 DynamicTablesPkg: Adds WSMT generator for X64
    a5f5432728 SecurityPkg: Fix break missing at TPM_ALG_KEYEDHASH case
    50871ee0ec BaseTools: GenMake: FIx missing logs from GenMake.py
    91853ca6a5 MdeModulePkg/VariableStandaloneMm: Notify variable write ready in MM
    af15e4535d ArmPkg: Fix timer wrap-around
    4ef87f455b MdePkg: Add Reset Reason definitions
    f7abf6af2d SecurityPkg: Fix exponent unmarshaled as 16 bits
    96b90e150c SecurityPkg: Measure Invoke EBS even in failure case
    baecba68a3 MdePkg: Remove duplicate source from BaseMemoryLib INF files
    95ee7f3ef7 BaseTools: Trim: Add header/footer for ASL include
    90d861f63d CryptoPkg/BaseCryptLibMbedTls: Fix uninitialized variable errors
    468a36b22f CryptoPkg/OpensslLib CLANGDWARF: Use gnu99 C dialect for asm() support
    5c63e22a9f OvmfPkg: Move kernel hashes section to end
    662272ef41 Sync AARCH64 GCD Capabilities with Page Table
    2069a63a8e OvmfPkg/PlatformInitLib: allow switching to 4-level paging
    f6092b5e2b MdePkg: Remove the old name of LoongArch CSR 0x20
    bc518f81fd OvmfPkg: Using the new name of LoongArch CSR 0x20 register
    2fe24171ac UefiCpuPkg: Using the new name of LoongArch CSR 0x20 register
    a066ca16d3 MdePkg: Rename the LoongArch CSR 0x20 register
    d5c7bba504 StandaloneMmPkg: Restart dispatcher once MM entry is registered for X64
    0b0b7041cc OvmfPkg/OvmfXen: Introduce Xen's ResetSystemLib, to use xen hypercall
    6ed258d89d OvmfPkg/XenHypercallLib: Add SchedOp hypercall
    043eab84e5 OvmfPkg/XenPlatformPei: Remove Hypercall Page
    0e6f6c715c OvmfPkg/XenHypercallLib: Use direct hypercalls
    9d5a9940e4 OvmfPkg: Refactor PcdSetNxForStack usage in TDVF
    a1b0703e8e EmbeddedPkg: Improve LocateAndInstallAcpiFromFvConditional
    5aa6842715 MdeModulePkg/VariableStandaloneMm: Fix TCG MOR secure feature issue
    f31aa47dee MdePkg: CoreValidateHandle Optimization
    0596e5fa05 MdeModulePkg: CoreValidateHandle Optimization
    a63a7dbf85 ArmVirtPkg: Drop incorrect reference to LzmaDecompressLib
    0a6d41ba0a ArmPlatformPkg/ArmPlatformLib: Drop unused MPCore routines
    5c566abb12 ArmVirtPkg/ArmPlatformLib: Drop unused MPCore routines
    5749b70b5a ArmPlatformPkg: Retire PrePi
    029c7a2829 ArmPlatformPkg: Retire PrePeiCore
    76c5f035a1 ArmPlatformPkg: Retire ArmPlatformStackLib
    391666da2c OvmfPkg/QemuVideoDxe: ignore display resolutions smaller than 640x480
    58035e8b5e OvmfPkg/VirtioGpuDxe: ignore display resolutions smaller than 640x480
    6a7be5a841 DynamicTablesPkg: AML code generation for IO resouce descriptor.
    b6c4708c4d MdeModulePkg/Bus/Pci/NvmExpressDxe: Nvm Express Media Sanitize Protocol.
    7801fe428b MdePkg Nvme.h: Update fields from 1.4c specification.
    1169122c6f MdeModulePkg NonDiscoverablePciDeviceIo: MMIO Memory XP By Default
    01735bbe4a MdeModulePkg: Gcd: Only Update gMemoryMap Attributes if Correct GCD Type
    bb248a9509 MdeModulePkg: MAT Set RO/XP on Code/Data Sections Outside Image Memory
    254641f342 MdeModulePkg: MAT: Do Not Set EfiMemoryMappedIo[PortSpace] Attrs
    31f0225005 RedfishPkg/RedfishHttpDxe: check response content type.
    14e6c48103 RedfishPkg/RedfishHttpDxe: add status code check for modification request
    2fe9b6c22f MdePkg:BaseArmTrngLibNull: Assert causing FVP stalling
    383f729ac0 OvmfPkg/PlatformInitLib: Reserve Sec Page Tables in TDVF
    9cd66aca1a CryptoPkg:  Support BrainpoolP512r1 algorithm
    41a51d1735 ArmPkg/GenericWatchdogDxe: Disable WDOG before the protocol installed
    7cde720e51 ShellPkg: Correct smbiosview strings and conditions for SMBIOS Type9
    319835abb8 UefiCpuPkg/MpInitLib: Skip X2APIC enabling when BSP in X2APIC already
    7ed3989166 UefiCpuPkg/MpInitLib: Sync BSP's APIC mode to APs in InitConfig path
    94f68d0b56 UefiCpuPkg/MpInitLib: Separate X2APIC enabling to subfunction
    84e7b74c8c UefiCpuPkg/UefiCpuPkg.dsc: Include PiSmmCpuStandaloneMm and required Libs
    0de7882b46 UefiCpuPkg/PiSmmCpuDxeSmm: Simplify SMM Profile Size Calculation
    2e6ca59e33 UefiCpuPkg/PiSmmCpuDxeSmm: Avoid PcdCpuSmmProfileEnable check in MM
    ae0d54cd43 UefiCpuPkg/PiSmmCpuDxeSmm: Cleanup SMM_CPU_SYNC_MODE
    1816c78f43 UefiCpuPkg/PiSmmCpuDxeSmm: Refine DxeSmm PageTable update logic
    5bcf6049f2 UefiCpuPkg/PiSmmCpuDxeSmm: Add PiSmmCpuStandaloneMm.inf
    3690d30a6e UefiCpuPkg/PiSmmCpuDxeSmm: Check logging PF address for MM
    0593183d76 UefiCpuPkg/PiSmmCpuDxeSmm: Start SMM Profile early for MM
    79468b58c3 UefiCpuPkg/PiSmmCpuDxeSmm: Differentiate PerformRemainingTasks
    268397a892 UefiCpuPkg/PiSmmCpuDxeSmm: Enable CodeAccessCheck in MM Entry Point
    1c19ccd510 UefiCpuPkg/PiSmmCpuDxeSmm: Refactor code to create default Page Table
    14cb36685b UefiCpuPkg/PiSmmCpuDxeSmm: Add PiCpuStandaloneMmEntry for MM
    7b9b4ed57f UefiCpuPkg/PiSmmCpuDxeSmm: Add GetSupportedMaxLogicalProcessorNumber
    167e902624 UefiCpuPkg/PiSmmCpuDxeSmm: Impl IsSmmCommBufferForbiddenAddress for MM
    9ee5334796 UefiCpuPkg/PiSmmCpuDxeSmm: Define mIsStandaloneMm to indicate SMM or MM
    5f88a44637 UefiCpuPkg/PiSmmCpuDxeSmm: Impl GetSmiCommandPort for MM
    ee54bda382 UefiCpuPkg/PiSmmCpuDxeSmm: Impl CreateExtendedProtectionRange for MM
    614d6c91bf UefiCpuPkg/PiSmmCpuDxeSmm: Impl GetSmmCpuSyncConfigData for MM
    1f22b96b11 UefiCpuPkg/PiSmmCpuDxeSmm: Impl GetAcpiS3EnableFlag for MM
    502a9122a4 UefiCpuPkg/PiSmmCpuDxeSmm: Impl GetSmmProfileData for MM
    cc996831bd UefiCpuPkg/PiSmmCpuDxeSmm: Add empty .c for MM CPU specific impl
    9d9bbb6f5f UefiCpuPkg/PiSmmCpuDxeSmm: Move GetSmiCommandPort into DxeSmm Code
    abc2f59523 UefiCpuPkg/PiSmmCpuDxeSmm: Move GetUefiMemoryMap into DxeSmm code
    0c037b5fa7 UefiCpuPkg/PiSmmCpuDxeSmm: Create extended protection MemRegion in func
    d480f106a6 UefiCpuPkg/PiSmmCpuDxeSmm: Get SmmCpuSyncConfig data from func
    23c5ee6e23 UefiCpuPkg/PiSmmCpuDxeSmm: Move GetAcpiS3EnableFlag into DxeSmm code
    5547d1487c UefiCpuPkg/PiSmmCpuDxeSmm: Move SMM profile data allocation into func
    89fe9c5d79 UefiCpuPkg/PiSmmCpuDxeSmm: Use SMM Variable to set SmmProfileBase
    c8a1295d3e UefiCpuPkg/PiSmmCpuDxeSmm: Get SMRAM info from gEfiSmmSmramMemoryGuid
    8ccf7f65e5 UefiCpuPkg/PiSmmCpuDxeSmm: Centralize Non-Mmram Mem Management Code
    cc5df45eb6 UefiCpuPkg/PiSmmCpuDxeSmm: Move common code into PiSmmCpuCommon.c
    cd29383f77 UefiCpuPkg/PiSmmCpuDxeSmm: Rename PiSmmCpuDxeSmm.h to PiSmmCpuCommon.h
    2a15750b79 UefiCpuPkg/PiSmmCpuDxeSmm: Update gSmst to gMmst
    cfaccc89a2 StandaloneMmPkg/Core: Migrate Memory Allocation Hob into MMRAM
    6b69f564a9 StandaloneMmPkg/Core: Add MemoryAttributes support
    b7931cafea StandaloneMmPkg/Core: Install protocol to notify MmEndOfPei event
    c8df60801f StandaloneMmPkg: Support using gEfiSmmSmramMemoryGuid to get MMRAM range
    487fa274c4 StandaloneMmPkg/Core: Restart dispatcher once MmEntryPoint is registered
    003a4d4ef4 StandaloneMmPkg/Core: Remove unused mMmramRanges and mMmramRangeCount
    f0254c9a1c StandaloneMmPkg: Remove definition for MM_CORE_PRIVATE_DATA
    0f89005d71 StandaloneMmMemLib: Drop MM_CORE_PRIVATE_DATA
    189398dcf8 StandaloneMmCoreMemoryAllocationLib: Drop MM_CORE_PRIVATE_DATA
    18591343b2 StandaloneMmPkg/Core: Drop MM_CORE_PRIVATE_DATA
    24e41d1fa3 StandaloneMmPkg/Core: Introduce MM Communication Buffer
    68487b4736 StandaloneMmPkg/Core: Switch to MM HobList after MM HostList is ready
    dd775aa4d4 StandaloneMmPkg/Core: Install Loaded Image Protocol for MM Core
    a44830727a StandaloneMmPkg/Core: Install Loaded Image Protocol for MM drivers
    6dc14fb5b4 StandaloneMmPkg/Core: Remove traditional MM driver support
    6855567d52 StandaloneMmPkg/MmIpl: Create memory resource HOBs
    378aff173c StandaloneMmPkg/MmIpl: Create MM profile data HOBs
    c775cc762e StandaloneMmPkg/MmIpl: Create misc HOBs for CPU
    0d91ebd96f StandaloneMmPkg/MmIpl: Create standalone MM foundation related HOBs
    5aa5ecd5ff StandaloneMmPkg/MmIpl: Dispatch StandaloneMm drivers in MM
    3ac296def1 StandaloneMmPkg/MmIpl: Install end of PEI notify PPI
    e98eca076a StandaloneMmPkg/MmIpl: Install MmCommunicationPpi
    8d764088ea StandaloneMmPkg/MmIpl: load MM Core and execute MM Core in MM RAM
    d7e6b863a1 StandaloneMmPkg/MmIpl: build MM communication buffer HOB
    e363c0b729 StandaloneMmPkg/MmIpl: StandaloneMmIplPei driver entrypoint
    82d2f6b3c3 MdeModulePkg/SmmCommunicationBufferDxe: Re-use FixedCommBuffer
    d64766bde6 StandaloneMmPkg: Create some notification of protocol and Event
    a2a8558958 StandaloneMmPkg: Install gEfiMmCommunicationProtocolGuid
    cf9b568405 StandaloneMmPkg: Install gEfiMmCommunication2ProtocolGuid
    eef29d5100 StandaloneMmPkg: Add a new MmCommunicationDxe driver
    0806fb60d4 StandaloneMmPkg: Create null instance for MmPlatformHobProducerLib
    c0b1ad64e4 UefiCpuPkg: Enable MmUnblockMemoryLib
    8f21911951 UefiCpuPkg: Add MM Unblock Page Library
    630e819bf3 StandaloneMmPkg/StandaloneMmPkg.ci.yaml: Add UefiCpuPkg dependency
    56908fd4be StandaloneMmPkg/StandaloneMmPkg.dec: Add gEventMmDispatchGuid
    43e8801410 StandaloneMmPkg: Add MmPlatformHobProducerLib library class
    0f36b5fa0a UefiCpuPkg: Add ACPI S3 Enable HOB definition
    39d9e15a9e UefiCpuPkg: Add MM CPU Sync Config definitions
    2c5d329e20 UefiCpuPkg: Add MM Profile related definitions
    21a2c8ae2a UefiCpuPkg: Add Unblock Region HOB definition
    45098bf1b8 MdeModulePkg/MdeModulePkg.dec: Add PcdMmCommBufferPages PCD
    ff04469d33 MdeModulePkg: Add MM Communication Buffer definition
    82b1f69196 MdePkg/MdePkg.dec: Add gEfiMmEndOfPeiProtocol definition
    1fd2f9ec8f IntelFsp2Pkg: Align FSP global data pointer for X64 build
    a0ac7cf67a UefiPayloadPkg: Update UefiPayload driver for FDT support.
    0c4d6bb405 UefiPayloadPkg: Update PayloadLoader to suport FDT.
    b0c6b049c4 UefiPayloadPkg: Add FDT Paser relative LIBs.
    a297b81b62 UefiPayloadPkg: Support Debug function when Hob was not available.
    04d8d94a42 UefiPayloadPkg: Addd header files for FDT structure and function.
    c3997e329a MdePkg: Fix build error after enable FDT support.
    90d0ec17e7 MdePkg/BaseFdtLib: Add FdtNodeOffsetByCompatible()
    99e4c8ea93 OvmfPkg/LoongArchVirt: Clear the PGD series registers
    25da777d95 Maintainers.txt: Cleanup inactive maintainers.
    39a999eb1d ArmPlatformPkg: Initialize Serial Port Before Writing
    ded4191e10 Maintainers.txt: Remove Susovan Mohapatra
    cc7bb9a86e IntelFsp2Pkg: Correcting Data Region Length of MCUD section
    a0594ca403 GitHub Action: Bump github/issue-labeler from 3.1 to 3.4
    b2a431868c UefiCpuPkg: CpuPageTableLibTestHost: Disable Random Test Suite
    efaf8931bb OvmfPkg/TdTcg2Dxe: Fix the SeparatorEvent issue in RTMRs
    ccda91c286 MdePkg: Define BrainpoolP512r1
    5a06afa7dd SecurityPkg: Allocate EfiACPIMemoryNVS buffer for TCG2
    fadb9dcb9d SecurityPkg: Correct Pages for TCG2 communication buffer
    0e8af88034 NetworkPkg: Improve GetBootFile() code flow
    f3040bed3c .mergify: Fix pull_request_rules deprecation
    1cc0fae8d9 MdeModulePkg/RamDiskDxe: fix memory leak on error path.
  - Add libbpf1 (libbpf.so.1) as a BuildRequires to satisfy build dependencies.
  - Add ovmf-Revert-Add-Stack-Cookie-Support-to-MSVC-and-GCC.patch (bsc#1236009)
    f53f029122d4 BaseTools: Add Stack Cookie Support to MSVC and GCC IA32/X64/ARM/AARCH64
  - Update openssl library to 3.0.15
  - Remove patch which are merged to edk2-stable202411:
  - ovmf-MdePkg-DebugLib-Enable-FILE-NAME-as-DEBUG-ASSERT-for.patch
    5c8bdb190f MdePkg DebugLib: Enable FILE NAME as DEBUG ASSERT for GCC12
* Wed Nov 13 2024 Joey Lee <jlee@suse.com>
- Add ovmf-x86_64-sev-code.bin and ovmf-x86_64-sev-vars.bin back
  because -code/-vars mode still be used in some cases. (bsc#1232762)
- Add 60-ovmf-x86_64-sev.json to descriptors.tar.xz for -code/-vars mode
  against SEV:
  - Removed features tag:
    "acpi-s4", "acpi-s3", "requires-smm", "secure-boot", "enrolled-keys"
  - Add features tag:
    "amd-sev", "amd-sev-es", "amd-sev-snp"
  - The 50-ovmf-x86_64-sev.json is for ovmf-x86_64-sev.bin unified image
    which is stateless mode.
  - The 60-ovmf-x86_64-sev.json is for ovmf-x86_64-sev-code/vars.bin.
    Please note that the -vars storage is non-secure because SEV does NOT
    support SMM (requires-smm).
* Mon Oct 21 2024 Joey Lee <jlee@suse.com>
- Removed the following patch files because they are merged to
  edk2-stable202408:
  - ovmf-EmbeddedPkg-Library-Support-SOURCE_DATE_EPOCH-in-Vir.patch
  - ovmf-NetworkPkg-TcpDxe-Fixed-system-stuck-on-PXE-boot-flo.patch
* Mon Oct 21 2024 Joey Lee <jlee@suse.com>
- Update to edk2-stable202408
  - Features (https://github.com/tianocore/edk2/releases):
    CryptoPkg:Add more crypto APIs (AESGCM/PEM/X509/RSA/PKCS5/PKCS7/Authenticode) based on Mbedtls
    CryptoPkg: Enable Openssl native instruction support for AARCH64
    CryptoPkg: Add support for aes128-sha256 and aes256-sha256 cipher
    UefiCpuPkg: S3 cleanup
    MdePkg/BaseLib: Add CRC16 CCITT False Implementation
    DynamicTablesPkg: ACPI TPM2 generator
    DynamicTablesPkg: Prepare for supporting other archs
    BaseTools: Add VS2022 support
    OvmfPkg: Add LoongArchVirt instance to OvmfPkg and enable it
  - Patches (git log --oneline --date-order edk2-stable202405..edk2-stable202408):
    b158dad150 EmulatorPkg: VS2022 Support on WinHost.
    b0f43dd3fd DynamicTablesPkg: Add parser for Tpm2 CM object
    d24df10cee DynamicTablesPkg: Add HexDump for CM Object parser
    75a9afa540 DynamicTablesPkg: ACPI TPM2 generator
    2bff58935f MdePkg: Tpm2Acpi.h: Max size for Parameters field
    ab6ad2fbdb NetworkPkg/DxeHttpLib: Support HTTP CONNECT message in Tx path.
    9761137743 RedfishPkg: Allow deletion of the bootstrap account
    a29a9cce5f MdePkg/BaseLib: Add CRC16 CCITT False Implementation.
    472be4d139 MdeModulePkg ConPlatform: Support IAD-style USB input devices.
    1b37b3659b .github/request-reviews.yml: Use GitHub App authentication
    51ada84cd5 .github/request-reviews.yml: Move workflow Py code to file
    59ad8aeda6 .github/request-reviews.yml: Formatting (non-functional)
    32a099c358 .github/request-reviews.yml: Improve doc and dbg messages
    f617b6ee0e .github/request-reviews.yml: Only post non-collab message once
    09ad1a0072 .github/request-reviews.yml: Add non-collab admin notification
    e86647decd .github/request-reviews.yml: Update PR reviewer exclusion
    eaf2b82eda .github/request-reviews.yml: Removed unused functionality
    d3e9e10770 .github/request-reviews.yml: Switch to PyGithub
    98f17cdcf4 .github/request-reviews.yml: Switch to GitPython
    057c26710a .github/request-reviews.yml: Cache PIP modules
    38c4cd4e88 .github/request-reviews.yml: Use sparse checkout
    5d43165ff8 UefiCpuPkg: rename and simplify IsAddressValid function
    cff0641360 UefiCpuPkg: remove unneeded code in SmmProfilePFHandler
    8b8ac5d986 UefiCpuPkg: rename the SmiDefaultPFHandler function
    cae90a8390 UefiCpuPkg: Remove duplicate code in SmiPfHandler
    b5c9bbff8e UefiCpuPkg:CpuDeadLoop in SmiPFHandler if SMM profile is disabled
    b3631ca944 UefiCpuPkg: remove unnecessary manipulation for smm page table
    9f29fbd33b UefiCpuPkg: always create full mapping SMM page table
    47bb9f9a97 UefiCpuPkg: Revert "UefiCpuPkg/PiSmmCpuDxeSmm: Fix system..."
    68b4c4b481 BaseTools/Capsule: Support Different Hash Algorithm for Payload Digest
    5ff99e0dab MdePkg /IoRemappingTable: Define additional IORT SMMUv3 node flags.
    159f1aee56 BaseTools/WinRcPath: Improve Performance.
    f203a6db92 OvmfPkg: Pass correct virtio-scsi request size
    24a375fcdd UefiCpuPkg/PiSmmCpuDxeSmm: Avoid use global variable in InitSmmS3Cr3
    8f3e132512 UefiCpuPkg/PiSmmCpuDxeSmm: Clean redundant SmmS3Cr3 Init
    66b4a2f91d UefiCpuPkg/PiSmmCpuDxeSmm: clean unused PCD for S3
    4f5de749cb DynamicTablesPkg/DynamicTableManagerDxe: Adds X64 GetAcpiTablePresenceInfo
    bc0fc75637 DynamicTablesPkg/AcpiFadtLib: Adds FADT X64 generator
    967cbd87b7 DynamicTablesPkg: Adds X64 namespace object
    87d3a6272c UefiCpuPkg/PiSmmCpuDxeSmm: Iterate page table to find proper entry
    24f8b97a9d UefiCpuPkg/PiSmmCpuDxeSmm: Remove assert check for PDE entry not exist
    f73b97fe7f UefiCpuPkg/PiSmmCpuDxeSmm: Check PDE entry exist or not before use
    9d8a5fbd0c UefiCpuPkg/PiSmmCpuDxeSmm: Enable single step after SmmProfile start
    bbee1cc852 DynamicTablesPkg: Fix some spelling mistakes found by cspell
    c26490ea29 EmbeddedPkg: Fix some spelling mistakes found by cspell
    669c5aa240 UefiPayloadPkg: Fix some spelling mistakes found by cspell
    1f6dbab8d9 RedfishPkg: Fix some spelling mistakes found by cspell
    ecb0d1e2cb MdePkg: Fix some spelling mistakes found by cspell
    394cbc4ab2 ArmVirtPkg: Fix some spelling mistakes found by cspell
    7b1646d454 ArmPlatformPkg: Fix some spelling mistakes found by cspell
    cf60ca4366 .pytool: Sort the list of words in cspell.base.yaml
    bd23183ac9 .pytool: Add "MPIDR" to the list of known words in cspell.base.yaml
    b0e7a75a49 ShellPkg/AcpiView: Add MPAM Parser
    3c8133ba87 ShellPkg: acpiview: Add routines to print reserved fields
    8a036c8913 ShellPkg: acpiview: Add routine to print 16 chars
    9e865f9579 ShellPkg/AcpiView: Update print-formatter prototype
    107d0c3800 ShellPkg/AcpiView: Update field-validator prototype
    29619603d2 MdePkg/IndustryStandard: Add definitions for MPAM ACPI specification
    5c9b889b81 IntelFsp2WrapperPkg/FspmWrapperPeim: Fix FspT/M address for measurement
    2d5390053f ArmVirtPkg: Switch all PrePeiCore users to new Sec.inf
    e85e29309e ArmPlatformPkg: Clone PrePeiUniCore into Sec
    91117d70d8 ArmPlatformPkg: Clone PrePiUniCore into PeilessSec
    bbe26ca2cc ArmPlatformPkg/PrePi: Make some functions STATIC
    12dc8d420b ArmPkg/ArmArchTimerLib: Drop pointless constructor
    e76b248d8f ArmPlatformPkg/PrePi: Drop call to TimerConstructor()
    8c10017aa7 ArmVirtPkg/PrePi: Drop call to TimerConstructor()
    1941a901f0 ArmPlatformPkg/PrePi: Drop secondary stack handling
    9c1bc36ad1 ArmPlatformPkg/PrePeiCore: Drop secondary stack handling
    96c8e75681 ArmPlatformPkg/PrePeiCore: Drop MPCore variant
    cee49c82d5 ArmPlatformPkg/PrePi: Drop MPCore variant
    4fc1c513f8 ArmPlatformPkg: Drop bogus reference to MPCore related PCD
    caac25e22e ArmVirtPkg: Drop bogus reference to MPCore related PCD
    a679ceca97 CryptoPkg: Enable Openssl Accel builds for AARCH64
    368f9b62a2 CryptoPkg/OpensslLib: Add AArch64Cap for arch specific hooks
    9403422f21 CryptoPkg/OpensslLib: Generate files for AARCH64 native support
    952ecf53f9 CryptoPkg/OpensslLib: Add native instruction support for AARCH64
    1715d67231 MdePkg/BaseRngLib: Prefer ArmReadIdAA64Isar0Reg() over ArmReadIdIsar0()
    30e53f8b5e MdePkg/BaseLib: AARCH64: Add ArmReadIdAA64Isar0Reg()
    a72d93e163 MdePkg/BaseLib: AARCH64: Add ArmReadCntPctReg()
    71b9bda1ac BaseTools/Scripts/BinToPcd.py: Update regex strings to use raw strings.
    85fad9912c MdePkg: Add PCI Express 6.0 Header Support
    7e5a5ae154 MdePkg/Acpi65.h: Fix GUID value
    eed43245df CodeQlQueries.qls: Pin to the 1.1.0 codeq/cpp-queries pack
    a9158fe9a6 StandaloneMmPkg: Enable SmmLockBoxMmDependency.
    3ada6c0db6 StandaloneMmPkg: Add LockBox Dependency Library
    1fc55a3933 OvmfPkg: Use heap memory for virtio-scsi request
    b342070ce6 OvmfPkg: Use heap memory for virtio-blk request
    02f7ecbbb2 EmbeddedPkg: Retire EfiResetSystemLib and ResetRuntimeDxe
    f9b021f84f OvmfPkg/LoongArchVirtQemu: Drop bogus references to EfiResetSystemLib
    03f49e4409 UefiCpuPkg: remove last instances of EFI_D_
    e2528a5209 OvmfPkg: remove last instances of EFI_D_
    9df400fd4d MdeModulePkg: NvmExpressDxe: Add Timeout Status Codes
    f8f34edd9d MdeModulePkg/UfsPassThruDxe: Migrate UFS Initial Completion Timeout to PCD
    5289ad177d MdeModulePkg/UfsBlockIoPei: Migrate UFS Initial Completion Timeout to PCD
    bc1c890e8e MdeModulePkg: Add the PcdUfsInitialCompletionTimeout in DEC File
    5b08df03f8 MdeModulePkg: Optimize PEI Core Migration Algorithm
    91a822749a BaseTools: fix build error with TOOL_CHAIN_TAG VS2015 & VS2015x86
    621a30c676 MdePkg: IORT header update for IORT Rev E.f spec
    84fc1ec52f MdePkg: Update HEST Revision As 2
    909abd7104 EmbeddedPkg: NonCoherentDmaLib: Set EFI_MEMORY_XP Capability on DMA Buffer
    be1d408773 DynamicTablesPkg: Add EFIAPI to generators hooks
    7537028fa5 DynamicTablesPkg: Fix conversion compiler warnings
    40a0dbdd18 DynamicTablesPkg: FdtHwInfoParserLib: Create wrapper to get INTC addr cells
    d8aa665b31 DynamicTablesPkg: FdtHwInfoParserLib: Move IRQ map to arch folder
    5782aef055 DynamicTablesPkg: FdtHwInfoParserLib: Move ArmLib.h to ArmGicCParser.c
    a7cc72c360 DynamicTablesPkg: FdtHwInfoParserLib: Make Serial Port parser arch neutral
    f16817ec84 DynamicTablesPkg: FdtHwInfoParserLib: Make Pci parser arch neutral
    4bb08e8863 DynamicTablesPkg: FdtHwInfoParserLib: Refactor to prepare for other archs
    e2fda42a22 DynamicTablesPkg: FdtHwInfoParserLib: Move ARM parsers to Arm directory
    47b830db58 DynamicTablesPkg: DynamicTableManagerDxe: Refactor PresenceArray
    dfd867bd83 DynamicTablesPkg: AcpiSsdtCpuTopologyLib: Avoid dependency on GICC
    c6e0eed072 DynamicTablesPkg: AcpiSratLib: Prepare to support other archs
    acaf99827f DynamicTablesPkg: AcpiSpcrLib: Prepare to support other archs
    2e6076edaf DynamicTablesPkg: AcpiDbg2Lib: Prepare to support other archs
    e69e1eea2c DynamicTablesPkg: AcpiFadtLib: Prepare to support other archs
    b242de55e2 DynamicTablesPkg: Acpi: Prepare common libraries to support other archs
    e640c04a7b DynamicTablesPkg: Acpi: Move generic libraries to common folder
    fb6a7147f3 DynamicTablesPkg: Move PSD info to Arch Common
    6466a6e63e DynamicTablesPkg: Move PCC Type 5 info to Arch Common
    e8119798b1 DynamicTablesPkg: Move PCC Type 3 & 4 info to Arch Common
    78b77d9ec4 DynamicTablesPkg: Move PCC Type2 info to Arch Common
    870cf728ef DynamicTablesPkg: Move PCC Type1 info to Arch Common
    db4496d30a DynamicTablesPkg: Move PCC Type0 info to Arch Common
    b0ecf17a31 DynamicTablesPkg: Move PCC structure definitions to Arch Common
    ff249c62e3 DynamicTablesPkg: Move Continuous perf control info to Arch Common
    afa7f8a6b1 DynamicTablesPkg: Move Cache info to Arch Common
    79dd25848e DynamicTablesPkg: Move Processor hierarchy info to Arch Common
    d7a47297cd DynamicTablesPkg: Rename GicCToken field in Processor Hierarchy Info
    ead3b42391 DynamicTablesPkg: Move LPI info object to Arch Common
    0b5abcb90e DynamicTablesPkg: Move Generic Initiator affinity info to Arch Common
    3a644f4a43 DynamicTablesPkg: Move PCI device Handle object to Arch Common
    0ca10ddc0f DynamicTablesPkg: Move ACPI device Handle object to Arch Common
    71b0e9decb DynamicTablesPkg: Move Mem Affinity Info to Arch Common
    11dcf74d42 DynamicTablesPkg: Move Pci Interrupt Map Info to Arch Common
    4333f5c316 DynamicTablesPkg: Move CM_ARM_GENERIC_INTERRUPT struct to Arch Common
    83b01dc5cc DynamicTablesPkg: Move Pci Address Map Info to Arch Common
    ae1ba78718 ArmVirtPkg: Kvmtool: Update Pci Config Space Info in Cfg Manager
    93bb65dcfc DynamicTablesPkg: Move Pci Config Space Info to Arm namespace
    4f29b082e8 DynamicTablesPkg: Move Cm Reference object to Arch Common
    8e9ece1234 DynamicTablesPkg: Move FADT Fixed Features Flags to Arch Common
    87a53216e7 DynamicTablesPkg: Move Hypervisor Vendor Id to Arch Common
    e5d8bd476c DynamicTablesPkg: Move Serial Port Info Objects to Arch Common
    1775c9d51c ArmVirtPkg: Kvmtool: Update Power Mgmt Profile info in Cfg Manager
    4362ddea7f DynamicTablesPkg: Move Power Mgmt Profile Info Object
    6dad45b7dd ArmVirtPkg: Kvmtool: Update ConfigMgr to support ArchCommon
    58c36ce09f DynamicTablesPkg: Drop Reserved29 object ID from Arm Namespace
    b0b0812a6e DynamicTablesPkg: Drop Cpu Info object ID from Arm Namespace
    fc8a16871c DynamicTablesPkg: Update documentation for CM_OBJECT_ID
    9c040c003a DynamicTablesPkg: Update DynamicPlatRepo for Arch Common namespace
    3c2d524ceb DynamicTablesPkg: TokenFixer: Return Non Arm NS objs as unsupported
    af337d1291 DynamicTablesPkg: Add support for ArchCommon objects in CmObjParser
    15ce6edd04 DynamicTablesPkg: Introduce an Arch Common Namespace header file
    cb3c2362cd DynamicTablesPkg: Introduce ObjectId to validate CmObject Parser Array
    991b70c0da DynamicTablesPkg: Replace ProcNodeIdInfo with EArmObjReserved29
    6fb4e7b4ad DynamicTablesPkg/SsdtCpuTopology: Update function's parameter description
    0dacb43505 DynamicTablesPkg: Introduce an Arch Common Namespace
    43e2395c1b MdeModulePkg: fix issue caused by uninitialized variable
    51edd4830d UefiCpuPkg: fix issue when SMM profile is enabled
    ecb1d67775 BaseTools/tools_def CLANGDWARF: Always use -Oz in RELEASE mode
    b7f963d570 FmpDevicePkg: Assert on PcdFmpDeviceImageTypeIdGuid Size Mismatch
    52eb643d07 ArmVirtPkg/ArmVirtQemu: Switch to generic ResetSystemLib
    08c60b40da ArmVirtPkg: Implement DT-based ArmMonitorLib for the PEI phase
    358b19e6bf ArmVirtPkg: Move to generic ArmPsciResetSystemLib
    418b8176b8 ArmPkg: Retire ArmSmcPsciResetSystemLib
    0343e75233 .github/request-reviews.yml: Switch to pull_request_target
    7868d509dd .azurepipelines: Disable the PR gate code coverage job
    d7e36ccbbd MdeModulePkg: Add NVMe Long Delay Time Events
    03ad59e631 MdeModulePkg: Consume SOC related ACPI table from ACPI Silicon HOB
    6589843cc6 BaseTools/codeql: Update to CodeQL 2.18.1
    6830074642 ShellPkg: Add missing apps
    ffc09b51cb MdeModulePkg: Remove EFI_MEMORY_* Defines
    c82ca2bb44 MdePkg: Move MEMORY_TYPE_* Defines to EFI_MEMORY_TYPE Enum
    41426040da BaseTools: Move MEMORY_TYPE_* Defines to EFI_MEMORY_TYPE Enum
    b1bce5e564 ArmPkg/ArmMonitorLib: Implement SMCCC protocol correctly and directly
    43130ae403 ArmPkg: Convert PcdMonitorConduitHvc to FixedAtBuild
    8665187b01 ShellPkg: Correct smbiosview strings for SMBIOS Type0
    556640bcea UefiCpuPkg/MpInitLib: Reduce compiler dependencies for LoongArch
    6271b617b4 .github/workflows/request-reviews.yml: Add workflow
    89a06a245b .github: Add GitHub helper python script
    3f0c4cee94 BaseTools/GetMaintainer.py: Add GitHub username argument
    a96d2a8f2d PrmPkg: Don't Set Access Attributes of Runtime MMIO Ranges
    a7abb77c59 ArmPkg: Introduce ResetSystemLib implementation based on ArmMonitorLib
    a9c8c47d53 ArmPkg: Disable AuditOnly mode for uncrustify
    d4ae23b1e6 ShellPkg: Support parser of MADT for LoongArch64
    9bc7a36120 UefiCpuPkg: Removing redundant parameter in RestoreVolatileRegisters
    6fe3137fe5 UefiCpuPkg: Change RestoreVolatileRegisters second parameter
    3912aa3d32 UefiCpuPkg: Combine the code to set ApInitDone
    9f06e5c702 UefiCpuPkg: Remove ApInitReconfig status
    4a0c77be68 UefiCpuPkg: Let AP always save/restore volatile registers
    7fc08c68cd UefiCpuPkg: Sync the init timer count instead of current timer count
    7033f359a9 UefiCpuPkg: Preserve Local APIC Timer Settings During BSP Switch
    76f441c57c UefiCpuPkg: Also exchange CPU_AP_DATA in SortApicId()
    f5901ff2a4 ArmPkg: Remove Deprecated ArmPsciResetSystemLib
    da591416ee BaseTools: Move GnuNoteBti.bin to BaseTools
    990bc4e562 BaseTools: Move GccLto Files to BaseTools
    f96298d75c ShellPkg/Acpiview: Add HEST Parser
    32e7f9aa6c UefiCpuPkg: Revert "UefiCpuPkg/PiSmmCpuDxeSmm:Map SMRAM in 4K..."
    46eb0ca29b ShellPkg: Changes to print Type17 in Smbiosview
    c5ab17430b ArmPlatformPkg: PL031RealTimeClockLib: Set MMIO Memory XP
    1b8ca81133 ArmVirtPkg: KvmtoolRtcFdtClientLib: Set MMIO Memory NX
    e10de1cb03 ArmPkg: ArmMmuLib: Add AARCH64 Memory Attribute Update Failure Log
    74833ca459 ArmPkg: ArmMmuLib: Add ARM32 Memory Attribute Update Failure Logging
    37287bf9ad ArmPkg: CpuDxe: Add Memory Attribute Protocol Logging
    c5582e435c ArmVirtPkg: QemuVirtMemInfoPeiLib: Allow Dynamic PcdSystemMemorySize
    8984fba2f2 EmbeddedPkg: Mark DMA Memory Allocations XP By Default
    469f29fe76 MdeModulePkg/VariablePolicyLib: Use wildcard character constant
    734aaff862 ArmPlatformPkg: Update LcdHwNullLib to prevent init
    489e4a60ea MdeModulePkg/SmiHandlerProfileInfo: Include profile SMI in profile
    62bf2aefc7 .pytool/Plugin: Improve plugin log messages
    cee9d1b16b MdeModulePkg: DxeCore: Fix Use-After-Free guard causing page fault
    0adc868b36 MdePkg/BaseLib: Optimize LOONGARCH64 csr usage
    11c50d6ca1 MdeModulePkg/UfsBlockIoPei: Wait fDeviceInit Be Cleared by Devices
    23d3fc056d ShellPkg/Acpiview: Add EINJ Parser
    873f35625d MdePkg/IndustryStandard: Update EINJ information according to ACPI 6.5
    5b429acec7 MdePkg/IndustryStandard: Add GET_EXECUTE_OPERATION_TIMINGS define
    c2d6e2e18a MdePkg/IndustryStandard: Add SET_ERROR_TYPE_WITH_ADDRESS define
    dd58d1227c MdePkg: Added support for Smbios 3.7.0 Spec
    e32d24ef8c MdePkg: Define SMBIOS Protocol header according IndustryStandard
    b3441e0100 MdeModulePkg/Core/DxeIplPeim: Enhance Code in DxeIplFindDxeCore Function
    43b7a856fa RedfishPkg: Reduce DEBUG_ERROR to DEBUG_MANAGEABILITY in various places
    6b4dd3625b MdeModulePkg/SmiHandlerProfileInfo: Declare correct XML encoding
    55b043732d MdePkg/UefiDebugLibDebugPortProtocol: ExitBootServicesCallback() static
    690f13fcb4 ArmPlatformPkg/Driver/PL061Gpio: Error checking for pin on release build
    f9c373c838 EmbeddedPkg: Add option to disable EFI Memory Attribute Protocol
    1bb9f47739 BaseTools/CodeQL: Removed unused static function query
    8e6ba0dcae BaseTools/HostBasedUnitTestRunner: Promote Unittest error to CI fail.
    5366def8d0 BaseTools: drop GeneralCheckNonAscii() from ECC
    8ade6d7bd1 BaseTools: fix consistent Ecc misspelling of ASCII
    8bb9145ad1 OvmfPkg: Add network support for LoongArch QEMU platform
    91226e1eec OvmfPkg/RiscVVirt: Configure zkr PCD for Virt
    b54bc983c6 MdePkg/Library: Add RISCV64 support to BaseRngLib
    d4dbe5e101 SecurityPkg/Tcg2Acpi: Revise debug print
    807ab61359 UefiPayloadPkg:Modify the PCD PcieResizableBar to dynamic PCD
    5dc6f19b38 OvmfPkg: Fix the wild pointer in Fdt16550SerialProtHookLib
    b92e16d5c3 BaseTools: Remove fno-plt from LoongArch CC flags
    2b6d0eb434 OvmfPkg/OvmfPkgX64: Set default value of CC_MEASUREMENT_ENABLE to TRUE
    2e7230f1ba IntelFsp2WrapperPkg: FSP measurement based on PcdFspMeasurementConfig
    72d6e247b7 MdePkg/StmApi.h: Add SMM_REV_ID definition for STM header
    f122c6f639 MdeModulePkg/RuntimeResetSystemLib: Make global static
    5c86b0b57c NetworkPkg/HttpDxe: Track HttpInstance URL buffer length.
    071d2cfab8 OvmfPkg/Sec: Skip setup MTRR early in TD-Guest
    0f45be1633 .github: Update pull_request_template.md
    6c061c4715 BaseTools/Ecc: Allow `static` as a modifier
    3abe627f29 RedfishPkg/RedfishPlatformConfigDxe: remove false alarm
    497766f709 ShellPkg: UefiShellDebug1CommandsLib: Conformance Profiles in Dmem.c
    960b6e8309 MdePkg: Adding EBBR EFI_CONFORMANCE_PROFILE_TABLE GUIDs
    3ad878fde5 MdePkg: Adding support for EFI_CONFORMANCE_PROFILE_TABLE
    f46b5b06c6 ShellPkg: UefiShellDebug1CommandsLib: Image Execution Table in Dmem.c
    749065300a ShellPkg: UefiShellDebug1CommandsLib: Dumping RT Properties in Dmem.c
    f91211049c MdeModulePkg: Remove PeiAllocatePool() Assert
    7aaee521a1 FmpDevicePkg: Correct broken Depex in FmpDxe
    426b69830e BaseTools: change non-ASCII characters in LinuxGcc5ToolChain.py
    95a6892aac BaseTools: Add VS2022 support.
    049e12c03d StandaloneMmPkg/Core: Dump all HOB info in entrypoint
    e94cbfc845 UefiPayloadPkg/UefiPayloadEntry: Use HobPrintLib to dump HOBs
    d5b03d5fba MdeModulePkg: Add HobPrintLib instance
    19bcc73213 MdeModulePkg: Add HobPrintLib header file
    d5fad2176c SecurityPkg/Tcg: Correct buffer valid check func
    0986faad97 MdeModulePkg/VariableSmm: Fix NonPrimary Buffer check issue
    8befdb1441 MdeModulePkg/VariableSmm: Add func for Primary Buffer valid check
    acfdb6771c MdeModulePkg/VarCheckPolicyLib: Fix buffer valid check for MM
    c0021d31f8 MdeModulePkg/VarCheckPolicyLib: Update buffer valid check func name
    67d3be644f MdeModulePkg/FaultTolerantWriteSmm: Update buffer valid check func name
    26bc42f1e3 BaseTools/GenerateCapsule.py: Fix checking for DepExp presence
    eeddb86aaa BaseTools/GenerateCapsule.py: Fix inconsistent error formatting
    47c1078175 BaseTools/GenerateCapsule.py: Require --output for --decode
    822ff966c6 BaseTools/GenerateCapsule.py: Better error message on --decode failure
    3be79ece37 BaseTools/GenerateCapsule.py: Disallow UpdateImageIndex == 0 on --encode
    8e7bd66dc1 BaseTools/GenerateCapsule.py: Fix --decode operation
    5a4a7172bc BaseTools/FmpCapsuleHeader.py: Explain error when throwing exceptions
    f8bf46be59 UefiCpuPkg/PiSmmCpuDxeSmm: Consume PcdCpuSmmApSyncTimeout2
    4efcd654ec Revert "UefiCpuPkg/PiSmmCpuDxeSmm: Consume PcdCpuSmmApSyncTimeout2"
    a3359ffb25 OvmfPkg/LoongArchVirt: Optimize the use of serial port libraries
    22d0babd33 MdeModulePkg/StandaloneMmReportStatusCodeLib: Support MM_CORE_STANDALONE
    a1d94d9e6e MdePkg/StandaloneMmServicesTableLib: Support MM_CORE_STANDALONE
    051c7bb434 StandaloneMmPkg: Fix section data length returned larger than actual data
    bef0d333dc UefiCpuPkg/PiSmmCpuDxeSmm: Fix system hang when SmmProfile enable
    9389b9a208 MdePkg/Tdx.h: Fix the order of NumVcpus and MaxVcpus
    ed9a64af1b SecurityPkg/Tcg2Config: avoid potential build error
    2809966189 OvmfPkg: Enable AMD SEV-ES DebugVirtualization
    63a7152471 UefiCpuPkg: Add AMD SEV-ES features support
    9f06feb5d2 OvmfPkg: Add AMD SEV-ES DebugVirtualization feature support
    3f28aa2fb0 MdePkg: Add AMD SEV features to PcdConfidentialComputingGuestAttr
    bc3a1ec2a2 MdePkg/Register/Amd: Define all bits from MSR_SEV_STATUS_REGISTER
    6852f6984b EmbeddedPkg/VirtualRealTimeClockLib: Support SOURCE_DATE_EPOCH
    8430c69dc1 MdePkg/Nvme.h: Add missing NVMe capability descriptions
    cdffb638c8 AmdSev: enable kernel hashes without initrd
    4e36bed812 MdeModulePkg/NvmExpressDxe: use format "0x%%lx" for UINT64 values.
    4f73eef838 MdeModulePkg/NvmExpressDxe: fix format used for Eui64 conversion
    6b9307192b BaseTools: InfBuildData: Fix Private value retrieval
    592725d229 DscCompleteCheck: Allow git ignore syntax
    ed07a2bb11 MdeModulePkg/UsbBusDxe: USB issue fix when the port reset
    4f174696fd .pytool: CompilerPlugin: Pass through build vars
    6b256cef01 OvmfPkg: Create SP800155 HOBs from QemuFwCfgFile
    ff1c4fa168 MdePkg: UefiTcgPlatform.h updates
    b2216427ca EmbeddedPkg/.ci.yaml: add temporary workaround ECC exception
    e939ecf6c1 SecurityPkg: Consume gEdkiiTcg2AcpiCommunicateBufferHobGuid
    9a76c7945b SecurityPkg: Build gEdkiiTcg2AcpiCommunicateBufferHobGuid
    cb6ba975ae SecurityPkg: Add new gEdkiiTcg2AcpiCommunicateBufferHobGuid
    add3ca4e00 SecurityPkg:Consume gEdkiiTcgPhysicalPresenceInterfaceVerHobGuid
    97ede07beb SecurityPkg/Tcg2StandaloneMm:Consume gEdkiiTpmInstanceHobGuid
    cb38d27f1d SecurityPkg/Tcg2ConfigPei: Build two new HOBs
    f9950cceec SecurityPkg:Add new HOB for PhysicalPresenceInterfaceVersion
    5ab96f5437 SecurityPkg: Add a new gEdkiiTpmInstanceHobGuid
    8bf27965db DynamicTablesPkg: AmlLib remove unnecessary cast
    469d09d6b2 DynamicTablesPkg: AmlLib CONST cleanup
    8c09d862bf BaseTools: BinToPcd: Remove xdrlib dependency
    3b2025969e pip: bump edk2-pytool-library from 0.21.5 to 0.21.8
    dc3ed379df UefiCpuPkg/Library: Add MM_STANDALONE type for SmmCpuPlatformHookLib
    ed46e507e6 UefiCpuPkg/Library: Add MM_STANDALONE type for MmSaveStateLib
    a5f147b2a3 pip: bump edk2-pytool-extensions from 0.27.5 to 0.27.6
    6862b9d538 NetworkPkg/DxeNetLib: adjust PseudoRandom error logging
    ae09721a65 MdeModulePkg/DisplayEngineDxe: Support "^" and "V" key on pop-up form
    89377ece8f MdeModulePkg/ImagePropertiesRecordLib: Reduce debug level
    dc002d4f2d CryptoPkg: Fix wrong comment for CryptoPkg
    78bccfec9c OvmfPkg/Sec: use cache type #defines from ArchitecturalMsr.h
    71e6cc8dad UefiCpuPkg/MtrrLib.h: use cache type #defines from ArchitecturalMsr.h
    5bef25dca4 MdePkg/ArchitecturalMsr.h: add #defines for MTRR cache types
    ce4c76e46d OvmfPkg/Sec: Setup MTRR early in the boot process.
    e21bfae345 ReadMe.rst: Add mbedtls submodule license
    0333faf50e ArmPkg: delete PcdArmArchTimerFreqInHz
    7ee89453b5 ArmVirtPkg: drop use of PcdArmArchTimerFreqInHz
    a715d456de ArmPkg: drop manual ARM programming of generic timer frequency
    2fbaaa96d1 MdePkg/BaseLib: Fix an instruction write width error in LoongArch64
    5db0091418 UefiCpuPkg/ExceptionHandler: Fix a context error in LoongArch64
    dc93ff8a55 CryptoPkg: Extend TLS handshake debug output
    84d8eb08e1 CryptoPkg: Add SNI extension to TLS ClientHello
    10b4bb8d6d AmdSev: Halt on failed blob allocation
    56059941ec AmdSev: Rework Blob Verifier
    be38c01da2 OvmfPkg: refine TdTcg2Dxe
    d512bd3129 UefiCpuPkg: Correct the count of different type of Cache.
    57a890fd03 MdePkg: Check if compiler has __has_builtin before trying to use it
    95e220e95d MdePkg/ArmLib: Drop obsolete library declarations
    e76be772aa ArmPkg/ArmLib ArmMmuLib: Drop support for EL3/MON execution
    4d4f569924 MdeModulePkg: Avoid efi memory allocation for SP memory
    26a30abdd0 MdeModulePkg/DxeCapsuleLibFmp: Fix compilation error
    c1d1910be6 OvmfPkg/QemuVideoDxe: add feature PCD to remap framebuffer W/C
    ffce430d2b OvmfPkg/BhyvePkg: honor FwCfg when setting the bootorder
    bfda27ddc8 Maintainers.txt: Update maintainers and reviewers for OvmfPkg/LoongArchVirt
    7a1739d896 OvmfPkg/PlatformCI: Add CI coverage for LoongArchVirtQemu
    c2d6efaef9 OvmfPkg/LoongArchVirt: Add self introduction file
    d6dcf621df OvmfPkg/LoongArchVirt: Add build file
    e5e2cf48a9 OvmfPkg/LoongArchVirt: Support PEI phase
    9912434785 OvmfPkg/LoongArchVirt: Support SEC phase
    c63d90085b OvmfPkg/LoongArchVirt: Add reset system library
    79835e08f5 OvmfPkg/LoongArchVirt: Add real time clock library
    74433f66b1 OvmfPkg: Add a new GUID called gRtcRegisterBaseAddressHobGuid
    ab4b1f113d OvmfPkg/LoongArchVirt: Add the early serial port output library
    05f74f1ca7 OvmfPkg/LoongArchVirt: Add serial port hook library
    ace279c036 OvmfPkg/LoongArchVirt: Add CpuMmuInit library
    e3e27f22d2 OvmfPkg/LoongArchVirt: Add stable timer driver
    b0c5781671 .devcontainer: bump Fedora version to 39
    176b9d41f8 MdeModulePkg/Core/Pei: Install MigrateTempRamPpi
    537a81ae81 MdePkg/Include: Update AMD specification references
    a9def1ed9d MdePkg/Include: Update Msr.h header guard define
    17424fae4f MdePkg/Include: Remove deprecated AMD SEV-SNP header file
    55c3ecde32 UefiCpuPkg/MpInitLib: Update references to SEV-SNP header file
    d40c71ef3f MdePkg/Include: Update reference to SEV-SNP header file
    6eaeef2c9b MdePkg/Include: Add AMD SEV-SNP header file
    128513afcd MdeModulePkg:Add global variable mVariableRtCacheInfo
    081df0ec20 MdeModulePkg: Refine InitVariableCache()
    92974e3d18 MdeModulePkg:Remove the usage of PcdEnableVariableRuntimeCache
    689f415a49 MdeModulePkg:Consume gEdkiiVariableRuntimeCacheInfoHobGuid
    c1c2e474a2 MdeModulePkg:Remove unneed FreePages for RuntimeHobCacheBuffer
    645d9f6f8d MdeModulePkg:Remove unnecessary global variables
    d8f513de3e MdeModulePkg:Create gEdkiiVariableRuntimeCacheInfoHobGuid
    025a95b7ed MdeModulePkg:Add new gEdkiiVariableRuntimeCacheInfoHobGuid
    9fc61309bf ArmPkg/ProcessorSubClassDxe: Limit values to 0xFF
    587100a95d UefiCpuPkg/SmmCpuSyncLib: Add MM_STANDALONE tag.
    a7dbd2ac7b CryptoPkg: Fix strncpy for BaseCryptLibMbedTls
    aa99d36be9 BaseTools/BuildReport: Improve compile_commands generation
    d8095b36ab ArmPkg/CompilerIntrinsicsLib: provide __ashlti3
    a84876ba28 OvmfPkg/Xen: Fix use of networking
    cf323e2839 ArmPkg,MdePkg: Move ArmPkg/Chipset/Aarch64[|Mmu].h to MdePkg
    c68fb69dfe ArmPkg,MdePkg: Move ArmPkg/Chipset/ArmV7[|Mmu].h to MdePkg
    f2b9d5417d ArmPkg,MdePkg: move ArmLib.h to MdePkg
    5e776299a2 MdePkg/X86UnitTestHost: set rdrand cpuid bit
    94961b8817 CryptoPkg/Test: call ProcessLibraryConstructorList
    ce91687a1b OvmfPkg: Override PcdCpuSmmApSyncTimeout2 to 10ms
    870c1ae253 UefiCpuPkg: Refine the PCD usage comment
    cb3134612d UefiCpuPkg/PiSmmCpuDxeSmm: Consume PcdCpuSmmApSyncTimeout2
    af2bbe1b79 UefiCpuPkg: Add PcdCpuSmmApSyncTimeout2 PCD
    712797cf19 OvmfPkg: wire up RngDxe
    a61bc0accb SecurityPkg/RngDxe: add rng test
    c3a8ca7b54 MdePkg/BaseRngLib: Add a smoketest for RDRAND and check CPUID
    d3b32dca06 MdePkg/BaseLib: Let CpuDeadLoop() be breakable in debugger
    0982da4f50 UefiPayloadPkg: Enable UPL FIT build config from cmdline
    6d15276ced UefiPayloadPkg: Fix LoadDxeCore for payload size > 16MB
    3dcc7b73df ArmPkg: Revert "Allow SMC/HVC monitor conduit to be specified at runtime"
    2c19297e6c ArmVirtPkg/ArmVirtQemu: Revert "Permit the use of dynamic PCDs in PEI"
    7bcd49edd0 ArmVirtPkg: Revert "Use dynamic PCD to set the SMCCC conduit"
    059676e4fa ArmVirtPkg/ArmVirtQemu: Implement ArmMonitorLib for QEMU specifically
    5bea691233 ArmVirtPkg/PrePi: Enable VFP before calling into C code
    ab069d5801 OvmfPkg/QemuVideoDxe: purge VbeShim
    c36414b131 MdeModulePkg/DxeCapsuleLibFmp: Fix crash if no ESRT is found
    948f234170 CryptoPkg: Fix BaseCryptLib CrtWrapper strncpy and strcat
    df8c61e4c0 CryptoPkg: Fix BaseCryptLib CrtWrapper strcpy
    8c826be35c MdeModulePkg: In RemoveTableFromRsdt don't read from unallocated memory
    665b223d57 ShellPkg/Pci.c: Update supported link speed to PCIe Gen6
    80b59ff832 MdeModulePkg: Warn if out of flash space when writing variables
    f9c2f2fa0f BaseTools/Scripts: Fix PatchCheck commit range
    71606314f8 CryptoPkg: Fix wrong logic in X509GetTBSCert
    90cb1ec332 OvmfPkg/PlatformInitLib: allow PhysBits larger than 48
    603ad2d6ae OvmfPkg/PlatformInitLib: add support for GuestPhysBits
    65b0d08786 MdeModulePkg/HiiDatabaseDxe: Remove assert for VarStoreId = 0
    b45aff0dc9 OvmfPkg: add morlock support
    10ab1c67c4 ArmVirtPkg: Remove the NorFlashQemuLib
    10cd8b45ce MdePkg: Remove non-ASCII characters from header file
    e2e09d8512 MdePkg: Add Ipmi Net Sensor Thresholds command defines.
    7772e339bd ArmVirtPkg: Enable the non-hardcode version FdtNorFlashQemuLib
    cac1ea6c2a OvmfPkg: Add no hardcode version of FdtNorFlashQemuLib
    de4cc40b8c MdeModulePkg/HiiDatabaseDxe: Avoid struct assignment
    839bd17973 UefiCpuPkg:fix issue when splitting paging entry
    077760fec4 UefiCpuPkg: Remove GetAcpiCpuData() in CpuS3.c
    e3b3e907e1 MdeModulePkg:Remove MpService2Ppi field in SMM_S3_RESUME_STATE
    d390b163f8 UefiCpuPkg: Remove unneeded MpService2Ppi assignment
    341ee5c31b UefiCpuPkg:Remove code to wakeup AP and relocate ap
    525578bdd5 UefiCpuPkg:Remove code to handle APIC setting and Interrupt
    cdc1a88272 UefiCpuPkg:Relocate AP to new safe buffer in PeiMpLib
    669291db5a UefiCpuPkg: Install gEdkiiEndOfS3ResumeGuid in S3Resume
    fcd09b1edb UefiCpuPkg:Move some code in DxeMpLib to common place
    68310cd56a UefiCpuPkg:Abstract some DxeMpLib code to function
    ffb8481ba8 UefiCpuPkg: Disable PG in IA32 ApLoopCode
    7421ea1f2a UefiCpuPkg: Remove code to set register table
    b7db4d895a UefiCpuPkg:Set PcdCpuFeaturesInitOnS3Resume to TRUE
    db4101c308 UefiCpuPkg: Remove code to load mtrr setting
    ad245ffeff UefiCpuPkg: LoadMtrrData for all cpu in S3Resume
    3a516aa240 UefiCpuPkg: Save MTRR by lockbox in CpuS3DataDxe
    32a9ee736e UefiCpuPkg: Add locbox lib instance in DSC
    52a4bc65f6 OvmfPkg: Save MTRR by lockbox in CpuS3DataDxe
    87f22f4b5c MdeModulePkg: Add gEdkiiS3MtrrSettingGuid
    27b044605c ArmPkg: Set BIOS Segment to 0 in SMBIOS Type 0 table
    b0930e3f4e CryptoPkg/BaseCryptLib: Enable more functions for SMM/StandaloneMM
    de2330450f MdeModulePkg: Update GCD attribute conversion to support SP attribute
    7339bfeffa OvmfPkg/VirtioRngDxe: check if device is ready
    3b36aa96de CryptoPkg: Remove deprecated code related to SHA-1
    7c584bb048 CryptoPkg: Fix bug for correct return value checking when get X509Cert
    746cc5cc40 CryptoPkg: Add support for aes128-sha256 and aes256-sha256 cipher
    5f68a363d0 pip: bump edk2-pytool-extensions from 0.26.4 to 0.27.5
    a8dc6bf73f pip: bump edk2-pytool-library from 0.20.0 to 0.21.5
    ced13b93af NetworkPkg TcpDxe: Fixed system stuck on PXE boot flow in iPXE environment
    e784848116 pip: bump regex from 2023.12.25 to 2024.5.15
    9518d77eb8 OvmfPkg: Update VMM Hob list check to support new resource attributes
    c695e3182a MdePkg: Add Ipmi definitions header file for OEM net function
    cd4cebabf5 UefiPayloadPkg: Update ReadMe.md to swig install
    843f2d0964 EmulatorPkg: fix build error.
    30b6d08e27 StandaloneMmPkg: Initialize 'WillReturn' variable
    b40c64ec25 MdeModulePkg/SMM: Initialize 'WillReturn' variable
    79655e2768 SecurityPkg: Update libspdm submodule to use GitLab cmocka repo
    55f8bddade .github: Add PR template
    0e3189d406 BaseTools/Scripts: Remove Cc: tag check from PatchCheck.py
    08281572aa Add SM3 functions with openssl for Mbedtls
    ed7a3143b7 CryptoPkg: Update *.inf in BaseCryptLibMbedTls
    3096fcf81d CryptoPkg: Add ImageTimestampVerify based on Mbedtls
    27a7345882 CryptoPkg: Add AuthenticodeVerify based on Mbedtls
    b5412646db CryptoPkg: Add more RSA related functions based on Mbedtls
    e065735b1b CryptoPkg: Add Pkcs5 functions based on Mbedtls
    acfd991b68 CryptoPkg: Add Pkcs7 related functions based on Mbedtls
    40fa5cf299 CryptoPkg: Add X509 functions based on Mbedtls
    f44cc28972 CryptoPkg: Add Pem APIs based on Mbedtls
    8deeda7ce0 CryptoPkg: Add rand function for BaseCryptLibMbedTls
    1d8fedb0cd CryptoPkg: Add AeadAesGcm based on Mbedtls
    88a4de450f UefiCpuPkg/MpLib:Do not assume BSP is #0.
  - Removed patches which are merged to edk2-stable202408:
  - ovmf-EmbeddedPkg-Library-Support-SOURCE_DATE_EPOCH-in-Vir.patch (bsc#1217704)
    6852f6984bda EmbeddedPkg/VirtualRealTimeClockLib: Support SOURCE_DATE_EPOCH
  - ovmf-NetworkPkg-TcpDxe-Fixed-system-stuck-on-PXE-boot-flo.patch (bsc#1230587)
    ced13b93afea NetworkPkg TcpDxe: Fixed system stuck on PXE boot flow in iPXE environment
  - Add pylibfdt as new submodule
  - pylibfdt-cfff805481bdea27f900c32698171286542b8d3c.tar.gz
  - https://github.com/devicetree-org/pylibfdt/archive/cfff805481bdea27f900c32698171286542b8d3c.tar.gz
  - https://github.com/devicetree-org/pylibfdt/
  - edk2 commit ids:
    10416bf46e7e Tianocore: Support FDT library.
  - Updated ovmf.spec
  - unpacked pylibfdt-cfff805481bdea27f900c32698171286542b8d3c.tar.gz to MdePkg/Library/BaseFdtLib/libfdt
  - We also got image size issue when cross compiling x86_64 FD_SIZE_2MB image
    on aarch64 environment. So using x86_64-suse-linux-gcc-12 on SLE15-SP7 or
    Leap 15.4 codebases. Here is the pseudocode in ovmf.spec:
    ifnarch x86_64
    BuildRequires:  cross-x86_64-binutils
    if sle_version >= 150500 && sle_version <= 150700
    BuildRequires:  cross-x86_64-gcc12
    else
    BuildRequires:  cross-x86_64-gcc+gcc_version
    endif
    endif
  - The x86_64-suse-linux-gcc-12 be auto-linked to x86_64-suse-linux-gcc
    after installed cross-x86_64-gcc12. So we don't need to add any
    downstream patch for corss compiling x86_64 2MB image on aarch64.
* Wed Oct  9 2024 Joey Lee <jlee@suse.com>
- Add ovmf-MdePkg-DebugLib-Enable-FILE-NAME-as-DEBUG-ASSERT-for.patch
  '5c8bdb190f6d MdePkg DebugLib: Enable FILE NAME as DEBUG ASSERT for GCC12'
  (bsc#1230425)
- Using gcc12 for building x86_64 ovmf image:
  As the item 'Changed the approach for creating the edk2 source code tarball'
  in 'Update to edk2-stable202405' change log. We modified the folder name in
  edk2-edk2-stable%%{version}.tar.gz source code tarball to avoid the size
  problem against FD_SIZE_2MB config. (bsc#1230425)
  We can use gcc-12 to avoid the size problem because gcc-12 supported
  __FILE_NAME__ macro for reproducing the size of firmware image. So we
  applied the above 5c8bdb190f6d patch and aldo the following SLE15-SP7/
  Leap 15.7 specific patch for setting the gcc-12 as the default compiler
  for x86_64 ovmf:
  - ovmf-BaseTools-Using-gcc12-for-building-image.patch
    'BaseTools: Using gcc12 for building x86_64 ovmf image'
  - This patch only be applied to x86_64 image when building on SUSE
    15.5/15.6/15.7 codebases. Here is the pseudocode in ovmf.spec:
    ifarch x86_64
    if sle_version >= 150500 && sle_version <= 150700
    Patch13 ovmf-BaseTools-Using-gcc12-for-building-image.patch
    endif
    endif
    The main target is SLE15-SP7 and Leap 15.7. The SUSE 15.5/15.6 is
    for building in Virtualization development project on OBS:
- Changed the edk2-edk2-stable202405.tar.gz back to the tarball which directly
  downloading from https://github.com/tianocore/edk2.
  Because we moved to gcc-12 for reducing the size of firmware image.
  - Against this change, we modified the setup command in %%prep section in
    ovmf.spec back to original statement:
    new: %%setup -q -n edk2-edk2-stable%%{version}
    old: %%setup -q -n edk2
* Wed Sep 18 2024 Fabian Vogt <fvogt@suse.com>
- ovmf-rpmlintrc: Add wildcard to make the filter effective on 15.x
  again
* Wed Sep 18 2024 Joey Lee <jlee@suse.com>
- Add ovmf-NetworkPkg-TcpDxe-Fixed-system-stuck-on-PXE-boot-flo.patch
  NetworkPkg TcpDxe: Fixed system stuck on PXE boot flow in
  (bsc#1230587)
* Mon Sep  9 2024 Joey Lee <jlee@suse.com>
- Update to edk2-stable202405
  - Features (https://github.com/tianocore/edk2/releases):
    MAT Logic Incorrectly Reports Runtime Images
    SecurityPkg:Add EFI Device Authentication Signature Database and SPDM
    CryptoPkg:add additional RSAES-OAEP crypto functions
    OvmfPkg:Add 5-level paging support
    OvmfPkg:SEV-SNP Support for running under an SVSM
    OvmfPkg:RBP register shall be cleared in TDVMCALL
    OvmfPkg:Harden #VC instruction emulation (CVE-2024-25742)
    Add SPI bus driver stack
    NetworkPkg: Predictable TCP ISNs
    NetworkPkg: Use of a Weak PseudoRandom Number Generator
    UefiCpuPkg: Add new SmmRelocationLib library
  - Patches (git log --oneline --date-order edk2-stable202402..edk2-stable202405):
    3e722403cd ArmVirtPkg/ArmVirtQemu: Add RngDxe driver
    66c69871e7 ArmVirtPkg: Reverse inclusion order of MdeLibs.inc and ArmVirt.dsc.inc
    c98f7f7550 ArmVirtPkg: Use dynamic PCD to set the SMCCC conduit
    865229bcc8 ArmVirtPkg/ArmVirtQemu: Permit the use of dynamic PCDs in PEI
    4ddf2448ed MdePkg/BaseRngLib AARCH64: Remove overzealous ASSERT()
    9440986d4e ArmVirtPkg: Move PcdMonitorConduitHvc
    32460bb5b1 ArmPkg: Allow SMC/HVC monitor conduit to be specified at runtime
    207b6d68a0 NetworkPkg: Update the PxeBcDhcp6GoogleTest due to underlying changes
    dff3d3811f MdePkg: Add MockHash2 Protocol for testing
    4afb939531 MdePkg: Adds Protocol for MockRng
    72a9ef1c8a MdePkg: Add MockUefiBootServicesTableLib
    1904a64bcc NetworkPkg TcpDxe: SECURITY PATCH CVE-2023-45236
    4c4ceb2ceb NetworkPkg: SECURITY PATCH CVE-2023-45237
    a85336531c SecurityPkg RngDxe: Remove incorrect limitation on GetRng
    e10d83234c ArmVirtPkg: Add Hash2DxeCrypto to ArmVirtPkg
    677204f941 ArmVirtPkg PlatformCI: Support virtio-rng-pci
    cb9d711891 OvmfPkg: Add Hash2DxeCrypto to OvmfPkg
    4f58e0cf99 OvmfPkg PlatformCI: Support virtio-rng-pci
    024a291b3e EmulatorPkg: Add Hash2DxeCrypto to EmulatorPkg
    319bb7223a EmulatorPkg: Add RngDxe to EmulatorPkg
    7142e64841 CodeQL: Update from 2.16.1 to 2.17.3
    284dbac43d MdeModulePkg: Potential UINT32 overflow in S3 ResumeCount
    558a25366d MdePkg/BaseLib: Fix AARCH64 compilation error
    4b6ee06a09 MdePkg: Add MmUnblockMemoryLib to MdeLibs.dsc
    3c0b84420f DynamicTablesPkg: Adds integer to the AML package node
    25996a3441 MdePkg: Updated SpcrTable structure for Revision_4
    b82c9631da OvmfPkg: Use newly defined Unaccepted Memory Type
    f3b0ee0cee MdePkg: Update Delayed Dispatch PPI as per PI 1.8 Spec
    09340de246 MdeModulePkg: Use newly defined Unaccepted Memory Type
    6fd2d58d5d MdePkg: Define Unaccepted Memory Type
    b538d6a1b1 MdePkg: Add new Resource Attributes defined in PI 1.8 Spec
    b04e11b4c4 MdePkg: Add definition for NVMe Over Fabric Device Path
    5cbfb93abe UefiCpuPkg/Library: Support to get processor extended info
    952b5cf94c MdeModulePkg: Adding SpiHc Drivers
    82b0358e3f MdeModulePkg: SpiHc: SpiHc Drivers
    5590cefe93 MdeModulePkg:BaseSpiHcPlatformLib: Adding NULL lib instance
    916f495e77 MdeModulePkg: Adding SpiBus Drivers
    efc7ccf906 MdeModulePkg/Bus/Spi/SpiBus: Adding SpiBus Drivers
    fa7fdb89a3 MdePkg/SpiConfiguration: Correct the definition spelling
    2727231b0a UefiCpuPkg/PiSmmCpuDxeSmm: Remove SmBases relocation logic
    23ed7f209c UefiPayloadPkg/UefiPayloadPkg.dsc: Include SmmRelocationLib
    6b3a89a9fd OvmfPkg/PlatformPei: Relocate SmBases in PEI phase
    4a6400b084 OvmfPkg/SmmCpuFeaturesLib: Check Smbase Relocation is done or not
    04c36d5a1b OvmfPkg: Refine SmmAccess implementation
    6a468a8b55 OvmfPkg/PlatformInitLib: Create gEfiSmmSmramMemoryGuid
    3dfd64305b OvmfPkg/SmmRelocationLib: Add library instance for OVMF
    47f212295f UefiCpuPkg/SmmRelocationLib: Add library instance for AMD
    c56ea95b28 UefiCpuPkg/SmmRelocationLib: Remove unnecessary CpuIndex
    9783dc01cc UefiCpuPkg/SmmRelocationLib: Remove unnecessary global variable
    7421094136 UefiCpuPkg/SmmRelocationLib: Avoid unnecessary memory allocation
    42e8fa84f7 UefiCpuPkg/SmmRelocationLib: Rename global variables
    51fcd2023b UefiCpuPkg/SmmRelocationLib: Add SmmRelocationLib library instance
    af9b851732 UefiCpuPkg: Add SmmRelocationLib class
    987bea6525 UefiCpuPkg/PiSmmCpuDxeSmm: Handle the NULL gMpInformation2HobGuid
    1c0d4ae2c0 MdeModulePkg/XhciDxe: Add PCD for the delay of HCRST
    c12bbc1490 MdeModulePkg/XhciDxe: Reset endpoint while USB Transaction error
    17f333f2a4 OvmfPkg: Add sp800155Event3 support
    7097c97bde SecurityPkg: Recognize sp800155Event3 event
    370c55b2ba MdePkg: Add TcgSp800155Event3 type info
    24fa360857 RedfishPkg: Rename x-uefi-redfish to x-UEFI-redfish
    248aa153f6 IntelFsp2Pkg/PatchFv.py: FIX for GCC 32BIT build error
    fecf55a66a OvmfPkg/CcExitLib: Drop special handling for Encrypted MMIO to APIC
    f0ed194236 OvmfPkg: Don't make APIC MMIO accesses with encryption bit set
    fd290ab862 OvmfPkg/ResetVector: Clear SEV encryption bit for non-leaf PTEs
    5f783827bb Maintainers.txt: Update my email address
    5d4c5253e8 Maintainers.txt: Update StandaloneMmPkg and UefiCpuPkg Reviewer
    ec6e59aefe OvmfPkg: Remove QemuFwCfgLibMmio.inf
    1699845c5f OvmfPkg/RiscVVirt: Enable QemuFwCfgMmioDxeLib.inf
    3a4efc98b0 ArmVirtPkg: Enable QemuFwCfgMmioDxeLib.inf
    3d87214a20 OvmfPkg: Copy the same new INF as QemuFwCfgLibMmio.inf
    fcce7f77e6 OvmfPkg: Add the QemuFwCfgMmioLib PEI stage version
    748d57d40f OvmfPkg: Add the way of HOBs in QemuFwCfgLibMmio
    5e31c5666d OvmfPkg: Separate QemuFwCfgLibMmio.c into two files
    e942b85a21 OvmfPkg: Add a GUID for QemuFwCfgLib
    0c74aa2073 UefiCpuPkg/Library: Cleanup debug message in LmceSupport
    88781ccd74 ReadMe.rst: Add libspdm submodule license
    54a4fd9b35 SecurityPkg: Add libspdm submodule
    9bc2725198 .gitmodule: Add libspdm submodule for EDKII
    cf3b34c0b8 .pytool/CISettings.py: add libspdm submodule.
    750d763623 SecurityPkg: add DeviceSecurity support
    c3f615a1bd SecurityPkg: Add TCG PFP 1.06 support.
    d8e4c4b000 MdeModulePkg/Variable: Add TCG SPDM device measurement update
    74db2ed3e5 MdePkg: Add devAuthBoot GlobalVariable
    5f391c6606 MdePkg: Add TCG PFP 1.06 support.
    338fd26b8f MdePkg: Add SPDM1.2 support.
    094727264f MdePkg: Add Cxl30.h into IndustryStandard
    c0dfe3ec1f BaseTools/GetUtcDateTime.py: Python 3.12 support
    66c24219ad OvmfPkg/VirtHstiDxe: do not load driver in confidential guests
    90b6725562 Update to CodeQL 2.16.1
    d97f964f7c BaseTools/Fmmt.py: Python 3.12 support
    e3fa6986ae OvmfPkg: Harden #VC instruction emulation somewhat (CVE-2024-25742)
    86c8d69146 IntelFsp2Pkg/PatchFv.py: Python 3.12 support
    680030a6ec IntelFsp2Pkg/GenCfgOpt.py: Python 3.12 support
    7dd7b89058 ArmVirtPkg/ArmVirtQemu: always build XIP code with strict alignment
    f29160a896 OvmfPkg/VirtHstiDxe: add README.md
    506740982b OvmfPkg/VirtHstiDxe: add code flash check
    ddc43e7a41 OvmfPkg/VirtHstiDxe: add varstore flash check
    538b8944c1 OvmfPkg: Add VirtHstiDxe to OVMF firmware build
    d0906f602b OvmfPkg: Add VirtHstiDxe driver
    be92e09206 OvmfPkg/IntelTdx: Update TDVF README
    6780b3aba0 Maintainers: AMD as SPI driver stack maintainer
    1dc752d903 MdeModulePkg: Add SPI NOR FLash SFDP drivers to DSC
    8b02ecc5f0 MdeModulePkg/SpiNorFlashJedecSfdp: SPI NOR Flash JEDEC SFDP
    6dc09fda04 MdeModulePkg: Add definitions in DEC for SPI NOR Flash SFDP driver
    390b10b548 MdePkg/Include: Add SPI NOR Flash JEDEC SFDP header file
    7dec566775 MdePkg/Include: Update definitions of SPI related header files
    0afb874349 OvmfPkg/BaseMemEncryptLib: Check for presence of an SVSM when not at VMPL0
    47001ab989 Ovmfpkg/CcExitLib: Provide SVSM discovery support
    a010681f74 UefiCpuPkg/MpInitLib: AP creation support under an SVSM
    28fecae8a3 OvmfPkg/AmdSvsmLib: Add support for the SVSM create/delete vCPU calls
    18fdffe825 OvmfPkg/BaseMemEncryptSevLib: Maximize Page State Change efficiency
    b505f11f39 OvmfPkg/AmdSvsmLib: Add support for the SVSM_CORE_PVALIDATE call
    5a67a2efa7 OvmfPkg: Create a calling area used to communicate with the SVSM
    f6bf37c171 OvmfPkg/BaseMemEncryptSevLib: Use AmdSvsmSnpPvalidate() to validate pages
    ee89b59430 UefiCpuPkg/MpInitLib: Use AmdSvsmSnpVmsaRmpAdjust() to set/clear VMSA
    6ced1e91ef Ovmfpkg/AmdSvsmLib: Create AmdSvsmLib to handle SVSM related services
    789727ccf3 Ovmfpkg: Prepare OvmfPkg to use the AmdSvsmLib library
    d2b18e6bc2 UefiPayloadPkg: Prepare UefiPayloadPkg to use the AmdSvsmLib library
    30d274e354 UefiCpuPkg/AmdSvsmLib: Create the AmdSvsmLib library to support an SVSM
    c0bf953fe8 MdePkg/BaseLib: Add a new VMGEXIT instruction invocation for SVSM
    8ccbf075f0 MdePkg/Register/Amd: Define the SVSM related information
    069f9911a3 OvmfPkg/BaseMemEncryptSevLib: Maximize Page State Change efficiency
    2b330b57db OvmfPkg/BaseMemEncryptSevLib: Re-organize page state change support
    f40c1f2a30 MdePkg: Avoid hardcoded value for number of Page State Change entries
    5fe9db0f82 OvmfPkg/BaseMemEncryptSevLib: Calculate memory size for Page State Change
    6b14ef6b28 OvmfPkg/BaseMemEncryptSevLib: Fix uncrustify errors
    4bd3b5ab13 OvmfPkg/PlatformPei: Retrieve APIC IDs from the hypervisor
    5bdb091133 UefiCpuPkg/MpInitLib: Always use AP Create if GhcbApicIds HOB is present
    8a6471819b MdePkg: GHCB APIC ID retrieval support definitions
    c212fec9cf OvmfPkg/BaseMemEncryptLib: Fix error check from AsmRmpAdjust()
    61185f1d50 SecurityPkg: Delete TdTcg2Dxe and HashLibTdx in SecurityPkg
    93fac4fd7b OvmfPkg: Update TdTcg2Dxe path in OvmfPkgX64 and IntelTdxX64.dsc
    c98fbda328 OvmfPkg/TdTcg2Dxe: Add TdTcg2Dxe
    93ff80a218 OmvfPkg/HashLibTdx: Add HashLibTdx
    71aaf7a308 Security/SecTpmMeasurementLibTdx: Delete unused SecTpmMeasurementLibTdx
    fcfdbe2987 NetworkPkg/WifiConnectionManagerDxe: Update UI according to UEFI spec
    b6cd5ddce9 SecurityPkg/OpalPasswordDxe: Force reparsing IFR binary when RETRIEVE
    32e2968a1e SecurityPkg/OpalPasswordDxe: Change callback action to meet UEFI spec
    7ea05d8fe9 ShellPkg/SmbiosView: Support New ProcessorUpgrade for SMBIOS Type4
    bfcf2d66c7 MdePkg/SmBios.h: Add New ProcessorUpgrade definitions for SMBIOS Type4
    6363872629 UefiCpuPkg/UefiCpuPkg.dsc: Add CpuMmio2Dxe.inf to LoongArch64 field
    0b2f97c00a UefiCpuPkg: Add CpuDxe driver for LoongArch64
    abaf405ed9 UefiCpuPkg: Add multiprocessor library for LoongArch64
    392a368533 UefiCpuPkg: Add a new GUID to store the processors resource
    032830e968 UefiCpuPkg: Add CpuMmuLib to UefiCpuPkg
    c5fb47ddab UefiCpuPkg: Added a new PCD named PcdLoongArchExceptionVectorBaseAddress
    78e5019071 UefiCpuPkg: Add CpuMmuLib.h to UefiCpuPkg
    7750468c37 UefiCpuPkg: Add CPU exception library for LoongArch
    439030bc37 UefiCpuPkg: Add LoongArch64 CPU Timer instance
    cc63e04afc UefiCpuPkg/CpuDxe: Reorder the INF file alphabetically
    022ddb8f84 UefiCpuPkg/MpInitLib: Reorder the INF files alphabetically
    fecca982e3 UefiCpuPkg/CpuExceptionHandlerLib: Reorder the INF files alphabetically
    18ad6485a9 UefiCpuPkg/CpuTimerLib: Reorder the INF file alphabetically
    70892b13b2 StandaloneMmPkg: Support to unregister MMI handler in MMI handlers
    74f6ce6734 MdeModulePkg/SMM: Support to unregister SMI handler in SMI handlers
    da7858117f Revert ae1079b386a597108a8070652bf7cdaa4ec3dda3
    b594fba4ec Revert 17b28722008eab745ce186b72cd325944cbe6bf0
    de95e919be Revert 049ff6c39c73edd3709c05bd0e46184320471358
    31cd5ee8c0 Revert 2ec8f0c6407f062441b205b900038933865c7b3c
    5ba3602e45 BaseTools: Use Stronger Matching for NULL Linked Libraries
    d77efa2ebe BaseTools: Don't Recurse NULL Includes Not Linked to Module
    0707d9296d SecurityPkg/Tcg2Config: Hide BIOS unsupported hash algorithm from UI
    e25808f501 MdePkg: Update the comments of GetInformation function
    98f150a954 MdeModulePkg/AcpiTableDxe: Prefer xDSDT over DSDT when installing tables
    963671d380 ShellPkg: Update smbiosview type 4 with SMBIOS 3.6 fields
    665789b61b IntelFsp2WrapperPkg: Fsp T UPD Structure Bug Fix
    013006e4ef IntelFsp2WrapperPkg: Fsp T new ARCH UPD Support
    543add1d41 IntelFsp2Pkg: Fsp T new ARCH UPD Support
    932db9df0c MdeModulePkg/AcpiTableDxe: PCD switch to avoid using ACPI reclaim memory
    b7f8779fe1 OvmfPkg/RiscVVirt: Disable Svpbmt extension
    3d5352d934 UefiCpuPkg: RISC-V: MMU: Support Svpbmt extension
    6ddfbeb0d6 UefiCpuPkg: RISC-V: MMU: Explictly use UINT64 instead of UINTN
    f1203a4099 MdePkg.dec: RISC-V: Define override bit for Svpbmt extension
    c98c14576f CryptoPkg/BaseCryptLibUnitTest: add unit test functions
    503344cdbd CryptoPkg/Driver: add additional RSAES-OAEP crypto functions
    89ff5da9f9 CryptoPkg/BaseCryptLib: add additional RSAES-OAEP crypto functions
    ee28bea4c0 SecurityPkg/SecureBootConfigDxe: Update UI according to UEFI spec
    8707f835ae ArmPkg: Remove ArmCortexA9.h
    ee249efe8c ArmPkg: Remove ArmCortexA5x.h
    6fb3cc05dc RedfishPkg/RedfishPlatformConfigDxe: support menu path report
    79d4d8a81c EmulatorPkg/Redfish: Use edk2 Redfish debug PCDs
    2e4e41d012 RedfishPkg/RedfishPlatformConfigDxe: HII string is deleted unexpectedly
    c8f56800fd RedfishPkg/RedfishPlatformConfigDxe:Add RefishDebugLib support
    b0be42516e RedfishPkg/RedfishDebugLib: Introduce Redfish DEBUG macro
    29114fc574 RedfishPkg/RedfishPlatformConfigDxe: Config language searching optimization
    b387114113 EmulatorPkg: Update the comments of ReadKeyStroke and ReadKeyStrokeEx
    7cc2010f46 EmbeddedPkg: Update the comments of ReadKeyStroke and ReadKeyStrokeEx
    b79a64d26e ShellPkg: Update the comments of ReadKeyStroke and ReadKeyStrokeEx
    e043e3e3bf MdeModulePkg: Update the comments of ReadKeyStroke and ReadKeyStrokeEx
    8f698f0a64 CryptoPkg: Remove interdependence for RsaPssVerify
    d402de2222 CryptoPkg: Update Md5/Sha1/Sha2 by using new mbedtls api
    278250045b CryptoPkg: Update OPTIONAL location for BaseCryptLibMbedTls
    37f63deeef MdeModulePkg: MemoryProtection: Use ImageRecordPropertiesLib
    596f856c13 MdeModulePkg: ImagePropertiesRecordLib: Consolidate Usage
    1fb6462c67 MdeModulePkg: ImagePropertiesRecordLib: Use SectionAlignment for CodeSize
    7fde22823d MdePkg: Add gEfiDeviceSignatureDatabaseGuid to dec
    e4e1f6229c MdePkg: Add UEFI 2.10 DeviceAuthentication
    cf58f47623 ShellPkg/Acpiview: Adds ACPI WSMT Table parse
    4b9312de05 ShellPkg/Acpiview: Adds HPET parser
    7f1ffba5de MdeModulePkg/Xhci: Skip another size round up for TRB address
    35f6a2780e OvmfPkg/TdxDxe: Clear the registers before tdcall
    a1a6da80aa OvmfPkg/CcExitLib: Update TDVMCALL_EXPOSE_REGS_MASK
    07c49d5d40 MdePkg/BaseLib: Update TDVMCALL_EXPOSE_REGS_MASK
    3840c35e34 IntelFsp2WrapperPkg: Error handling of FspmWrapperInit()
    ccbbc2a5c8 IntelFsp2WrapperPkg: Error handling of TpmMeasureAndLogDataWithFlags()
    e7486b5064 MdeModulePkg: DxeCore: Do Not Apply Guards to Unsupported Types
    68461c2c37 MdeModulePkg: DxeCore: Correct Runtime Granularity Memory Type
    bf8f16f771 MdeModulePkg: DxeCore: Fix CodeQL Error in FreePages
    019feb42a1 MdeModulePkg: Remove ArmPkg Dependency
    5572b43c67 BaseTools/GenFds: Apply OEM_CAPSULE_FLAGS during Capsule generation.
    308e6e0936 DynamicTablesPkg/SSDT: Require Package node in hierarchy
    6b3a512149 SecurityPkg: Update ReceiveData and SendData function description
    6f67ed45e0 MdeModulePkg: Update ReceiveData and SendData function description
    a8b80149e1 MdePkg: Update ReceiveData and SendData function description
    ddaf39263a EmbeddedPkg/NonCoherentIoMmuDxe: Make SetAttributes always succeed
    ccf91b518f Maintainers.txt: remove Laszlo's entries
    1c0db23151 UefiPayloadPkg: auto-generate SEC ProcessLibraryConstructorList() decl
    18fc96c9a9 UefiCpuPkg: auto-generate SEC ProcessLibraryConstructorList() decl
    1e603ac0d8 IntelFsp2Pkg: auto-generate SEC ProcessLibraryConstructorList() decl
    063a831c66 EmulatorPkg: auto-generate SEC ProcessLibraryConstructorList() decl
    f71a76ee01 ArmVirtPkg: auto-generate SEC ProcessLibraryConstructorList() decl
    91460083f1 ArmPlatformPkg: auto-generate SEC ProcessLibraryConstructorList() decl
    524feaa32f OvmfPkg/RiscVVirt/Sec: clean up ProcessLibraryConstructorList() decl
    9f9bf82209 OvmfPkg/IntelTdx: auto-gen & fix SEC ProcessLibraryConstructorList() decl
    1fbc121cfe OvmfPkg: auto-generate (and fix) SEC ProcessLibraryConstructorList() decl
    da4aa451ba pip-requirements.txt: require edk2-basetools version 0.1.51
    e60529df58 UefiPayloadPkg: Make Dsc accomodative of other archs
    2a0d4a2641 OvmfPkg/SmbiosPlatformDxe: tweak fallback release date again
    918288ab5a .github/workflows/codeql.yml: Update actions being deprecated
    bff9815b61 BaseTools/GenFds: Resolve absolute workspace INF paths
    1ae5bee967 DynamicTablesPkg/SsdtSerialPortFixupLib: Add Interrupt node for SPIs only
    855f528199 ArmPkg/ArmGicArchLib: Add macros for SPI and extended SPI ranges
    970aacd191 UefiPayloadPkg: UPL arch backward support ELF
    3775122ede ShellPkg/SmbiosView: Support New ProcessorFamily for SMBIOS Type4
    47723854fd MdePkg/SmBios.h: Add New ProcessorFamily definitions for SMBIOS Type4
    275d0a39c4 OvmfPkg/ResetVector: wire up 5-level paging for TDX
    318b0d714a OvmfPkg/ResetVector: print post codes for 4/5 level paging
    49b7faba1d OvmfPkg/ResetVector: add 5-level paging support
    e3bd782373 OvmfPkg/ResetVector: split SEV and non-CoCo workflows
    b7a97bfac5 OvmfPkg/ResetVector: split TDX BSP workflow
    4329b5b0cd OvmfPkg/ResetVector: add CreatePageTables4Level macro
    52e44713d2 OvmfPkg/ResetVector: add ClearOvmfPageTables macro
    fded08e744 OvmfPkg/ResetVector: improve page table flag names
    371940932d MdeModulePkg/Core/Pei: Improve the copy performance
    2ec8f0c640 StandaloneMmPkg: Disallow unregister MMI handler in other MMI handler
    049ff6c39c StandaloneMmPkg: Support to unregister MMI handler inside MMI handler
    17b2872200 MdeModulePkg/SMM: Disallow unregister SMI handler in other SMI handler
    ae1079b386 MdeModulePkg/SMM: Support to unregister SMI handler inside SMI handler
    dcffad2491 UefiCpuPkg/CpuPageTableLib: qualify page table accesses as volatile
    d159e22913 UefiCpuPkg/CpuPageTableLib: Fix IN OUT parameters marked as IN
    dc7cfa9bab UefiCpuPkg/MpInitLib: add struct MP_HAND_OFF_CONFIG
    bac9c74080 BaseTools/AutoGen: declare ProcessLibraryConstructorList() for SEC modules
    adebfe121c OvmfPkg/PlatformInitLib: add 5-level paging support
    13fbc16556 MdeModulePkg/DxeIplPeim: rename variable
    73ac735be8 MdeModulePkg/DxeIplPeim: fix PcdUse5LevelPageTable assert
    d9a6e7b0b8 RedfishPkg/RedfishCrtLib: fix unresolved external symbol issue
    d4c76fa17d RedfishPkg/RedfishDebugLib: use RedfishHttpLib
    422dfaab31 RedfishPkg/RedfishLib: include RedfishServiceData.h
    9da786c16f RedfishPkg: introduce RedfishHttpLib
    0ce2012c6c RedfishPkg: implement Redfish HTTP protocol
    1988f2df29 RedfishPkg: introduce Redfish HTTP protocol
    3e91e42136 BaseTools: Syntax warning invalid escape sequence \C
    6d571c0070 BaseTools/Scripts/PatchCheck: Error if commit modifies multiple packages
    0bbec15b54 BaseTools/Scripts/PatchCheck: Error if no Cc tags are present
    45ad13bb64 BaseTools/Scripts/PatchCheck: Return CommitMessageCheck errors
    dae8c29dab BaseTools/Scripts/PatchCheck: Update Author checks
    e59a40b92c EmbeddedPkg/Scripts/LauterbachT32: Fix EfiLoadDxe.cmm
    aceb3490a2 OvmfPkg/PlatformPei: log pei memory cap details
    3ad1d7eb7b OvmfPkg/PlatformPei: rewrite page table calculation
    8757e648d1 OvmfPkg/PlatformPei: consider AP stacks for pei memory cap
    9d32a02a72 OvmfPkg/PlatformPei: log a warning when memory is tight
    ba9c3ceaf8 StandaloneMmPkg: Arm: Update to use the new StandaloneMmCpu driver
    e7a7169446 StandaloneMmPkg: Make StandaloneMmCpu driver architecture independent
    74b5309da9 RedfishPkg/RestJsonStructureDxe: Refine REST JSON C Structure DXE driver
    33c81c25bb MdeModulePkg/TraceHubDebugSysTLib: Use wider type for loop comparisons
    d25421d0d8 UefiCpuPkg/MpInitLib: return early in GetBspNumber()
    5e09b5d6d7 UefiCpuPkg/MpInitLib: Add support for multiple HOBs to SaveCpuMpData()
    c8e77454b5 UefiCpuPkg/MpInitLib: Add support for multiple HOBs to MpInitLibInitialize
    e2c9d8eba4 UefiCpuPkg/MpInitLib: Add support for multiple HOBs to SwitchApContext()
    b485230462 UefiCpuPkg/MpInitLib: Add support for multiple HOBs to GetBspNumber()
    a3ee1eea96 UefiCpuPkg/MpInitLib: Add support for multiple HOBs to GetMpHandOffHob
    1f161a7915 MdeModulePkg/Bus/Usb/UsbNetwork: Check array index range before access
    68238d4f94 MdePkg Updated the comments of EFI_SYSTEM_TABLE and ReadKeyStroke
    44fdc4f398 BaseTools: Update keybaord map based on UEFI spec 2.10
    d0c0e1960a MdePkg: Update keybaord map based on UEFI spec 2.10
    ba96acd963 ArmVirtPkg/XenAcpiPlatformDxe: Install FACS table from DT
    f881b4d129 OvmfPkg: only add shell to FV in case secure boot is disabled
    bc982869dd OvmfPkg/CI: copy shell to virtual drive
    8d7c48e0e7 OvmfPkg: switch MicrovmX64 to new shell include files
    6bb39cfd00 OvmfPkg: switch IntelTdxX64 to new shell include files
    a7a0443751 OvmfPkg: switch AmdSevX64 to new shell include files
    796e1b82df OvmfPkg: switch OvmfPkgIa32X64 to new shell include files
    65200edb3a OvmfPkg: switch OvmfPkgIa32 to new shell include files
    bda5b4a6cf OvmfPkg: ShellDxe.fdf.inc: add VariablePolicyDynamicCommand to FV
    7f17a15564 OvmfPkg: Shell*.inc: allow building without network support
    b25f84d7b3 OvmfPkg: add ShellDxe.fdf.inc
    efca2c6cfc OvmfPkg: add ShellLibs.dsc.inc
    2cb466cc2c OvmfPkg: add ShellComponents.dsc.inc
    7fa4a984c4 UefiPayloadPkg/Gop: Clean up unused protocol and Guid
    11ad164bce UefiPayloadPkg: Make UPL build script arch agnostic
    8ccd63d14d UefiCpuPkg: Fix issue that IsModified is wrongly set in PageTableMap
    c10e5703fe UefiCpuPkg/CpuMpPei: Don't write CR3 in ConvertMemoryPageToNotPresent
    2f4b07b668 UefiCpuPkg/CpuPageTableLib: Enhance function header for PageTableMap()
    2ca8d55974 UefiCpuPkg/PiSmmCpuDxeSmm: Check BspIndex first before lock cmpxchg
    d698bcfe4f UefiCpuPkg/PiSmmCpuDxeSmm: Avoid BspIndex typecasting
  - Removed patches which are merged to edk2-stable202405:
  - ovmf-OvmfPkg-SmbiosPlatformDxe-tweak-fallback-release-dat.patch
    9aa057b29834 OvmfPkg/SmbiosPlatformDxe: tweak fallback release date again
  - Add brotli as new submodule
  - brotli-f4153a09f87cbb9c826d8fc12c74642bb2d879ea.tar.gz
  - https://github.com/google/brotli/archive/f4153a09f87cbb9c826d8fc12c74642bb2d879ea.tar.gz
  - https://github.com/google/brotli
  - edk2 commit ids:
    1193aa2dfbbd MdeModulePkg: update brotli submodule
    42af706dfba7 BaseTools: Update brotli submodule
  - Updated ovmf.spec
  - unpacked brotli-f4153a09f87cbb9c826d8fc12c74642bb2d879ea.tar.gz to
    BaseTools/Source/C/BrotliCompress/brotli and
    MdeModulePkg/Library/BrotliCustomDecompressLib/brotli
  - We add brotli back to ovmf.spec as a submodule to align with edk2 mainline.
    Then we can remove ovmf-disable-brotli.patch to reduce the number of downstream patches.
  - removed ovmf-disable-brotli.patch
  - Add libspdm as new submodule
  - libspdm-50924a4c8145fc721e17208f55814d2b38766fe6.tar.gz
  - https://github.com/DMTF/libspdm/archive/50924a4c8145fc721e17208f55814d2b38766fe6.tar.gz
  - https://github.com/DMTF/libspdm.git
  - edk2 commit ids:
    79655e276860 SecurityPkg: Update libspdm submodule to use GitLab cmocka repo
    54a4fd9b35ca SecurityPkg: Add libspdm submodule
    9bc272519868 .gitmodule: Add libspdm submodule for EDKII
  - Updated ovmf.spec
  - unpacked libspdm-50924a4c8145fc721e17208f55814d2b38766fe6.tar.gz to SecurityPkg/DeviceSecurity/SpdmLib/libspdm
  - Changed the approach for creating the edk2 source code tarball:
  - Original approach for getting the edk2 source code tarball is
    directly downloading edk2-edk2-stable%%{version}.tar.gz from
    https://github.com/tianocore/edk2.
  - New approach is that we download edk2-edk2-stable%%{version}.tar.gz
    from https://github.com/tianocore/edk2. Then we repackage the tarball
    for renaming the build root folder from edk2-edk2-stable%%{version}/ to
    edk2/. This approach can reduce the size of FV image against
    FD_SIZE_2MB config.
    (I believe that the reason is "gcc -g" produced bigger image when the
    name of build root folder has longer name)
  - A advantage by using edk2/ as the build root folder name is that it
    aligns with the edk2 git project name. In development stage, developer
    should find that the FV image size is too big for FD_SIZE_2MB config.
    So we use the same name of build root folder with development stage.
  - Another approach for getting the source tarball is using git in local
    edk2 git repo:
    git archive --format=tar.gz -o ./edk2-edk2-stable%%{version}.tar.gz --prefix=edk2/ edk2-stable%%{version}
    For example:
    git archive --format=tar.gz -o ./edk2-edk2-stable202405.tar.gz --prefix=edk2/ edk2-stable202405
  - Against this change, we modified the setup command in %%prep section in
    ovmf.spec:
    old: %%setup -q -n edk2-edk2-stable%%{version}
    new: %%setup -q -n edk2
* Tue Aug 20 2024 Joey Lee <jlee@suse.com>
- Removed -code/-vars files of AMD SEV flavor because SEV ovmf only
  supports unified image.
- Updated 50-ovmf-x86_64-sev.json descriptor
  - Use ovmf-x86_64-sev.bin unified image instead of separate images
    ovmf-x86_64-sev-code/vars.bin.
  - add "mode": "stateless", currently SEV ovmf only supports
    stateless mode.
- Removed "amd-sev" and "amd-sev-es" feature tags from the following
  descriptors because we separate SEV as a flavor:
    60-ovmf-x86_64-2m.json
    60-ovmf-x86_64.json
- Add descriptors.tar.xz.README as the readme of descriptors.tar.xz
* Mon Aug 12 2024 Joey Lee <jlee@suse.com>
- Add ovmf-x86_64-sev flavor to X64 against AMD SEV.
  - Moved "-D SECURE_BOOT_ENABLE" from OVMF_FLAGS to EXTRA_FLAGS_X64,
    , BUILD_OPTIONS_X86, BUILD_OPTIONS_AA64 and BUILD_OPTIONS_RV64
    because SEV can NOT work with secure boot.
- Removed ovmf-Revert-OvmfPkg-PlatformPei-Update-ReserveEmuVariable.patch
  because the SEV ovmf be separated from X64 ovmf as an independent flavor.
  - The original patch reverts "58eb8517ad OvmfPkg/PlatformPei: Update
    ReserveEmuVariableNvStore" which affects all ovmf flavor.
  - The secure boot be disabled in SEV flavor, so we do not need revert
    58eb8517ad anymore. (bsc#1209266)
- Add 50-ovmf-x86_64-sev.json to descriptors.tar.xz for SEV flavor
  - Removed features tag:
    "acpi-s3", "requires-smm", "secure-boot", "enrolled-keys"
  - Add features tag:
    "amd-sev", "amd-sev-es", "amd-sev-snp"
* Tue Jul 16 2024 Joey Lee <jlee@suse.com>
- Update to edk2-stable202402
  - Features (https://github.com/tianocore/edk2/releases):
    NetworkPkg: Packet->Length is not updated before being used by Dhcp6AppendIaAddrOption to safely know it can append.
    NetworkPkg: Out-of-bounds read when processing IA_NA/IA_TA options in a DHCPv6 Advertise message
    Heap Buffer Overflow in Tcg2MeasureGptTable()
    Add LoongArch help functions and defines in MdePkg and move some ArmVirtPkg libraries and PCDs to OvmfPkg
    Add NVMe Sanitize command support to Nvme.h
    Remove CSM support from OvmfPkg
    MAT Logic Incorrectly Reports Runtime Images
  - Patches (git log --oneline --date-order edk2-stable202311..edk2-stable202402):
    edc6681206 UefiCpuPkg/PiSmmCpuDxeSmm: fix NULL deref when gSmmBaseHobGuid is missing
    72c441df36 UefiCpuPkg/PiSmmCpuDxeSmm: distinguish GetSmBase() failure modes
    5fd3078a2e NetworkPkg: : Updating SecurityFixes.yaml
    75deaf5c3c NetworkPkg: Dhcp6Dxe: Packet-Length is not updated before appending
    af3fad99d6 NetworkPkg: Dhcp6Dxe: Removes duplicate check and replaces with macro
    1c440a5ece NetworkPkg: Dhcp6Dxe: SECURITY PATCH CVE-2023-45229 Related Patch
    a1c426e844 UnitTestFrameworkPkg: Add DSC and host tests that always fail
    0a989069df UnitTestFrameworkPkg/SampleGoogleTest: Use EXPECT_ANY_THROW()
    2d144d7e14 UnitTestFrameworkPkg/UnitTestDebugAssertLib: Add GoogleTest support
    312ccaf81b UnitTestFrameworkPkg/UnitTestLib: GetActiveFrameworkHandle() no ASSERT()
    81b69f306f UnitTestFrameworkPkg: Expand host-based exception handling and gcov
    46c6de57b0 UnitTestFrameworkPkg: MSFT CC_FLAGS add /MT to for host builds
    ded41a64bd MdePkg/Include: Rename _DEBUG() to address name collision
    8801c75b4d OvmfPkg: Align XenRealTimeClockLib function headers with return values
    dcdc6f8e3f ArmPlatformPkg: Align PL031 library function headers with return values
    844ead5bce EmbeddedPkg: Align RealTimeClock function headers with return values
    ef4d35d4ed MdeModulePkg: Align RuntimeDxe function headers with UEFI return values
    e4ceae5c18 MdePkg: Add EFI_UNSUPPORTED return for some Runtime Service functions
    dcf2e39dce EmbeddedPkg: compiler error due to arithmetic operation on void pointer
    e32b58ab5a BaseTools: Remove Duplicate sets of SkuName and SkuId from allskuset
    8f316e99ec BaseTools: Optimize GenerateByteArrayValue and CollectPlatformGuids APIs
    4d1f0babe2 MdePkg: Add SynchronizationLib to MdeLibs.dsc.inc
    1d0b95f645 NetworkPkg: : Adds a SecurityFix.yaml file
    ff2986358f NetworkPkg: UefiPxeBcDxe: SECURITY PATCH CVE-2023-45235 Unit Tests
    fac297724e NetworkPkg: UefiPxeBcDxe: SECURITY PATCH CVE-2023-45235 Patch
    7f04c7a253 MdePkg: Test: Add gRT_GetTime Google Test Mock
    458c582685 NetworkPkg: UefiPxeBcDxe: SECURITY PATCH CVE-2023-45234 Unit Tests
    1b53515d53 NetworkPkg: UefiPxeBcDxe: SECURITY PATCH CVE-2023-45234 Patch
    c9c87f08dd NetworkPkg: Ip6Dxe: SECURITY PATCH CVE-2023-45232 Unit Tests
    4df0229ef9 NetworkPkg: Ip6Dxe: SECURITY PATCH CVE-2023-45232 Patch
    6f77463d72 NetworkPkg: Ip6Dxe: SECURITY PATCH CVE-2023-45231 Unit Tests
    bbfee34f41 NetworkPkg: Ip6Dxe: SECURITY PATCH CVE-2023-45231 Patch
    07362769ab NetworkPkg: Dhcp6Dxe: SECURITY PATCH CVE-2023-45229 Unit Tests
    1dbb10cc52 NetworkPkg: Dhcp6Dxe: SECURITY PATCH CVE-2023-45229 Patch
    5f3658197b NetworkPkg: Dhcp6Dxe: SECURITY PATCH CVE-2023-45230 Unit Tests
    8014ac2d7b NetworkPkg: : Add Unit tests to CI and create Host Test DSC
    f31453e8d6 NetworkPkg: Dhcp6Dxe: SECURITY PATCH CVE-2023-45230 Patch
    959f71c801 MdeModulePkg: Optimize CoreConnectSingleController
    9eddbab650 MdeModulePkg: Remove handle validation check in CoreGetProtocolInterface
    62b43ec896 ArmVirtPkg: Move PlatformBootManagerLib to OvmfPkg
    6bbce86d21 ArmVirtPkg: Move two PCD variables into OvmfPkg
    0cca97e0a8 ArmVirtPkg: Move the FdtSerialPortAddressLib to OvmfPkg
    5a3788bfca OvmfPkg/RiscVVirt: Remove PciCpuIo2Dxe from RiscVVirt
    010f7298ce OvmfPkg/RiscVVirt: Enable CpuMmio2Dxe
    147beaa5e7 ArmVirtPkg: Enable CpuMmio2Dxe
    55a0cdb61c UefiCpuPkg: Add a new CPU IO 2 driver named CpuMmio2Dxe
    54c2cdb241 ArmVirtPkg: Move PCD of FDT base address and FDT padding to OvmfPkg
    3db49a6ca8 EmbeddedPkg: Add PcdPrePiCpuIoSize width for LOONGARCH64
    f560c5d112 MdePkg: Add some comments for LoongArch exceptions
    3f8fb8aeb9 MdePkg: Add a new library named PeiServicesTablePointerLibKs0
    bc0b418cba MdePkg: Add IOCSR operation for LoongArch
    0565a8e885 MdePkg: Add CSR operation for LoongArch
    414ad233a5 MdePkg: Add read stable counter operation for LoongArch
    344dc4b9d3 MdePkg: Add LoongArch Cpucfg function
    2ff435b264 MdePkg: Add LoongArch64 local interrupt function set into BaseLib
    57684402e4 MdePkg: Add LoongArch64 exception function set into BaseLib
    e5b5073153 MdePkg: Add LoongArch64 FPU function set into BaseCpuLib
    9e1576bc10 MdePkg: Add the header file named Csr.h for LoongArch64
    ae59b8ba41 UefiCpuPkg/PiSmmCpuDxeSmm:Map SMRAM in 4K page granularity
    397a084b9b UefiCpuPkg: Add more Paging mode enumeration
    30a25f2778 UefiCpuPkg: Reduce and optimize access to attribute
    056b4bf74b BaseTools/Scripts/PatchCheck.py: Check for Change-id
    141dcaed6c UefiCpuPkg: Add cache operations support for Arch proto
    cd6f215223 OvmfPkg/ResetVector: Fix SNP CPUID table processing results for ECX/EDX
    a1b98c8f84 StandaloneMmPkg/Core: Output status in MMI handler assertion
    927ea1364d ShellPkg: Update smbiosview for LoongArch
    a3aab12c34 MdeModulePkg: Dxe: add LOONGARCH64 to mMachineTypeInfo
    3656352675 UefiPayloadPkg/Crypto: Support external Crypto drivers.
    97c3f5b8d2 OvmfPkg/IoMmuDxe: Provide an implementation for SetAttribute
    0e9b124f9c UefiCpuPkg/BaseXApic[X2]ApicLib: Implements AMD extended cpu topology
    d14526372d MdePkg: Adds AMD Extended CPU topology CPUID
    40a45b5a2b Basetools: Include PCD declarations from Library Instance
    af6e0e728f MdeModulePkg/Core/Dxe: Set MemoryTypeInfo bin range from HOB
    c5e702e45a MdeModulePkg/Core/Dxe: Initialize GCD before RT memory allocations
    909a9a5ae4 ArmPkg: Disable watchdog interaction after exiting boot services
    9ac93da5b5 ArmPkg: Introduce global mTimerPeriod and remove calculation
    beefa753f3 ArmPkg: Update GenericWatchdogDxe to allow setting full 48-bit offset
    98c7cb3be7 OvmfPkg/ResetVector: send post codes to qemu debug console
    a6013625a3 PcAtChipsetPkg/HpetTimerDxe: Fix nested interrupt time accuracy
    dc33394701 DynamicTablesPkg: Exempt some _CPC field from checks
    dec9d35738 DynamicTablesPkg: Add PcdDevelopmentPlatformRelaxations Pcd
    b2c4916344 DynamicTablesPkg: Add DynamicTablesScmiInfoLib
    fc04cfd119 DynamicTablesPkg: Generate _PSD in SsdtCpuTopologyGenerator
    3344495489 DynamicTablesPkg: Add AmlCreatePsdNode() to generate _PSD
    0a9060b259 DynamicTablesPkg: Add PsdToken field to CM_ARM_GICC_INFO object
    71ec5d3415 DynamicTablesPkg: Add CM_ARM_PSD_INFO object
    e3992e40c7 DynamicTablesPkg: Rename AmlCpcInfo.h to AcpiObjects.h
    ec15e345ae DynamicTablesPkg: Use new CPC revision macro
    9f0ebabb57 ArmPkg/ArmScmiDxe: Add PERFORMANCE_DESCRIBE_FASTCHANNEL support
    3630cdf6e7 ArmPkg/ArmScmiDxe: Rename PERFORMANCE_PROTOCOL_VERSION
    4c43209a74 MdePkg/Library/BaseCpuLibNull: Add missing X86 specific services
    7d7decfa3d UefiPayloadPkg/Crypto: Support external Crypto drivers.
    9a75b030cf StandaloneMmPkg/Hob: Integer Overflow in CreateHob()
    aeaee8944f EmbeddedPkg/Hob: Integer Overflow in CreateHob()
    049695a0b1 MdeModulePkg/PciBusDxe: Add feedback status for PciIoMap
    ff52277e37 MdeModulePkg/DriverSampleDxe: EFI_BROWSER_ACTION_REQUEST_QUESTION_APPLY
    588cfc63d2 MdeModulePkg/SetupBrowserDxe: EFI_BROWSER_ACTION_REQUEST_QUESTION_APPLY
    5694ff42d5 MdePkg: Add EFI_BROWSER_ACTION_REQUEST_QUESTION_APPLY
    97e1ef8730 MdePkg: Add FdtLib gmock support
    d24187a81f MdePkg/BaseFdtLib: Rename standard functions
    1063665fa5 MdeModulePkg/ResetSystemRuntimeDxe: Print Reset Data
    7f72c2829f MdePkg/Library/BaseCpuLibNull: Add StandardSignatureIsAuthenticAMD()
    417ebe6d1d MdePkg/Include/Guid: Update the definition of FileName in EFI_FILE_INFO
    2ddae5df31 StandaloneMmPkg/Core: Remove optimization for depex evaluation
    d97f3a1d80 .pytool/Plugin: UncrustifyCheck: use stat instead of os.stat
    313f9f0155 PrmPkg/PrmInfo: Drop -r parameter
    0b09397dfa UefiPayloadPkg: CbParseLib: Fix integer overflow
    0c6d29be8b CryptoPkg: Add dummy inttypes header to fix clang build
    da228b29bd MdePkg/Library/BaseIoLibIntrinsic: Fix TD MMIO read type cast
    5d016fe0a0 MdePkg/IndustryStandard: Add _PSD/_CPC/Coord types definitions
    0223bdd4e4 FmpDevicePkg: Add DECLARE_LENGTH opcode of dependency expression
    00bf6890a9 MdePkg: Add DECLARE_LENGTH opcode of dependency expression
    9d3fe85fcc NetworkPkg/Ip4Dxe: Fix Reset To Default
    264636d8e6 SecurityPkg: : Updating SecurityFixes.yaml after symbol rename
    326db0c907 SecurityPkg: DxeTpmMeasureBootLib: SECURITY PATCH 4117/4118 symbol rename
    40adbb7f62 SecurityPkg: DxeTpm2MeasureBootLib: SECURITY PATCH 4117/4118 symbol rename
    b481b00f59 OvmfPkg/VirtNorFlashDxe: move DoErase code block into new function
    735d0a5e2e OvmfPkg/VirtNorFlashDxe: ValidateFvHeader: unwritten state is EOL too
    b25733c974 OvmfPkg/VirtNorFlashDxe: allow larger writes without block erase
    28ffd72689 OvmfPkg/VirtNorFlashDxe: add a loop for NorFlashWriteBuffer calls.
    35d8ea8097 OvmfPkg/VirtNorFlashDxe: clarify block write logic & fix shadowbuffer reads
    0395045ae3 OvmfPkg/VirtNorFlashDxe: add casts to UINTN and UINT32
    59f024c76e UefiPayloadPkg/Hob: Integer Overflow in CreateHob()
    9971b99461 RedfishPkg/JsonLib: Add JSON delete object function
    8f6d343ae6 SecurityPkg: : Adding CVE 2022-36764 to SecurityFixes.yaml
    0d341c01ee SecurityPkg: DxeTpmMeasureBootLib: SECURITY PATCH 4118 - CVE 2022-36764
    c7b2794421 SecurityPkg: DxeTpm2MeasureBootLib: SECURITY PATCH 4118 - CVE 2022-36764
    1ddcb9fc6b SecurityPkg: : Adding CVE 2022-36763 to SecurityFixes.yaml
    4776a1b39e SecurityPkg: DxeTpmMeasureBootLib: SECURITY PATCH 4117 - CVE 2022-36763
    2244465432 SecurityPkg: DxeTpm2MeasureBootLib: SECURITY PATCH 4117 - CVE 2022-36763
    a4b8944e27 MdePkg: Update the Label definitions of the EFI_NVDIMM_LABEL
    682a5ed1a2 NetworkPkg: RFC1323 definition changed to RFC7323
    638e4ca238 MdePkg: RFC1323 definition changed to RFC7323
    7c2757c298 MdePkg: Update the comments of callback in EFI_FORM_BROWSER2_PROTOCOL
    82e149f2bf OvmfPkg: CloudHv: Enable PcdUse1GPageTable
    6d204e8fbc OvmfPkg: Update PlatformAddressWidthInitialization for CloudHv
    bfad87ceec OvmfPkg: Add CloudHv support to PlatformScanE820 utility function.
    195e59bd0c MdePkg: Update the comments of HiiConfigAccess ExtractConfig
    d65b183f92 RedfishPkg/RedfishCrtLib: handle floating point number in JSON
    6a01fb2ea5 OvmfPkg: RiscVVirt: Fix network drivers not be built
    c15a899d83 NetworkPkg: Triger regularly scan only if not connect to AP
    f5b91c60ef UefiCpuPkg: change name of gMpInformationHobGuid2
    db59ff333d UefiCpuPkg:Limit PhysicalAddressBits in special case
    cfe4846572 UefiCpuPkg/PiSmmCpuDxeSmm: Optimize PatchSmmSaveStateMap and FlushTlbForAll
    2bce85bd86 pip-requirements.txt: Update to latest
    58355ec192 .pytool/Readme.md: Update matrix for DynamicTablesPkg
    0765ee6cd3 MdePkg/BaseLib: Fix boot DxeCore hang on riscv platform
    ebf378a1ad OvmfPkg/RiscVVirt: Override Sstc extension
    f91029947b UefiCpuPkg/CpuTimerDxeRiscV64: Add support for Sstc
    8ae17a71af MdePkg/BaseLib: RISC-V: Add function to update stimecmp register
    fd629ef6e3 MdePkg.dec: RISC-V: Define override bit for Sstc extension
    889535caf8 MdePkg: Update GetHealthStatus function description
    e7cfdc5f14 CryptoPkg: Fix redefinition error of int defines
    6c488a2f39 BaseTools: Fix raw strings containing valid escape characters
    7d055812cc IntelFsp2Pkg\Tools\ConfigEditor:Added new USF config workstream.
    bc34a79cd2 RedfishPkg/RedfishDebugLib: add function to print buffer.
    265b4ab91b RedfishPkg/RedfishRestExDxe: Update Supported function
    b0e892d8a9 RedfishPkg/RedfishRestExDxe: Uncrustify RedfishRestExDriver.h
    0a12d8bd55 RedfishPkg/RedfishRestExDxe: Implement EDKII_HTTP_CALLBACK_PROTOCOL
    8466480965 NetworkPkg/HttpDxe: Add HttpEventTlsConfigured HTTP callback event
    43ab6622a8 NetworkPkg/HttpDxe: Consider TLS certificate not found as a success case
    0abd598e3f NetworkPkg/HttpDxe: Refactor TlsCreateChild
    edba0779ba UefiPayloadPkg/UefiPayloadEntry: Remove SCI enabling check
    4a443f73fd OvmfPkg/VirtNorFlashDxe: sanity-check variables
    ae22b2f136 OvmfPkg/VirtNorFlashDxe: stop accepting gEfiVariableGuid
    3b1ddbddee OvmfPkg/RiscVVirt: use gEfiAuthenticatedVariableGuid unconditionally
    08a6528bac UefiCpuPkg: Check lower 24 bits of ProcessorNumber
    2a5c08caaf UefiCpuPkg: set EXTENDED_PROCESSOR_INFORMATION to 0
    f2b074398c MdePkg: Update the definition of EFI_NVDIMM_LABEL_FLAGS_LOCAL
    e7152e6186 CryptoPkg: fix gcc build fail for CryptoPkgMbedtls
    c3d865a4c2 UefiPayloadPkg: Add macro to enable selection of timer
    ff1305c9fb MdePkg: Update the definition of CapsuleImageSize on EFI_CAPSULE_HEADER
    9cf1d03ebe Add EFI_STATUS return to EMU_THUNK_PROTOCOL.SetTime()
    5a2490df0e EmulatorPkg: Update MMTimerThread() signature
    3114fd8ed7 EmulatorPkg: Improve comments in WinThunk.c
    e8166a852e UefiCpuPkg/CpuMpPei: Parallel get stack base for better performance.
    e449451770 CryptoPkg: move define to CrtLibSupport
    16c8cfc810 DynamicTablesPkg: Fix IA32 compilation errors
    ea658e35a9 DynamicTablesPkg: Fix X64 compilation errors
    7a5823f85b EmbeddedPkg: Add DtPlatformLoaderLib gmock support
    5804e94886 EmbeddedPkg: Add host based dependency to ci
    0d39caefb9 EmbeddedPkg/PrePiMemoryAllocationLib: Add ReallocatePool
    d7d4f09ff8 RedfishPkg: RedfishDiscoverDxe: add [] brackets to URI for IPv6 addresses
    91f1ce4e27 RedfishDiscoverDxe: handle memory allocation error conditions.
    139887a989 RedfishDiscoverDxe: release resources when refreshing information data
    f8de39afab RedfishDiscoverDxe: add a helper function deallocating string resources.
    d1c21f8d55 RedfishDiscoverDxe: refine InitInformationData() function
    17870bf3f5 RedfishDiscoverDxe: refine InitInformationData(), remove unnecessary casts
    2cd1b439d7 RedfishDiscoverDxe: introduce InitInformationData helper function
    9e3de4eee0 EmulatorPkg: RedfishPlatformHostInterfaceLib: get rid of unused variable
    5e2338d3df EmulatorPkg: fix typo. PcdRedfishServie -> PcdRedfishService
    24de462a9d RedfishPkg: add proper initialization of IPMI request
    8b59cb79fa RedfishPkg: add Component Name protocols to RedfishConfigHandler driver
    a87e8505b1 RedfishPkg: RedfishDiscoverDxe: fix memory leak on error path.
    d81813368a RedfishPkg: RedfishPlatformConfigDxe: reduce memory allocations
    0f66c2e687 RedfishPkg: get rid of unused definitions from RedfishCrtLib.h
    4fdd5165c1 RedfishPkg: fix RedfishPlatformCredentialLib library class name typo.
    59b4b5017c RedfishPkg: fix RedfishPlatformHostInterfaceLib library class name typo.
    58d9463939 UefiCpuPkg/PiSmmCpuDxeSmm: Reduce one round BSP & AP sync
    41d1c4475b UefiCpuPkg/PiSmmCpuDxeSmm: Invert ReleaseAllAPs & InitializeDebugAgent
    3a4ec6de01 UefiCpuPkg/PiSmmCpuDxeSmm: Align BSP and AP sync logic for SMI exit
    e1b62f3e28 UefiCpuPkg/PiSmmCpuDxeSmm: Check SMM Debug Agent support or not
    c7c2de798a MdeModulePkg/DebugAgentLibNull: Indicate SMM Debug Agent support or not
    7b3b39a2e4 SourceLevelDebugPkg/Library: Indicate SMM Debug Agent support or not
    54c662845f StandaloneMmPkg/Core: Remove dead code
    1065536c64 MdeModulePkg: Support customized FV Migration Information
    d01defe06b DynamicTablesPkg: AML Code generation to invoke a method
    29ce755cba DynamicTablesPkg: Corrects function pointer typedef of AML_PARSE_FUNCTION
    f8c918c46f DynamicTablesPkg: Corrects AmlCodeGenRdWordBusNumber parameters
    ea65643547 DynamicTablesPkg: AML Code generation for word I/O ranges
    5d533bbc27 BaseTools/GenFw: Correct offset when relocating an ADR
    9f0061a03b BaseTools: Resolve regex syntax warnings
    89705ad6c6 BaseTools: FMMT GuidTool Auto Select Config file Enabling
    a83d953dc2 UefiCpuPkg/PiSmmCpuDxeSmm: Consume SmmCpuSyncLib
    cc698d0335 UefiCpuPkg/PiSmmCpuDxeSmm: Simplify RunningApCount decrement
    0a248f169d UefiPayloadPkg: Specifies SmmCpuSyncLib instance
    32f84bd310 OvmfPkg: Specifies SmmCpuSyncLib instance
    69eb9ad4a1 UefiCpuPkg: Implements SmmCpuSyncLib library instance
    6f6a43cc8e MdePkg/MdeLibs.dsc.inc: Add SafeIntLib instance
    ba822d2851 UefiCpuPkg: Adds SmmCpuSyncLib library class
    e14a022246 UefiCpuPkg/PiSmmCpuDxeSmm: Optimize Semaphore Sync between BSP and AP
    8c1e9f9c6f MdeModulePkg/UefiBootManagerLib: Signal ReadyToBoot on platform recovery
    b1f33cbf81 OvmfPkg/RiscVVirt: Override for RISC-V CPU Features
    904b002c50 MdePkg: Utilize Cache Management Operations Implementation For RISC-V
    26727c2ae2 MdePkg: Implement RISC-V Cache Management Operations
    30faafd024 MdePkg: Rename Cache Management Function To Clarify Fence Based Op
    286b30f517 MdePkg: Move RISC-V Cache Management Declarations Into BaseLib
    3c66390e4a StandaloneMmPkg/Core: Fix the failure to find uncompressed inner FV
    4a9fcab124 StandaloneMmPkg/Core: Fix issue that offset calculation might be wrong
    0904161f6f StandaloneMmPkg/Core: Fix potential memory leak issue
    c012284048 StandaloneMmPkg/Core: Limit FwVol encapsulation section recursion
    74daeded0c ShellPkg: Tidy for code readability
    3ce5f2d445 FatPkg/FatPei: Check array offset before use
    7f5e75895b ArmPkg/DebugPeCoffExtraActionLib: Drop RVCT and Cygwin support
    59a952d9ab CloudHv: Add CI for CloudHv on AArch64
    b8a3eec88c RedfishPkg/RedfishDicovery: Remedy Redfish service discovery flow
    cee7ba349c ArmVirtQemu: Allow EFI memory attributes protocol to be disabled
    725acd0b9c UefiCpuPkg: Avoid assuming only one smmbasehob
    e51965ddd1 UefiCpuPkg: Cache core type in MpInfo2 HOB
    fc4f6627f8 UefiCpuPkg: Add a new field in MpInfo2 HOB
    be44fff723 UefiCpuPkg: Consume MpInfo2Hob in PiSmmCpuDxe
    e10f1f5a04 UefiCpuPkg: Build MpInfo2HOB in CpuMpPei
    c02eed8e5a UefiCpuPkg: Create gMpInformationHobGuid2 in UefiCpuPkg
    1d50544aa2 MdePkg:simplify Fifo API in BaseIoLibIntrinsic
    3c73532a8a MdePkg: Change IoLibFifo.c to IoLibFifoCc.c
    aa2f32cefa ArmVirtPkg: Sync debug level comments in ArmVirt.dsc.inc
    9e9c35970a MdePkg: Update MdePkg.uni with manageability debug level
    20ca600d67 MdePkg: Add manageability debug level to PcdFixedDebugPrintErrorLevel
    03be51e106 MdePkg: Improve wording of manageability debug level comment
    5b5481526f BaseTools: fixing FMMT ShrinkFv issue
    59f0d350a9 BaseTools: FMMT support ELF UPLD parser
    9627447625 BaseTools: FMMT replace output file is not generated successfully
    b5f5106c1e BaseTools: FMMT replace new free space fixing in replace
    bb13a4adab StandaloneMmPkg/StandaloneMmHobLib: Remove HOB creation
    85a5141a32 MdePkg: Add UEFI v2.10 ISA memory type definition
    3c40ee8c68 MdePkg: Define the DevicePath argument from LoadImage as optional
    2cd9d5f6fa Maintainers.txt: add Aaron Young as MptScsi and PvScsi reviewer
    ff22700fc0 Maintainers.txt: add Laszlo Ersek as a UefiCpuPkg maintainer
    408ca20a95 Maintainers.txt: add Laszlo Ersek as an OvmfPkg maintainer
    b59574a066 Maintainers.txt: add Laszlo Ersek as an ArmVirtPkg maintainer
    e8c23d1e27 OvmfPkg/MemEncryptSevLib: Fix address overflow during PVALIDATE
    7eb5040607 UefiCpuPkg/PiSmmCpuDxeSmm: Get processor extended information
    ad0b1cc144 UefiCpuPkg/BaseXApicLib: Fix CPUID_V2_EXTENDED_TOPOLOGY detection
    fe2abc9b74 ShellPkg: Fix typos
    eccdab611c OvmfPkg: remove CSM_ENABLE build macro
    605248f0fd OvmfPkg: remove Pcd8259LegacyModeEdgeLevel and Pcd8259LegacyModeMask
    cf9030f69f OvmfPkg: remove gEfiLegacy8259ProtocolGuid
    67864ffd52 OvmfPkg: remove 8259InterruptControllerDxe
    fb5c153abd OvmfPkg: exclude 8259InterruptControllerDxe
    05cffb6637 OvmfPkg: remove 8254TimerDxe
    89bd992b1f OvmfPkg: exclude 8254TimerDxe
    0e0a0a5ee8 OvmfPkg: remove Csm16
    528ae029ad OvmfPkg: remove Rule.Common.USER_DEFINED.CSM from all FDF files
    e8f860d924 OvmfPkg: exclude Csm16.inf / Csm16.bin
    769c46a9a2 OvmfPkg: remove <FrameworkDxe.h>
    f14317e9ba OvmfPkg: remove gEfiLegacyInterruptProtocolGuid
    504a0fed85 OvmfPkg: remove gEfiLegacyBiosProtocolGuid
    dd63cb95af OvmfPkg: remove gEfiLegacyBiosPlatformProtocolGuid
    f19b3d0cdc OvmfPkg: remove gEfiFirmwareVolumeProtocolGuid
    bc495d89d4 OvmfPkg: remove CsmSupportLib
    86cc0f15d9 OvmfPkg: unplug CsmSupportLib from BdsDxe
    8bd14e685e OvmfPkg: remove LegacyBiosDxe PCDs
    9d4becddba OvmfPkg: remove gEfiLegacyBiosGuid
    5161ba8ea0 OvmfPkg: remove gEfiIsaAcpiProtocolGuid
    0730f564ad OvmfPkg: remove gEfiIsaIoProtocolGuid
    d7e41ce340 OvmfPkg: exclude NullMemoryTestDxe driver
    f0c5d652d9 OvmfPkg: remove LegacyBiosDxe
    209480b047 Revert "OvmfPkg: don't assign PCI BARs above 4GiB when CSM enabled"
    87d0e572c8 OvmfPkg/IncompatiblePciDeviceSupportDxe: ignore CSM presence
    934b7f5a73 OvmfPkg: exclude LegacyBiosDxe
    ec60da4232 OvmfPkg: remove Bios Video PCDs
    4493d74e18 OvmfPkg: remove gEfiVgaMiniPortProtocolGuid
    59dc8743ce OvmfPkg: remove Csm/BiosThunk/VideoDxe
    ac79397267 OvmfPkg: exclude the CSM-based VideoDxe driver
    e948ceeb80 OvmfPkg: remove gEfiLegacyDevOrderVariableGuid
    545a5f6b68 OvmfPkg: remove LegacyBootMaintUiLib
    237a0564d4 OvmfPkg: unplug LegacyBootMaintUiLib from UiApp
    3f3e90d678 OvmfPkg: remove LegacyBootManagerLib
    0600bea167 OvmfPkg: unplug LegacyBootManagerLib from BdsDxe and UiApp
    3099db510e OvmfPkg: remove PcdCsmEnable
    506cc670c0 OvmfPkg: cripple CSM_ENABLE macro
    238690a30d OvmfPkg/Bhyve: use a proper PCI IO range
    553dfb0f57 UefiCpuPkg: Backup and Restore MSR IA32_U_CET in SMI handler.
    fd1dd8568c UefiCpuPkg: Only change CR4.CET bit for enable and disable CET.
    3018685da8 UefiCpuPkg: Use CET macro definitions in Cet.inc for SmiEntry.nasm files.
    04d47a9bf0 UefiCpuPkg: Use macro CR4_CET_BIT to replace hard code value in Cet.nasm.
    b5f20eca8a UefiCpuPkg: Add macro definitions for CET feature for NASM files.
    ff4c49a5ee MdeModulePkg/Bus: Fix XhciDxe Linker Issues
    df2ec2aab0 PcAtChipsetPkg: Fix AcpiTimerLib incompatibility with XhciDxe
    b59ab98049 BaseStackCheckLib: Fix STACK FAULT message
    7e18c9a788 UefiCpuPkg/CpuMpPei: Use CpuPageTableLib to set memory attribute.
    02d6f39bd5 UefiCpuPkg/CpuPageTableLib/TestCase: Refine test case for PAE paging.
    c83ffd2676 UefiCpuPkg/CpuPageTableLib: Init local variable before using it.
    ef3fde64aa MdePkg:Add NVME Sanitize command support to Nvme.h
    120aa60644 RedfishPkg/HostInterfaceBmcUsbNic: Fix potential memory corruption issue
    5cdeff1eb3 RedfishPkg/HostInterfaceBmcUsbNic: Fix incorrect HI protocol record size
    cf31257ec9 RedfishPkg/HostInterfaceBmcUsbNic: Correct MAC address reference
    cfafa45002 RedfishPkg/RedfishDiscovery: Refine SMBIOS 42h code
    4b5e2b3ac1 RedfishPkg/RedfishDiscovery: Add more debug message
    dbaf9d3046 RedfishPkg/RedfishConfigHandler: Correct the prototype of callback function
    8325fd6466 RedfishPkg/RedfishConfigHandler: Use Redfish HI readiness notification
    843ed20714 RedfishPkg/RedfishHostInterfaceDxe: Add Redfish HI readiness notification
    a3b56f93e1 RedfishPkg/BmcUsbNicLib: Update BMC USB NIC searching algorithm
    3e133f730b MdePkg/Test: Add google tests for BaseLib
    e2d4f75913 MdePkg/BaseLib: Fix CRC16-ANSI calculation
    7182621edc UnitTestFrameworkPkg/Readme.md: Remove gtest main() limitation
    c3769e392b UnitTestFrameworkPkg: Fix Google Test components with multiple files
    70b174e24d RedfishPkg/HostInterfaceBmcUsbNic: Set default Redfish service port
    534021965f MdeModulePkg: Optimize CoreInstallMultipleProtocolInterfaces
    26d484d086 .github/workflows/codeql.yml: Add emacs output
    b4f8c75e31 RedfishPkg: add explicit variable initialization
    ed923afda5 RedfishPkg: fix memory leak in HiiUtilityLib
    59b6b5059b EmbeddedPkg: Allow longer android kernel command line
    c0207583e0 EmbeddedPkg: Fix Android Boot Command Line Length Bug
    4f99b5fb93 BaseTools/Conf/target.template: Use VS2019 as default tool chain
    68d506e0d1 UefiCpuPkg/PiSmmCpuDxeSmm: Use NonSmm BSP as default SMM BSP.
    88580a79d4 MdeModulePkg/Variable: Merge variable header + data update into one step
    cdf36b1e36 .git-blame-ignore-revs: Ignore recent uncrustify commits
    466f2f0c5f MdeModulePkg/DxeCapsuleLibFmp: Fix crash with VirtualAddressMap omitted
    38ba4a64c5 ArmPkg/Drivers/CpuDxe: Use lower and upper attributes
    e1627f7720 Maintainers.txt: Remove myself as a tools maintainer
    9eec96bd4f OvmfPkg/ResetVector: Define SNP metadata for kernel hashes
    6436d9b693 OvmfPkg/AmdSev: Reorder MEMFD pages to match the order in OvmfPkgX64.fdf
    3c5f9ac5c3 UefiCpuPkg/MpInitLib: Copy SEV-ES save area pointer during APIC ID sorting
    447798cd3a UefiCpuPkg/MpInitLib: Use AsmCpuidEx() for CPUID_EXTENDED_TOPOLOGY leaf
    d451bba399 ArmPkg/ArmMmuLib: Use function pointer type
    0e9ce9146a OvmfPkg: Format with Uncrustify 73.0.8
    972e3b0b9d EmulatorPkg: Format with Uncrustify 73.0.8
    ec9cb4452e .pytool/UncrustifyCheck: Update to 73.0.8
    4ec2fab279 MdeModulePkg: Update DumpImageRecord() in ImagePropertiesRecordLib
    3565ee6c29 MdeModulePkg: Add Logic to Create/Delete Image Properties Records
    aa77dac3fb MdeModulePkg: Transition SMM MAT Logic to Use ImagePropertiesRecordLib
    960c7b25c2 UefiCpuPkg: Use Attribute From SMM MemoryAttributesTable if Nonzero
    cf78580a34 MdeModulePkg: Add NULL checks and Return Status to ImagePropertiesRecordLib
    7ae0516dd9 MdeModulePkg: Fix MAT SplitTable() Logic
    e2f2bbe208 MdeModulePkg: Fix MAT SplitRecord() Logic
    acb29d4cbe MdeModulePkg: Fix MAT Descriptor Count Calculation
    0a9e215312 MdeModulePkg: Add ImagePropertiesRecordLib Host-Based Unit Test
    7284c44951 MdeModulePkg: Move Some DXE MAT Logic to ImagePropertiesRecordLib
    561362368b MdeModulePkg: Update MemoryAttributesTable.c to Reduce Global Variable Use
    26460342d0 UefiPayloadPkg: Add ImagePropertiesRecordLib Instance
    1ef4e102c2 OvmfPkg: Add ImagePropertiesRecordLib Instance
    21b831c5b5 EmulatorPkg: Add ImagePropertiesRecordLib Instance
    16b1e88502 ArmVirtPkg: Add ImagePropertiesRecordLib Instance
    8bc44608b8 MdeModulePkg: Add ImagePropertiesRecordLib
    33e31c289c UefiCpuPkg/MpInitLib: Update the comments of _CPU_MP_DATA.
    cb3f41a937 UefiCpuPkg/MpInitLib: Enable execute disable bit.
  - Removed patches which are merged to edk2-stable202402:
  - ovmf-SecurityPkg-DxeTpm2MeasureBootLib-SECURITY-PATCH-4117.patch
    1ddcb9fc6b41 SecurityPkg: : Adding CVE 2022-36763 to SecurityFixes.yaml
  - ovmf-SecurityPkg-DxeTpmMeasureBootLib-SECURITY-PATCH-4117.patch
    4776a1b39ee0 SecurityPkg: DxeTpmMeasureBootLib: SECURITY PATCH 4117 - CVE 2022-36763
  - ovmf-SecurityPkg-Adding-CVE-2022-36763-to-SecurityFixes.y.patch
    224446543206 SecurityPkg: DxeTpm2MeasureBootLib: SECURITY PATCH 4117 - CVE 2022-36763
  - ovmf-SecurityPkg-DxeTpm2MeasureBootLib-SECURITY-PATCH-4118.patch
    8f6d343ae639 SecurityPkg: : Adding CVE 2022-36764 to SecurityFixes.yaml
  - ovmf-SecurityPkg-DxeTpmMeasureBootLib-SECURITY-PATCH-4118.patch
    0d341c01eeab SecurityPkg: DxeTpmMeasureBootLib: SECURITY PATCH 4118 - CVE 2022-36764
  - ovmf-SecurityPkg-Adding-CVE-2022-36764-to-SecurityFixes.y.patch
    c7b279442181 SecurityPkg: DxeTpm2MeasureBootLib: SECURITY PATCH 4118 - CVE 2022-36764
  - ovmf-SecurityPkg-DxeTpm2MeasureBootLib-SECURITY-PATCH-4117-4118-symbol-rename.patch
    264636d8e698 SecurityPkg: : Updating SecurityFixes.yaml after symbol rename
  - ovmf-SecurityPkg-DxeTpmMeasureBootLib-SECURITY-PATCH-4117-4118-symbol-rename.patch
    326db0c90720 SecurityPkg: DxeTpmMeasureBootLib: SECURITY PATCH 4117/4118 symbol rename
  - ovmf-SecurityPkg-Updating-SecurityFixes.yaml-after-symbol.patch
    40adbb7f628d SecurityPkg: DxeTpm2MeasureBootLib: SECURITY PATCH 4117/4118 symbol rename
* Fri May 31 2024 Fabian Vogt <fvogt@suse.com>
- Remove unused openSUSE-UEFI-SIGN-Certificate-2048.crt
- Use virt-fw-vars to create varstores with enrolled keys instead
  of using QEMU + generated .iso images:
  * Includes newer 2023 certs from Microsoft
  * Remove now unused files:
    + gen-key-enrollment-iso.sh
    + ovmf-set-fixed-enroll-time.patch
    + ovmf-build-funcs.sh
  * No longer build and package EnrollDefaultKeys.efi and Shell.efi
* Wed May 15 2024 Joey Lee <jlee@suse.com>
- Removed ovmf-UefiCpuPkg-BaseXApicX2ApicLib-fix-CPUID_V2_EXTENDED_.patch
  file which is merged to edk2-stable202311:
  - 170d4ce8e90a UefiCpuPkg/BaseXApicX2ApicLib: fix CPUID_V2_EXTENDED_TOPOLOGY detection
* Fri May 10 2024 Joey Lee <jlee@suse.com>
- Update to edk2-stable202311
  - Features (https://github.com/tianocore/edk2/releases):
    UefiPayloadPkg:Enhance the build processing for Universalpayload
    SplitFspBin.py cannot support FSP binary with child FV included
    Cache Disable should not be set by default in CR0 after ResetVector in x64 build
    SMM perf record is copied multiple times to FPDT table if multiple ReadyToBoot events are signaled
    In some cases, LocateHandleBuffer() may allocate a callee freed buffer when an error occurs
    OvmfPkg/IoMmuDxe: don't rely on TPLs to manage concurrency
    Recent OVMF build.sh change breaks useful functionality
    UEFI cryptography agile solution - separate crypto algorithm (phase I)
    Use MpService2Ppi to wakeup CPU in Smm CpuS3
    Move RngLibTimer from MdePkg to MdeModulePkg
    EFI_RNG_PROTOCOL Describe the DRBG algorithm used in the Arm RNDR instruction
    Faulty Rng algo selection for Arm
    RngDxe assert
    Add New Intel Processor family for SMBIOS Type 4 from SMBIOS 3.7.0
    NetworkPkg: HTTP protocol throughput too small
    MailBoxVersion should be 0 according to the ACPI spec 6.5
    Pyrite support - Secure erase is only available if encryption is supported
    Remove assembly/tool logic that creates AP waking vector in 4G-20h
    MdeModulePkg/Bus/Ata/AtaBusDxe: Coverity scan flags SIGN_EXTENSION issue
    MdeModulePkg/Bus/Pci/NvmExpressPei: Coverity scan flags DEADCODE issue
    MdeModulePkg/Bus/Pci/UhciDxe: fix Coverity issues
    DynamicTablesPkg: Add support for generating ACPI ThermalZones
    DynamicTablesPkg: Add support for PCI IO using Qword resources
    MdeModulePkg/XhciDxe: Use Performance Timer for XHCI Timeouts
    MdeModulePkg/Bus/Pci/XhciDxe: Need to abort the command for command timeout
    BaseTools: Add support for LOONGARCH64 R_LARCH_RELAX relocation
    UefiPayloadPkg: Add FIT support
    SMBIOS BCD revision is not match SMBIOS version
    Xhci: Skip size round up for TRB when getting PCI device/host memory address
    MdePkg: various fixes to ARM/AArch64 SetJump/LongJump
    TlsLib should not have a list of Ciphers which may or may not agree with what is available
    MtrrLib modules and Unit test Enhancement
    Use the base SortLib for Redfish modules only
    evaluate the feasibility of using mbedtls as crypto library
    bogus RealTimeClockLib class interface: LibRtcVirtualNotifyEvent
    OvmfPkg/VirtioFsDxe: tolerate opening an absolute pathname relative to a regular file
    UefiDevicePathLib DevPathToTextAcpiEx overflows the device path node when searching for optional strings
    DynamicTablesPkg/TableHelperLib updates
    Update Edk2-pytools to latest versions
    duplicate installation of EFI_REAL_TIME_CLOCK_ARCH_PROTOCOL in RealTimeClockLib instances
    UefiCpuPkg/BaseXApicX2ApicLib: fix CPUID_V2_EXTENDED_TOPOLOGY detection
    OvmfPkg/AcpiPlatformDxe: Coverity scan flags FORWARD_NULL and UNUSED_VALUE issues
    RedfishPkg/RedfishLib: Return HTTP headers to caller
    ArmVirtPkg: support two PL011 UARTs
    Update MADT for ACPI 6.5, and add TRBE & ETE support
    Add Variable Policy Audit App and Shell Command
    Use CodeQL CLI
    TDVF: TdVmCall needs handle the retry results for MapGPA
    Update GetMaintainer to handle case where a package has only reviewers and no maintainers
    Add 0x0B/Platform Runtime Mechanism (PRM) in Address Space ID of Generic Address Structure (GAS)
    Fix build error when remove "-Wno-sometimes-uninitialized" option
  - Patches (git log --oneline --date-order edk2-stable202308..edk2-stable202311):
    8736b8fdca RedfishPkg: RedfishDiscoverDxe: Optimize the Redfish Discover flow
    f444c4bea5 RedfishPkg: RedfishDiscoverDxe: Fix issue if IPv4 installed after RestEx
    8dd52c949e Revert "RedfishPkg: RedfishDiscoverDxe: Fix issue if IPv4 installed later"
    15538bc62e Revert "RedfishPkg: RedfishDiscoverDxe: Optimize the Redfish Discover flow"
    23dbb8a07d DynamicTablesPkg: Fix ETE _UID Creation
    3db76e6476 RedfishPkg: RedfishDiscoverDxe: Optimize the Redfish Discover flow
    06b27ccb90 RedfishPkg: RedfishDiscoverDxe: Fix issue if IPv4 installed after RestEx
    c9cce5a005 MdeModulePkg/RegularExpressinoDxe: Fix clang error
    33deaa3b84 BaseTools/Scripts/GetMaintainer: Sort output addresses
    706811819d BaseTools/Scripts/GetMaintainer: Handle reviewer only case
    05f3c3f3d0 BaseTools/Scripts/GetMaintainer: refactor internal returns as dicts
    1cb580be85 BaseTools/Scripts/GetMaintainer: Simplify logic
    431ead235f BaseTools/Scripts/GetMaintainer: Fix logic bug collecting maintainers
    589f2e49e5 UefiCpuPkg/PiSmmCpuDxeSmm: Fix CP Exception when CET enable
    35c0c63edb Maintainers.txt: Remove unused OvmfPkg Confidential Computing path
    e077ccff6d BaseTools/tools_def: drop -mgeneral-regs-only for AArch64 CLANGDWARF
    8a41004643 OvmfPkg/BaseMemEncryptTdxLib: Handle retry result of MapGPA
    212cf07aaa MdePkg/Tdx.h: Add TDVMCALL_STATUS_RETRY
    68e37f4578 MdePkg/BaseLib: Update TdVmcall to always output the value in R11
    616f0d5037 IntelFsp2WrapperPkg: Add variable initialization
    bb18fb80ab Maintainers.txt: Remove Orphan status option
    c96b4da2a0 ReadMe.rst: Add CodeQL/analyze directory under other licenses
    d461137e22 BaseTools/Plugin/CodeQL: Enable 30 queries
    a3e8efcc8e .pytool/CISettings: Enable CodeQL audit mode
    1384ce443d .github/workflows/codeql.yml: Add CodeQL workflow
    29763016e0 .pytool/CISettings.py: Integrate CodeQL
    b531ca4bb3 BaseTools/Plugin/CodeQL: Add integration helpers
    5464d0bed6 BaseTools/Plugin/CodeQL: Add CodeQL build plugin
    c1393bd486 Remove existing CodeQL infrastructure
    da21991953 BaseTools: GenFw: auto-set nxcompat flag
    e53c618ea4 MdePkg: IndustryStandard: Add DLL Characteristics
    ae02d487a3 BaseTools: Update PatchCheck.py to allow whitespace issues in .rtf files
    778134e491 ShellPkg/Dp: Allow dp command to work without ACPI
    ee942c5360 MdeModulePkg/DxeCorePerformanceLib: Install BPDT in config table
    038499a268 Maintainers.txt: Update based on active community members
    08ac799d36 IntelFsp2Pkg/PatchFv: Fix syntax issue in markdown manual
    0b4acb88d6 IntelFsp2Pkg/SwitchStack: Reserve 32B when calling C function in 64bit
    8da978bf68 ReadMe.rst: Add Apache License 2.0 and update submodule list
    fbbbd98499 DynamicTablesPkg: Fix assert in CmObject parser
    1b1509abee RedfishPkg/RedfishCrtLib: remove multiple definitions.
    ccbe2e9383 UefiCpuPkg: Correct file description for MpHandOff header file
    36812d6c3e .github/workflows: Add Stale Check
    a6871b5359 ArmVirtPkg/PlatformCI/ReadMe.md: Update contents
    2e128302e6 ArmVirtPkg: Add varpolicy shell command
    fe6cd1c187 OvmfPkg: Add varpolicy shell command
    d4358a7f76 ShellPkg: Add varpolicy dynamic shell command and app
    f3b2187d55 MdeModulePkg/VariablePolicy: Add more granular variable policy querying
    8e74629070 .azurepipelines: Fix Python version (to 3.12)
    2426a35625 MdePkg ACPI65: Add 0x0B/PRM to Generic Address Structure
    aa8431822b MdeModulePkg/DxeCore: Allow relocation of images with large address
    a671a14e63 ArmPkg/ArmLib: Add ArmHasEte () helper function
    08431081a3 ArmPkg/ArmLib: Add ArmHasTrbe () helper function
    09fd4e4172 DynamicTablesPkg: Fix referencing of CPC token
    3ee23713e1 DynamicTablesPkg: Add ETE device to CPU node in AML
    f81ee47513 DynamicTablesPkg: Add an ET info object parser
    4821daa524 DynamicTablesPkg: Add an ET info object to Arm namespace
    2b0d117b4b ShellPkg: Acpiview: Update MADT parser for TRBE interrupt
    50e8518276 DynamicTablesPkg: Update FADT generator to ACPI 6.5
    36e9f3d08a DynamicTablesPkg: Update MADT generator for ACPI 6.5
    cf62548a35 DynamicTablesPkg: Add TRBE interrupt to GICC object parser
    db9800dce8 DynamicTablesPkg: Add TRBE interrupt to GICC object
    f9925c8953 MdePkg: MADT: Add TRBE interrupt to GICC
    822c54eb01 MdePkg: MADT: Add Online capable flag in GICC
    4f3ee7fbaf Maintainers.txt: update Gary's email address
    7806713f00 BaseTools: Plugin: Integration of edk2-pytools
    7f5c24ad35 .pytool: Integration of edk2-pytools
    7ff6ab2b3e UefiPayloadPkg: Fix incorrect code on Fit function.
    7e08d17a4a Maintainers.txt: Add .pytool maintainers to BaseTools/Plugin
    ca32f75fc6 .pytool: Undo uncrustify check change
    1e27258a89 UnitTestFrameworkPkg: Apply uncrustify formatting to relevant files
    a00f7a355a SecurityPkg: Apply uncrustify formatting to relevant files
    716a3292e0 MdePkg: Apply uncrustify formatting to relevant files
    504953ef97 MdeModulePkg: Apply uncrustify formatting to relevant files.
    41c622523d .pytool: Add cpp support to uncrustify plugin
    d0cac9f63f .pytool: Set uncrustify check to audit only (temporary)
    f945b72331 ArmVirtPkg: steer DebugLib output away from SerialPortLib+console traffic
    601abf5d50 ArmVirtPkg: introduce DebugLibFdtPL011Uart DXE Runtime instance
    ba5d955e25 ArmVirtPkg: introduce DebugLibFdtPL011Uart RAM instance
    b7e6d97973 ArmVirtPkg: introduce DebugLibFdtPL011Uart Flash instance
    115b59d9c6 ArmVirtPkg: store separate console and debug PL011 addresses in GUID HOB
    66046aeb6d ArmVirtPkg: adhere to the serial port selected by /chosen "stdout-path"
    5fc3c39704 ArmVirtPkg: adjust whitespace in block scope declarations
    f078a6fdd4 ArmVirtPkg/Fdt16550SerialPortHookLib: rebase to FdtSerialPortAddressLib
    eb83b53309 ArmVirtPkg: introduce FdtSerialPortAddressLib
    74c687cc2f UefiCpuPkg/MpInitLib: Wait for all APs to finish initialization
    fe43b42676 MdeModulePkg/Include: API of IPMI Get System Interface Capabilities
    9a38ddc806 MdePkg/Include: Definitions of IPMI Get System Interface Capabilities
    8765f3eb42 RedfishPkg/RedfishLib: return HTTP headers to caller
    1cbdd6e9ff RedfishPkg/libredfish: introduce new interfaces.
    cf68ff6130 RedfishPkg/RedfishLib: introduce new interfaces.
    9bb5ef1287 MdePkg: Add Cxl20.h into IndustryStandard
    884ef98454 MdePkg/Pldm.h: Add define for the PLDM response flag
    00dbde5fa4 MdePkg/Mctp.h: Correct typo in structure member name
    1f21e11168 Maintainers.txt: Update maintainers list
    cf87fd95c1 OvmfPkg/AcpiPlatformDxe: Fix Coverity report issues
    170d4ce8e9 UefiCpuPkg/BaseXApicX2ApicLib: fix CPUID_V2_EXTENDED_TOPOLOGY detection
    d85bf54b7f ArmPlatformPkg/PL031RealTimeClockLib: remove needless instance init steps
    a6648418c1 MdeModulePkg: Optimize BmExpandPartitionDevicePath
    e17e58e81b DynamicTablesPkg: HOWTO for Handcrafted tables
    fb044b7fe8 RedfishPkg/RedfishDiscoverDxe: remove Redfish false alarm
    da73578bf7 RedfishPkg/RedfishPlatformConfigDxe: add debug message.
    2ad52adb66 IntelFsp2WrapperPkg: CI: Add PrEval entry
    87ef986eeb MdeModulePkg: CI: Add PrEval entry
    f8923b72de MdePkg: CI: Add PrEval entry
    e44097a965 PrmPkg: CI: Add PrEval entry
    e5b4fe21ae RedfishPkg: CI: Add PrEval entry
    b24c8b0467 IntelFsp2Pkg: CI: Add PrEval entry
    1cd0227c5d FmpDevicePkg: CI: Add PrEval entry
    22b667c821 EmbeddedPkg: CI: Add PrEval entry
    2298769ecf DynamicTablesPkg: CI: Add PrEval entry
    36b41b067f CryptoPkg: CI: Add PrEval entry
    cbcdf4ff7b UnitTestFrameworkPkg: CI: Add PrEval entry
    9f5e409623 Edk2: edk2-pytools: Update to latest versions
    309450db26 DynamicTablesPkg/AmlLib: Enumerate memory attributes
    ec7f734366 DynamicTablesPkg/TableHelperLib: Enhance error handling
    575bd4f55c DynamicTablesPkg/TableHelperLib: Fix and improve text handling
    c591395f4a EmbeddedPkg/NorFlashInfoLib: Update norflash device list
    bed477d9cf Maintainers.txt: Stop to be reviewer of several modules
    0355e559c6 MdePkg/Test: Add DevicePathLib host test module
    96ed60dfd7 MdePkg/UefiDevicePathLib: Fix AcpiEx print logic
    8abbf6d87e OvmfPkg/VirtioFsDxe: tolerate opening an abs. pathname rel. to a reg. file
    b75d9f556d BaseTools: trim warning to error
    7fe49887c4 EmbeddedPkg/RealTimeClockLib: drop LibRtcVirtualNotifyEvent from lib class
    3c3136d3b6 EmbeddedPkg/VirtualRealTimeClockLib: drop LibRtcVirtualNotifyEvent
    e6e0e7ba74 EmbeddedPkg/TemplateRealTimeClockLib: drop LibRtcVirtualNotifyEvent
    189addfde6 ArmPlatformPkg/PL031RealTimeClockLib: hide LibRtcVirtualNotifyEvent
    c62fb45549 PcAtChipsetPkg/PcatRealTimeClockRuntimeDxe: rename LibRtcVirtualNotifyEvent
    747a08eae2 RedfishPkg/RedfishDiscoverDxe: introduce PcdRedfishSendReceiveTimeout
    01e1bc2894 ArmPkg/ArmPsciMpServices: Add EFI_NOT_READY return
    772ec92577 UefiCpuPkg: RISC-V: MMU: Introduce a PCD for SATP mode
    a445e1a42c ShellPkg: Increase PcdShellPrintBufferSize from UINT16 to UINT32
    03d6569f70 MdeModulePkg: UsbRndis: get rid of magic values
    e07948255c MdeModulePkg: UsbNetwork: fix Ethernet functional descriptor processing
    326b9e1d81 UefiCpuPkg/CpuDxe: Eliminate the unused variable.
    eebd446875 CryptoPkg: Add CryptAes functions based on Mbedtls Add CryptAes APIS.
    c109e4a244 CryptoPkg: Add basic Readme for BaseCryptLibMbedTls
    26754b3707 CryptoPkg: Add Mbedtls submodule in CI
    c5fedb030a CryptoPkg: Add MD5/SHA1/SHA2 functions based on Mbedtls
    4049ca493c CryptoPkg: Add Null functions for building pass
    b26f7dfe29 CryptoPkg: Add all .inf files for BaseCryptLibMbedTls
    97f51f2e9b CryptoPkg: Add RSA functions based on Mbedtls
    60222e7eb9 CryptoPkg: Add HKDF functions based on Mbedtls
    731aa70881 CryptoPkg: Add HMAC functions based on Mbedtls
    586f05b9de CryptoPkg: Add mbedtls_config and MbedTlsLib.inf
    1a79cc7d95 CryptoPkg: Add mbedtls submodule for EDKII
    95c9f470ca RedfishPkg: Use base version SortLib for the specific modules
    137f799aae UefiCpuPkg/CpuDxe: Update RefreshMemoryAttributesFromMtrr
    01b0d19dbb UefiCpuPkg/MtrrUnitTest: Add Unit test of setting/getting memory attributes
    c4fdec0a83 UefiCpuPkg/MtrrLib: Improve MtrrDebugPrintAllMtrrsWorker.
    4b7b32f846 UefiCpuPkg/MtrrLib: Add API MtrrGetMemoryAttributesInMtrrSettings.
    c032db3308 UefiCpuPkg/MtrrLib: Update APIs related to set memory attributes.
    1d0fd0bb3d UefiCpuPkg/MtrrUnitTest: Update UnitTestMtrrSetAllMtrrs().
    1217f59d23 UefiCpuPkg/MtrrLib: Fix MtrrSetAllMtrrs to handle absent fixed MTRRs.
    cc070b88e4 UefiCpuPkg/MtrrUnitTest: Update UnitTestMtrrGetFixedMtrr().
    0103d09ebe UefiCpuPkg/MtrrLib: Update MtrrGetFixedMtrr().
    a519014472 UefiCpuPkg/MtrrUnitTest: Update UnitTestMtrrGetAllMtrrs().
    0d89ceae31 UefiCpuPkg/MtrrLib: Fix MtrrGetAllMtrrs to return correct MTRR setting.
    5b76b4a9f9 UefiCpuPkg/MtrrUnitTest: Update test to cover no-fixed-mtrr cases.
    1ec374cb50 UefiCpuPkg/MtrrUnitTest: Update UnitTestMtrrGetDefaultMemoryType.
    f784fc0e39 UefiCpuPkg/MtrrUnitTest: Update UnitTestGetFirmwareVariableMtrrCount.
    ca3f8638fa UefiCpuPkg/MtrrUnitTest: Update the Unit Test for IsMtrrSupported().
    bf03c4a52a UefiCpuPkg/MtrrLib: Add internal function MtrrLibIsMtrrSupported.
    4ddd8ac3a2 CryptoPkg/TlsLib: fix tls cipher configuration
    5087a07736 ArmVirtPkg/FdtPL011SerialPortLib: initialize implicitly
    82191f8a0e .github: Fix Python version (to 3.11)
    6439c73356 .azurepipelines: Fix Python version (to 3.11)
    d073a54511 MdePkg/DxeRngLib: Add missing GUID declaration in inf
    1497c4b074 MdePkg/BaseLib: fix typo in Arm SetJump
    1a66bd51ca MdePkg/BaseLib: ensure ARM LongJump never returns 0
    2b2705343a MdePkg/BaseLib: correct register sizes in AArch64 SetJump/LongJump
    ae79efb7bd MdePkg/BaseLib: use normal register init in ARM SetJump implementations
    80bbea192a MdePkg/BaseLib: add ASSERT in ARM* SetJump implementations
    cbf0e4f5b3 MdePkg/BaseLib: fix comments in ARM* SetJump/LongJump implementations
    f6a314e5b5 Maintainers.txt: add Sami as maintainer of arm-architectural subdirs
    f36e1ec1f0 MdeModulePkg/Xhci: Skip size round up for TRB during address translation
    ad1c0394b1 EmulatorPkg: Fix Terminal Issues
    be971fc302 MdeModulePkg/SmbiosDxe: Fix BcdRevision is not match with SMBIOS version
    bf0bdacdd6 MdeModulePkg: Fix misspelling
    39f3c26e8c UefiPayloadPkg: Add FIT support
    d6b05375b4 MdePkg/BaseFdtLib: Add Fdt function.
    c70d914428 BaseTools/GenFw: Add support for LOONGARCH64 relax relocation
    d11f0ea045 MdeModulePkg/XhciDxe: Abort the Address Device cmd when time out
    43dcf453fc MdeModulePkg/XhciDxe: Use Performance Timer for XHCI Timeouts
    8b2e6b90b8 DynamicTablesPkg: AcpiSsdtPcieLibArm: Use QWord to describe I/O range
    909e870e34 DynamicTablesPkg: AML Code generation for I/O ranges
    b5003ab725 DynamicTablesPkg: Add Aml NameUnicodeString API
    fd0ccccb42 DynamicTablesPkg: Add support to add Strings to package
    b2df3ee17f DynamicTablesPkg: Add support for simple method invocation.
    8f5505a4c9 DynamicTablesPkg: Add ThermalZone CodeGen function
    28a267af40 MdeModulePkg/Bus/Pci/UhciDxe: Fix FORWARD_NULL Coverity issues
    e9f5d8c0e0 MdeModulePkg/Bus/Pci/UhciDxe: Fix BAD_SHIFT Coverity issue
    f67e1934d9 RedfishPkg/JsonLib: fix JsonObjectGetValue issue
    ea628f28e5 RISCV: Fix InternalLongJump to return correct value
    89dad77cfb ArmPkg/ArmLib: Add ArmHasVhe () helper function
    4317b4824b MdeModulePkg/Bus/Pci/NvmExpressPei: Fix DEADCODE Coverity issue
    4fb69c2bee MdeModulePkg/Bus/Ata/AtaBusDxe: Fix SIGN_EXTENSION Coverity issue
    eb485b6438 ArmVirtPkg: handle virtual EL2 timer in DT
    baee97670f ArmPkg: add EL2 virtual timer interrupt Pcd
    7275993dc6 RedfishPkg/RedfishRestExDxe: return HTTP status code to caller.
    cbcf0428e8 BaseTools/Plugin: Add DebugMacroCheck
    97d367f37e OvmfPkg/PlatformCI: Disable DebugMacroCheck
    8803033c0c DynamicTablesPkg.ci.yaml: Add debug macro exception
    1312c2e9fd ArmVirtPkg.ci.yaml: Add debug macro exception
    bc7bbd3bc4 SecurityPkg.ci.yaml: Add debug macro exception
    5cfb5d6c01 pip-requirements.txt: Add regex
    6f0729484f RedfishPkg/PlatformHostInterfaceBmcUsbNicLib: Fix DEBUG macro args
    408e463135 MdeModulePkg: Memory Bin Range Update Accounts for Guard Page
    db38c7de64 UefiCpuPkg/ResetVector: Remove AP waking vector from ResetVector
    dea6002d6e OvmfPkg: Remove applicationProcessorEntryPoint
    718cf21a5a UefiCpuPkg/SecCore: Remove AP waking Vector logic in SecCore
    392456240a BaseTools: Remove logic to create AP waking vector in GenFv
    29cce3356a OvmfPkg/RiscVVirt/README: document direct kernel boot
    1bfd63ac39 OvmfPkg/RiscVVirt/README: explain the "acpi=off" machine property
    5242bae5dd OvmfPkg/RiscVVirt/README: explain that "-bios" is only useful with TCG
    cdfe4310dd Pyrite support - Secure erase is only available if encryption is supported.
    4a1afea6f7 RedfishPkg/RedfishPlatformConfigDxe: fix can not set one-of option issue.
    b844b106e2 OvmfPkg/TdxDxe: Change MadtMpWk->MailBoxVersion from 1 to 0
    7f1a8cad99 Maintainers.txt: Make myself maintainer for OvmfPkg/RiscVVirt
    6d074d6a10 OvmfPkg: raise DXEFV size to 14.5 MB in the traditional platform FDFs
    c95158e419 OvmfPkg/PlatformBootManagerLib: refer to virtio console subsys symbolically
    4f4a2c3b07 ArmPkg/ArmMmuLib: Drop buggy secure memory type check
    b7a48bed16 OvmfPkg/RiscVVirt/README.md: bring your own OpenSBI
    e880c307c5 MdeModulePkg/BootMaintenanceManagerUiLib: Check array index before access
    a5cbb59905 Maintainers.txt: Update reviewers and maintainers for DynamicTablesPkg
    cc26a2cb31 MdeModulePkg/Core/Dxe: Fix memory leak issue in FwVolBlock.c
    f18ec60fa4 MdeModulePkg/Core/Dxe: Fix memory leak issue in FwVol.c
    0bcc503595 MdeModulePkg/HiiDatabase: Fix incorrect AllocateCopyPool size
    b240eab035 NetworkPkg: Increase HTTP buffer size and enable TCP window scaling
    d4ae5df711 MdePkg/SmBios.h: Add New Intel Processor family
    d42ad81e22 Add a .editorconfig file to tell editors basic formatting details
    28a74d7ab2 OvmfPkg/Bhyve: don't exit early if RSDP is not found in memory
    493a375eef ShellPkg/UefiShellNetwork2CommandsLib: Check array index before access
    60d0f5802b MdePkg/Library/TdxLib: Remove unnecessary comparison
    b74f1f7ab5 SecurityPkg: RngDxe: Fixing mAvailableAlgoArray allocator
    ff7ddc02b2 SecurityPkg/RngDxe: Simplify Rng algorithm selection for Arm
    19438cff97 SecurityPkg/RngDxe: Use GetRngGuid() when probing RngLib
    5443c2dc31 MdePkg/Rng: Add GetRngGuid() to RngLib
    414c0f2089 MdeModulePkg/Rng: Add GUID to describe unsafe Rng algorithms
    cf07238e5f MdePkg/Rng: Add GUID to describe Arm Rndr Rng algorithms
    bd1f0eecc1 MdePkg/DxeRngLib: Request raw algorithm instead of default
    65b5dd828e SecurityPkg/SecurityPkg.dec: Move PcdCpuRngSupportedAlgorithm to MdePkg
    e93468442b MdePkg: Add deprecated warning to BaseRngLibTimer
    2f981bddcb MdeModulePkg: Duplicate BaseRngLibTimerLib to MdeModulePkg
    2ce5ae43c2 UefiCpuPkg/PiSmmCpuDxe: use MpService2Ppi to wakeup AP in s3
    cf82c09bac UefiCpuPkg/PiSmmCpuDxe: code refinement for CpuS3.c
    48de494bb4 UefiCpuPkg/S3Resume2Pei: assert for invalid excution mode combo
    bc19f50c70 UefiCpuPkg/S3Resume2Pei: prepare MpService2Ppi in S3Resume
    b1955cddb2 MdeModulePkg: add MpService2Ppi field in SMM_S3_RESUME_STATE
    634192665e MdePkg/Library/BaseRngLib: Fix include guard
    b29150aa3e ArmVirtPkg: use PcdTerminalTypeGuidBuffer for VirtioSerial console
    aff67922c5 OvmfPkg/Include: remove QemuSmramSaveStateMap.h
    163083fd80 OvmfPkg/PlatformBootManagerLib: setup virtio-mmio devices.
    b81557a00c OvmfPkg/README: Document Secure Boot
    bbf1822295 SecurityPkg/SecureBoot: Support RSA4096 and RSA3072
    24da5c2f28 CryptoPkg/BaseCryptLib: add sha384 and sha512 to ImageTimestampVerify
    4d196352f3 OvmfPkg: Revert "Update build.sh to allow building OVMF then running QEMU"
    9b3d4f28f0 ArmVirtPkg: ArmVirtQemu: Add Graphics and Input
    d1e4a16f86 OvmfPkg: Fix Hii form name mismatch with EFI variable
    f008890ae5 OvmfPkg/AmdSev: fix BdsPlatform.c assertion failure during boot
    a23f4377c1 Revert "ArmPkg: add ArmCpuInfo EFI application"
    8b66f9df1b OvmfPkg/AmdSev: Disable PcdFirstTimeWakeUpAPsBySipi
    dfb941d32a OvmfPkg/IoMmuDxe: don't rely on TPLs to manage concurrency
    beafabdae4 MdeModulePkg: Fix memory leak in LocateHandleBuffer()
    4c8144dd66 ShellPkg: Add ProcessorUpgradeSocket definitions from SMBIOS 3.7.0
    a60eef3afa MdePkg: Add ProcessorUpgradeSocket definitions from SMBIOS 3.7.0
    c5753c3e38 ArmPkg/SmbiosMiscDxe: use UINT64 for BiosPhysicalSize
    0c4d0b6c8a MdeModulePkg/DxeCorePerformanceLib:fix smm perf issue
    e8aa4c6546 UefiCpuPkg/ResetVector: Cache Disable should not be set by default in CR0
    a481c11144 ShellPkg/SmbiosView: Update display of PCIe system slot ID
    5f46eb2307 MdeModulePkg/PciBusDxe: Fix boot hang with faulty PCI Option ROM
    9896a9c618 SecurityPkg/Tpm2DeviceLibTcg2: Make mTcg2Protocol static
    14bf2cb411 BaseTools: drop tautological warning overrides for CLANGDWARF
    020cc9e2e7 OvmfPkg: Disable PcdFirstTimeWakeUpAPsBySipi
    a107fcb618 RedfishPkg/RedfishPlatformConfigDxe: Fix unused variable
    b1e558f636 IntelFsp2Pkg: Add get and set FspSmmInit upd data pointer functions
    2c7fd32676 IntelFsp2Pkg: Support child FV in SplitFspBin.py
    92006e5804 UefiPayloadPkg:Enhance the build processing for Universalpayload
  - Removed patches which are merged to edk2-stable202311:
  - ovmf-UefiCpuPkg-BaseXApicX2ApicLib-fix-CPUID_V2_EXTENDED_.patch
    170d4ce8e90a UefiCpuPkg/BaseXApicX2ApicLib: fix CPUID_V2_EXTENDED_TOPOLOGY detection
  - Add mbedtls as new submodule
  - mbedtls-3.3.0.tar.gz
  - https://github.com/Mbed-TLS/mbedtls
  - Bug 4177 - evaluate the feasibility of using mbedtls as crypto library
  - https://bugzilla.tianocore.org/show_bug.cgi?id=4177
  - The openssl 3.0 has size problem. One alternative is to use mbedtls
  - Updated ovmf.spec
  - unpacked mbedtls-3.3.0.tar.gz to CryptoPkg/Library/MbedTlsLib/mbedtls
* Fri May 10 2024 Joey Lee <jlee@suse.com>
- Add the following patches from edk2-stable202402 for CVE-2022-36763:
  - ovmf-SecurityPkg-DxeTpm2MeasureBootLib-SECURITY-PATCH-4117.patch
    1ddcb9fc6b41 SecurityPkg: : Adding CVE 2022-36763 to SecurityFixes.yaml
  - ovmf-SecurityPkg-DxeTpmMeasureBootLib-SECURITY-PATCH-4117.patch
    4776a1b39ee0 SecurityPkg: DxeTpmMeasureBootLib: SECURITY PATCH 4117 - CVE 2022-36763
  - ovmf-SecurityPkg-Adding-CVE-2022-36763-to-SecurityFixes.y.patch
    224446543206 SecurityPkg: DxeTpm2MeasureBootLib: SECURITY PATCH 4117 - CVE 2022-36763
    (bsc#1218678, CVE-2022-36763)
- Add the following patches from edk2-stable202402 for CVE-2022-36764:
  - ovmf-SecurityPkg-DxeTpm2MeasureBootLib-SECURITY-PATCH-4118.patch
    8f6d343ae639 SecurityPkg: : Adding CVE 2022-36764 to SecurityFixes.yaml
  - ovmf-SecurityPkg-DxeTpmMeasureBootLib-SECURITY-PATCH-4118.patch
    0d341c01eeab SecurityPkg: DxeTpmMeasureBootLib: SECURITY PATCH 4118 - CVE 2022-36764
  - ovmf-SecurityPkg-Adding-CVE-2022-36764-to-SecurityFixes.y.patch
    c7b279442181 SecurityPkg: DxeTpm2MeasureBootLib: SECURITY PATCH 4118 - CVE 2022-36764
    (bsc#1218679, CVE-2022-36764)
- All the above patches for CVE-2022-36763 and CVE-2022-36764 need the
  following patches. We also backported them:
  - ovmf-SecurityPkg-DxeTpm2MeasureBootLib-SECURITY-PATCH-4117-4118-symbol-rename.patch
    264636d8e698 SecurityPkg: : Updating SecurityFixes.yaml after symbol rename
  - ovmf-SecurityPkg-DxeTpmMeasureBootLib-SECURITY-PATCH-4117-4118-symbol-rename.patch
    326db0c90720 SecurityPkg: DxeTpmMeasureBootLib: SECURITY PATCH 4117/4118 symbol rename
  - ovmf-SecurityPkg-Updating-SecurityFixes.yaml-after-symbol.patch
    40adbb7f628d SecurityPkg: DxeTpm2MeasureBootLib: SECURITY PATCH 4117/4118 symbol rename
    (bsc#1218678, CVE-2022-36763)(bsc#1218679, CVE-2022-36764)
* Thu Apr 11 2024 Joey Lee <jlee@suse.com>
- Add ovmf-EmbeddedPkg-Library-Support-SOURCE_DATE_EPOCH-in-Vir.patch
  Support SOURCE_DATE_EPOCH in VirtualRealTimeClockLib for reproducible.
  (bsc#1217704)
* Fri Mar 22 2024 Joey Lee <jlee@suse.com>
- Removed EFI shell from 4mb x86_64 ovmf image because it has
  security concern. Removed shell can also save space of ovmf
  image. (bsc#1219890, CVE-2023-48733)
  - Updated ovmf.spec: add BUILD_SHELL=FALSE to BUILD_OPTIONS_X64
  - 2mb x86_64 ovmf and smm x86_64 ovmf are already removed
    shell since edk2-stable202208 and earlier.
  - The BUILD_SHELL build option is not available on aarch64 and xen ovmf.
  - Shell.efi still be built independently and be packaged to ovmf-tools.
    User can copy it to EFI partition for running it by firmware's boot
    manager if they still need a shell. But user should either disables
    secure boot or sign Shell.efi by himself.
* Thu Mar  7 2024 Callum Farmer <gmbr3@opensuse.org>
- Use built QEMU_VARS.fd as base for AARCH64/AARCH32 vars file
- Ensure riscv64 code/vars is 32M otherwise it won't load
- Use truncate instead of 2 dd commands
* Thu Mar  7 2024 Joey Lee <jlee@suse.com>
- Updated descriptors.tar.xz tarball, adding secure-boot feature tag
  to the following firmware descriptor of qemu. For libvirt, the
  enrolled-keys feature relies on secure-boot (bsc#1217422):
    /usr/share/qemu/firmware/60-ovmf-x86_64-2m-ms.json
    /usr/share/qemu/firmware/60-ovmf-x86_64-2m-opensuse.json
    /usr/share/qemu/firmware/60-ovmf-x86_64-2m-suse.json
    /usr/share/qemu/firmware/60-ovmf-x86_64-ms.json
    /usr/share/qemu/firmware/60-ovmf-x86_64-opensuse.json
    /usr/share/qemu/firmware/60-ovmf-x86_64-suse.json
  User should awares that the secure-boot feature of ovmf is NOT real
  secure without SMM. Adding secure-boot is just for enabling
  enrolled-keys. Otherwise preloaded keys ovmf can not be auto-selected
  by libvirt.
* Mon Mar  4 2024 Joey Lee <jlee@suse.com>
- Add ovmf-OvmfPkg-SmbiosPlatformDxe-tweak-fallback-release-dat.patch
  tweak fallback release date again (bsc#1219024)
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autopatch macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Nov 21 2023 Joey Lee <jlee@suse.com>
- Sync change log to prepare for sending edk2-stable202308 ovmf to SLE15-SP6
  (jsc#PED-6233, jsc#PED-5523)
  - Removed the following backported patches because they are merged
    to edk2 mainline:
  - ovmf-SecurityPkg-DxeImageVerificationLib-Check-result-of-.patch
  494127613b SecurityPkg/DxeImageVerificationLib: Check result of GetEfiGlobalVariable2
  (CVE-2019-14560, bsc#1174246)
* Wed Nov 15 2023 Joey Lee <jlee@suse.com>
- Add ovmf-UefiCpuPkg-BaseXApicX2ApicLib-fix-CPUID_V2_EXTENDED_.patch
  fix CPUID_V2_EXTENDED_TOPOLOGY detection (bsc#1216472)
* Wed Nov 15 2023 Joey Lee <jlee@suse.com>
- Sync change log to prepare for sending edk2-stable202308 ovmf to SLE15-SP6
  (jsc#PED-6233, jsc#PED-5523)
  - Removed the following backported patches because they are merged
    to edk2 mainline:
  - ovmf-MdeModulePkg-PiSmmCore-SmmEntryPoint-underflow-CVE-2.patch
  cab1f02565 MdeModulePkg/PiSmmCore: SmmEntryPoint underflow (CVE-2021-38578)
  (bsc#1196741)
* Sat Sep 23 2023 Joey Lee <jlee@suse.com>
- Update to edk2-stable202308
  - Features (https://github.com/tianocore/edk2/releases):
    CryptoPkg: consume OpenSSL 3.0
    Replace the OVMF-specific SataControllerDxe with the generic one in MdeModulePkg
    Remove the duplicated definitions from BaseTools
    Arm GIC Library and Driver improvements
    Use restricted memory mappings in PEI
    Add SmmCpuFeaturesLib implementation for AMD Processor family
    Add USB Network RNDIS Drivers
    Support Standalone MM based variable services in PEI on ARM systems
    Add RISC-V MMU support
    Add RISC-V support to CLANGDWARF toolchain
  - Patches (git log --oneline --date-order edk2-stable202305..edk2-stable202308):
    819cfc6b42 OvmfPkg/RiscVVirt: Fix issues in VarStore Blockmap config
    00b51e0d78 MdeModulePkg: HeapGuard: Don't Assume Pool Head Allocated In First Page
    48089f3a7c OvmfPkg/Bhyve: build platform info HOB
    eaffa1d7ff UefiCpuPkg:Wake up APs after power-up or RESET through SIPI.
    1d76560146 OvmfPkg: Disable PcdFirstTimeWakeUpAPsBySipi.
    98e9d29e06 UefiCpuPkg: Add PcdFirstTimeWakeUpAPsBySipi
    055c7bd1a7 UefiCpuPkg: Add SendStartupIpiAllExcludingSelf
    991515a058 CryptoPkg: remove BN and EC accel for size optimization
    e91bfffd4f CryptoPkg/openssl: update CI config for openssl 3.0
    46226fb5d3 CryptoPkg: remove strcmp to syscall
    c0aeb92663 CryptoPkg: run configure.py to update all generated files
    dfa6147a79 CryptoPkg: add more dummy implement of openssl for size optimization
    2bead79cfc CryptoPkg: add implemention of _ftol2_sse() to avoid build error
    b2ff8e45db CryptoPkg: add define of maximum unsigned size_t
    4b5faa5775 CryptoPkg: add missing gcc instructions
    43e0ede26b CryptoPkg: Enable memcpy sys call in RISCV64 build
    f0d3e59754 CryptoPkg: Align with 4096 when build with OpensslFullAccel
    bdf3142eb7 CryptoPkg/TlsLib: use unsigned long for ErrorCode
    20193b20b5 CryptoPkg: disable C4133 warning in openssl libraries
    bf1ff73c8c CryptoPkg: Add instrinsics to support building openssl3 on IA32 windows
    cea8e3b513 CryptoPkg: adapt 3.0 change in SslNull.c
    ea7a37d352 CryptoPkg: use UEFI provider as default
    9b9b331e0f CryptoPkg: Move all UEFI implement of openssl to OpensslStub
    5e1900f266 CryptoPkg/openssl: adapt EcSm2Null.c for openssl 3.0
    174a306ccd CryptoPkg/openssl: store dummy update for openssl 3.0
    3af00aec7f CryptoPkg/openssl: move compiler_flags to buildinf.c
    c638d1f672 CryptoPkg/openssl: adapt rand_pool.c to openssl 3.0 changes
    eac38f74c4 CryptoPkg/TlsLib: ERR_GET_FUNC is gone
    2a6dc1211f CryptoPkg/BaseCryptLib: drop BIO_* dummy functions
    63c8d160ae CryptoPkg/BaseCryptLib: adapt CryptSm3.c to openssl 3.0 changes.
    84158d0ebe CryptoPkg/BaseCryptLib: no openssl deprecation warnings please
    ac492c3ead CryptoPkg/openssl: UefiAsm.conf update for openssl 3.0
    81f5aa0700 CryptoPkg/openssl: add openssl3 configure scripts
    7cede6d5f4 CryptoPkg/openssl: update Openssl*.inf files for openssl 3.0
    49a113a7a4 CryptoPkg/openssl: cleanup all openssl1.1.1 generated files and code
    9d6d237c3c CryptoPkg/openssl: update submodule to openssl-3.0.9
    136931c4db MedPkg/Include: Add PCI_EXPRESS_EXTENDED_CAPABILITY_DVSEC_ID
    3c274c0d83 MdePkg: Add new status codes to PrintLib
    107ddf1de9 MdePkg: Add missing status codes
    2d8c17a9b6 OvmfPkg/PlatformCI: Boot OVMF in SMP mode.
    bae848ee25 OvmfPkg/PlatformCI VS2019: Disable workaround for cpuhp bugfix
    744c42bfd8 OvmfPkg/PlatformCI: Use recent Qemu on Windows
    01ad4134c3 MdeModulePkg: Solve boot hang Xhci driver when use USB DVD with empty disk
    ef05145136 ArmPkg: DefaultExceptionHandlerLib: Do Not Allocate Memory
    7672d1cca5 MdeModulePkg/SetupBrowser: Load storage via GetVariable for EfiVarStore
    fa789cc68a BaseTools: scan Edk2ToolsBuild.py make output
    5cadb8ce21 BaseTools: BinToPcd: Resolve xdrlib deprecation
    d11968fcc5 MdeModulePkg/Bus/Ata/AtaAtapiPassThru: Fix UNUSED_VALUE Coverity issue
    c7c1170a45 MdeModulePkg/Bus/Ata/AtaAtapiPassThru: Fix SIGN_EXTENSION Coverity issue
    677f2c6f15 OvmfPkg/RiscVVirt: Update README for CLANGDWARF support
    3f49462558 BaseTools/tools_def: Add CLANGDWARF support for RISC-V
    0f9fd06919 OvmfPkg/RiscVVirt: SecEntry: Remove unnecessary assembly directives
    8543840cfd OvmfPkg/RiscVVirt: use 'auto' alignment and FIXED for XIP modules
    70f3e62dc7 OvmfPkg/BhyvePkg: enable bus enumeration
    f284981506 Revert "OvmfPkg/Bhyve: remove IncompatiblePciDeviceSupport DXE driver"
    1c923b9f25 Revert "OvmfPkg/Bhyve: consume PciHostBridgeLibScan"
    c7a7f09c1d UefiCpuPkg: Decouple the SEV-ES functionality.
    25a6745fe8 RedfishPkg/RedfishDiscoverDxe: fix netmask check issue
    dcf05f958e MdePkg/Include/IndustryStandard: Remove VS20xx workaround
    5309ddc83b EmulatorPkg/Win/Host: Fix RUNTIME_FUNCTION redefinition error
    925c445fd3 OvmfPkg/RiscVVirt: Avoid printing hard coded timeout value
    7427dd3fc0 OvmfPkg/RiscVVirt: Check "no-map" and mark EfiReservedMemoryType
    c6b512962e UnitTestFrameworkPkg: UnitTestPersistenceLib: Save Unit Test Cache Option
    b2de9ec5a7 CryptoPkg/OpensslLib: Upgrade OpenSSL to 1.1.1u
    6510dcf6f7 NetworkPkg/HttpDxe: fix driver binding start issue.
    a52044a9e6 OvmfPkg/IoMmuDxe: add locking to IoMmuAllocateBounceBuffer
    08aacbf056 OvmfPkg/CloudHv: update Maintainers.txt entry
    4d1014093f UefiCpuPkg: Uses gMmst in MmSaveStateLib
    39ded59c09 OvmfPkg/PeilessStartupLib: Updated with PcdSecureBootSupported
    3399f64588 RedfishPkg/RedfishRestExDxe: reset session when TCP timeout happens
    dd49d448b0 MdeModulePkg/Bus/Pci/EhciDxe: Fix FORWARD_NULL Coverity issues
    f220dcbba8 UefiCpuPkg: RISC-V: Support MMU with SV39/48/57 mode
    cc13dcc576 OvmfPkg: RiscVVirt: Remove satp bare mode setting
    33d0a3cc92 OvmfPkg/RiscVVirt: Add VirtNorFlashDxe to APRIORI list
    a8a72fc1ff OvmfPkg/RiscVVirt: SEC: Add IO memory resource hob for platform devices
    a9fc9bb466 OvmfPkg/RiscVVirt: VirtNorFlashPlatformLib: Fix wrong flash size
    fbec9aec00 MdePkg/Register: RISC-V: Add satp mode bits shift definition
    7178047402 MdePkg/BaseLib: RISC-V: Support getting satp register value
    e674096acc OvmfPkg/ResetVector: Fix assembler bit test flag check
    ff3382a51c MdeModulePkg/Bus/Usb/UsbNetwork/UsbCdcNcm: Add USB Cdc NCM devices support
    5e400d22a0 MdeModulePkg/Bus/Usb/UsbNetwork/UsbCdcEcm: Add USB Cdc ECM devices support
    fc0d5922f1 MdeModulePkg/Bus/Usb/UsbNetwork/UsbRndis: Add USB RNDIS devices support
    8dab4eebe4 UefiPayloadPkg: Integrate UiApp and BootManagerMenuApp into MultiFv
    964a4f032d UefiCpuPkg: Eliminate the second INIT-SIPI-SIPI sequence.
    629c1dacc9 UefiCpuPkg: ApWakeupFunction directly use CpuMpData.
    8bb018afaf UefiCpuPkg: Create MpHandOff.
    243212b0d0 UefiCpuPkg: Refactor the logic for placing APs in Mwait/Runloop.
    88f436883b UefiCpuPkg: Refactor the logic for placing APs in HltLoop.
    63923a5642 MdeModulePkg/Variable: TcgMorLockSmm Key Mismatch changes lock state
    96d691166f RedfishPkg/RedfishDebugLib: add new interfaces
    60475162a6 RedfishPkg/JsonLib: add object clear interface
    b164b6d149 RedfishPkg/RedfishPlatformConfigDxe: hide debug message
    98ab6e8718 RedfishPkg/RedfishRestExDxe: fix CPU exception in RedfishRestExDxe
    af8859bce2 OvmfPkg/PlatformCI: Skip GCC5_OVMF_IA32X64_FULL_NOOPT build
    1fadd18d0c UefiCpuPkg: Get processor extended information for SmmCpuServiceProtocol
    6c744465b6 ArmPkg: Add Function Headers to MMU Logic
    3b74b0394d ArmPkg: Fix Unsafe ASSERTs in MMU Logic
    1b25a7049c ArmPkg: Update GetMemoryRegion() to Handle No mapping
    cdbdd12460 ArmPkg: Apply Uncrustify to Non-Compliant Files
    f2188fe5d1 OvmfPkg: Uses MmSaveStateLib library
    fbb6f18e1c UefiCpuPkg: Removes SmmCpuFeaturesReadSaveStateRegister
    065fa2dcc2 UefiCpuPkg: Implements MmSaveStateLib for Intel
    867851dc30 UefiCpuPkg: Implements SmmCpuFeaturesLib for AMD Family
    11dae72d3f UefiCpuPkg/SmmCpuFeaturesLib: Restructure arch-dependent code
    775b337c78 UefiCpuPkg: Implements MmSaveStateLib library instance
    4f3ddc6e15 UefiCpuPkg: Adds MmSaveStateLib library class
    8d34c7afb3 MdePkg: Adds AMD SMRAM save state map
    ad7d3ace1a UefiCpuPkg: CpuTimerDxeRiscV64: Fix timer event not working correctly
    5a13f5c2fa RedfishPkg: Fix SortLib library class name typo.
    f5c987fcac UefiCpuPkg/PiSmmCpuDxeSmm: Remove unnecessary function
    4ceefd6dd1 UefiCpuPkg: Refinement to smm runtime InitPaging() code
    b4394cca2d UefiCpuPkg: Sort mProtectionMemRange when ReadyToLock
    7132df94ac UefiCpuPkg: Sort mSmmCpuSmramRanges in FindSmramInfo
    b4dde1ae6a UefiCpuPkg: Use GenSmmPageTable() to create Smm S3 page table
    701b5797b2 UefiCpuPkg: Add GenSmmPageTable() to create smm page table
    d706d9c64a UefiCpuPkg: Extern mSmmShadowStackSize in PiSmmCpuDxeSmm.h
    ef64ae06f8 UefiCpuPkg/PiSmmCpuDxeSmm: Clear CR0.WP before modify page table
    7b6e7d0098 UefiCpuPkg/PiSmmCpuDxeSmm: Add 2 function to disable/enable CR0.WP
    f51967280b UefiCpuPkg/PiSmmCpuDxeSmm: Avoid setting non-present range to RO/NX
    6585ced558 UefiCpuPkg: Add DEBUG_CODE for special case when clear RP
    2d212083d0 UefiCpuPkg: Use CpuPageTableLib to convert SMM paging attribute.
    8c99839776 MdeModulePkg: Remove other attribute protection in UnsetGuardPage
    a78938f274 OvmfPkg:Remove code that apply AddressEncMask to non-leaf entry
    6607062e91 MdeModulePkg: Variable: Introduce MM based variable read service in PEI
    01ac3d8b69 ArmPkg: MmCommunicationPei: Introduce MM communicate in PEI
    4416bf3383 NetworkPkg: Correct the length of EAP Identity when in ASCII format
    44a3d93af3 Maintainers.txt: Update NetworkPkg maintainers and reviewers
    1a39bdf2c5 BaseTools/tools_def: Add "-fno-unwind-tables" to GCC5_RISCV64_CC_FLAGS
    ea7a3015a2 OvmfPkg/VirtioSerialDxe: Remove noisy debug print on supported() call
    2f8b51d6af ArmPkg/OpteeLib: Map shared communication buffer non-executable
    8a1f540596 ArmPkg: Drop individual memory permission helpers
    7054f1a54e StandaloneMmPkg: Include correct MmuLib header
    28eb51dd54 UefiCpuPkg/ResetVector: Remove pre-built binaries
    8ef7e222ae UefiCpuPkg/ResetVector: Add guidance of FDF ffs rule
    ab85db3260 UefiCpuPkg: Include ResetVector in DSC
    81cb0371f9 CI: Use latest image for Linux jobs (Qemu 8, gcc 12)
    638dfb4135 OvmfPkg/PciHotPlugInitDxe: fix io window size
    5542e528cd ArmPkg/CpuDxe: Simplify memory attributes protocol implementation
    a21a994f55 MdeModulePkg/DxeIpl ARM AARCH64: Switch to generic handoff code
    4249829cf2 ArmPkg/CpuPei: Implement the memory attributes PPI
    8f5ad634ad ArmPkg/ArmMmuLib: Extend API to manage memory permissions better
    9df2c0a555 MdeModulePkg/DxeIpl: Use memory attribute PPI to remap the stack NX
    dfacaab57e MdeModulePkg/DxeIpl: Merge EBC, RISCV64 and LOONGARCH code
    9eb8f2c99f MdeModulePkg: Define memory attribute PPI
    ac33eee8b8 IntelFsp2WrapperPkg: Get HobListPtr before calling the Multiphase FSPS
    5779671137 OvmfPkg/Bhyve: include TPM driver
    c301291dc3 OvmfPkg/Bhyve: install Acpi tables provided by FwCfg
    5a118a61d1 OvmfPkg: move QemuFwCfgAcpi into AcpiPlatformLib
    0f612c1443 OvmfPkg: move BootScript into AcpiPlatformLib
    ea88df6b26 OvmfPkg: move PciEncoding into AcpiPlatformLib
    f5d851673d OvmfPkg: avoid including AcpiPlatformLib twice
    8f63f4143d OvmfPkg/Library: fix definition of GetAcpiRsdpFromMemory
    6ee981c858 SecurityPkg: SubClassTpm: Updated default value
    7c703f0a8a MdePkg: PiStatusCode: Add TPM subclass definition to MdePkg
    e7667b7b9a MdePkg: PiStatusCode: Add new Host Software class Error Code to MdePkg
    49f06b6640 OvmfPkg/RiscVVirt: Add a readme for build and test
    37423fa344 OvmfPkg/RiscVVirt: Add support for separate code and variable store
    420cd54993 OvmfPkg/RiscVVirt: Add VirtNorFlashDeviceTreeLib library
    f6c4b0a78e OvmfPkg/RiscVVirt: Fix couple of issues in VarStore
    fcd71642df MdePkg: Code optimization to SMM InternalAllocateAlignedPages
    56f65e4bad MdeModulePkg/SmmCore: Perf-log PlatformHookBefore/AfterSmmDispatch
    a87f5fdb3d UefiCpuPkg/SmmCpu: Add PcdSmmApPerfLogEnable control AP perf-logging
    2d3974a351 MdeModulePkg/SmmCorePerformanceLib: Disable perf-logging at runtime
    92759eeb0c MdeModulePkg/SmmPerformanceLib: Disable perf-logging after ExitBS
    0c136bbba0 MdeModulePkg/SmmCore: Add perf-logging for SmmDriverDispatchHandler
    e4ff852136 MdeModulePkg/SmmCore: Add perf-logging for time-consuming procedures
    ad6c8540cc UefiCpuPkg/CpuSmm: Add perf-logging for MP procedures
    0da3df78ff UefiCpuPkg/CpuSmm: Add perf-logging for time-consuming BSP procedures
    4a0642ad27 Maintainers.txt: update maintainer for CryptoPkg
    ea55bd8f66 UefiCpuPkg: RISC-V: TimerLib: Fix delay function to use 64-bit
    4dba2a9d08 UefiCpuPkg: CpuTimerDxeRiscV64: Fix incorrect value sent to SbiSetTimer
    aad98d915a UefiPayloadPkg: Fix incorrect code on AddSectionHeader
    51bb8eb76c UefiPayloadPkg: Add CAPSULE_SUPPORT in UPL and set it as FALSE in default
    6250124de8 Maintainers.txt: Remove me from maintainers of UefiPayloadPkg,ShellPkg
    e5b515f832 Maintainers.txt: Remove UEFI Shell Binaries section
    530f5b0912 UnitTestFrameworkPkg: Add UnitTestPeiServicesTablePointerLib
    8314a85893 ShellPkg/SmbiosView: type 45 and type 46 support.
    69abcf1e78 UefiPayloadPkg: Enhance build script for BuildEntryOnly
    8d238f1433 Maintainers.txt: Update maintainers for StandaloneMmPkg
    aa3ea84407 Maintainers.txt: Remove reviewer for StandaloneMmPkg
    c082da89cf RedfishPkg: update Readme.md
    67fc78d026 MdeModulePkg/Bus: Fix port multiplier port in AhciPei PEIM
    ded0b489af MdePkg/BaseLib: Add SpeculationBarrier implementation for RiscV64
    d189de3b0a MdePkg ACPI65: Update MADT Revision pre ACPI Spec 6.5
    cdd20638bc CharEncodingCheckPlugin: Remove Noisy Print
    4bd0849d81 OvmfPkg/Bhyve: install ACPI tables from memory
    1288c5415c OvmfPkg/Xen: export AcpiTable installation into AcpiPlatformLib
    f211292711 OvmfPkg/Xen: export search of RSDP into a library function
    c1dd400a13 OvmfPkg: Create additional PML1 entries for large SEV-SNP VMs
    8fbf857a0b OvmfPkg/RiscVVirt: Remove unimplemented NxForStack configuration
    4354c22f38 ArmPkg: add SMC defines for SiP service calls
    0364ccfead ArmPkg: Enable AuditMode for Uncrustify CI checks
    a8acc12dfd ShellPkgDisconnect: zero-initialize handles
    78262899d2 ShellPkg: Add a condition to print accurate type0 Bios Size in smbiosview.
    41abf00bf9 OvmfPkg: Remove SataControllerDxe
    77fee3a9d8 OvmfPkg/Xen: Replace the OVMF-specific SataControllerDxe
    07c7e68360 OvmfPkg/AmdSev: Replace the OVMF-specific SataControllerDxe
    069d403587 OvmfPkg/IntelTdx: Replace the OVMF-specific SataControllerDxe
    b26359c176 OvmfPkg/CloudHv: Replace the OVMF-specific SataControllerDxe
    d85b84e201 OvmfPkg/Bhyve: Replace the OVMF-specific SataControllerDxe
    bc59ede170 OvmfPkg/Microvm: Replace the OVMF-specific SataControllerDxe
    f5137e1a54 OvmfPkg: Replace the OVMF-specific SataControllerDxe
    2bc46e67b6 MdeModulePkg/SataControllerDxe: Fix up ASSERTS (Private != NULL)
    82b81c6464 MdeModulePkg/SataControllerDxe: Remove useless null check
    897a2b447e MdeModulePkg/SataControllerDxe: Log expected errors at DEBUG_INFO level
    5e8958472c MdeModulePkg/SataControllerDxe: Clean up error handling in Start()
    ded1d5414b ArmPkg: Fix ArmGicAcknowledgeInterrupt () for GICv3
    8bcddbcce2 ArmPkg: Adjust variable type and cast for RegShift & RegOffset
    8da2b97392 ArmPkg: Prevent SgiId from setting RES0 bits of GICD_SGIR
    cfb4a10d76 ArmPkg: Remove unused function declarations
    08a08129ae ArmPkg: Typecast IntID to UINT32 in ArmGicV2EndOfInterrupt
    7f198321ee ArmPkg: Make variables used for GicInterrupt UINTN
    937fbe4878 ArmPkg: Fix return type for ArmGicGetInterfaceIdentification
    ed132ef8ae ArmPkg: Fix Non-Boolean comparison in ArmGicEnableDistributor
    ea522a12b3 ArmPkg: Fix ArmGicSendSgiTo() parameters
    a44fef7de3 ArmPkg: Fix data type used for GicInterruptInterfaceBase
    4ec9a6f6cd ArmPkg: Fix data type used for GicDistributorBase
    b38068f9f6 ArmPkg: Fix GicV2 BaseAddress types
    15f83fa364 ArmVirt/PlatformBootManagerLib: set up virtio serial as console
    aaf546879a ArmVirt/PlatformBootManagerLib: factor out IsVirtioPci()
    a196b04926 ArmVirt/PlatformBootManagerLib: factor out IsVirtio()
    6925150feb ArmVirt: add VirtioSerialDxe to ArmVirtQemu builds
    1df6658bcb BaseTools: remove duplicate includes: IndustryStandard/*.h
    6101bd125a BaseTools: remove duplicate includes: IndustryStandard/PeImage.h
    c15941a643 BaseTools: switch from EFI_IMAGE_MACHINE_* to IMAGE_FILE_MACHINE_*
    fdc6288f81 BaseTools: drop IMAGE_FILE_MACHINE_ARM hacks
    ff52068d92 MdePkg/PeImage.h: add bits from BaseTools version
    26d6ef38e7 BaseTools: remove duplicate includes: IndustryStandard/Acpi*.h
    69ac88cabd BaseTools: remove duplicate includes: <arch>/ProcessorBind.h
    6a07d9cacf BaseTools: remove WinNtInclude.h
    140e4422b1 MdePkg: don't set visibility to hidden
    bd035a066f BaseTools: add -fdirect-access-external-data to clang pie builds
    7ffc433c2e BaseTools: make sure the got is empty
    c1e8537690 OvmfPkg/PlatformInitLib: limit phys-bits to 46.
    578a715cfc OvmfPkg/QemuFlashFvbServicesRuntimeDxe: refine flash detection
    4e5a804222 OvmfPkg/VirtioSerialDxe: use TPL_NOTIFY
    9f12d6b6ec UefiCpuPkg/PiSmmCpuDxeSmm:add Ap Rendezvous check in PerformRemainingTasks.
    5bb7bfbe81 UefiCpuPkg/CpuService.c:check cpu sync mode in SmmCpuRendezvous()
    d15d2667d5 RedfishPkg: Use DEBUG_MANAGEABILITY
    d8e5d35ede UefiPayloadPkg: Add CpuPageTableLib required by SecCore & CpuMpPei
    55bee4a9de OvmfPkg: Add CpuPageTableLib required by SecCore & CpuMpPei
    0d382976c2 MdeModulePkg/DxeIpl: Align Page table Level setting with previous level.
    56ad09ba75 UefiCpuPkg/CpuMpPei: Conditionally enable PAE paging in 32bit mode
    b4d3b77973 UefiCpuPkg/SecCore: Migrate page table to permanent memory
    0f9283429d UefiCpuPkg/ResetVector: Support 5 level page table in ResetVector
    d064a6f790 UefiCpuPkg/ResetVector: Modify Page Table in ResetVector
    0fba57da65 UefiCpuPkg/ResetVector: Combine PageTables1G.asm and PageTables2M.asm
    c19e3f578f UefiCpuPkg/ResetVector: Simplify page table creation in ResetVector
    cc62b85a4a UefiCpuPkg/ResetVector: Rename macros about page table.
    48c53994e6 IntelFsp2Pkg/Library/BaseFspCommonLib: Fix OVERRUN Coverity issue
    69e10f0211 IntelFsp2WrapperPkg: Fix ASSERT when FSP-S/M use FFS3.
    9d9761af50 RedfishPkg/RedfishPlatformConfigDxe: fix value type issue.
    1034d223f8 ArmPkg/CpuDxe: Perform preliminary NX remap of free memory
    03663c4319 ArmVirtPkg/ArmVirtQemu: Use read-only memory region type for code flash
    8e934ab956 ArmVirtPkg: Dispatch variable service if variable emulation is enabled
    84d0b21d18 ArmVirtPkg: Fallback to variable emulation if no CFI is found
    0e5aecfed1 ArmVirtPkg: Define variables for emulating runtime variables
    86cc274941 ArmPkg: Configure PcdEmuVariableNvModeEnable as a dynamic PCD
    0b4263a2c2 ArmVirtPkg/PrePi: Allocate separate stack for Dxe phase
    647cd40cf6 ArmPkg/CpuDxe AARCH64: Report Memory Protection Attributes To GCD
    04c5b3023e OvmfPkg/MicrovmX64: enable 1G pages
    b63e17d746 OvmfPkg/OvmfPkgIa32X64: enable 1G pages
    d4d24001f7 OvmfPkg/PlatformInitLib: check PcdUse1GPageTable
    27727338b2 OvmfPkg/PciHotPlugInitDxe: Do not reserve IO ports by default.
    9181782c30 OvmfPkg/Bhyve/PlatformPei: drop S3Verification()
    098c557023 OvmfPkg/PlatformPei: drop S3Verification()
    c0bce66068 OvmfPkg/VirtIoSerialDxe: Update for VS2015x86 compatibility
    e1f5c6249a MdeModulePkg SdMmcPciHcDxe: SD/MMC capability debug print is incorrect
    5258c4186f RedfishPkg/RedfishPlatformConfigDxe: Fix string assert issue
    ba2300f97b PcAtChipsetPkg: RTC Runtime unable to get correct IO port by PCD
    0f8323b44b BaseTools: toolsetup.bat always execute PYTHON_HOME
  - Removed patches which are merged to edk2-stable202308:
  - ovmf-riscv64-missing-memcpy.patch
    CryptoPkg: Enable memcpy sys call in RISCV64 build
  - 43e0ede26b    edk2-stable202308~15
  - Upgrade OpenSSL to 3.0.9
  - Add openssl-3.0.9.tar.gz      openssl-3.0.9.tar.gz.asc  openssl.keyring
  - Update openssl.keyring, openssl.keyring.README
  - Update ovmf.spec:
    Source1:        https://www.openssl.org/source/old/3.0/openssl-%%{openssl_version}.tar.gz
    Source111:      https://www.openssl.org/source/old/3.0/openssl-%%{openssl_version}.tar.gz.asc
  - Removed EFI shell from ia32 ovmf because the flash space is not enough.
  - Update ovmf.spec: Add IA32 BUILD_SHELL=FALSE to BUILD_OPTIONS_X86
  - After 37423fa344 OvmfPkg/RiscVVirt: Add support for separate code and variable store
    be merged to edk2-stable202308. RISC-V supported (and only supported)
    separate code/vars stores. So changed ovmf.spec.
    Add:
    cp Build/RiscVVirtQemu/DEBUG_GCC*/FV/RISCV_VIRT_CODE.fd ovmf-riscv64-code.bin
    cp Build/RiscVVirtQemu/DEBUG_GCC*/FV/RISCV_VIRT_VARS.fd ovmf-riscv64-vars.bin
    Remove statements relates to:
    qemu-uefi-riscv64.bin
* Thu Jul 20 2023 Joey Lee <jlee@suse.com>
- Removed the following patches because they are not necessary and
  they blocked for submit to openSUSE:Factory. (bsc#1205978)
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformAddHobCB.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformGetLowMem.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformReservati.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformScanE820-.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-reorder-PlatformQemuU.patch
* Thu Jul 20 2023 Joey Lee <jlee@suse.com>
- Add openssl.keyring.README to shim.spec as Source113 to avoid
  erroe when submit to openSUSE:Factory
* Wed Jul 19 2023 Andreas Schwab <schwab@suse.de>
- Enable support for riscv64
* Tue Jul 18 2023 Joey Lee <jlee@suse.com>
- Update to edk2-stable202305 (bsc#1205588)
  - Features (https://github.com/tianocore/edk2/releases):
    Expose IBT/BTI compatible runtime DXE drivers via memory attributes table
    Update toolchain support
    MdePkg: Support FDT library
    Add google mocks support to UnitTestFrameworkPkg GoogleTestLib
    Platform Redfish Host Interface library for USBNIC
    [OpenSSL] Update OpenSSL version to version 1.1.1t to include CVE fix
    Replace pre-standard FUNCTION with C99 func throughout edk2
    Implement EFI memory attributes protocol for ARM platforms
    Add TraceHubLib Support
  - Patches (git log --oneline --date-order edk2-stable202302..edk2-stable202305):
    ba91d0292e MdeModulePkg/Core/Pei: set AprioriCount=0 before walking through next FV
    5ce29ae84d ArmPkg/ArmMmuLib AARCH64: Add missing ISB after page table update
    c5cf7f69c9 pip-requirements.txt: Update edk2 pip modules
    0abfb0be6c OvmfPkg: RiscVVirt: Add missing SerialPortInitialize to Sec
    45da4e3135 MdePkg: add SBI-based SerialPortLib for RISC-V
    2900e75511 MdePkg: BaseRiscVSbiLib: make more useful to consumers
    cafb4f3f36 UefiPayloadPkg: Fix boot shell issue for universal UEFI payload
    80bc13db83 Maintainers.txt: Update reviewers and maintainers for FdtLib.
    d322557712 BaseTools/tools_def: Disable overzealous unused variable warning on Clang
    e2607d3a78 BaseTools/tools_def: Drop ref to undefined CLANGDWARF_ARM_PREFIX
    0b37723186 ShellPkg/UefiShellDebug1CommandsLib: Replace hardcoded SMBIOS strings.
    2d4c76f783 MdePkg/IndustryStandard: Add SMBIOS anchor string & length defines.
    c08a3a96fd MdePkg/IndustryStandard: Add IPMI Interface Capabilities definitions
    083b029538 MdePkg: Add new PCDs for IPMI SSIF
    dea6c7dc2a MdePkg/IndustryStandard: Add definitions for IPMI SSIF
    0a0e60caf2 Maintainers.txt: Update reviewers and maintainers for TraceHubDebugLib.
    0f0422cedc MdeModulePkg: Add TraceHubDebugSysTLib library
    3d50fdc5c6 MdePkg: Add NULL library of TraceHubDebugSysTLib
    c6bb7d54be MdePkg: Add MipiSysTLib library
    782948c1a7 MdePkg: Add mipisyst submodule
    6dd64168ed BaseTools/Plugin: Too many execute files cause "cmd too long" failure
    c6382ba0f2 SecurityPkg: Add missing break in Tpm2TestParms
    77f75c7fb8 BaseTools: Update Tests/TestTools.py to allow it to work on Windows
    b9bbb4ae93 BaseTools: only print the environment once in toolsetup.bat
    dd246227d6 BaseTools: Update toolsetup.bat to not use BASETOOLS_PYTHON_SOURCE
    f47415e031 BaseTools: Revert Set the CLANGDWARF OBJCOPY path in tools_def.template
    6fb2760dc8 OvmfPkg: drop PlatformBootManagerLibGrub
    81dc0d8b4c OvmfPkg/AmdSev: stop using PlatformBootManagerLibGrub
    63887e272d OvmfPkg/NvVarsFileLib: disable in case PcdBootRestrictToFirmware is set
    41d7832db0 OvmfPkg/PlatformBootManagerLib: add PcdBootRestrictToFirmware
    e6447d2a08 Remove bashisms from edksetup.sh and BaseTools/BuildEnv
    373a95532a BaseTools: Remove the CLANGCC build rule for Hii-Binary-Package.UEFI_HII
    ecbc394365 BaseTools: Set CLANGDWARF RC path to llvm-objcopy in tools_def.template
    11f62f4cc0 BaseTools: Set the CLANGDWARF OBJCOPY path in tools_def.template
    c6f47e678f BaseTools: Remove BUILDRULEFAMILY from CLANGDWARF in tools_def.template
    9165a7e95e CryptoPkg: Delete CLANG35 and CLANG38 build flags; add CLANGDWARF flags
    e97b9b4e5a MdePkg: Add more HobLib/PeiServicesLib gmock support
    25c9d44315 MdeModulePkg: Add more PciHostBridgeLib gmock support
    bee67e0c14 OvmfPkg: Relax assertion that interrupts do not occur at TPL_HIGH_LEVEL
    ae0be176a8 OvmfPkg: Clarify invariants for NestedInterruptTplLib
    5215cd5baf BaseTools: Update toolsetup.bat and Tests/PythonTest.py to check ver
    e6de6052a0 edksetup.bat: if toolsetup.bat fails, just exit
    11ec5161fa BaseTools: use threading.current_thread in NmakeSubdirs.py
    db7e6291c0 BaseTools: Remove Python2/Python3 detection from toolset.bat
    6eeb58ece3 RedfishPkg: Fix compile issue on Linux
    665fca9ee7 RedfishPkg: Add missing newline character
    a1f6485a9b RedfishPkg: Create RestEx child on selected interface
    05762bd2e0 RedfishPkg: Fix condition checking of error status
    c580e27efc RedfishPkg: Correct variable type to prevent memory corruption
    d89492456f Securitypkg/hddpassword: Update HddPasswordDxeInit to use Variable Policy
    8dbf868e02 Add volatile keyword to NvmExpressPei's Passthru CQ
    293b97d0c4 Add the volatile keyword to NvmExpressDxe's Passthru CQ
    4dea9e4a0e BaseTools/Conf: Add quotes to ADDDEBUGFLAG in tools_def.txt
    8e985ac3fd BaseTools/Conf: Align CLANGDWARF and CLANGPDB warning overrides
    66494e5324 MdeModulePkg/CapsuleApp: Add EFIAPI to CompareFileNameInAlphabet()
    eabaeb0613 OvmfPkg: move OvmfTpmDxe.fdf.inc to Include/Fdf
    8bca1bb977 OvmfPkg: move OvmfTpmPei.fdf.inc to Include/Fdf
    b65c0eed6b BaseSynchronizationLib: Fix LoongArch64 synchronization functions
    757f502a3b BaseTools/Conf/tools_def.template: Bump VERSION to 3.00
    050d6e9434 BaseTools: Delete CLANG38 from tools_def.template
    128547b081 BaseTools: Remove CLANG35 toolchain from tools_def.template
    4ef4b81c9b BaseTools: As with CLANGDWARF IA32 and X64, use lld for ARM and AARCH64
    98edce75fa BaseTools: Add ARM and AARCH64 CLANGDWARF support in tools_def.template
    0fc07b1c6a BaseTools/Conf/tools_def.template: Add section for deprecated toolchains
    01225075db Add GCC and GCCNOLTO toolchains to tools_def.txt and update packages
    66803cafcf BaseTools: Update VS toolchain descriptions in tools_def.txt.template
    d7c6030a47 BaseTools: Remove EBC (EFI Byte Code) compiler definitions
    8b441847e3 BaseTools: Remove unused IPHONE_TOOLS and SOURCERY_CYGWIN_TOOLS defs
    ba634ce82b edksetup.bat: Remove VS2008-VS2013 remnants
    c844d86bee MdePkg: Remove VS2008-VS2013 remnants
    c3ac3301e9 BaseTools: Remove VS2008-VS2013 remnants
    0363584ac9 BaseTools: Remove VS2008, 2010, 2012 and 2013 toolchain definitions
    94c802e108 MdePkg/BasePeCoffLib: Deal with broken debug directories
    ff7cb2d7c9 .pytool: Support FDT library.
    5d586606c7 MdePkg: Support FDT library.
    10416bf46e Tianocore: Support FDT library.
    d992a05ade Maintainers.txt: Update for IntelFsp2Pkg and IntelFsp2WrapperPkg.
    4b02045f86 OvmfPkg/PlatformBootManagerLib: setup virtio serial console
    c6c4362051 OvmfPkg/VirtioSerialDxe: wire up in OvmfPkg*
    4d1452c599 OvmfPkg/VirtioSerialDxe: add driver
    1694b00511 OvmfPkg: add IndustryStandard/VirtioSerial.h
    92da8a154f OvmfPkg: replace SECURE_BOOT_FEATURE_ENABLED with PcdSecureBootSupported
    a818a873e5 ArmVirtPkg: allow setting Firmware Version from build command line
    8d59bbf47e OvmfPkg: allow setting Firmware Version from build command line
    5de2a54b2c ArmPkg/PlatformBootManagerLib: Add path to boot UEFI Shell over UiApp
    d6b42ed7ed SecurityPkg: add TIS sanity check (tpm12)
    832fbc6e32 SecurityPkg: add TIS sanity check (tpm2)
    23c71536ef UefiPayloadPkg: Fix issues when MULTIPLE_DEBUG_PORT_SUPPORT is true
    56e9828380 RedfishPkg: Add Redfish Platform Config Protocol to RedfishPkg
    83d77fa311 RedfishPkg: Helper library of EDKII_REDFISH_PLATFORM_CONFIG_PROTOCOL
    01b31b585e RedfishPkg: Implementation of EDKII_REDFISH_PLATFORM_CONFIG_PROTOCOL
    02990e2558 RedfishPkg: introduce HII utility helper library
    78f088b5a7 RedfishPkg: introduce EDKII_REDFISH_PLATFORM_CONFIG_PROTOCOL
    ecbcff0f49 MdeModulePkg/RegularExpressionDxe: Fix Arm build error
    d226811a66 SecurityPkg/DxeImageVerificationLib: Add AUTH_SIG_NOT_FOUND Action
    95ef765839 UefiPayloadPkg: Clang dependency removal
    e5e1cd1a83 .azurepipelines: Switch linux image default to Fedora-37
    04f8371cdd .azurepipelines: Choose container that have installed lcov
    9688e231d7 BaseTools/Plugin: Report error if code coverage failure
    edacc551e6 OvmfPkg/CcExitLib: Use documented XSave area base size for SEV-SNP
    ce781cf8bb OvmfPkg/CcExitLib: Fix SEV-SNP XSave area size calculation
    e5c7d0b017 OvmfPkg/AmdSevDxe: Update ConfidentialComputing blob struct definition
    f384303dc5 OvmfPkg/AmdSevDxe: Allocate SEV-SNP CC blob as EfiACPIReclaimMemory
    ede0bd1496 UefiCpuPkg: Update PT code to support enable collect performance
    61e2c83424 UefiCpuPkg: Update code to support enable ProcTrace only on BSP
    5a349b96b1 RedfishPkg: Remove the Discover Token global variables
    18f463edba DynamicTablesPkg/SsdtCpuTopology: Allow multi-packages topologies
    6127bf1f30 BaseTools: Add quotes around OBJCOPY cmd in build_rule.template
    2c2cb23528 ArmPkg: add ArmCpuInfo EFI application
    a7c8969d03 ArmLib: add functions to read system registers
    ed2ff315db MdePkg: Add DEBUG_MANAGEABILITY print error level
    3163f34a42 BaseTools/Plugin: Clarify code coverage failure message
    697e594fad MdePkg/Include: Add DMTF PLDM SMBIOS definitions
    9bf79303ae ArmPkg: older assemblers may lack ID_AA64ISAR2_EL1
    67b5dba791 UefiPayloadPkg: Move Network modules from Dxe FV to Network FV in elf
    45f5341f6d MdePkg/Include: Add DMTF PLDM Base definitions
    8f4ec0cc43 ArmPkg/ArmMmuLib: Fix ArmReplaceLiveTranslationEntry() alignment
    f433fa59d2 ArmPkg/AsmMacroIoLibV8: Introduce ASM_FUNC_ALIGN()
    e3d2c08322 CryptoPkg: Enable DXE_CORE support in DxeCryptLib.inf
    b16284e2a0 IntelFsp2Pkg/Tools: Enhance PathFv.py to patch Fd file directly
    6ded9f50c3 edk2: Add .git-blame-ignore-revs file
    797f526ae2 BaseTools: Update SetupGit.py to add new 'fp' alias for patch formatting
    c9fb11f92f BaseTools: Update PatchCheck.py to check for __FUNCTION__
    55b67b6950 MdeModulePkg/RegularExpressionDxe: Fix GCC build error
    d795fb571b Maintainer.txt: add myself as reviewer for bhyve's OvmfPkg
    42b0443599 ShellPkg: UefiShellDebug1CommandsLib: Uefi Config Tables in Dmem.c
    5430f7f60d MdePkg: Add new JedecJep106Lib to fetch JEDEC JEP106 manufacturer
    f9278458b6 OvmfPkg/VirtioMmioDeviceLib: virtio 1.0: Fix SetQueueAlignment.
    89520115b8 UefiPayloadPkg: Update default memory type information for S4
    dc5f2905eb UefiPayloadPkg: Always build MemoryTypeInformation HOB for DXE GCD
    b991aec050 UefiCpuLib: Remove UefiCpuLib.
    51734dfc48 ShellPkg: Update smbiosview type 0/4/17/41 with SMBIOS 3.5 fields
    61652efd04 FmpDevicePkg: Update code to be more C11 compliant by using __func__
    33f30cfec2 UefiPayloadPkg: Update code to be more C11 compliant by using __func__
    66f6a64dd9 EmulatorPkg: Update code to be more C11 compliant by using __func__
    457b4e42f7 SourceLevelDebugPkg: Update code to be more C11 compliant by using __func__
    84f553cb63 NetworkPkg: Update code to be more C11 compliant by using __func__
    74ce342f18 CryptoPkg: Update code to be more C11 compliant by using __func__
    f1d31a6ec7 StandaloneMmPkg: Update code to be more C11 compliant by using __func__
    9e7b042ecb PrmPkg: Update code to be more C11 compliant by using __func__
    1295e37d4b UnitTestFrameworkPkg: Update to be more C11 compliant by using __func__
    f20e35982b ArmPlatformPkg: Update code to be more C11 compliant by using __func__
    997419d16f RedfishPkg: Update code to be more C11 compliant by using __func__
    ccbbb4b1c5 EmbeddedPkg: Update code to be more C11 compliant by using __func__
    dd0b33e3e5 SecurityPkg: Update code to be more C11 compliant by using __func__
    7b82da70ed MdeModulePkg: Update code to be more C11 compliant by using __func__
    8ba392687b OvmfPkg: Update code to be more C11 compliant by using __func__
    089013a697 UefiCpuPkg: Update code to be more C11 compliant by using __func__
    1639b6bf07 ArmVirtPkg: Update code to be more C11 compliant by using __func__
    f2cc962cd2 ArmPkg: Update code to be more C11 compliant by using __func__
    cf4af503fb PrmPkg/Library: HOST_APPLICATION IA32/X64 only
    b27b897369 MdeModulePkg: HOST_APPLICATION IA32/X64 only
    eb20c21fcc MdePkg/Library/BaseLib: HOST_APPLICATION IA32/X64 only
    358e23c1be SecurityPkg/Library/SecureBootVariableLib: HOST_APPLICATION IA32/X64 only
    0657e74116 SecurityPkg/Library/SecureBootVariableLib: Fix VS20xx 4122 errors
    c28c16e7c4 SecurityPkg: Add gmock example
    1a24843ecb MdeModulePkg/Library/UefiSortLib: Add GoogleTestLib example
    09458c2b0b MdePkg: Add gmock examples
    e4af282e9f UnitTestFrameworkPkg/ReadMe.md: Add gmock documentation
    d0252b8fc1 UnitTestFrameworkPkg:  Add gmock support to GoogleTestLib
    caa389625f .pytool/CISettings.py: Add subhook submodule
    0c6d851d25 UnitTestFrameworkPkg: Add subhook submodule required for gmock
    6405cd0304 MdeModulePkg: Enable forward edge CFI in mem attributes table
    d6457b3090 MdePkg/PeCoffLib: Capture DLL characteristics fields in image context
    b62d7ac97b BaseTools/GenFw: Add DllCharacteristicsEx field to debug data
    6c299acf48 BaseTools/GenFw: Parse IBT/BTI support status from ELF note
    cdf6ff1719 UefiPayloadPkg:Add new build commands for UniversalPayload
    3e3be2cbc2 UefiCpuPkg/CpuExceptionHandlerLib: Drop special XCODE5 version
    68c89b987f OvmfPkg: Drop special Xcode5 version of exception handler library
    e5fcaeb133 UefiCpuPkg/CpuExceptionHandlerLib: Make runtime fixups XCODE-only
    4764aa50ef UefiCpuPkg/PeiCpuExceptionHandlerLib: Use SEC/PEI specific asm component
    95f0330953 UefiCpuPkg/CpuExceptionHandlerLib: Use single SEC/PEI version
    a257988f59 BaseTools/tools_def CLANGDWARF: Permit text relocations
    8d185dfb66 BaseTools: Update antlr makefile to use cc by default
    2bb6938949 BaseTools/Conf/tools_def: Fix linking using CLANGDWARF_IA32
    a56ee36c49 BaseTools: Build against C++14 when building with clang
    728ff1da33 BaseTools: Allow users to build with clang using CC=clang CXX=clang++
    206168e83f BaseTools: Allow users to specify compiler to use with make CC= CXX=
    cdd79996c2 pip-requirements.txt: bump edk2-basetools to 0.1.43
    7df447930c IntelFsp2Pkg: LoadMicrocodeDefault() causing unnecessary delay.
    af98f1fb03 IntelFsp2Pkg: TempRamInit API should preserve EBX/RBX register.
    fb89f62d27 .azurepilelines/templates: Split CryptoPkg builds
    56e70968e9 .github.workflows: Split MdeModulePkg and CryptoPkg analysis
    26997800c9 .github/codeql/edk2.qls: Enable CWE 120, 787, and 805 queries
    0734975824 .github/codeql/edk2.qls: Enable CWE 457, 676, and 758 queries
    e03657dca8 UefiCpuPkg: Fix conditionally uninitialized variables
    11dd44dfbe ShellPkg: Fix conditionally uninitialized variables
    7dc182ed1e PcAtChipsetPkg: Fix conditionally uninitialized variables
    3fab32d41d NetworkPkg: Fix conditionally uninitialized variables
    321240b135 MdePkg: Fix conditionally uninitialized variables
    07251f3c6a MdeModulePkg: Fix conditionally uninitialized variables
    84d77d9bf5 CryptoPkg: Fix conditionally uninitialized variable
    dbe820d5fa BaseTools/VfrCompile: Fix potential buffer overwrites
    4693b325e8 BaseTools/PatchCheck.py: Add PCCTS to tab exemption list
    33f517445b MdeModulePkg/SmbiosDxe: Fix pointer and buffer overflow CodeQL alerts
    fc00ff286a .github/dependabot.yml: Disable automatic rebasing
    b4af23aaab .github/workflows/codeql-analysis.yml: Add PIP caching
    4ca4d2b9df UefiCpuPkg/MtrrLib: use new IS_POW2() macro.
    12d3d60f51 OvmfPkg: Consume new alignment-related macros
    495809a614 MdeModulePkg: Consume new alignment-related macros
    836042ffd8 MdePkg/Base.h: Introduce various alignment-related macros
    24e6daa2bc OvmfPkg: Rename IS_ALIGNED macros to avoid name collisions
    583f1aba8b MdeModulePkg: Rename IS_ALIGNED macros to avoid name collisions
    67a6f414aa UefiCpuPkg/MpInitLib: Ensure SEV-SNP VMSA allocations are not 2MB aligned
    3323359a81 UefiCpuPkg/MpInitLib: Reuse VMSA allocation to avoid unreserved allocation
    54051768cd UefiCpuPkg/PiSmmCpuDxeSmm: fix format string
    71210053fa UefiCpuPkg/MtrrTest: Add test cases for TME-MK enable case
    bb40c3836f UefiCpuPkg/CpuDxe: Substract TME-MK KEY_ID_BITS from CPU max PA
    f2f526e074 UefiCpuPkg/CpuDxe: Refactor to use CPUID definitions
    263782f667 UefiCpuPkg/MtrrLib: Substract TME-MK KEY_ID_BITS from CPU max PA
    bb5c115fa6 UefiCpuPkg/MtrrTest: Only claim CPUID max leaf as 1
    24f57f9648 MdePkg: Add TME-MK related CPUID and MSR definitions
    2f499c36db UefiCpuPkg/Test: Disable random test cases
    4dca07ff0f Maintainers.txt: BaseTools Bob Feng -> reviewer, Rebecca Cran -> maintainer
    eb6a748272 MdeModulePkg/Ahci: Skip retry for non-transient errors
    66f4b1b0d2 OvmfPkg/CI: Revert SMP mode
    b08a19eae2 .azurepipelines/templates: Increase run to shell timeout
    e9e6167123 PcAtChipsetPkg/PcatRealTimeClockRuntimeDxe:  PcdRtcDefaultYear bounds
    6f0c65cdb0 RedfishPkg/RedfishPlatformCredentialIpmiLib: IPMI implementation
    53eb26b238 MdePkg: Update MemoryAttributesTable to v2.10
    3b4d1b38ea ArmVirtPkg/ArmPlatformLibQemu: Make IdMap.S BTI compatible
    e701a4d51e ArmPlatformPkg/PrePeiCore: Make vector table object BTI compatible
    f484427d10 ArmPkg, BaseTools AARCH64: Add BTI ELF note to .hii objects
    77ea6b547e ArmPkg/GccLto AARCH64: Add BTI note to LTO helper library
    48d642a310 ArmPkg: Emit BTI opcodes when BTI codegen is enabled
    f8b1854b92 MdePkg/BaseRngLib AARCH64: Make asm files BTI compatible
    35318c2eb9 MdePkg/BaseSynchronizationLib AARCH64: Make asm files BTI compatible
    0ee255f50a MdePkg/BaseMemoryLibOptDxe AARCH64: Make asm files BTI compatible
    c4c7fb2174 MdePkg/BaseLib AARCH64: Make asm files BTI compatible
    e504b3917e MdePkg/BaseLib AARCH64: Make LongJump() BTI compatible
    ea1312a5b4 MdePkg/BaseIoLibIntrinsic AARCH64: Make asm files BTI compatible
    c5cd360277 MdePkg/BaseCpuLib AARCH64: Make asm files BTI compatible
    6521e4d202 MdePkg/ProcessorBind AARCH64: Add asm macro to emit GNU BTI note
    e3e88d90e8 UefiPayloadPkg: Support more input parameter
    f92a9dce10 OvmfPkg/CI: Boot OVMF in SMP mode.
    6f415f8af4 ArmVirtPkg: Fix depex in kvmtool guest Rtc library
    47b1d61169 ArmVirtPkg: Fix parsing of serial port node
    cc6a0cff99 DynamicTablesPkg: Fix parsing of serial port node
    31f0af7964 DynamicTablesPkg: Reduce log output from TableHelperLib
    b697a31a8d OvmfPkg: Use Xcode5 version of CpuExceptionHandlerLib for CLANGDWARF
    8f8e4fa3f3 OvmfPkg: Replace static struct initialization with ZeroMem call
    e3aba976f6 RedfishPkg: fix config handler driver issues
    0cd7542a69 RedfishPkg: Redfish discover driver improvement
    c2abf77116 RedfishPkg/JsonLib: address coverity issue
    5eb3d1bcc1 ArmVirtPkg: can't find gUefiOvmfPkgTokenSpaceGuid
    07e17188df ArmPkg/SmbiosMiscDxe: Adjust the priority of getting firmware version
    e4b3fd905a OvmfPkg/PlatformInitLib: simplify mtrr setup
    82c1aa87f9 OvmfPkg/PlatformInitLib: move mmconfig to 0xe0000000
    5eab38ad03 OvmfPkg/PlatformInitLib: update address space layout comment
    71fd87e98a OvmfPkg/RiscVVirt: Support multiple reserved memory ranges
    144028626e SecurityPkg/FvReportPei: Use FirmwareVolumeShadowPpi
    c8e631588b MdeModulePkg/Include/Ppi: Add FirmwareVolumeShadowPpi
    2bc8545883 UefiCpuPkg/CpuPageTableLib: Reduce the number of random tests
    aea5930c40 UefiCpuPkg/CpuPageTableLib: Add RandomTest for PAE paging
    aad9a30144 UefiCpuPkg/CpuPageTableLib: Enable PAE paging
    878cbd871d UefiCpuPkg: Combine branch for non-present and leaf ParentEntry
    f7686f2727 UefiCpuPkg/CpuPageTableLib: Add check for page table creation
    aa3153b872 UefiCpuPkg: Modify UnitTest code since tested API is changed
    2e01a5c128 UefiCpuPkg: Fix IA32 build failure in CpuPageTableLib.inf
    8727cc9a8e UefiCpuPkg/CpuPageTableLib: Modify RandomTest to check IsModified
    c8c6cf149d UefiCpuPkg/CpuPageTableLib: Add OUTPUT IsModified parameter.
    3b2661d247 UefiCpuPkg/CpuPageTableLib: Enable non-1:1 mapping in random test
    cecf279c32 UefiCpuPkg/CpuPageTableLib:Modify RandomTest to check Mask/Attr
    ecfe6382c1 UefiCpuPkg/CpuPageTableLib: Add LastMapEntry pointer
    661a669c81 UefiCpuPkg/CpuPageTableLib:Modify RandomBoolean() in RandomTest
    14ef21e559 UefiCpuPkg/CpuPageTableLib: Add manual test to check Mask and Attr
    a926c6c49e UefiCpuPkg/CpuPageTableLib:Add check for Mask and Attr
    96e8676577 UefiCpuPkg/MpInitLib: Add code to initialize MapMask
    c90cb726f8 UefiCpuPkg/CpuPageTableLib: Fix issue when splitting leaf entry
    b6b54367c3 UefiCpuPkg/CpuPageTableLib:Clear PageSize bit(Bit7) for non-leaf
    4904a2b1ec UefiCpuPkg/CpuPageTableLib: Fix the non-1:1 mapping issue
    563a2d2695 UefiCpuPkg/CpuPageTableLib:Initialize some LocalVariable at beginning
    c18fbd2c31 UefiCpuPkg/CpuPageTableLib: Add check for input Length
    da3dad181e UefiCpuPkg/CpuPageTableLib: Remove unneeded 'if' condition
    d55d73152e PcAtChipsetPkg: Add PCD for RTC default year
    b1db096575 UefiCpuPkg: Solve that stack top address is not mapped in pagetable
    1bfc89414d UefiPayloadPkg: Add gUefiAcpiBoardInfoGuid support
    69e59545b1 MdePkg/Include: Add IPMI KCS definitions
    2c93253c95 MdePkg/Include: Add DMTF MCTP definitions
    07fa6d1841 MdePkg/Include/Ppi: Remove Itanium leftover data structure
    f6bd3286ed IntelFsp2Pkg: Fix NASM X64 build warnings.
    1f26a9e62e BaseTools: Replace duplicate __PcdSet prototype with __PcdGet
    b4e2cf092a BaseTools: Source/C/Common: Fix doc block locations and convert to Doxygen
    cf6a0a52b0 OvmfPkg/PlatformBootManagerLib: use utf8 for the serial console.
    4f441d024b UefiCpuPkg/PiSmmCpuDxeSmm: fix error handling
    2e71876081 UefiCpuPkg/PiSmmCpuDxeSmm: drop support for obsolete processors
    494127613b SecurityPkg/DxeImageVerificationLib: Check result of GetEfiGlobalVariable2
    b7a8264ae4 RedfishPkg: Update Readme.md
    f077bff840 RedfishPkg: Update Redfish DSC
    f8fb208a3e RedfishPkg/Library: Redfish BMC USBNIC Host Interface
    b17a3a133b MdePkg: Update code to be more C11 compliant by using __func__
    d6107c593b MdePkg: Update Base.h to be compliant with C11
    410ca0ff94 CryptoPkg/Library: add -Wno-unused-but-set-variable for openssl
    0e57170097 MdeModulePkg/BmBoot: Skip removable media if it is not present
    16e0969ef7 ArmVirtPkg/ArmVirtQemu: Use PEI flavor of ArmMmuLib for all PEIMs
    b05523a4e9 ArmPkg/ArmMmuLib: Introduce region types for RO/XP WB cached memory
    852227a9d5 ArmPkg/Mmu: Remove handling of NONSECURE memory regions
    1c4dfadb46 ArmPkg/CpuDxe: Implement EFI memory attributes protocol
    b977956a6c MdePkg: Add Memory Attribute Protocol definition
    f4a6f63999 ArmPkg/CpuDxe: Expose unified region-to-EFI attribute conversion
    ae2c904c3d ArmPkg/ArmMmuLib: Avoid splitting block entries if possible
    f07a9df9af ArmVirtPkg: Enable stack guard
    6b821be140 ArmPkg/ArmMmuLib: Implement EFI_MEMORY_RP using access flag
    041c7a31c2 ArmPkg/ArmMmuLib ARM: Clear individual permission bits
    28dce5b130 ArmPkg/ArmMmuLib ARM: Isolate the access flag from AP mask
    699372d388 ArmPkg/CpuDxe ARM: Fix page-to-section attribute conversion
    3b76284883 ArmPkg/ArmMmuLib ARM: Split off XN page descriptor bit from type field
    82ccaaf8e7 ArmPkg/ArmMmuLib ARM: Remove half baked large page support
    997c6967b0 MdePkg/BaseCacheMaintenanceLib: RISC-V: Fix InvalidateInstructionCacheRange
    7cfe9048e3 OvmfPkg/PlatformCI: Add CI coverage for RiscVVirtQemu
    961792c9d6 UefiPayloadPkg: Correct MAX_LOGICAL_PROCESSORS value
    a1386bb252 UefiCpuPkg/PiSmmCpuDxeSmm: Fix S3 failure in SmmRestoreCpu
    e4c1d8d231 ShellPkg/Library: Fix 32-bit truncation of pointer values
    d2bfe28966 BaseTools: Extend fields for module_report.json
    4ad7ea9c84 BaseTools: Generate compile information in build report
    9b94ebb0c8 DynamicTablesPkg: Add SMBIOS String table helper library
    a4c9c2b0f0 UefiPayloadPkg: Remove UefiCpuLib from module INFs.
    c20408163f UefiCpuPkg: Remove UefiCpuLib from module INFs.
    16bd7aa076 SourceLevelDebugPkg: Remove UefiCpuLib from module INFs.
    866d3b9fd5 PcAtChipsetPkg: Remove UefiCpuLib from module INFs.
    cd81e8e030 OvmfPkg: Remove UefiCpuLib from module INFs.
    fa78edc57e IntelFsp2Pkg: Remove UefiCpuLib from module INFs.
    b294633c68 MdePkg: Move API and implementation from UefiCpuLib to CpuLib
    bf0c14a562 OvmfPkg: Add CpuLib to module INFs that depend on UefiCpuLib.
    fd1820b7ea UefiCpuPkg/MicrocodeMeasurementDxe: Fix exception
    4ca4041b0d CryptoPkg/OpensslLib: Upgrade OpenSSL to 1.1.1t
    8820767fb3 IntelFsp2Pkg: Fix GCC Compiler warning.
    a0f9628705 OvmfPkg/SmbiosPlatformDxe: tweak fallback release date
    2fccd1f153 ArmPkg/SemihostFs: replace SetMem with ZeroMem
    69da506c92 UefiCpuPkg: BaseRiscV64CpuExceptionHandlerLib: clean up
    5ad2592ab3 UefiCpuPkg: CpuTimerDxeRiscV64: fix tick duration accounting
    db0a3087a5 MdeModulePkg: Dxe: add RISCV64 to mMachineTypeInfo
    6ceaef4804 MdePkg: BaseCpuLib: Fix RISCV CpuSleep symbol name.
    5bd2e5dfe6 MdePkg: BaseLib: don't log in RISCV InternalSwitchStack
    dc5880d02f MdePkg: BasePeCoffLib: Allow AArch64 and x64 images in ImageFormatSupported
    7fa4692636 OvmfPkg: RiscVVirt: add SATA support
    75fb0cfc82 SecurityPkg/RngDxe: Conditionally install EFI_RNG_PROTOCOL
    bfb574db11 SecurityPkg/RngDxe: Correctly update mAvailableAlgoArrayCount
    aa1cd447b3 UefiCpuPkg: Calculate DisplayFamily correctly
    f335d91a3b CryptoPkg/BaseCryptLib: avoid using SHA512()
    5a6455e04c CryptoPkg/BaseCryptLib: avoid using SHA384()
    7fc183df71 CryptoPkg/BaseCryptLib: avoid using SHA256()
    437ed29f27 CryptoPkg/BaseCryptLib: avoid using SHA1()
    c7c2599759 UefiCpuPkg: Move AsmRelocateApLoopStart from Mpfuncs.nasm to AmdSev.nasm
    0d1ad06c27 UefiCpuPkg: Rename AsmRelocateApLoopStart.
    facf52aeb8 UefiCpuPkg: Put APs in 64 bit mode before handoff to OS.
    6bc74286e7 UefiPayloadPkg: Add CpuPageTableLib required by MpInitLib.
    c6e655743f OvmfPkg: Add CpuPageTableLib required by MpInitLib.
    e9782e6907 UefiCpuPkg: Allocate contiguous memory for stacks and APs loop.
    a6f799e7fd UefiCpuPkg: Split the path in RelocateApLoop into two.
    0c3f8766b0 UefiCpuPkg: Check AP_SAFE_STACK_SIZE during build time.
    46f51898ff MdeModulePkg: Improve formatting of DEBUG messages in UsbBusDxe
    a1d595fc9c OvmfPkg/SmmCpuFeaturesLib: Check SmBase relocation supported or not
    f6b86eec5a UefiCpuPkg/SmmCpuFeaturesLib: Skip SMBASE configuration
    ec07fd0e35 UefiCpuPkg/PiSmmCpuDxeSmm: Consume SMM Base Hob for SmBase info
    7b8c5a8eb4 UefiCpuPkg/SmmBaseHob.h: Add SMM Base HOB Data
    85c6c14c4c UefiCpuPkg/PiSmmCpuDxeSmm: Replace mIsBsp by mBspApicId check
    cb4820b6c1 UefiCpuPkg/PiSmmCpuDxeSmm: Fix invalid InitializeMpSyncData call
    5a0932b7d4 RedfishPkg/RedfishDebugLib: provide Redfish debug
    fc14c809cb ShellPkg: Improve "ping" output by adding equals sign after time
  - Respin the following patches:
  ovmf-pie.patch
  ovmf-disable-brotli.patch
  ovmf-Revert-ArmVirtPkg-make-EFI_LOADER_DATA-non-executabl.patch
    ovmf-Revert-OvmfPkg-PlatformPei-Update-ReserveEmuVariable.patch
  - Add public-mipi-sys-t-1.1-edk2.tar.gz
  - public-mipi-sys-t: https://github.com/MIPI-Alliance/public-mipi-sys-ti
  - https://github.com/MIPI-Alliance/public-mipi-sys-t/releases/tag/v1.1%%2Bedk2
  - Unpackage to MdePkg/Library/MipiSysTLib/mipisyst in source code
  - Upgrade OpenSSL to 1.1.1t
  - Add openssl-1.1.1t.tar.gz, openssl-1.1.1t.tar.gz.asc
  - Update openssl.keyring
  - Add openssl.keyring.README
  - Update ovmf.spec:
    Source1:        https://www.openssl.org/source/old/1.1.1/openssl-%%{openssl_version}.tar.gz
    Source111:      https://www.openssl.org/source/old/1.1.1/openssl-%%{openssl_version}.tar.gz.asc
  - Removed the following workaround patches (bsc#1205978)
  - Removed
    ovmf-Revert-OvmfPkg-PlatformInitLib-reorder-PlatformQemuU.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformReservati.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformAddHobCB.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformGetLowMem.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformScanE820-.patch
  - Respin
    ovmf-Revert-OvmfPkg-PlatformInitLib-dynamic-mmio-window-s.patch
    to simplify workaround code.
  - Because edk2 upstream expert confirmed that the bsc#1205978 is
    a SUSE specific issue. So we removed some workaround revert patches.
    And we only keep one respined simple workaround patch until qemu
    issue be fixed.
* Fri Jun 30 2023 Callum Farmer <gmbr3@opensuse.org>
- Initial riscv64 support
  * Update descriptors.tar.xz
  * Enable on TW/16 (riscv64 toolchain not available on 15)
- Add ovmf-riscv64-missing-memcpy.patch: fixes undefined memcpy
* Mon Mar 20 2023 Joey Lee <jlee@suse.com>
- Add ovmf-Revert-OvmfPkg-PlatformPei-Update-ReserveEmuVariable.patch
  to revert 58eb8517ad7b56574f8f04b770a59a9cbed796c4 patch to prevent
  booting hangs when SEV + secure boot. (bsc#1209266)
* Thu Mar 16 2023 Joey Lee <jlee@suse.com>
- Removed patches which are merged to edk2-stable202302 (bsc#1209266):
  - ovmf-tools_def-add-fno-omit-frame-pointer-to-GCC48_-IA32-.patch
    tools_def: add -fno-omit-frame-pointer to GCC48_{IA32,X64}_CC_FLAGS
    (bsc#1199597)
  - 129404f6e4        edk2-stable202302~200
  - ovmf-OvmfPkg-PlatformInitLib-Fix-integrity-checking-faile.patch
    OvmfPkg/PlatformInitLib: Fix integrity checking failed of NvVarStore
    (bsc#1206078)
  - ceb52713b0        edk2-stable202302~226
* Wed Mar 15 2023 Joey Lee <jlee@suse.com>
- Update to edk2-stable202302 (bsc#1209266)
  - Features (https://github.com/tianocore/edk2/releases):
    Add support for RISC-V qemu virt machine
    Add RPMB related commands and DCB definition for NVMe
    SecurityBoot - remove self-signed PK requirement in SetupMode
    SecurityBoot - support Authenticated SetVariable with ContentInfo
    TDVF Optimization - Enable Separate-Fv in OvmfPkg/IntelTdx
    TDVF Optimization - Pre-alloc shared memory for TDVF DMA
    TDVF Optimization - Enable Multi-core based lazy-accept
    TDVF - Fix Instruction Pointer Incrementation by TD #VE MMIO Handler
    TDVF - Incorrect implementation in the TDX RTMR implementation
    TDVF - Incorrect protocol and structure version in the TDX CC measurement
    TDVF - TdTcg2Dxe lives in the Ovmfpkg instead of the SecurityPkg
    TDVF - need measurement VMM input ACPI table before register
    TDVF - need integrate feature in config-B to config-A
  - Patches (git log --oneline --date-order edk2-stable202211..edk2-stable202302):
    f80f052277 OvmfPkg/RiscVVirt: Add Stack HOB
    1eeca0750a UefiPayloadPkg: remove the change that get platform specific logic
    bc82574de4 OvmfPkg/RiscVVirt: Fix SCT memory allocation test case failure
    2c5961cccf BaseTools/tools_def.template: Update -march parameter for RISC-V
    02fcfdce1e BaseTools: Update WindowsVsToolChain plugin
    5c551d6d91 Maintainers.txt: Add entry for OvmfPkg/RiscVVirt
    92b27c2e6a OvmfPkg/RiscVVirt: Add build files for Qemu Virt platform
    e1aaef001f OvmfPkg/RiscVVirt: Add SEC module
    a43a62f9b0 OvmfPkg/RiscVVirt: Add PciCpuIo2Dxe module
    6d5ae344cd OvmfPkg/RiscVVirt: Add VirtNorFlashPlatformLib library
    c126e3588d OvmfPkg/RiscVVirt: Add ResetSystemLib library
    6720b8e46f OvmfPkg/RiscVVirt: Add PrePiHobListPointerLib library
    d78df93863 OvmfPkg/RiscVVirt: Add PlatformBootManagerLib library
    f13264b340 ArmVirtPkg: Fix up the location of PlatformHasAcpiDtDxe
    09cd17b0de ArmVirtPkg/PlatformHasAcpiDtDxe: Move to OvmfPkg
    a7dec790dc UefiCpuPkg/UefiCpuPkg.ci.yaml: Ignore RISC-V file
    c27cdc941d UefiCpuPkg: Add CpuDxeRiscV64 module
    98fa877efd UefiCpuPkg: Add CpuTimerDxeRiscV64 module
    705c3469b5 UefiCpuPkg: Add BaseRiscV64CpuTimerLib library
    cbac2c74e8 UefiCpuPkg: Add BaseRiscV64CpuExceptionHandlerLib
    d6017bca19 UefiCpuPkg: Add RISCV_EFI_BOOT_PROTOCOL related definitions
    76e956547e MdePkg: Add BaseRiscVSbiLib Library for RISC-V
    550f196e82 MdePkg/BaseLib: RISC-V: Add few more helper functions
    8aeb405466 MdePkg/Register: Add register definition header files for RISC-V
    38da9606f7 MdePkg: Added Call for AfterReadyToBoot Event
    419c0aafa6 MdePkg: Add After Ready To Boot Event Definition from UEFI 2.9
    77d6772708 MdeModulePkg/Library: PcdAcpiS3Enable set FALSE cause Assert
    68c1bedbf2 MdeModulePkg/Variable: Attribute combination should return EFI_UNSUPPORTED
    090642db7a MdeModulePkg/EsrtFmpDxe: Support multiple devices with 0 HardwareInstance
    f9c6b5134e MdeModulePkg/Pci: Display more information of PCIe devices
    1b5420e807 OvmfPkg/AmdSevDxe: Close mAcceptAllMemoryEvent
    f67ec87704 OvmfPkg: Fix SevMemoryAcceptance memory attributes
    540522fec0 .devcontainer/devcontainer.json: Add devcontainer file
    b3f321f2d7 .mergify/config.yml: Remove rebase_fallback attribute (deprecated)
    93a21b465b MdePkg: Add NVMe boot partition header definition
    069703228c MdePkg: Add RPMB related commands and DCB definition for NVMe
    39254d922e RedfishPkg/RedfishRestExDxe: Two PCDs for controlling the requests
    289d93b79c StandaloneMmPkg/StandaloneMmMemLib: Change max address computation
    173a7a7daa OvmfPkg: Update build.sh to allow building OVMF then running QEMU
    f6ce1a5cd8 EmulatorPkg/PeiTimerLib: Bug fix in NanoSecondDelay
    b59e6fdae2 .pytool/Plugin/EccCheck: Add PACKAGES_PATH support
    5db84c85c3 MdePkg:IORT header update for IORT Rev E.e spec
    96192ba5bd MdeModulePkg: EfiUnacceptedMemoryType is not allowed in AllocatePool
    8a763b533b MdeModulePkg: Disambiguate the meaning of PcdDxeIplSwitchToLongMode
    aef0061ac2 BaseTools: remove useless dependency on libuuid
    aea8a9c954 RedfishPkg: fix multiple SMBIOS type 42 version issue
    b98e2113b5 ArmPkg/ArmScmiDxe: Fix the calculation of RequiredArraySize
    9d669016d9 OvmfPkg/IntelTdx: Update README
    ff8485179c SecurityPkg/TdTcg2Dxe: td-guest shall halt when CcMeasurement install fail
    cc18c503e0 SecurityPkg: don't require PK to be self-signed by default
    f6e4824533 OvmfPkg: require self-signed PK when secure boot is enabled
    566cdfc675 SecurityPkg: limit verification of enrolled PK in setup mode
    7c138e4008 EmbeddedPkg/PrePiLib: Drop unused PCD PcdPrePiCpuIoSize
    4d37059d8e OvmfPkg: Support Tdx measurement in OvmfPkgX64
    1f9bd937b3 OvmfPkg/PlatformPei: Build GuidHob for Tdx measurement
    6ea50514c1 OvmfPkg/OvmfPkgX64: Measure TdHob and Configuration FV in SecMain
    d92db8a086 OvmfPkg/IntelTdx: Add PeiTdxHelperLib
    019621d078 OvmfPkg/IntelTdx: Measure TdHob and Configuration FV in SecMain
    c0984d1ff2 OvmfPkg: Refactor ProcessHobList
    852ae4cd80 OvmfPkg: Refactor MeaureFvImage
    f41acc651f OvmfPkg: Refactor MeasureHobList
    d59279f8ce OvmfPkg/PeilessStartupLib: Update the define of FV_HANDOFF_TABLE_POINTERS2
    d09c1d4b88 OvmfPkg/IntelTdx: Add SecTdxHelperLib
    d3109e5f18 OvmfPkg/IntelTdx: Add TdxHelperLibNull
    6ba931bebf OvmfPkg: Add Tdx measurement data structure in WorkArea
    935343cf16 OvmfPkg/AcpiPlatformDxe: Measure ACPI table from QEMU in TDVF
    7623b4bf6a MdeModulePkg: ScsiDiskDxe: clean up comment in ScsiDisk.c
    13b97736c8 UefiCpuPkg: Fix SMM code hangs when InitPaging
    11f0014c0e MdePkg: Label CreateEvent NotifyFunction and NotifyContext optional
    ae6e470252 MdeModulePkg/Bus/Ata/AhciPei: Fix DEADCODE Coverity issue
    558b37b49b ShellPkg/AcpiView: ERST Parser
    d375273c89 MdeModulePkg: ScsiBusDxe: Refactor DiscoverScsiDevice()
    bda715bf6d MdePkg: Fix UINT64 and INT64 word length for LoongArch64
    2f2fd79fc4 UefiPayloadPkg: Set RTC dynamic PCD to PeiPCDdatabase
    3509103132 MdePkg: Added serveral tables to MATD used by LoongArch64
    c5ef1f01a1 MdePkg: Add ACPI 6.5 header
    620cddb1e0 MdePkg: Add Acpi65.h to IgnoreFiles area
    c59230bce1 ArmVirtPkg: Remove RealView Debugger lines from ArmVirtPkg.dsc.inc
    8c170ad491 ArmPkg: Remove RealView Debugger support
    15f98047d2 BaseTools: Remove CYGWIN_NT-5.1-i686 ref from Scripts/PatchCheck.py
    cdcee3d17b BaseTools: Delete Bin/{CYGWIN_NT-5.1-i686,Darwin-i386} directories
    4b384c21ad MdeModulePkg: Correct memory type in PrePiDxeCis.h
    bb13762548 tools_def: Remove duplicated -Os
    e7aac7fc13 ArmPkg: implement EFI_MP_SERVICES_PROTOCOL based on PSCI calls
    d1855afc6e ArmPkg: Add GET_MPIDR_AFFINITY_BITS and MPIDR_MT_BIT to ArmLib.h
    0d129ef7c3 OvmfPkg/PlatformPei: SEV-SNP make >=4GB unaccepted
    466d8f65e3 OvmfPkg: Implement AcceptAllUnacceptedMemory in AmdSevDxe
    26847fb6be OvmfPkg: Introduce the OvmfSevMemoryAcceptance protocol
    a00e2e5513 OvmfPkg: Add memory acceptance event in AmdSevDxe
    ca573b8615 ArmVirtPkg/PlatformCI: Perform build test of ArmVirtKvmTool
    0eda253317 ArmVirtPkg/PlatformCI: Add CI coverage for ArmVirtQemuKernel
    ed1806b2c0 ArmVirtPkg/PlatformCI: Enable optional features on Qemu AARCH64 builds
    01a06884a1 ArmVirtPkg/PlatformCI: factor out reusable PlatformBuildLib.py
    619f077252 ArmVirtPkg/ArmVirtQemu: enlarge initial flash mapping
    6c8a08bd8a ArmVirtPkg/PrePi: Ensure timely execution of library constructors
    d0ff1cae3a CryptoPkg/Library: Reinstate ARM/AARCH64 sections in SmmCryptLib.inf
    f25ee54763 OvmfPkg: fix BuildResourceDescriptorHob call in PlatformAddHobCB()
    37d3eb026a SecurityPkg/AuthVariableLib: Check SHA-256 OID with ContentInfo present
    7afef31b2b MdeModulePkg: remove garbage pixels in LaffStd glyphs
    e96a5734f6 ShellPkg: Export default shell delay as PCD
    bf5678b580 OvmfPkg/PlatformInitLib: catch QEMU's CPU hotplug reg block regression
    c3e128a4cd OvmfPkg/PlatformInitLib: factor out PlatformCpuCountBugCheck()
    3beb8c9654 OvmfPkg/PlatformCI VS2019: Enable temporary workaround for cpuhp bugfix
    51411435d5 EmbeddedPkg: Add back FfsFindSectionData
    0826808d4f EmbeddedPkg: Rename FfsFindSectionData as FfsFindSectionDataWithHook
    18df11da8c MdeModulePkg: Add IpmiCommandLib
    ae55e9fca6 MdeModulePkg/IpmiCommandLib: Add NULL instance library
    bde407db51 MdeModulePkg/Include: Add IpmiCommandLib header file
    426efcc374 RedfishPkg/Include: Redfish USB Interface V2 update
    663e70851c RedfishPkg/Include: Add Redfish IPMI definitions
    cabcc6851b MdePkg/IndustryStandard: Update IPMI definitions
    998ebe5ca0 OvmfPkg/CcExitLib: Initialize Status in IoExit
    5c7a611353 OvmfPkg/BaseMemEncryptTdxLib: Refactor error handle of SetOrClearSharedBit
    e0dcfb31fb SecurityPkg/TdTcg2Dxe: Extend EFI boot variable to PCR[1]
    e05132aaa0 OvmfPkg/CcExitLib: Refactor TDX MmioExit
    c01622057c OvmfPkg/CcExitLib: Move common X86 instruction code to separate file
    70d1481b55 OvmfPkg/PeilessStartupLib: Find NCCFV in non-td guest
    c3f4f5a949 OvmfPkg/IntelTdx: Enable separate-fv in IntelTdx/IntelTdxX64.fdf
    066d3c8004 OvmfPkg: Add PCDs/GUID for NCCFV
    c673216f53 EmbeddedPkg/PrePiLib: Add FFS_CHECK_SECTION_HOOK when finding section
    6c1988af76 ShellPkg: Display SMBIOS Type38 fields in smbiosview in formatted view
    ea382b3b21 CI: use ubuntu-22.04 image (Linux only)
    7edf120150 OvmfPkg: CI: use ubuntu-22.04 vm_image (Linux only)
    5f8b749c73 EmulatorPkg: CI: use ubuntu-22.04 vm_image (Linux only)
    7e88204fe1 ArmVirtPkg: CI: use ubuntu-22.04 vm_image (Linux only)
    84cb35232d BaseTools: remove ext_dep files for gcc
    5d25638e1b .pytool: CISettings.py: don't add scopes for GCC
    7fab007f33 OvmfPkg: CI: Use Fedora 35 container (Linux only)
    32c76a8cd4 EmulatorPkg: CI: Use Fedora 35 container (Linux only)
    7cddfae1e8 ArmVirtPkg: CI: Use Fedora 35 container (Linux only)
    ef09160098 CI: Use Fedora 35 container (Linux only)
    36d7626a37 CI: Allow running in a container.
    becff4f473 CI: add ~/.local/bin to PATH (Linux only)
    65cc189414 OvmfPkg: CI: use Python version from defaults template
    7d62df623f EmulatorPkg: CI: use Python version from defaults template
    89ed7e4795 ArmVirtPkg: CI: use Python version from defaults template
    3579551734 CI: make Python version configurable
    015a001b03 OvmfPkg/PlatformInitLib: reorder PlatformQemuUc32BaseInitialization
    c0a0b9bc35 OvmfPkg/PlatformInitLib: Add PlatformReservationConflictCB
    328076cfdf OvmfPkg/PlatformInitLib: Add PlatformAddHobCB
    124b765051 OvmfPkg/PlatformInitLib: Add PlatformGetLowMemoryCB
    e037530468 OvmfPkg/PlatformInitLib: Add PlatformScanE820 and GetFirstNonAddressCB
    a107ad0f62 BaseTools/tools_def CLANG38: Suppress unaligned access warning
    021930d7c2 BaseTools/tools_def ARM: Make choice for soft float ABI explicit
    e974064303 BaseTools/tools_def ARM AARCH64: Get rid of ARCHCC and ARCHASM flags
    096cd41ce7 BaseTools/tools_def RISCV: Make OpenSBI references RISCV-only
    d05739a3ff Fix cyclic dependency error on OptionROM build
    987cc09c7c ArmVirt: don't use unaligned CopyMem () on NOR flash
    47ab397011 MdeModulePkg/XhciPei: Unlinked XhciPei memory block
    be8d6ef385 MdeModulePkg/Usb: Read a large number of blocks
    8147fe090f MdeModulePkg/Xhci: Initial XHCI DCI slot's Context value
    7cd55f3009 OvmfPkg/AcpiPlatformDxe: Return error if installing NotifyProtocol failed
    66f18fde49 OvmfPkg/AcpiPlatformDxe: Refactor QemuAcpiTableNotifyProtocol
    2ef0ff39e5 OvmfPkg/AcpiPlatformDxe: Add log to show the installed tables
    165f1e4936 OvmfPkg/AcpiPlatformDxe: Use local variable in QemuFwCfgAcpi.c
    f81273f7fb OvmfPkg/AcpiPlatformDxe: Use local variable in CloudHvAcpi.c
    43b3ca6b7f OvmfPkg/AcpiPlatformDxe: Remove QEMU_ACPI_TABLE_NOTIFY_PROTOCOL
    ba08910df1 OvmfPkg: fix OvmfTpmSecurityStub.dsc.inc include
    9d70d8f20d MdeModulePkg: Notify BeforeExitBootServices in CoreExitBootServices
    82b0ee8354 MdePkg: Add EFI_EVENT_BEFORE_EXIT_BOOT_SERVICES_GUID
    59aa48bb7d OvmfPkg: Realize EfiMemoryAcceptProtocol in AmdSevDxe
    e5ec3ba409 OvmfPkg/VirtNorFlashDxe: map flash memory as uncacheable
    85fd05ab97 OvmfPkg/PlatformInitLib: fix comment about uncacheable MTRRs
    fe405f08a0 NetworkPkg: Add WiFi profile sync protocol support
    ec54ce1f1a ArmVirtPkg/ArmVirtQemu: Avoid early ID map on ThunderX
    5ee17c5418 ArmVirtPkg/ArmPlatformLibQemu: Ensure that VFP is on before running C code
    717f35a9f2 DynamicTablesPkg: FdtHwInfoParserLib: Fix compatible string
    82dd766f25 BaseTools: Reduce the LoongArch64 compiler size
    2cc6d4c8ed UefiPayloadPkg: Fix debug print error level hob not save correct
    33a3408fbb Revert "UefiCpuPkg: Duplicated AsmRelocateApLoop as AsmRelocateApLoopAmd"
    ae80fe997d Revert "OvmfPkg: Add CpuPageTableLib required by MpInitLib."
    5ef3990735 Revert "UefiPayloadPkg: Add CpuPageTableLib required by MpInitLib."
    cbcf0cd65e Revert "UefiCpuPkg: Has APs in 64 bit long-mode before booting to OS."
    d8d829b89d UefiPayloadPkg: Move RTC PCD to dynamic PCD
    5386c9e6da Maintainers.txt: Update reviewers for OVMF/Confidential Computing
    5654ce1d2c SecurityPkg: Move TdTcg2Dxe from OvmfPkg to SecurityPkg
    0aca5901e3 Maintainers.txt: designate Gerd Hoffmann as UefiCpuPkg reviewer
    8c2357809e .azurepipelines: Skip CodeCoverage if coverage.xml not found
    c32e733151 Maintainers.txt: Update NetworkPkg & MM modules Reviewer
    9ce09870e7 OvmfPkg/SmmCpuFeaturesLib: drop obsolete API implementation
    ff379e1b48 UefiCpuPkg/SmmCpuFeaturesLib: drop obsolete API implementation
    d452feedf2 OvmfPkg: raise DXEFV size to 13 MB in the traditional platform FDFs
    12e4043bd6 OvmfPkg/QemuVideoDxe/VbeShim.sh: remove end-of-options delimiter for nasm
    992d5451d1 MdeModulePkg/Bus/Pci/XhciDxe: Reset port if status change returns an error
    89c5d90003 .azurepipelines: Install code coverage tool
    6bb00aa484 BaseTools/Plugin: Add coverage support for Unit Test
    3701f105fa UnitTestFrameworkPkg: Add code coverage support for GCC
    b670700ddf UefiCpuPkg/PiSmmCpuDxeSmm:Fix PF issue caused by smm page table code
    bbd30066e1 BaseTools: Generate deps for Arm targets
    3a872dac7b BaseTools: Use BUILD_CC when checking gcc version in DevicePath
    c5d68ef6e7 BaseTools: Fix IA32 UINT64 alignment for CLANG toolchains
    a086f4a63b OvmfPkg: Use NestedInterruptTplLib in nested interrupt handlers
    a24fbd6061 OvmfPkg: Add library to handle TPL from within nested interrupt handlers
    9bf473da4c OvmfPkg: Send EOI before RestoreTPL() in timer interrupt handlers
    bf65d7ee88 OvmfPkg/PlatformInitLib: pass through reservations from qemu
    16acacf24c OvmfPkg: fix PlatformConfig
    d8d4abdff9 UefiPayloadPkg: Fix boot issue for non-universal payload
    538ac013d6 ArmVirtPkg: Remove CcProbeLib from ArmVirtQemu.dsc
    8cb4b429a2 OvmfPkg/AcpiPlatformDxe: Check PcdConfidentialComputingGuestAttr
    ec87305f90 PcAtChipsetPkg: Move RTC PCD to dynamic PCD
    129404f6e4 tools_def: add -fno-omit-frame-pointer to GCC48_{IA32,X64}_CC_FLAGS
    3e8b7e1055 tools_def: remove GCC_IA32_CC_FLAGS/GCC_X64_CC_FLAGS
    62031335bd CryptoPkg: Need to enable crypto functions
    72a9386f67 UefiCpuPkg: Simplify the code to set smm page table as RO
    0426115b67 UefiCpuPkg: Remove unused API in SmmCpuFeaturesLib.h
    b822be1a20 UefiCpuPkg/PiSmmCpuDxeSmm: Introduce page table pool mechanism
    0b633b1494 OvmfPkg/OvmfXen: Build platform info HOB in XenPlatformPei
    451521ccbc OvmfPkg/PlatformInitLib: Implement multi-core accept memory for TDVF
    c55cf3f795 OvmfPkg: Enable APs to accept memory for TDVF
    0547ffbf6d OvmfPkg/Sec: Move TDX APs related nasm code to IntelTdxAPs.nasm
    4d8651c2fb OvmfPkg: Add TdxMailboxLibNull in some platform dsc
    b21fe5a8a6 OvmfPkg/TdxMailboxLib: Add NULL instance of TdxMailboxLib
    a00b71b009 OvmfPkg/TdxMailboxLib: Delete global variables
    b2d76fdd42 SecurityPkg: deprecate RpmcLib and VariableKeyLib
    3c16e6fb97 UefiPayloadPkg: Fixed that The UPL info section is not aligned at 4-byte
    a7e722941c MdePkg: Fix typos and spacing in Library/PerformanceLib.h
    4bdc41cf17 MdePkg: Fix typo of EFI_INVALID_PARAMETER in Protocol/UsbIo.h
    ec25e904c7 MdeModulePkg/Bus/Pci/XhciDxe: Check port is compatible before getting PSIV
    01c2fb0d22 MdeModulePkg/XhciDxe/Xhci: Don't check for invalid PSIV
    3f378450df UefiPayloadPkg: Add CpuPageTableLib required by MpInitLib.
    4a86424224 OvmfPkg: Add CpuPageTableLib required by MpInitLib.
    73ccde8f6d UefiCpuPkg: Has APs in 64 bit long-mode before booting to OS.
    7bda8c6481 UefiCpuPkg: Duplicated AsmRelocateApLoop as AsmRelocateApLoopAmd
    6937fc8338 UefiPayloadPkg/SerialPortLib: Enhance multi port behaviour
    259e1e0462 EmulatorPkg/RedfishHostInterface: Add NULL function
    2846c19da9 RedfishPkg/RedfishHostInterface: Platform Redfish HI notification
    ceb52713b0 OvmfPkg/PlatformInitLib: Fix integrity checking failed of NvVarStore
    560f9bb063 UefiPayloadPkg: Define default values for the DynamicEX PCDs
    39ba0f8dfc CryptoPkg: Need to enable crypto functions
    5fb3f5723a DynamicTablesPkg: Allow for specified CPU names
    05da2d24b0 UefiPayloadPkg: Move bdsdxe.inf from DXEFV to BDSFV
    8bd2028f9a MdeModulePkg: Supporting S3 in 64bit PEI
    6acf72901a UefiCpuPkg: Supporting S3 in 64bit PEI
    4dd7b86556 Maintainers: Update OvmfPkg/IoMmuDxe
    47b9521513 OvmfPkg/IoMmuDxe: Add SEV support for reserved shared memory
    09f01d4efb OvmfPkg/IoMmuDxe: Rename AmdSevIoMmu to CcIoMmu
    c4e76d2fba OvmfPkg/IoMmuDxe: Reserve shared memory region for DMA operation
    316e6df435 OvmfPkg: Add reference to new build instructions
    7a548f3ea9 EmulatorPkg: Add reference to new build instructions
    30697b94fd BaseTools: Add reference to new build instructions
    f70f493d1b ArmVirtPkg: Add reference to new build instructions
    0e3e62fc2b .pytool/Readme.md: Add reference to new build instructions
    e254c71e9e OvmfPkg/AcpiPlatformDxe: Differentiate TDX case for Cloud Hypervisor
    57162cb62d OvmfPkg/PlatformInitLib: Transfer GUID Extension HOB
    e03b0d0672 OvmfPkg/PlatformInitLib: Differentiate TDX case for Cloud Hypervisor
    0adc35fccd OvmfPkg/AmdSev/SecretDxe: Allocate secret location as EfiACPIReclaimMemory
    3e3f5bb21c OvmfPkg/PlatformPei: Validate SEC's GHCB page
    01c0d3c0d5 OvmfPkg/SecTpmMeasurementLib: Fix the mapping error of PCR and RTMR index
    fb91d6cbd0 OvmfPkg/TdTcg2Dxe: Fix the mapping error between PCR index and MR index
    19f7c63ea9 OvmfPkg/TdTcg2Dxe: Fix incorrect protocol and structure version
    44fc90eb0e UnitTestFrameworkPkg/UnitTestLib: Print expected Status on ASSERT fail
    cda98df162 OvmfPkg/QemuFwCfgLib: remove mQemuFwCfgSupported + mQemuFwCfgDmaSupported
    81bbc1452c OvmfPkg/QemuFwCfgLib: rewrite fw_cfg probe
    e59747bd82 OvmfPkg/DebugLibIoPort: use Rom version for PEI
    f6a196c7eb OvmfPkg/PlatformPei: remove mFeatureControlValue
    862614e254 OvmfPkg/PlatformPei: remove mPlatformInfoHob
    4bc2c74851 OvmfPkg/PlatformPei: Verification: stop using mPlatformInfoHob
    7dbb8a24d1 OvmfPkg/PlatformPei: NoExec: stop using mPlatformInfoHob
    cc6efda777 OvmfPkg/PlatformPei: MemTypeInfo: stop using mPlatformInfoHob
    27874a382c OvmfPkg/PlatformPei: PeiMemory: stop using mPlatformInfoHob
    00743d144b OvmfPkg/PlatformPei Q35 SMM helpers: stop using mPlatformInfoHob
    9d9d15b42a OvmfPkg/PlatformPei: PeiFv: stop using mPlatformInfoHob
    78c373f2a5 OvmfPkg/PlatformPei: AmdSev: stop using mPlatformInfoHob
    916825b84f DynamicTablesPkg: SSDT _LPI revision is incorrect
    d103840cfb MdePkg/UnitTestHostBaseLib: Remove HOST_APPLICATION limitation
    1cd902f1f4 UnitTestFrameworkPkg: Modify APIs in UnitTestPersistenceLib
    e986f4ce96 MdePkg/BaseCpuLib: Remove assembly for CpuFlushTlb
    804e8c6566 Maintainers.txt: Change Anthony's github id
    592bf33a29 ShellPkg/Shell: Do not set end device path if already end
    1fd8d08970 ShellPkg/AcpiView: APMT Parser
    aa65bb4020 MdePkg/IndustryStandard: add definitions for ACPI APMT
    11ce7a2de7 DynamicTablesPkg: Remove duplicated words
    5890a18409 MdeModulePkg: SdMmcPciHcDxe: Fix issue that SD1.0 cards can't be recognized
    a654289439 MdeModulePkg/Ata: Fix command status reporting
    4cb94f20b0 OvmfPkg/SmbiosPlatformDxe: use PcdFirmware*
    1ef86f1201 mv OvmfPkg: move fdf include snippets to Include/Fdf
    5eb973eb62 OvmfPkg: move dsc include snippet for Network support to Include/Dsc
    5c25f6c67b OvmfPkg: move dsc and fdf include snippets for TPM support to subdirs
    127e2c5315 OvmfPkg: Add INVD case in #VE handler
    54d81d06fc MdeModulePkg/DxeCore: Use correct type for alignment mask
    8a485e4bb8 EmulatorPkg: Record Argc, Argv and Envp in EmuThunk Ppi
    2c284027b2 EmulatorPkg: Remove unnecessary dependency on EmbeddedPkg
    22f73b6d2d EmulatorPkg: Add persistent memory in EmuThunkPpi
    1c75bf3c21 UefiCpuPkg: Bug fix in 5LPage handling
    c14c4719f9 UefiCpuPkg: Check SMM Delayed/Blocked AP Count
    4e17aba4b5 EmulatorPkg/Win: Unload DLLs before reset
    2280af5ff8 UefiCpuPkg/Test: develop UEFI App and dynamic cmd for MP services UT
    cf3d4508b2 UefiCpuPkg/Test: Move EfiMpServiceProtocol UT in a separate function
    d9e7f6fe49 MdeModulePkg: Put USB DEBUGs that occur for bulk timeouts under VERBOSE
    ca33daafc6 RedfishPkg: Remove overlapping private include path in DEC file
    a639248bd0 UefiPayloadPkg: Support multiple firmware volume
    7bee249891 EmulatorPkg/WinHost: Add Reset2 PPI
    a121165e35 EmulatorPkg/WinHost: XIP for SEC and PEI_CORE
    d2842bb6ec EmulatorPkg/WinHost: pre-allocate "physical" RAM
    735a7496cb RedfishPkg: Fix typos of the .inc filenames
    7de1c71dd2 CryptoPkg/BaseCryptLib:time overflow
    5d5be45bd1 CryptPkg: Enable CryptoPkg BaseCryptLib ParallelHash for PEI and DXE
    47d988387e OvmfPkg/PlatformInitLib: Add check to NvVarStoreFV HeaderLength
    a1d5723914 UnitTestFrameworkPkg: Library classes private to public
    a8a78ef194 CryptoPkg/OpensslLib: Upgrade OpenSSL to 1.1.1s
    beb0f8d483 MdeModulePkg: Disable PciDegrade support for LoongArch64
    dd3ba82d31 .github/ISSUE_TEMPLATE/config.yml: Add initial issue template
    8aff08c817 EmbeddedPkg/MetronomeDxe: Update outdated lower bound comment
    b92e049522 BaseSynchronizationLib: Fix RISC-V helper name
    c8c978d328 ShellPkg/DpDynamicCommand: Add ResetEnd support in DP command
    ae3bc559f9 .github/dependabot.yml: Enable dependabot
    d992163da6 ShellPkg/SmbiosView: Update ProcessorUpgradeTable
    85d805ed32 UefiPayloadPkg: The UPL info section is not aligned at 4-byte boundary
    6ae2b6648e ArmPkg/ArmTrngLib: Remove ASSERTs in ArmTrngLibConstructor()
  - Removed patches which are merged to mainline:
  - ovmf-tools_def-add-fno-omit-frame-pointer-to-GCC48_-IA32-.patch
    tools_def: add -fno-omit-frame-pointer to GCC48_{IA32,X64}_CC_FLAGS
    (bsc#1199597)
  - 129404f6e4        edk2-stable202302~200
  - ovmf-OvmfPkg-PlatformInitLib-Fix-integrity-checking-faile.patch
    OvmfPkg/PlatformInitLib: Fix integrity checking failed of NvVarStore
    (bsc#1206078)
  - ceb52713b0        edk2-stable202302~226
  - Add the following revert patches to avoid Page-Fault exception when booting
    with edk2-stable202302 ovmf. (bsc#1205978)
    ovmf-Revert-OvmfPkg-PlatformInitLib-reorder-PlatformQemuU.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformReservati.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformAddHobCB.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformGetLowMem.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-Add-PlatformScanE820-.patch
    ovmf-Revert-OvmfPkg-PlatformInitLib-dynamic-mmio-window-s.patch
  - This is for workaround problem temporary. (bsc#1205978)
  - Removed the following revert patches because they are not work for
    edk2-stable202302. Those revert patches causes ovmf falls in unlimited
    boot loops. Because we do not have plan to upgrade ovmf of 15.4. So
    let's removed them:
    [#] nasm-2.14 doesn't support corresponding instructions.
    ovmf-Revert-MdePkg-Remove-the-macro-definitions-regarding.patch
    ovmf-Revert-UefiCpuPkg-Replace-Opcode-with-the-correspond.patch
    ovmf-Revert-SourceLevelDebugPkg-Replace-Opcode-with-the-c.patch
    ovmf-Revert-MdePkg-Replace-Opcode-with-the-corresponding-.patch
    ovmf-Revert-MdeModulePkg-Replace-Opcode-with-the-correspo.patch
  - Respin the following patches:
  - ovmf-gdb-symbols.patch
  - ovmf-disable-ia32-firmware-piepic.patch
  - fix-aarch64.patch
  - ovmf-Revert-OvmfPkg-OvmfXen-Set-PcdFSBClock.patch
  - Rename fix-aarch64.patch to ovmf-Revert-ArmVirtPkg-make-EFI_LOADER_DATA-non-executabl.patch
    It's express purpose more clearly. (bsc#1207095)
  - modified ovmf-build-funcs.sh, add the following qmeu paramter:
  - fw_cfg name=opt/org.tianocore/X-Cpuhp-Bugcheck-Override,string=yes
    It can disable the checking of CPU hotplug register block misbehaves
    in qemu. Qemu needs dab30fbef38 patch, otherwise that ovmf will hang
    when booting and show a message to indicate qemu bug. (bsc#1209266)
* Wed Feb 15 2023 Joey Lee <jlee@suse.com>
- Add ovmf-Revert-OvmfPkg-OvmfXen-Set-PcdFSBClock.patch to revert
  71cdb91f313380152d7bf38cfeebe76f5b2d39ac patch (bsc#1205613)
  - 71cdb91f313380152d7bf38cfeebe76f5b2d39ac OvmfPkg/OvmfXen: Set PcdFSBClock
  - We are waiting better upsteam patch, revert the issue patch first.
    Then PcdFSBClock will back to fixed variable.
  - Reference: https://edk2.groups.io/g/devel/topic/94891128#96077
  https://bugzilla.tianocore.org/show_bug.cgi?id=4340
* Thu Jan 19 2023 Paolo Stivanin <info@paolostivanin.com>
- Add fix-aarch64.patch: this fixes https://bugzilla.suse.com/show_bug.cgi?id=1207095
* Thu Dec  8 2022 Joey Lee <jlee@suse.com>
- Add ovmf-OvmfPkg-PlatformInitLib-Fix-integrity-checking-faile.patch
  to avoid "NvVarStore Variable header State was invalid" issue when
  rebooting or booting second time. System hangs when booting. (bsc#1206078)
  The error message in ovmf log:
  Select Item: 0x19
  Select Item: 0x25
  Reserved variable store memory: 0x7FF7C000; size: 528kb
  NvVarStore Variable header State was invalid.
  ASSERT /home/abuild/rpmbuild/BUILD/edk2-edk2-stable202211/OvmfPkg/Library/PlatformInitLib/Platform.c(807): ((BOOLEAN)(0==1))
* Fri Dec  2 2022 Joey Lee <jlee@suse.com>
- Add ovmf-Revert-OvmfPkg-PlatformInitLib-dynamic-mmio-window-s.patch
  to avoid Page-Fault exception when booting with edk2-stable202211
  ovmf. (bsc#1205978)
  - This is a revert patch for workaround problem temporary.
* Tue Nov 29 2022 Joey Lee <jlee@suse.com>
- In the PFLASH_CODE in ovmf-build-funcs.sh, Use readonly=on instead of
  readonly becuase we got the following message when building ovmf
  on SLE15-SP3/SP4 code base:
  [  981s] qemu-system-x86_64: -drive if=pflash,format=raw,unit=0,readonly,file=ovmf-x86_64-ms-code.bin: warning: short-form boolean option 'readonly' deprecated
  [  981s] Please use readonly=on instead
  [  981s] char device redirected to /dev/pts/0 (label charserial1)
* Mon Nov 28 2022 Joey Lee <jlee@suse.com>
- Update to edk2-stable202211 (jsc#PED-1410)
  - Features (https://github.com/tianocore/edk2/releases):
  CryptoPkg remove EC PCD and merge optimized openssl libs
  Add GoogleTest unit test support to UnitTestFrameworkPkg
  Add Raw algorithm support using Arm FW-TRNG interface
  TDVF Lazy Accept in OvmfPkg
  Debug code to audit BIOS TPM extend operations
  Add a new feature to enable LoongArch prot for EDKII
  CryptoPkg: Need to add additional cipher algos and TLS API to meet WPA3
  IntelFsp2(Wrapper)Pkg: Support FSP 2.4 MultiPhaseInit
  CryptoPkg: Need to support EC and BN API due to WPA3 feature
  Add PCI_DEVICE_PPI support for NvmExpressPei
  - Patches (git log --oneline --date-order edk2-stable202208..edk2-stable202211):
    fff6d81270 pip-requirements.txt: Update to edk2-pytool-extensions 0.20.0
    2ddc8e1b67 pip-requirements.txt: Update to edk2-pytool-library 0.12.1
    93629f2c7c ArmPkg/ArmTrngLib: Remove ASSERT in GetArmTrngVersion()
    0cb30c3f5e Maintainers: Update the VmgExitLib to CcExitLib
    765ba5bf05 OvmfPkg/UefiCpuPkg: Add CcExit prefix to the APIs of CcExitLib
    a89f558d3c OvmfPkg/UefiCpuPkg/UefiPayloadPkg: Rename VmgExitLib to CcExitLib
    b9e702c3c9 UefiCpuPkg/ResetVector:Add Option to reserve 4K region at 4GB
    6d55ad9a59 MdePkg/Test: Add port of BaseSafeIntLib unit tests to GoogleTest
    31377aba8f BaseTools/Plugin/HostBaseUnitTestRunner: Enable gtest xml output
    80f097711b .pytool: Add googletest submodule to CISettings.py
    d4586fe3ae UnitTestFrameworkPkg/Library/CmockaLib: Generate symbol information
    cef0c5c684 UnitTestFrameworkPkg: Add googletest submodule and GoogleTestLib
    c1b073a9dc MdePkg/Include/Library: Undefine _ASSERT() if already defined
    933b4c333c MdePkg/Include: Update Base.h to improve C++ compatibility
    3182843f3b IntelFsp2Pkg: Improvement of supporting null UPD pointer in FSP-T
    c8fb724046 ArmPkg/ArmTrngLib: Fix incorrect GUID reference in DEBUG() output
    3b1f3414f2 .github/workflows: Update CodeQL to install Python 3.10.6
    c17c3c24d8 ShellPkg:Improved Smbios Type9 data under smbiosview
    342813a3f7 pip-requirements.txt: Update edk2-pytool-library to 0.12.0
    b0fd309719 edk2.qls: Allow error severity results and add new queries
    179efe5d69 BaseTools: Fix wrong type of arguments to formatting functions
    0be81a4d83 BaseTools/Source/C: Use /Z7 instead of /Zi for host tools
    6032b46dce PrmPkg/PrmSsdtInstallDxe: Update PRMT Device CID to PNP0C02.
    6c1a4a376e .github: Add initial CodeQL config and workflow files
    c7aecf2a4f Maintainers.txt: Add .github maintainers and reviewers
    50bee4cc12 CryptoPkg: Sha1 functions causing build errors
    239bcf7805 PrmPkg: Use UnitTestFrameworkPkg UEFI BS library
    6e8b0b6913 UnitTestFrameworkPkg: Add UnitTestUefiBootServicesTableLib
    82e70d9ac0 CryptoPkg/Readme.md: typo and grammar fixes
    35043a5ec0 MdePkg/BaseLib: Fix out-of-bounds reads in SafeString
    b556f2445c ArmVirtPkg: Kvmtool: Add RNG support using Arm TRNG interface
    9eb5ccda50 SecurityPkg/RngDxe: Add Arm support of RngDxe
    ff29cdb968 SecurityPkg/RngDxe: Rename AArch64/RngDxe.c
    6cdddccf00 SecurityPkg/RngDxe: Add debug warning for NULL PcdCpuRngSupportedAlgorithm
    863fe9e191 SecurityPkg/RngDxe: Add AArch64 RawAlgorithm support through ArmTrngLib
    4b3e9d80be SecurityPkg/RngDxe: Check before advertising Cpu Rng algo
    199031b2b0 SecurityPkg/RngDxe: Documentation/include/parameter cleanup
    922bf317f1 SecurityPkg/RngDxe: Remove ArchGetSupportedRngAlgorithms()
    aade3b93fe SecurityPkg/RngDxe: Replace Pcd with Sp80090Ctr256Guid
    8a89747844 SecurityPkg/RngDxe: Rename RdRandGenerateEntropy to generic name
    e00ec499c5 ArmPkg/ArmTrngLib: Add Arm TRNG library
    351fe77666 ArmPkg: Add FID definitions for Arm TRNG
    ef4cf3d88d MdePkg/ArmTrngLib: Add NULL instance of Arm TRNG Library
    cbce5a1a93 MdePkg/ArmTrngLib: Definition for Arm TRNG library class interface
    3d480a93de ArmPkg/ArmHvcLibNull: Add NULL instance of ArmHvcLib
    9d8ed9c8ee ArmPkg: Sort HVC/SMC section alphbetically in ArmPkg.dsc
    aa0f522471 ArmPkg/ArmMonitorLib: Add ArmMonitorLib
    9a50990cdb ArmPkg/ArmMonitorLib: Definition for ArmMonitorLib library class
    dcf8c79056 ArmPkg: PCD to select conduit for monitor calls
    cc650a0378 ArmPlatformPkg: Retire NorFlashDxe driver
    eff44c008d OvmfPkg/VmgExitLig: HALT on #VE when access to private memory
    2695e49219 UefiPayloadPkg: Boot mode in PHIT HOB will not be updated
    ee3da09bb2 MdeModulePkg/Ufs :Coverity scan flags multiple issues in edk2-stable202205
    eae9e51d98 MdeModulePkg/scsi :Coverity scan flags multiple issues in edk2-stable202205
    b84f32ae5b IntelFsp2Pkg: FSP should support input UPD as NULL.
    cab1f02565 MdeModulePkg/PiSmmCore: SmmEntryPoint underflow (CVE-2021-38578)
    c46204e25f IntelFsp2Pkg: Update Function header to support IA32/X64.
    957a15adaf UefiCpuPkg/SmmCpuFeaturesLib: Clean up header file inclusion in SmmStm.c
    ae62a6e44d UefiCpuPkg/SmmCpuFeaturesLib: Abstract arch dependent code
    ed8bfada03 UefiCpuPkg/SmmCpuFeaturesLib: Rename the common C file
    8487ec0ee7 CryptoPkg/Test: Simplify BaseCryptLib host based unit tests
    b5dbf8267b pip-requirements.txt: Bump pytool extensions and library
    85dba961c7 UnitTestFrameworkPkg: Support FILE_GUID override in host based unit tests
    720c25ab41 OvmfPkg: Call gEdkiiMemoryAcceptProtocolGuid to accept pages
    7dcc2f3870 OvmfPkg: Realize EdkiiMemoryAcceptProtocol in TdxDxe
    2af33db365 MdePkg: The prototype definition of EdkiiMemoryAcceptProtocol
    d1e41c620f OvmfPkg: Introduce lazy accept in PlatformInitLib and PlatformPei
    6ca9f410d1 ShellPkg: Update shell command memmap to show unaccepted memory
    43e306806e MdeModulePkg: Update Dxe to handle unaccepted memory type
    502c01c502 MdePkg: Add UEFI Unaccepted memory definition
    9b648112a5 OvmfPkg: Use BZ3937_EFI_RESOURCE_MEMORY_UNACCEPTED defined in MdeModulePkg
    32c5a470ad MdePkg: Increase EFI_RESOURCE_MAX_MEMORY_TYPE
    00bbb1e584 MdeModulePkg: Add PrePiHob.h
    df7ce74e6c RedfishPkg/RedfishDiscoverDxe: Fix memory free issue
    66772bc852 Maintainers.txt: Add 'Pierre Gondois' as DynamicTablesPkg reviewer
    e9a3613ce0 ShellPkg/AcpiView: Update PCCT fields for ACPI 6.5
    c9a4df88fd DynamicTablesPkg: Readme.md: Update available tables for generation
    1729fb8a82 DynamicTablesPkg/AmlLib: Allow larger AccessSize for Pcc address space
    8405b1480f DynamicTablesPkg: Add PCCT Generator
    dab7bac94c DynamicTablesPkg: Add PCCT related objects
    a5672d43a6 DynamicTablesPkg: Fix Ssdt PCI generation comments
    5acd6489df DynamicTablesPkg: FdtHwInfoParserLib: Remove wrong comment
    0bcd3cc06e DynamicTablesPkg: Remove deprecated APIs
    2ef32f914a DynamicTablesPkg: Fix wrong/missing fields in CmObjParser
    a64cc43552 DynamicTablesPkg: Fix GTBlock and GTBlockTimerFrame CmObjParsers
    3bcc2e22ef DynamicTablesPkg: Update CmObjParser for MinorRevision
    44b7a856f0 DynamicTablesPkg: Update CmObjParser for IORT Rev E.d
    48c6e7dbcd DynamicTablesPkg: Add PrintString to CmObjParser
    020891f173 DynamicTablesPkg: Use correct print formatter
    52199bf532 MdeModulePkg/ScsiDiskDxe: Update proper device name for ScsiDisk drive
    d98efb4682 UefiCpuPkg: Restore HpetTimer after CpuExceptionHandlerLib test
    99338ef81e ArmVirtPkg/ArmVirtKvmTool: Migrate to OVMF's VirtNorFlashDxe
    b92298af82 ArmVirtPkg/ArmVirtQemu: migrate to OVMF's VirtNorFlashDxe
    789a723285 OvmfPkg/VirtNorFlashDxe: use EFI_MEMORY_WC and drop AlignedCopyMem()
    25589c4a76 OvmfPkg/VirtNorFlashDxe: avoid switching between modes in a tight loop
    ca01e6216a OvmfPkg/VirtNorFlashDxe: avoid array mode switch after each word write
    83f11f9572 OvmfPkg/VirtNorFlashDxe: drop block I/O protocol implementation
    68d234989b OvmfPkg/VirtNorFlashDxe: remove disk I/O protocol implementation
    0a64106c56 OvmfPkg/VirtNorFlashDxe: remove CheckBlockLocked feature
    c1ff81f799 OvmfPkg/VirtNorFlashDxe: clone ArmPlatformPkg's NOR flash driver
    16bf588b60 OvmfPkg: clone NorFlashPlatformLib into VirtNorFlashPlatformLib
    115cebbe4d ArmVirtPkg/ArmVirtQemu: Clear XIP flags instead of overriding them
    b6efc505e4 ArmVirtPkg/ArmVirtQemu: omit PCD PEIM unless TPM support is enabled
    7136d5491e ArmVirtPkg/QemuVirtMemInfoLib: use HOB not PCD to record the memory size
    fead469a3b ArmVirtPkg/ArmVirtQemu: avoid shadowing PEIMs unless necessary
    75d2be4a37 ArmVirtPkg/ArmVirtQemu: Drop unused variable PEIM
    07be1d34d9 ArmVirtPkg/ArmVirtQemu: enable initial ID map at early boot
    a26050f74d ArmVirtPkg/ArmVirtQemu: use first 128 MiB as permanent PEI memory
    2eff4ddc77 ArmVirtPkg/ArmVirtQemu: implement ArmPlatformLib with static ID map
    9ca2dc7bec ArmVirtPkg/ArmVirtQemu: wire up timeout PCD to Timeout variable
    2997ae3873 ArmVirtPkg: make EFI_LOADER_DATA non-executable
    9e2c88b16e Maintainers.txt: Update maintainers and reviewers for LoongArch64
    9670f79937 Maintainers.txt: Update maintainers list
    26638d2aa3 IntelFsp2WrapperPkg: Check header revision for MultiPhase support.
    7464db4474 MdeModulePkg: Fix spelling error in PciSioSerialDxe
    56035d1c8b ArmPlatformPkg/PrePeiCore: Print the firmware version early in boot
    db2c22633f Ps2KbdCtrller: Make wait for SUCCESS after BAT non-fatal
    fb493ac84e ArmPlatformPkg/PrePeiCore: permit entry with the MMU enabled
    b28acb22e0 ArmVirtPkg: do not enable iSCSI driver by default
    f4213fed34 ArmVirtPkg: remove EbcDxe from all platforms
    acb2acccfd BaseTools/Tests: Use quotes around PYTHON_COMMAND
    4fcd5d2620 CryptoPkg/Library/OpensslLib: update auto-generated files
    0882d6a32d CryptoPkg/Library/OpensslLib: Add generated flag to Accel INF
    d79295b5c5 CryptoPkg/Library/OpensslLib: Update process_files.pl INF generation
    3b46a1e243 Revert "CryptoPkg: Update process_files.pl to auto add PCD config option"
    244ce33bdd CryptoPkg: Add Readme.md
    584b246e88 CryptoPkg: Fixed host-based unit tests
    0c9744787e CryptoPkg: Update DSC to improve CI test coverage
    dfc7c3dc8c CryptoPkg: Remove PcdOpensslEcEnabled from CryptoPkg.dec
    a57b4c11a5 CryptoPkg/Library/OpensslLib: Remove PrintLib from INF files
    e75951ca89 CryptoPkg/Library/OpensslLib: Produce consistent set of APIs
    ea6d859b50 CryptoPkg/Library/OpensslLib: Combine all performance optimized INFs
    dd00f92b2f CryptoPkg/Library: Cleanup BaseCryptLib and TlsLib
    961fadf60c CryptoPkg/Test/UnitTest/Library/BaseCryptLib: Unit test fixes
    8f8372439d CryptoPkg/Library/BaseCryptLib: Update internal functions/variables
    8437368c69 CryptoPkg/Library/BaseCryptLib: Add missing UNI file and fix format
    d7d9866ef4 CryptoPkg: Document and disable deprecated crypto services
    4d29da411f remove GCC build warning
    6fd754ec0f BaseTools: Fixed the multiple pairs brackets issue in GenFv
    2355f0c09c BaseTools: Fix check for ${PYTHON_COMMAND} in Tests/GNUmakefile
    913a308df9 BaseTools/Scripts/PatchCheck.py: Allow tab in Makefile
    c6720db5dd MdeModulePkg/XhciDxe: Add boundary check for TRB ring allocation
    31b1638468 ArmPkg/ArmMmuLib: Reuse XIP MMU routines when splitting entries
    999c53e2ca ArmPkg/ArmMmuLib: permit initial configuration with MMU enabled
    0487cac09f ArmPkg/ArmMmuLib: Disable and re-enable MMU only when needed
    ab644cfac5 ArmPkg/ArmMmuLib: don't replace table entries with block entries
    0f6eccdbf7 BaseTools: Add missing spaces for PCD expression values in AutoGenC
    1d0ff11526 BaseTools: Correct initialization data size check for array PCDs
    d23eb3aa99 BaseTools/GenFds: Correct file type set for the PIC section
    0a29933ea9 BaseTools: Support COMPAT16 section generation
    225810a182 BaseTools: Add support for SUBTYPE_GUID section generation
    81aeb94648 BaseTools: Correct BPDG tool error prints
    09e74b81ba BaseTools/FMMT: Add Shrink Fv function
    0e6db46b1b BaseTools/FMMT: Add Extract FV function
    b03dceb87f BaseTools: Remove duplicated words in Python tools
    c4663e7277 pip-requirement: Upgrade the edk2-basetools version from 0.1.29 to 0.1.39
    9d6915ca91 UefiCpuPkg/Test: Add unit tests for MP service PPI and Protocol
    6f1bb567aa UefiCpuPkg: Add R8/R9 etc in EccCheck ExceptionList
    012e424601 UefiCpuPkg: Add Pei/DxeCpuExceptionHandlerLibUnitTest in dsc
    055eaacc34 UefiCpuPkg: Add Unit tests for PeiCpuExceptionHandlerLib
    beabde5875 UefiCpuPkg: Add Unit tests for DxeCpuExceptionHandlerLib
    b8e54e15de UefiCpuPkg/CpuPageTableLib:Support PAE paging for PageTableParse
    a7e070808c UefiCpuPkg:Add RegisterExceptionHandler in PeiCpuExceptionHandlerLib
    d618fe05bf BaseTools: Remove duplicated words in C tools
    8fc06b6e19 Fix bug on SRIOV ReservedBusNum when ARI enable.
    4aa7e66c06 MdeModulePkg: Fixed extra 1 SR-IOV reserved bus
    e0200cc47a NetworkPkg: Add LoongArch64 architecture.
    2ce4bfb843 MdeModulePkg/DxeIplPeim : LoongArch DxeIPL implementation.
    380821a949 MdeModulePkg/CapsuleRuntimeDxe: Add LoongArch64 architecture.
    dad7fc29d9 MdeModulePkg/Logo: Add LoongArch64 architecture.
    ced203c3d5 MdePkg/BaseSafeIntLib: Add LoongArch64 architecture for BaseSafeIntLib.
    104df6136f MdePkg/BaseSynchronizationLib: LoongArch cache related code.
    f89815a125 MdePkg/BaseCpuLib: LoongArch Base CPU library implementation.
    dbbb045ff1 MdePkg/BasePeCoff: Add LoongArch PE/Coff related code.
    10d291f746 MdePkg/BaseIoLibIntrinsic: IoLibNoIo for LoongArch architecture.
    264e930de0 MdePkg/BaseCacheMaintenanceLib: LoongArch cache maintenance implementation.
    cd24eb578b MdePkg/BaseLib: BaseLib for LOONGARCH64 architecture.
    f0a704f9b5 MdePkg/Include: LoongArch definitions.
    76bf716a7a MdePkg: Add LoongArch LOONGARCH64 binding
    b1b5177a0c .pytool: Add LoongArch64 architecture on LoongArch64 EDK2 CI.
    ab9768cd46 .azurepipelines: Add LoongArch64 architecture on LoongArch64 EDK2 CI.
    bcdafe1179 BaseTools: Enable LoongArch64 architecture for LoongArch64 EDK2 CI.
    114e6075b6 BaseTools: Add LoongArch64 binding.
    c53807cb7b BaseTools: Updated build tools to support new LoongArch.
    cb4f1dfcc1 BaseTools: Updated for GCC5 tool chain for LoongArch platfrom.
    1aa311d175 BaseTools: Update GenFw/GenFv to support LoongArch platform.
    082b563fc4 .python/SpellCheck: Add "Loongson" and "LOONGARCH" to "words" section
    10daf3ee24 MdeModulePkg: Use LockBoxNullLib for LOONGARCH64
    23d873f4cf MdePkg/DxeServicesLib: Add LOONGARCH64 architecture
    6e1ddbab8d UnitTestFrameworkPkg: Add LOONGARCH64 architecture for EDK2 CI.
    78b081334e ShellPkg: Add LOONGARCH64 architecture for EDK2 CI.
    711ee4103a SecurityPkg: Add LOONGARCH64 architecture for EDK2 CI.
    d2c0d52ed6 MdePkg/Include: Add LOONGARCH related definitions EDK2 CI.
    c5f4b4fd03 CryptoPkg: Add LOONGARCH64 architecture for EDK2 CI.
    ee2ea7868a NetworkPkg/HttpBootDxe: Add LOONGARCH64 architecture for EDK2 CI.
    ad8f2b7251 NetworkPkg: Add LOONGARCH64 architecture for EDK2 CI.
    2067672ded FmpDevicePkg: Add LOONGARCH64 architecture for EDK2 CI.
    d8c073c89b FatPkg: Add LOONGARCH64 architecture for EDK2 CI.
    e25963d458 MdePkg: Added LoongArch jump buffer register definition to MdePkg.ci.yaml
    0371178d0b MdePkg: Added file of DebugSupport.h to MdePkg.ci.yaml
    5bd2dbc698 UefiPayloadPkg: Remove deprecate Crypto Service
    e7d7f02c8e CryptoPkg: add Unit Test for X509 new function.
    22745df666 CryptoPkg: add new X509 function to Crypto Service.
    8ecae3d641 CryptoPkg: add new X509 function.
    190f77f8f4 CryptoPkg: add new X509 function definition.
    0371032289 CryptoPkg: add unit test for EC key interface.
    69a50a249b CryptoPkg: Add EC key interface to DXE and protocol
    f21a1d48fe CryptoPkg: Add EC key retrieving and signature interface.
    f80580f56b OvmfPkg/VirtioNetDxe: Check ChildHandle argument in GetControllerName
    8db4e9f9a0 CryptoPkg: Add new Tls APIs to DXE and protocol
    bb78d969b7 CryptoPkg: Extend Tls function library
    cafc573ac0 MdePkg: Add Tls configuration related define
    3c9e2f239a CryptoPkg: Fix integer overflow
    de103f1981 MdeModulePkg: Handle InitialVFs=0 case for SR-IOV
    4364d66168 UefiCpuPkg: Reset a parameter when BSP Exit in CPU relaxed mode.
    a670f12a74 UefiCpuPkg/CpuExceptionHandlerLib: Code optimization to allow bigger stack
    406ad0582a OvmfPkg: rename QemuBootOrderNNNN to VMMBootOrderNNNN
    3361336607 Revert "OvmfPkg/Microvm: no secure boot"
    8916a4f67f OvmfPkg/Microvm: add SECURE_BOOT_FEATURE_ENABLED
    9e6b552b4c OvmfPkg/PciHotPlugInitDxe: reserve more mmio space
    ecb778d0ac OvmfPkg/PlatformInitLib: dynamic mmio window size
    bbda386d25 OvmfPkg/PlatformInitLib: detect physical address space
    8f9ef9c9a0 OvmfPkg/PlatformInitLib: qemu cpuid physbits detection
    5ff7d712d4 MdeModulePkg/UefiBootManagerLib: Add Disk Info support for Ufs
    710f83b79d .azurepipelines: Add SourceLevelDebugPkg to CI
    cf01fdd5d7 SourceLevelDebugPkg: Add package CI YAML file
    d6d4a81f8a SourceLevelDebugPkg: Fix spelling errors
    1bd2ff1866 IntelFsp2WrapperPkg: Remove CI exception of PlatformMultiPhaseLib.
    f054beec54 IntelFsp2WrapperPkg: Add header for PlatformMultiPhaseLib.
    f931506815 .azurepipelines: Add SignedCapsulePkg to CI
    b3d379d188 SignedCapsulePkg: Add package CI YAML file
    769879e2a6 .azurepipelines: Add IntelFsp2Pkg and IntelFsp2WrapperPkg to CI
    9ecab62d40 IntelFsp2WrapperPkg: Add CI YAML file
    7c424c28b0 IntelFsp2WrapperPkg: Fix code formatting errors
    28b16c01cf IntelFsp2Pkg: Add CI YAML file
    a62bd922aa IntelFsp2Pkg/BaseFspMultiPhaseLib: Replace duplicate GUID
    629709a51d IntelFsp2Pkg: Fix code formatting errors
    12973359d0 EmbeddedPkg: Only run in CI for GCC5
    43c1111530 EmbeddedPkg: Add CI YAML file
    51e0599536 EmbeddedPkg/AcpiLib: Fix code formatting errors
    f01d3ee12c BaseTools/VolInfo: Update file and section type strings
    b6d324e06b BaseTools/VolInfo: Update copyright information
    4e1133b946 BaseTools/VolInfo: Parse apriori files
    c24328ca62 BaseTools/VolInfo: Increase GUID base name string
    8be33c6544 BaseTools/VolInfo: Fix EFI_SECTION_GUID_DEFINED parsing
    9fc029ee62 BaseTools/VolInfo: Correct buffer for GenCrc32 tool
    6a2b20ff97 MdeModulePkg/NonDiscoverablePciDeviceDxe: Allow partial FreeBuffer
    7aa06237b8 SecurityPkg: Remove enforcement of final GoIdle transition for CRB commands
    b7213bbd59 OvmfPkg/QemuBootOrderLib: skip unsupported entries in StoreQemuBootOrder
    d63242bd69 OvmfPkg/QemuBootOrderLib: allow slash in rom filenames
    2a0bd3bffc OvmfPkg/PlatformInitLib: q35 mtrr setup fix
    3c0d567c37 UefiPayloadPkg: Provide a wrapper for UniversalPayloadBuild.py
    f4d539007c OvmfPkg/PeilessStartupLib: move mPageTablePool to stack
    b3dd9cb836 MdeModulePkg/XhciDxe: Input context update for Evaluate Context command
    96f3efbd99 IntelFsp2WrapperPkg: Implement FSP 2.4 MultiPhase wrapper handlers.
    d97ee3244d CryptoPkg/Test: Add unit test for CryptoEc
    2157a23a86 CryptoPkg: Add ECC related usage reference
    3b382f5b38 CryptoPkg: Add EC APIs to DXE and protocol
    988e4d8f5e CryptoPkg: Add EC support
    0e7aa6bf9e CryptoPkg: Fix pem heap-buffer-overflow due to BIO_snprintf()
    582a7c9995 CryptoPkg: Add missing library mappings to DSC file
    ef9974b298 EmbeddedPkg/PrePi: Check for enough space before aligning heap pointer
    2500ce1011 DynamicTablesPkg: SSDT CPU _CPC generator
    58350c0055 DynamicTablesPkg: AML Code generation to add _CPC entries
    09c90532e7 DynamicTablesPkg: Add CM_ARM_CPC_INFO object
    953438e466 ArmPkg/SmbiosMiscDxe: Get SMBIOS information from OemMiscLib
    e5eb0e3347 ArmPkg/SmbiosMiscDxe: Remove redundant updates in SMBIOS Type 2
    7d74ea141e ArmPkg/SmbiosMiscDxe: Fix typo of "AssetTagType02"
    130b649a8b ArmPkg/SmbiosMiscDxe: Support fetching System UUID
    11b5093ce4 ArmPkg: Correct return value of "SMCCC_ARCH_SOC_ID" Function ID call
    8467a263f9 ArmPkg/ProcessorSubClassDxe: Get processor version from OemMiscLib
    a8e8c43a0e CryptoPkg/OpensslLib: Update generated files for native X64
    4102950a21 CryptoPkg/OpensslLib: Commit the auto-generated assembly files for IA32
    03f708090b CryptoPkg/OpensslLib: Add native instruction support for IA32
    0c9d4ad788 CryptoPkg/Test: Add unit test for CryptoBn
    42951543dd CryptoPkg: Add BigNum API to DXE and protocol
    fd0ad0c346 CryptoPkg: Add BigNum support
    5f403cdc6a CryptoPkg: add UnitTest for AeadAesGcm.
    022787f806 CryptoPkg: add AeadAesGcm to Crypto Service.
    a23f76e184 CryptoPkg: add AeadAesGcm support.
    acbc5747bc CryptoPkg: add AeadAesGcm function() definition.
    b19793a2ec CryptoPkg: add Hkdf UnitTest.
    e919c390e8 CryptoPkg: add new Hkdf api to Crypto Service.
    11b24ef0d7 CryptoPkg: add new Hkdf api in Crypt Lib.
    1336476233 CryptoPkg: add new Hkdf api definition in Crypt Lib.
    f3c69cb5a1 CryptoPkg: add Hmac Sha384 to host UnitTest.
    3f77ccb9c8 CryptoPkg: Add new hmac SHA api to Crypto Service.
    cbb3b6b950 CryptoPkg: Update CryptLib inf as the file name changed.
    0b1a1bdc30 CryptoPkg: Add HMAC-SHA384 cipher support.
    7bb42e3249 CryptoPkg: Add new hmac definition to cryptlib
    238f5f9544 RedfishPkg/JsonLib: Fix JsonLib build failure
    6f340acfb1 CryptoPkg/BaseCryptLib:Remove redundant init
    dd1e20b3c2 nasm_ext_dep.yaml: Remove leading zero in patch version
    62f00dad22 BaseTools: Edk2ToolsBuild: Fixing pipeline build due to path too long
    2c17d676e4 Maintainers.txt: Update email address
    415fc406d6 UefiPayloadPkg/PayloadLoaderPeim: remove GCC build warning
    3184e44df1 Maintainers.txt: Update maintainers/reviewers for CI and Test
    f46c7d1e36 IntelFsp2Pkg: Fix FspSecCoreI build failure.
    981bf66d5a IntelFsp2Pkg: NvsBufferPtr is missing in Fsp24ApiEntryM.nasm
    8c92a9508e DynamicTablesPkg: AcpiSsdtPcieLibArm: Allow use of segment number as UID
    45297e6c9b BaseTools: 64bit FSP FV map file cannot be created correctly
    1dccbd1a38 MdeModulePkg/AhciPei: Fix MMIO base assignment
    838c730fe6 MdeModulePkg SmbiosMeasurementDxe: Add Type4 CurrentSpeed to filter table
    db7afaee91 MdeModulePkg: Use configurable PCD for AHCI command retries
    970e262949 OvmfPkg: Allow runtime control of IPv4 and IPv6 support on QEMU
    d933ec115b OvmfPkg: gather common NetworkComponents overrides in .dsc.inc file
    477b5b7d55 OvmfPkg: Introduce alternate UefiDriverEntrypoint to inhibit driver load
    34969dd260 ArmPkg, ArmVirtPkg: put SpellCheck in AuditOnly mode
    cdb80a281f OvmfPkg/LegacyBootManagerLib: Fix debug macro arguments
    8fdb4de628 NetworkPkg/TcpDxe: Fix debug macro arguments
    e8a537d28d DynamicTablesPkg/AcpiPpttLibArm: Fix debug macro arguments
    e495b1009a SecurityPkg/SmmTcg2PhysicalPresenceLib: Add missing debug print specifier
    c403de7bd4 RedfishPkg/RedfishRestExDxe: Remove extra debug macro argument
    1096a9b04b MdeModulePkg: Fix imbalanced debug macros
    b4036b52b1 FatPkg/FatPei: Remove extraneous debug message argument
    917a7e3f34 ArmPlatformPkg/NorFlashDxe: Remove unused debug print specifier
    7b8f69d7e1 BaseTools/GenFw AARCH64: Convert more types of explicit GOT references
    d82ec90f51 pip-requirement: Upgrade the edk2-basetools version from 0.1.28 to 0.1.29
    8465fd59d3 OvmfPkg: Update I/O port related to ACPI devices for CloudHv
    54c8d5e432 UefiPayloadPkg: Allow DxeMain.inf to consume the new SerialPortLib
    11a04bb4a6 UefiPayloadPkg: Implement a new SerialPortLib instance
    512042eba8 OvmfPkg/QemuVideoDxe: fix bochs mode init
    314799a926 pip-requirement: Upgrade the edk2-basetools version from 0.1.24 to 0.1.28
    3d35a6c243 IntelFsp2Pkg: Adopt FSP 2.4 MultiPhase functions.
    5eeb088ad6 OvmfPkg/QemuBootOrderLib: add StoreQemuBootOrder()
    db463e8e9d CloudHv/arm: switch PeiMemLib to its own
    dba79765c4 CloudHv/arm: add PeiMemInfoLib
    520ba8e306 OvmfPkg/OvmfPkg*.dsc: Increase ACPI Reclaim memory size
    18b5b14932 OvmfPkg/IncompatiblePciDeviceSupportDxe: Ignore OptionRom in Sev guest
    f7da805b50 RedfishPkg/RedfishDiscoverDxe: Install protocol on each network interface
    39596c41c8 OvmfPkg: Add build-flag SECURE_BOOT_FEATURE_ENABLED
    3abaa281d3 OvmfPkg/TdxDxe: Set PcdEmuVariableNvStoreReserved
    70165fa6e2 OvmfPkg/NvVarsFileLib: Shortcut ConnectNvVarsToFileSystem in secure-boot
    ee91d9ef24 OvmfPkg: Reserve and init EmuVariableNvStore in Pei-less Startup
    58eb8517ad OvmfPkg/PlatformPei: Update ReserveEmuVariableNvStore
    4f173db8b4 OvmfPkg/PlatformInitLib: Add functions for EmuVariableNvStore
    0e72e8762a OvmfPkg/PeilessStartupLib: Delete TdxValidateCfv
    fb008dbe01 EmbeddedPkg: Add AllocateRuntimePages in PrePiMemoryAllocationLib
    7cc7c52670 OvmfPkg: Set default Pci PCDs in Tdx guest
    1b1c58ab32 OvmfPkg: Update CcProbeLib to DxeCcProbeLib
    c4bc1a9498 OvmfPkg: Add SecPeiCcProbeLib
    c05a218a97 EmbeddedPkg/GdbSerialDebugPortLib: fix compile warning
    b5d1dc94d0 OvmfPkg: increase max debug message length to 512
    1a24f5fb12 OvmfPkg/BhyvePkg: use correct PlatformSecureLib
    a4037690d9 EmbeddedPkg: Remove duplicated words
    05db766bee ArmPkg: Remove duplicated words
    1926702c95 ArmPlatformPkg: Remove duplicated words
    6dc4ac1347 ArmVirtPkg: Remove duplicated words
    e87ac5ef49 OvmfPkg: Remove duplicated words
    0ccf955674 StandaloneMmPkg: Remove duplicated words
    22c45b7c52 ArmPlatformPkg/PrePeiCore: Invoke constructors for SEC phase
    52bf4eba45 ArmPkg: Handle warm reboot request correctly
    aefcc91805 OvmfPkg/PlatformDxe: Handle all requests in ExtractConfig and RouteConfig
    165b5bcd68 OvmfPkg/PlatformDxe: Check RouteConfig arguments for spec compliance
    e61f3f4ef1 OvmfPkg: Add BUILD_SHELL flag for IA32, IA32X64, X64
    08522341c4 UefiPayloadPkg: To replace the libraries for the capsule driver.
    ec87181192 IntelFsp2WrapperPkg: Rename PlatformMultiPhaseLibSample.
    6edd257861 IntelFsp2WrapperPkg: Remove duplicated words
    ac55fcb051 DynamicTablesPkg: Fix typo in AmlCodeGenRdMemory32Fixed doxygen comment
    7719bc3f71 DynamicTablesPkg: Fix nested processor containers
    0a4079ad86 DynamicTablesPkg: AcpiSsdtPcieLibArm : Add UID to slot creation
    b9bb27e1ff DynamicTablesPkg: Add support to build _DSD
    033ba8bb29 DynamicTablesPkg: AcpiSsdtPcieLibArm: Added function to reserve ECAM space
    5236d47854 DynamicTablesPkg: DynamicTableManagerDxe: Added check for installed tables
    d9c8a9cf11 DynamicTablesPkg: DynamicPlatRepoLib: Adding more token fixers
    b18c0905ee DynamicTablesPkg: DynamicPlatRepoLib: Fix incorrect dereferencing
    2081054636 DynamicTablesPkg: DynamicPlatRepoLib: Added MemoryAllocationLib to inf
    9ca7ece8b3 MdeModulePkg/NvmExpressPei: Use PCI_DEVICE_PPI to manage Nvme device
    31a94f7fba IntelFsp2WrapperPkg: Add FSP 2.4 MultiPhase interface.
    df25a5457f IntelFsp2Pkg: Add FSP 2.4 MultiPhase interface.
    4b7bd4c591 UefiCpuPkg: Enhance logic in InitializeMpExceptionStackSwitchHandlers
    9ab2b34dd4 UefiCpuPkg: Use Top of each AP's stack to save CpuMpData
    76cf3d35e6 UefiCpuPkg: Simplify the implementation when separate exception stacks
    d1abb876f4 UefiCpuPkg/MpInitLib: Simplify logic in SwitchBsp
    76ec17526b UefiCpuPkg: Add PCD to control SMRR enable & SmmFeatureControl support
    367604b2f4 UefiCpuPkg/MpInitLib: Fix potential issue when IDT table is at above 4G
    3c06953fd7 ShellPkg: Adds Local APIC parser to AcpiView
    04ecdc38cd UefiCpuPkg/CpuPageTableLib/UnitTest: Add host based unit test
    383d34159d .azurepipelines: Use Python 3.10.6+
    227a133a0a Maintainers.txt: Update Maintainers/reviewers for universal payload
  - Removed patches which are merged to mainline:
  - ovmf-add-exclude-shell-flag.patch to add BUILD_SHELL flag for
    IA32, IA32X64, X64
  - e61f3f4ef1        edk2-stable202211~354
  - Modified shim.spec, use BUILD_SHELL instead of EXCLUDE_SHELL
  - Remove "-D EXCLUDE_SHELL" from ovmf-x86_64 and ovmf-x86_64-smm.
  - Add "-D BUILD_SHELL=FALSE" to ovmf-x86_64 and ovmf-x86_64-smm.
  - ovmf-bsc1199156-OvmfPkg-IncompatiblePciDeviceSupportDxe-Ignore-Optio.patch
    to ovmf to ignore OptionRom in Sev guest
  - 18b5b14932    edk2-stable202211~328
* Sat Nov 12 2022 Joey Lee <jlee@suse.com>
- Change the size of ovmf-x86_64 back to 2MB, and remove EFI shell to
  reduce the fv image size.
  - Originally the reason of changing the size of ovmf-x86_64 to 4MB is for
    preventing OBS exposes the following error:
    [  266s] GenFv: ERROR 3000: Invalid
    [  266s]   the required fv image size 0x1afed8 exceeds the set fv image size 0x1ac000
    The fv image size is too big. But we found that change ovmf-x86_64 to 4MB causes
    live migration problem on qemu. (bsc#1204220)
  - So let's change the size of ovmf_x86_64 back to 2MB and remove EFI shell
    to reduce the fv image size. If user wants to use EFI shell, they should move to
    ovmf-x86_64-4m image. So we add the "-D EXCLUDE_SHELL" build option to ovmf-x86_64
    flavor in ovmf.spec. (bsc#1204220)
* Thu Oct 13 2022 Joey Lee <jlee@suse.com>
- Update to edk2-stable202208 (jsc#PED-1410)
  - Features (https://github.com/tianocore/edk2/releases):
  Add CRC16 and CRC32C to MdePkg
  IntelFsp2Pkg/ConfigEditor: Support FSP 2.3 header
  Extend SecureBootVariableLib interfaces
  UEFI HTTPS Boot Support for HTTP Client Authentication (Basic or Digest)
  Support 64bit FspResetType for X64 build
  IntelFsp2Pkg/FspSecCore: Add FSP-I entry for SMM support
  Add PCI_DEVICE_PPI definition to EDK2
  Support to assign the subject name to sign the capsule file
  - Patches (git log --oneline --reverse edk2-stable202205..edk2-stable202208):
  7f0890776e MdeModulePkg/UniversalPayload: Align Identifier value with UPL spec
  b4be5f05dd UefiPayloadPkg: Align Identifier value with UPL spec
  dac2fc8146 UefiPayloadPkg: Align SpecRevision value with UPL spec
  3ca7326b37 OvmfPkg/VirtioGpuDxe: replace struct copy with CopyMem call
  fa2b212d61 IntelFsp2Pkg: Add FSP 2.3 header support
  11d8abcba2 IntelFsp2Pkg: FSP_TEMP_RAM_INIT call must follow X64 Calling Convention
  df1c7e91b4 IntelFsp2WrapperPkg: FSP_TEMP_RAM_INIT call for X64 Calling Convention
  62044aa99b OvmfPkg/ResetVector: Removing SEV-ES CPUID bit check
  54cd0d9b2f OvmfPkg: Fix TDVMCALL error in ApRunLoop.nasm
  64706ef761 OvmfPkg: Search EFI_RESOURCE_MEMORY_UNACCEPTED for Fw hoblist
  81ab97b7b9 OvmfPkg/AmdSev: remove unused SMM bits from .dsc and .fdf files
  0223898f3e OvmfPkg/Microvm: drop CODE and VARS files
  b57911c84c OvmfPkg/FdtPciHostBridgeLib: io range is not mandatory
  47f44097eb OvmfPkg/Platform: unfix PcdPciExpressBaseAddress
  ad3bafa7d5 OvmfPkg/Microvm/pcie: no vbeshim please
  bd10d4e201 OvmfPkg/Microvm/pcie: mPhysMemAddressWidth tweak
  632574ced1 OvmfPkg/Microvm/pcie: add pcie support
  5c9f151e0c OvmfPkg: CloudHv: Fix FW_BASE_ADDRESS
  43f3cfce19 OvmfPkg: Check for QemuFwCfg availability before accessing it
  3129ed374c OvmfPkg: CloudHv: Rely on QemuFwCfgLibNull implementation
  bf25f27e00 OvmfPkg: Don't access A20 gate register on Cloud Hypervisor
  72c5afd0b4 Security: Add HashLibTdx
  b1567b2e15 CryptoPkg: Add SecCryptLib
  dc443e4437 SecurityPkg: Add definition of EFI_CC_EVENT_HOB_GUID
  a708536dce OvmfPkg: Introduce SecMeasurementLib
  4b0a622635 OvmfPkg/IntelTdx: Measure Td HobList and Configuration FV
  ac03c339de OvmfPkg: Add PCDs for LAML/LASA field in CC EVENTLOG ACPI table
  f8264e1303 MdePkg: Define CC Measure EventLog ACPI Table
  57a6ee3461 OvmfPkg/IntelTdx: Add TdTcg2Dxe
  0a4019ec9d OvmfPkg/IntelTdx: Enable RTMR based measurement and measure boot
  0b36dea3f8 BaseTools: Fix dependency issue in PcdValueInit
  4f89e4b3e8 .pytool: UncrustifyCheck: Set IgnoreFiles path relative to package path
  2818fda9bc Security: Add SecTpmMeasurementLibTdx
  ff0ffe5999 OvmfPkg: Implement MeasureHobList/MeasureFvImage
  a81a650da1 OvmfPkg: Delete SecMeasurementLibTdx
  ff36b2550f OvmfPkg/Sec: fix stack switch
  21a9b605b8 CpuException: Avoid allocating code pages for DXE instance
  34d505123e CpuException: Init global variables in-place
  2fbc5ff0a5 CpuException: Avoid allocating page but using global variables
  2a09527ebc CpuException: Remove InitializeCpuInterruptHandlers
  e7abb94d1f CpuException: Add InitializeSeparateExceptionStacks
  54aeed7e00 MpInitLib: Allocate code buffer for PEI phase
  76323c3145 MpInitLib: remove unneeded global ASM_PFX
  b4d7b9d2b5 MpInitLib: Put SEV logic in separate file
  283ab9437a MpInitLib: Only allocate below 1MB memory for 16bit code
  ccc269756f MpInitLib: Move the Above1Mb vector allocation to MpInitLibInitialize
  f0b97e165e Revert "OvmfPkg/Sec: fix stack switch"
  b09ada6edc MdePkg: Remove "assert" from SmmCpuRendevousLibNull.c
  92288f4334 MdePkg/BaseLib: Add CRC16-ANSI and CRC32c implementations
  e2ae0bed29 ArmPkg/ArmExceptionLib: Follow new CpuExceptionHandlerLib APIs
  6676162f64 DxeMain: Fix the bug that StackGuard is not enabled
  16d97fa601 OvmfPkg: Use PcdOvmfWorkAreaBase instead of PcdSevEsWorkAreaBase
  05e57cc9ce SecurityPkg/HashLibTdx: Return EFI_UNSUPPORTED if it is not Tdx guest
  92ab049719 BaseTools: output the intermediate library instance when error occurs
  cc2db6ebfb UefiPayloadPkg: Increase the PcdMaximumUnicodeStringLength
  e8034b534a UefiPayloadPkg: Always split page table entry to 4K if it covers stack.
  cfe165140a UefiPayloadPkg: UniversalPayloadBuild.py to support --pcd feature
  b97243dea3 MdeModulePkg/XhciDxe: Check return value of XHC_PAGESIZE register
  3930d1791a ArmPlatformPkg: Remove overly verbose DEBUG lines in LcdGraphicsBlt
  aa1bce0e5e OvmfPkg: reduce the number of dsc include files for tpm libs
  6c9f218bc0 OvmfPkg/Library: Create base HardwareInfoLib for PCI Host Bridges
  2b1a5b8c61 Ovmf/HardwareInfoLib: Create Pei lib to parse directly from fw-cfg
  a1bd79c514 Ovmf/HardwareInfoLib: Add Dxe lib to dynamically parse heterogenous data
  3497fd5c26 Ovmf/PlatformPei: Use host-provided GPA end if available
  3f5b1b9132 OvmfPkg/PciHostBridgeUtilityLib: Initialize RootBridges apertures with spec
  f304308e1c ArmPlatformPkg: Add PCD for serial debug port interrupt
  4bfd668e5e UefiCpuPkg: CpuDxe: Set RW and P Attributes on Split Pages
  2aee08c0b6 UefiPayloadPkg: Backward support with python 3.6
  8f0722434b ArmVirtPkg: Include DxeHardwareInfoLib library class in dsc
  15b25045e6 Ovmf: Include HardwareInfoLib library classes for IntelTdx
  b600f253b3 BaseTools/Ecc: Fix grammar in Ecc error message
  7f4eca4cc2 MdeModulePkg/XhciDxe: Add access xHCI Extended Capabilities Pointer
  5914128871 BaseTools: Fix the GenMake bug for .cpp source file
  c13377153f MdePkg/Acpi62: Add type 7 NFIT Platform Capabilities Structure support
  21e6ef7522 UefiPayloadPkg: Align Attribute value with UPL spec
  8d0564deaf pip-requirements.txt: Update basetools version to 0.1.24
  f966093f5b OvmfPkg/PlatformCI: add IntelTdxBuild.py
  70586d4e3a MdePkg/Acpi62: Add bit definitions to NFIT Platform Capabilities Structure
  7861b24dc9 ArmPkg/Drivers: ArmGicIsInterruptEnabled returns incorrect value
  e1eef3a8b0 NetworkPkg: Add Wi-Fi Wpa3 support in WifiConnectManager
  134fbd552c SecurityPkg: UefiSecureBoot: Definitions of cert and payload structures
  d6bee54c45 SecurityPkg: PlatformPKProtectionLib: Added PK protection interface
  56c717aafa SecurityPkg: SecureBootVariableLib: Updated time based payload creator
  6de7c084db SecurityPkg: SecureBootVariableLib: Updated signature list creator
  6eb4079475 SecurityPkg: SecureBootVariableLib: Added newly supported interfaces
  fe73e9cd89 SecurityPkg: SecureBootVariableProvisionLib: Updated implementation
  d2a0f379d5 SecurityPkg: Secure Boot Drivers: Added common header files
  5678ebb42b SecurityPkg: SecureBootConfigDxe: Updated invocation pattern
  dbc4e3675f SecurityPkg: SecureBootVariableLib: Added unit tests
  152e37cc5a OvmfPkg: Pipeline: Resolve SecureBootVariableLib dependency
  f193b945ea EmulatorPkg: Pipeline: Resolve SecureBootVariableLib dependency
  9ab18fec82 StandaloneMmPkg: Fix issue about SpPcpuSharedBufSize field
  31d3eeb103 StandaloneMmPkg: Replace DEBUG_INFO with DEBUG_ERROR
  5496c763aa StandaloneMmPkg: Fix check buffer address failed issue from TF-A
  e93bc6309b UefiCpuPkg/SecCore: Add debug messages to illuminate data flow
  86a0f84470 ArmVirtPkg: Pipeline: Resolving newly introduced dependency
  c8e30482fd .gitignore: Ignore build tools build logs
  f6f3cc7ead UefiPayloadPkg: Add CryptoDxe driver to UefiPayload
  12dd064a18 MdePkg/include: Update DMAR definitions to Intel VT-d spec ver4.0
  9ab389c01b UefiCpuPkg: Update SEC_IDT_TABLE struct
  470206ba7f IntelFsp2Pkg: Update SEC_IDT_TABLE struct
  0d23c447d6 DynamicTablesPkg: Add support to specify FADT minor revision
  07c8e5e59b UefiPayloadPkg/PlatformBootManagerLib: Evenly space boot prompt
  176016387f BaseTools: add '-p' for Linux 'cp' command.
  039bdb4d3e BaseTools: Fix DSC LibraryClass precedence rule
  fc4a132c0e DynamicTables: Fix DT PCI interrupt flags parsing
  792ebb6374 DynamicTablesPkg: Fix generated _HID value for SBSA
  c966204049 IntelFsp2Pkg: Add Definition of EDKII_PEI_VARIABLE_PPI
  586b4a104b Maintainers.txt: Add IntelFsp2*Pkg Maintainer
  e18a5f813c Maintainers.txt: Update Maintainers/reviewers for UefiPayloadPkg
  e21b203911 UefiPayloadPkg: Add macro to support selective driver in UPL
  f0064ac3af Maintainers.txt: Update email address
  6cda306da1 DynamicTablesPkg: AcpiSsdtPcieLibArm: Correct translation value
  9ac155bf0b DynamicTablesPkg: AcpiSsdtPcieLibArm: Support UID > 0xF
  19a8768365 DynamicTablesPkg: AcpiSsdtPcieLibArm: Create support library
  671b0cea51 NetworkPkg/HttpBootDxe: Add Support for HTTP Boot Basic Authentication
  140446cd59 IntelFsp2Pkg: Support 64bit FspResetType for X64 build.
  24eac4caf3 IntelFsp2WrapperPkg: Support 64bit FspResetType for X64 build.
  4824924377 IntelFsp2Pkg/FspSecCore: Add FSP-I API for SMM support.
  3b8cee1781 Maintainers.txt: update Gary's email address
  7ef91af84c EmulatorPkg/PosixFileSystem: Add NULL check on memory allocation
  494f333aba MdeModulePkg/CoreDxe: Allow DXE Drivers to use untested memory
  343f37b5c0 MdeModulePkg/SetupBrowserDxe:Follow spec'd way to reconnect driver
  c8af26627a ArmPkg/CpuDxe: drop ARM_PROCESSOR_TABLE pseudo-ACPI table
  5a3641bfcd IntelFsp2Pkg: Add FSPI_ARCH_UPD.
  bf1ff540d9 MdePkg/UefiDevicePathLib: Add support for PEIMs
  6964b5c48c MdeModulePkg/Include: Long debug string is truncated to 104 char
  d32a84b5ad BaseTools: INF should use latest Pcd value instead of default value
  8ee26529d1 BaseTools/VolInfo: Correct alignment attributes display
  c0b7679aac BaseTools/VolInfo: Increase define for highest section value
  fca5de51e1 BaseTools/VolInfo: Correct EFI_SECTION_VERSION display
  8a5782d704 UefiCpuPkg: Fix nasm warning "signed byte value exceeds"
  a47241f133 UefiPayloadPkg: Add macro to support selection of CryptoDxe driver
  69f76d0f72 Maintainers.txt: Remove OvmfPkg/XenTimerDxe reference
  a8c4fe23c4 Maintainers.txt: Add missing github ids
  7f1c89f167 Maintainers.txt: Remove reviewer Harry Han
  b68d566439 BaseTools/Capsule: Support signtool input subject name to sign capsule file
  e3d468acb9 BaseTools/VolInfo: Show encapsulation sections
  2677286307 UefiPayloadPkg: Fix RelaAddress type always mismatch in if condition
  f26b70cb9f UefiPayloadPkg: Add support for logging to CBMEM console
  57783adfb5 OvmfPkg: Change default to disable MptScsi and PvScsi
  1774a44ad9 Maintainers.txt: Remove MptScsi and PvScsi reviewers
  0e7add1d75 OvmfPkg/XenHypercallLib: Fix naming of AArch64
  3eca64f157 IntelFsp2Pkg: FSPI_UPD is not mandatory.
  0d0bfcb457 IntelFsp2Pkg: Fix GenCfgOpt bug for FSPI_UPD support.
  8a210b9ac0 ShellPkg: Acpiview: Abbreviate field names to preserve alignment
  65c4f3f2be DynamicTablesPkg: Handle error when IdMappingToken is NULL
  f5cea604a6 DynamicTablesPkg: IORT set reference to Id array only if present
  238f903e8d DynamicTablesPkg: IORT set reference to interrupt array if present
  4c55f6394f MdePkg: IORT header update for IORT Rev E.d spec
  cd67efa1b2 ShellPkg: Acpiview: IORT parser update for IORT Rev E.d spec
  de200b7e2c DynamicTablesPkg: Update ArmNameSpaceObjects for IORT Rev E.d
  e9150618ec DynamicTablesPkg: IORT generator updates for Rev E.d spec
  6f4e10d6db SecurityPkg: Add retry mechanism for tpm command
  19cbfaa431 OvmfPkg/QemuVideoDxe: Zero out PixelInformation in QueryMode
  a551de0d93 ArmVirtPkg: Fix KVM Guest Firmware
  0dc9b78a46 Maintainers.txt: Add missing Github IDs for OvmfPkg TPM/TGC modules
  d219119721 UefiPayloadPkg/PlatformBootManagerLib: Correct spacing in boot prompt
  79aab22fca UefiPayloadPkg: Add a Macro to enable Boot Logo
  444260d45e UefiPayloadPkg: Load Boot Logo into ACPI table
  86757f0b47 MdeModulePkg: Add EDKII_PCI_DEVICE_PPI definition
  a8f59e2eb4 MdeModulePkg/AhciPei: Use PCI_DEVICE_PPI to manage AHCI device
  3e599bbc10 DynamicTablesPkg: Fix using RmrNodeCount unitlitialised
  a0a03b5154 BaseTools/GenSec: Fix typo
  f5f8c08db9 BaseTools/VolInfo: Show FV section boundaries
  d241a09afb BaseTools/VolInfo: Parse EFI_SECTION_FREEFORM_SUBTYPE_GUID header
  cf02322c98 BaseTools/GenSec: Support EFI_SECTION_FREEFORM_SUBTYPE_GUID sections
  1ee1622817 Basetools/GenFw: Allow AARCH64 builds to use the --prm flag
  9f197e44b1 PrmPkg: Enable external visibility on PRM symbols
  21200d9fe6 PrmPkg: Build Prm Samples with GCC for AARCH64
  57faeb782a PrmPkg: Support AArch64 builds using GCC
  1da2012d93 PrmPkg: Add details on AArch64 build to the Readme.
  0f7bccf584 UefiCpuPkg: Simplify InitializeSeparateExceptionStacks
  9a24c3546e MdeModulePkg: Move CPU_EXCEPTION_INIT_DATA to UefiCpuPkg
  f1688ec9da UefiCpuPkg: Simplify the struct definition of CPU_EXCEPTION_INIT_DATA
  75e3c2435c UefiCpuPkg: Create CpuPageTableLib for manipulating X86 paging structs
  f336e30ba1 UefiCpuPkg/CpuPageTableLib: Return error on invalid parameters
  bf334513b3 CpuPageTableLib: Fix a bug when a bit is 1 in Attribute, 0 in Mask
  13a0471bfd CpuPageTableLib: Refactor the logic
  9cb8974f06 CpuPageTableLib: Split the page entry when LA is aligned but PA is not
  c16f02f776 CpuPageTableLib: Avoid treating non-leaf entry as leaf one
  f4c845e46b CpuPageTableLib: Fix parent attributes are not inherited properly
  9f53fd4ba7 CpuPageTableLib: Fix a bug to avoid unnecessary changing to page table
  927113c83b CpuPageTableLib: Fix bug that wrongly requires extra size for mapping
  e9e2ecab2d CpuPageTableLib: define IA32_PAGE_LEVEL enum type internally
  e76496530c MdePkg/Library/UefiDevicePathLib: Add back StandaloneMm INF file
  bd06717863 MdeModulePkg: Enhance bus scan for all root bridge instances
  74f44d920a ShellPkg/SmbiosView: Display extended memory info in smbiosview -t 17
  83d5871184 UefiCpuPkg/PiSmmCpuDxeSmm: Add a new mIsShadowStack flag
  7b4754904e UefiCpuPkg/PiSmmCpuDxeSmm: Remove mInternalCr3 in PiSmmCpuDxeSmm
  62391b4ce9 MdeModulePkg/DxeIpl: Remove clearing CR0.WP when protecting pagetable
  803ed060ee UefiPayloadPkg: Remove clearing CR0.WP when protecting pagetable
  a2b61de2f6 IntelFsp2Pkg: FSPM_ARCH2_UPD mismatching bug.
  809b5a3d2a MdeModulePkg: Update the SMBIOS version by UPL
  2812668bfc UefiCpuPkg/CpuPageTableLib/UnitTest: Add host based unit test
  30d62f5e31 OvmfPkg/PlatformDxe: Check ExtractConfig and RouteConfig arguments
  b94836b224 OvmfPkg/VirtioGpuDxe: Check QueryMode arguments
  3f282f4510 OvmfPkg/VirtioFsDxe: Check GetDriverName arguments
  64a20bea97 MdeModulePkg/DumpDynPcd: Remove unsupported format specifiers
  9102518d29 MdePkg: Improved Smbios Type9 table and Smbios spec v3.5.0 Changes
  35d167ef3c ShellPkg: Improved Smbios Type 9 table changes in PrintInfo.c
  68bf712d4f MdePkg: Added support for SMBIOS spec v3.6.0 to Smbios.h
  e2ac68a23b BaseTools/Source/C/GenSec: Fix EFI_SECTION_FREEFORM_SUBTYPE_GUID header
  d5fd86f256 ShellPkg: Adds Local APIC parser to AcpiView
  2bb0020675 UefiPayloadPkg: Return PciRootBridges instead of NULL
  c15c9fa420 UefiPayloadPkg: Add macro to control NvmExpressDxe
  938430741f RedfishPkg/RedfishDiscoverDxe: USB Redfish host interface is not supported
  eebef1b3b7 RedfishPkg: Redfish modules may need to use the functions which are private
  f2bf043aaa RedfishPkg: Redfish functions for REST requests are not fully spec complied
  dfdba857a6 UefiPayloadPkg: Fix Coverity report defect
  4d83ee04f4 ShellPkg: Add revision check for DSDT Header on Arm
  0ede7cad73 Maintainers.txt: Update maintainers list
  722e03bc2e Revert "UefiCpuPkg/CpuPageTableLib/UnitTest: Add host based unit test"
  166c49c212 Revert "ShellPkg: Adds Local APIC parser to AcpiView"
  39ff9769ca Revert "BaseTools: Fix DSC LibraryClass precedence rule"
  ba0e0e4c6a BaseTools: Fix DevicePath GNUmakefile for macOS
  - Respin the following patches:
    ovmf-Revert-UefiCpuPkg-Replace-Opcode-with-the-correspond.patch
* Mon Sep 19 2022 Joey Lee <jlee@suse.com>
- Add patches to disable option ROM on sev (bsc#1199156)
    ovmf-bsc1199156-OvmfPkg-IncompatiblePciDeviceSupportDxe-Ignore-Optio.patch
* Mon Sep 12 2022 Joey Lee <jlee@suse.com>
- Modified ovmf.changes log, using PED-1410 instead of PED-1359 for
  pushing to SLE15-SP5.
* Tue Sep  6 2022 Joey Lee <jlee@suse.com>
- Because 5 revert patches in edk2-stable202205 for nasm-2.14 is against
  15-SP4/Leap 15.4 and earlier version. So add suse_version and sle_version
  checking logic in ovmf.spec when applying revert patches. (jsc#PED-1410)
* Tue Aug 23 2022 Joey Lee <jlee@suse.com>
- Removed patches in ovmf-bsc1196879-sev-fix.patch which are merged to
  edk2-stable202205:
  - OvmfPkg/AmdSev: reserve snp pages
  - de463163d9	edk2-stable202205-rc1~292
  - OvmfPkg/ResetVector: cache the SEV status MSR value
  - 63c50d3ff2	edk2-stable202205-rc1~291
  - OvmfPkg/BaseMemEncryptLib: use the SEV_STATUS MSR
  - f1d1c337e7	edk2-stable202205-rc1~290
* Tue Aug 16 2022 Joey Lee <jlee@suse.com>
- Update to edk2-stable202205
  - Features (https://github.com/tianocore/edk2/releases):
  Support PEI 64bit in IntelFsp2Pkg and IntelFsp2WrapperPkg
  IntelFsp2Pkg: BaseFspCommonLib Support for X64 Build
  Add PrmPkg
  BaseTools Enhance GenFw to support PRM GCC build
  Enable Intel TDX in OvmfPkg
  Generate CloudHv target as PVH ELF binary
  Add parallel hash feature into BaseCryptLib
  Configure/Enable elliptic curve ciphers in OpenSSL
  Add FMMT tool into edk2 BaseTools
  Dynamic variable flash information cannot be passed in Standalone MM
  - Patches (git log --oneline --reverse edk2-stable202202~..edk2-stable202205):
  b24306f15d NetworkPkg: Fix incorrect unicode string of the AKM/Cipher Suite
  2dbed52506 ArmVirtPkg/ArmVirtMemoryInitPeiLib: avoid redundant cache invalidation
  54cddc3ad4 ArmVirtPkg/ArmVirtKvmTool: wire up configurable timeout
  de463163d9 OvmfPkg/AmdSev: reserve snp pages
  63c50d3ff2 OvmfPkg/ResetVector: cache the SEV status MSR value in workarea
  f1d1c337e7 OvmfPkg/BaseMemEncryptLib: use the SEV_STATUS MSR value from workarea
  b1b89f9009 MdeModulePkg: Correct high-memory use in NvmExpressDxe
  84338c0d49 MdeModulePkg: Replace Opcode with the corresponding instructions.
  d3febfd9ad MdePkg: Replace Opcode with the corresponding instructions.
  7bc8b1d9f4 SourceLevelDebugPkg: Replace Opcode with the corresponding instructions.
  2aa107c0aa UefiCpuPkg: Replace Opcode with the corresponding instructions.
  bbaa00dd01 MdePkg: Remove the macro definitions regarding Opcode.
  6a890db161 BaseTools: Upgrade the version of NASM tool
  497ac7b6d7 UefiPayloadPkg/PayloadLoaderPeim: Use INT64 as input parameter
  dc39554d58 edk2/MdeModulePkg/Debuglib: Add Standalone MM support
  906242343f MdeModulePkg/GraphicsConsoleDxe: Check status to make sure no error
  b422b0fcf9 EmulatorPkg/EmuGopDxe: Set ModeInfo after Open successfully
  589d51df26 MdeModulePkg/Usb/Keyboard.c: Don't request protocol before setting
  b909b4ad09 OvmfPkg: Make the Xen ELF header generator more flexible
  0a707eb258 OvmfPkg: Xen: Use a new fdf include for the PVH ELF header
  0015a4e0a8 OvmfPkg: Xen: Generate fdf include file from ELF header generator
  9ac8c85d50 OvmfPkg: CloudHv: Remove VARS and CODE sections
  e1c7f9b4e5 OvmfPkg: Generate CloudHv as a PVH ELF binary
  d50d9e5549 OvmfPkg: CloudHv: Retrieve RSDP address from PVH
  82bfd2e86d OvmfPkg: CloudHv: Rely on PVH memmap instead of CMOS
  b83d0a6438 OvmfPkg: CloudHv: Add README
  4a68176cb5 UefiCpuPkg: Extend SMM CPU Service with rendezvous support.
  949b8a3d97 Maintainers.txt: Add new reviewer for UefiPayloadPkg
  091b6a1197 UefiPayloadPkg: Add build option for Above 4G Memory
  4adc364c75 UefiPayloadPkg: Fix case of protocol
  79f2734e5a MdeModulePkg: Add a check for metadata size in NvmExpress Driver
  af74efe494 UefiPayloadPkg: Make Boot Manager Key configurable
  62fa37fe7b BlSupportSmm: fix definition of SetSmrr()
  56530dec11 .pytool/Plugin/UncrustifyCheck: Output file diffs by default
  2aac8bb7ef .pytool: Update to newest pytools
  c63ef58698 .azurepipelines: Updated python version
  f06941cc46 MdeModulePkg: Add bRefClkFreq card attribute programming support
  2b175eeb6a RedfishPkg: fix memory leak issue
  10b4c8f3b7 Maintainers: Update Maintainers.txt for edk2 Redfish modules
  0fdd466c75 UefiCpuPkg/MpInitLib:remove optional in declaration
  52e09dcd7a UefiCpuPkg: Support FFS3 GUID in SearchForBfvBase.asm
  a13dfc769b MdeModulePkg/DxeIpl: Create 5-level page table for long mode
  c8ea48bdf9 DynamicTablesPkg: Fix serial port namespace path in DBG2
  414cd2a4d5 BaseTools/GenFw: Enhance GenFw to support PRM GCC build
  33438f7354 EmulatorPkg/RedfishPlatformCredentialLib: Check EFI_SECURE_BOOT_MODE_NAME
  5b56c52b5c EmulatorPkg/RedfishPlatformCredentialLib: Don't stop Redfish service
  0531f61376 IntelFsp2Pkg: BaseFspDebugLibSerialPort Support for X64
  411b3ff6dd IntelFsp2Pkg: BaseFspSwitchStackLib Support for X64
  b429959bb6 MdeModulePkg/SdMmcPciHcDxe: Make timeout for SD card configurable
  79a705fbaf UefiPayloadPkg: Hookup SD/MMC timeout
  28eeb08d86 MdePkg/Include: Smbios Specification 3.5.0 changes
  c1e662101a CryptoPkg: Add new hash algorithm ParallelHash256HashAll in BaseCryptLib.
  267a92fef3 MdePkg/AcpiXX.h: Update Error Severity type for Generic Error Status Block
  ec0b54849b IntelFsp2Pkg: BaseFspCommonLib Support for X64
  5d8d8b5148 MdeModulePkg/NvmExpressDxe: fix check for Cap.Css
  69218d5d28 MdeModulePkg/NvmExpressPei: fix check for NVM command set
  bf9230a9f3 BaseTools: Add the FeatureFlagExpression usage to the Source Section
  3115377bf0 BaseTools: Remove the redundant __FLEXIBLE_SIZE from PcdValueInit.c
  4a2e1000a1 CryptoPkg: update openssl submodule to 1.1.1n
  355515a06a CryptoPkg? Redefinition bug in CrtLibSupport.h.
  7b005f344e BaseTools: fix gcc12 warning
  85021f8cf2 BaseTools: fix gcc12 warning
  22130dcd98 Basetools: turn off gcc12 warning
  ec30a4a0c3 BaseTools:Support decimal version number in ECC check
  3ef2071927 UefiCpuPkg: Update BFV searching algorithm in VTF0
  691b178667 ShellPkg/AcpiView: Adds ACPI_PARSER bitfield parser
  40004ff9d5 ShellPkg/AcpiView: PrintFormatter for FADT Flags field
  7456990e8e MdeModulePkg/Ufs: bRefClkFreq attribute be programmed after fDeviceInit
  237c966396 UefiPayloadPkg/UefiPayloadPkg.ci.yaml: Remove duplicated entry
  76191052fd UefiPayloadPkg: Fix build error
  449eb01a8d UefiPayloadPkg: Fix architecture in the build instruction
  c248802e40 UefiPayloadPkg: Fix PciHostBridgeLib
  2b4b8013fe UefiPayloadPkg/Library/PlatformBootManagerLib: Remove broken VGA detection
  55637a2894 UefiPayloadPkg: Make Boot Timeout configurable
  2268920afc .azurepipelines: Use Python 3.8
  c3ca70669e .azurepipelines: Use windows-2019 VM image
  3b0de44759 EmulatorPkg: Use windows-2019 VM image
  75628d27c0 OvmfPkg: Use windows-2019 VM image
  b328bb54c6 BaseTools/Bin: Update GCC ARM compiler version
  3f0c788a5f MdePkg: Add Tdx.h
  77228269e7 MdePkg: Update Cpuid.h for Tdx
  818bc9596d MdePkg: Introduce basic Tdx functions in BaseLib
  c3001cb744 MdePkg: Add TdxLib to wrap Tdx operations
  eddcba40b5 UefiCpuPkg: Extend VmgExitLibNull to handle #VE exception
  daf8f642f3 OvmfPkg: Extend VmgExitLib to handle #VE exception
  de327f7d8a UefiCpuPkg/CpuExceptionHandler: Add base support for the #VE exception
  ab9d790901 MdePkg: Add helper functions for Tdx guest in BaseIoLibIntrinsic
  b6b2de8848 MdePkg: Support mmio for Tdx guest in BaseIoLibIntrinsic
  d74e932681 MdePkg: Support IoFifo for Tdx guest in BaseIoLibIntrinsic
  3571fc906f MdePkg: Support IoRead/IoWrite for Tdx guest in BaseIoLibIntrinsic
  7bed7ae6c5 UefiCpuPkg: Support TDX in BaseXApicX2ApicLib
  d983b102b3 MdePkg: Add macro to check SEV / TDX guest
  88da06ca76 UefiCpuPkg: Enable Tdx support in MpInitLib
  352eabdcd5 OvmfPkg: Add IntelTdx.h in OvmfPkg/Include/IndustryStandard
  6a608255bb OvmfPkg: Add TdxMailboxLib
  57bcfc3b06 OvmfPkg: Create initial version of PlatformInitLib
  102cafedad OvmfPkg/PlatformInitLib: Add hob functions
  9a9b33b3d6 OvmfPkg/PlatformPei: Move global variables to PlatformInfoHob
  5a2574a82e OvmfPkg/PlatformPei: Refactor MiscInitialization
  6d2ce5fd5c OvmfPkg/PlatformPei: Refactor MiscInitialization for CloudHV
  3dd47f9544 OvmfPkg/PlatformPei: Refactor AddressWidthInitialization
  432e4acd87 OvmfPkg/PlatformPei: Refactor MaxCpuCountInitialization
  f3801cf26c OvmfPkg/PlatformPei: Refactor QemuUc32BaseInitialization
  e510326245 OvmfPkg/PlatformPei: Refactor InitializeRamRegions
  12e860a1e8 OvmfPkg/PlatformPei: Refactor MemMapInitialization
  cec82a64cf OvmfPkg/PlatformPei: Refactor NoexecDxeInitialization
  f53f449f15 OvmfPkg/PlatformPei: Refactor MiscInitialization
  10460942ff OvmfPkg/PlatformInitLib: Create MemDetect.c
  96047b6663 OvmfPkg/PlatformInitLib: Move functions to Platform.c
  b22ac35b75 OvmfPkg: Update PlatformInitLib to process Tdx hoblist
  ccca1c2d5d OvmfPkg/Sec: Declare local variable as volatile in SecCoreStartupWithStack
  2b80269d98 OvmfPkg: Update Sec to support Tdx
  6b27c11690 OvmfPkg: Check Tdx in QemuFwCfgPei to avoid DMA operation
  bec9104201 MdeModulePkg: Skip setting IA32_ERER.NXE if it has already been set
  fd306d1dbc MdeModulePkg: Add PcdTdxSharedBitMask
  cc3620f304 UefiCpuPkg: Update AddressEncMask in CpuPageTable
  e23f8f52fd OvmfPkg: Update PlatformInitLib for Tdx guest
  cf17156d7d OvmfPkg: Update PlatformPei to support Tdx guest
  9fdc70af6b OvmfPkg: Update AcpiPlatformDxe to alter MADT table
  5aa8018639 OvmfPkg/BaseMemEncryptTdxLib: Add TDX helper library
  fae5c1464d OvmfPkg: Add TdxDxe driver
  07c721fea7 OvmfPkg/QemuFwCfgLib: Support Tdx in QemuFwCfgDxe
  2520182122 OvmfPkg: Update IoMmuDxe to support TDX
  c2e7be4055 OvmfPkg: Rename XenTimerDxe to LocalApicTimerDxe
  299c44cd4f UefiCpuPkg: Setting initial-count register as the last step
  c37cbc030d OvmfPkg: Switch timer in build time for OvmfPkg
  580a6b616b OvmfPkg: Add TdxWorkArea definition
  75942a52ae OvmfPkg: Add PrePiHobListPointerLibTdx
  4fe2678411 OvmfPkg: Add PeilessStartupLib
  1f29de4d20 OvmfPkg/IntelTdx: Add Sec to bring up both Legacy and Tdx guest
  55fda68a80 OvmfPkg: Update TdxDxe to set TDX PCDs
  f674fa9cde OvmfPkg: Update DxeAcpiTimerLib to read HostBridgeDevId in PlatformInfoHob
  149ed8e421 OvmfPkg/IncompatiblePciDeviceSupportDxe: Refine the configuration
  c477b2783f OvmfPkg/IncompatiblePciDeviceSupportDxe: Ignore OptionRom in Td guest
  cb8349f01a MdeModulePkg: Update PciEnumeratorSupport to ignore OptionRom if needed
  44a53a3bdd OvmfPkg: Introduce IntelTdxX64 for TDVF Config-B
  7fda517c3d OvmfPkg: Add dependency of VariableSmm driver to make it work normally.
  b953265a27 UefiPayloadPkg: Add a new DebugPrintErrorLevelLib instance
  0023e35cf4 UefiPayloadPkg: Change some configuration of the payload
  3e130e40fc UefiPayloadPkg: Consume the new added DebugPrintErrorLevelLib instance
  f16b05a13b .pytool/Plugin/UncrustifyCheck: Update func to return absolute paths
  dbfbaedb21 .pytool/Plugin/UncrustifyCheck: Add ignore file support
  d932199d39 OvmfPkg: Revert Uncrustify formatting in VbeShim.h files
  ad6816c319 OvmfPkg: Do not check VbeShim.h formatting with Uncrustify
  d2998af211 PrmPkg: Add package and include headers
  5f76c3e471 PrmPkg: Add PrmConfig protocol interface
  e189e01af2 PrmPkg/PrmContextBufferLib: Add initial library instance
  3f7af17c6b PrmPkg/PrmConfigDxe: Add initial driver
  9276e0d2b9 PrmPkg: Add initial PrmSamplePrintModule
  c63905aba7 PrmPkg: Add initial PrmSampleMemoryAllocationModule
  27b1a840e4 PrmPkg: Add initial PrmSampleHardwareAccessModule
  7c41ec47ca PrmPkg: Add initial PrmSampleContextBufferModule
  97ab54c1b1 PrmPkg: Add initial package DSC file
  d2cb6e67a4 Readme.md: Add initial content
  e846797662 PrmPkg: Add ALLOCATE_CONTEXT_BUFFER_IN_FW build option
  a6f8946bc9 PrmPkg: Enable variable growth for the PRM_MODULE_EXPORT macro
  ef05955996 PrmPkg: Publish PRM operation region to support PRM ACPI _DSM invocation
  f96517f4d0 PrmPkg: Export major/minor version in PRM module PE COFF header
  50e1432a40 PrmPkg: Add initial PrmSsdtInstallDxe module
  a409f4b67d PrmPkg: Remove PRM Module Update Lock
  0797989c5d PrmPkg: Remove ALLOCATE_CONTEXT_BUFFER_IN_FW build flag
  0b469caff6 PrmPkg/PrmContextBuffer.h: Add ACPI parameter support structures
  be2c927d7c PrmPkg/PrmLoaderDxe: Add ACPI parameter buffer support
  c1a7a50f67 PrmPkg/PrmSampleContextBufferModule: Remove OS debug print requirement
  4c8486fd72 PrmPkg/PrmSampleHardwareAccessModule: Add non-print PRM handlers
  7217263514 PrmPkg/SampleAcpiParameterBufferModule: Add initial module
  fec018624c PrmPkg/HardwareAccessModuleConfigLib: Add initial library
  d10b8dc5d8 PrmPkg/Samples/Readme.md: Add initial file
  6b7dde7cdd PrmPkg: Refactor some PrmLoaderDxe functionality into libraries
  4348c72ad0 PrmPkg/Application/PrmInfo: Add initial application
  e10c776487 PrmPkg: Enforce stricter types
  2e55b0cd9e PrmPkg/Test/PrmPkgHostTest.dsc: Add initial file
  3599f5479d PrmPkg/Test/UnitTest/Library: Add initial UEFI Boot Services test lib
  82d15dc6c1 PrmPkg/Library/DxePrmContextBufferLib: Add host-based unit tests
  68ee42c991 PrmPkg/DxePrmModuleDiscoveryLib: Add initial host-based unit tests
  c040831cf9 PrmPkg: Add PlatformGuid
  a9302b89a9 PrmPkg: Update PRM OpRegion
  f8e68587e2 Readme.md: Add iASL note and QEMU sample link
  4a4aeaa446 PrmPkg: Replace PcdPrmPlatformGuid with EDKII_DSC_PLATFORM_GUID
  17b2d64ced PrmPkg/Samples: Remove PrmSampleMemoryAllocationModule
  050b2ba27d PrmPkg/Samples: Remove PrmSamplePrintModule
  88f3d734f5 PrmPkg: Remove the concept of OS services
  deea4e58b0 Readme.md: Add a link to PRM Specification
  f3c11224b5 PrmPkg: Changes for edk2 repo transition
  a298a84478 PrmPkg: Apply uncrustify changes
  94f905b3bf MdeModulePkg/HiiDatabase: Fix Setup numeric default value incorrect issue
  b8c5ba2337 BaseTools: efi_debugging.py: Add debugger agnostic dbg Python Classes
  0d7fec9f79 BaseTools: Scripts/efi_gdb.py: Add gdb EFI commands and pretty Print
  4f4afcd288 BaseTools: Scripts/efi_lldb.py: Add lldb EFI commands and pretty Print
  bfefdc2c49 UefiPayloadPkg: Fix PciHostBridgeLib
  676084303d UefiPayloadPkg: Support IA32 Build
  63e155f24d UefiPayloadPkg: Add dependency of VariableSmm driver.
  dab96cf02e UefiPayloadPkg: Add --quiet argument to Universal Payload build script
  35a4b63247 NetworkPkg: Add PCDs for HTTP DNS RetryCount and RetryInterval
  38a9afd0fb NetworkPkg/HttpDxe: Decofigure Tcp4 before reconfiguring
  3974aa539e NetworkPkg/HttpDxe: Decofigure Tcp6 before reconfiguring
  c43ff5188d NetworkPkg/HttpDxe: Add ConnectionClose flag fo HTTP_PROTOCOL
  753fd319e2 NetworkPkg/HttpDxe: Detect 'Connection: close' header
  12a50c9ce1 NetworkPkg/HttpDxe: Detect HTTP/1.0 servers
  5576b17363 BaseTools: Fix DevicePath tool build failure issue
  4352d115c4 CryptoPkg/CrtLibSupport: add fcntl.h
  3b4b49cf00 CryptoPkg/CrtLibSupport: add strstr()
  58771f4b2d CryptoPkg/CrtLibSupport: add INT_MIN
  2759e42fbc CryptoPkg/CrtLibSupport: add UINT_MAX
  fd5f347c84 CryptoPkg/CrtLibSupport: add MODULESDIR
  03951e5645 CryptoPkg/CrtLibSupport: add off_t
  fab6285a73 CryptoPkg/CrtLibSupport: fix strcpy
  f5508a91e3 CryptoPkg/UnitTest: fix DH testcase
  c411566fad pip-requirements.txt: Update basetools version to 0.1.17
  8a5727c7a8 Maintainers.txt: Add Michael Kubacki as UnitTestFrameworkPkg maintainer
  1a49e2aa3c CryptoPkg: Add instrinsics to support building ECC on IA32 windows
  efc39e65e5 CryptoPkg: Reconfigure OpensslLib to add EC algorithms
  0c901fcc20 CryptoPkg: Make EC source file config-able
  f3da13461c CryptoPkg/TlsLibNull: Remove MU_CHANGE comment markers
  4cfb28f12a UefiPayloadPkg: Fix the build failure
  9bf7291d63 ShellPkg: Update smbiosview type 41 with SMBIOS 3.5 fields
  630df8c86e IntelFsp2Pkg: X64 compatible changes to support PEI in 64bit
  6f219bef55 IntelFsp2Pkg: Add FSPx_ARCH2_UPD support for X64
  d40965b987 IntelFsp2Pkg: Update FSP_GLOBAL_DATA and FSP_PLAT_DATA for X64
  00aa71ce20 IntelFsp2Pkg: FspSecCore support for X64
  6bec5a66ea IntelFsp2Pkg: SecFspSecPlatformLibNull support for X64
  4a6ed7e46a IntelFsp2WrapperPkg: Adopt FSPM_UPD_COMMON_FSP24 for X64
  86a2f3c439 IntelFsp2WrapperPkg: BaseFspWrapperApiLib support for X64
  91a03f78ba IntelFsp2WrapperPkg: SecFspWrapperPlatformSecLibSample support for X64
  3d97733f44 MdePkg: Add CC_GUEST_TYPE in ConfidentialComputingGuestAttr.h
  d020ac55b6 OvmfPkg: Replace GUEST_TYPE with CC_GUEST_TYPE
  74a3eb975d MdePkg: Add CcProbeLibNull
  2f44d77c68 OvmfPkg: Add CcProbeLib
  2a7e1e890d OvmfPkg: Add CcProbeLib in *.dsc
  7012cb73c4 MdePkg: Probe Cc guest in BaseIoLibIntrinsicSev
  76fda1def3 OvmfPkg: Call CcProbe in SecMain.c instead of TsIsEnabled
  532bd4ec38 CryptoPkg/Crt: fix strcpy build on older VS compilers
  6d2baf9dfb PrmPkg/DxePrmContextBufferLib: Fix unit test GCC compilation errors
  892787fed5 OvmfPkg/OvmfPkgX64: Adjust load sequence of TdxDxe and AmdSevDxe driver
  b06a007b64 CryptoPkg: Declare PcdEcEnabled in Library consuming OpensslLib
  fdfbf1fdab MdePkg: Update smbiosview type 9 with SMBIOS 3.5 fields
  a85ae8d964 ShellPkg: Update smbiosview type 9 with SMBIOS 3.5 fields
  2306555bf9 UefiPayloadPkg: Fix IA32 entry build failure
  f4dfec6ca1 BaseTools: Move gPlatformFinalPcd to Datapipe and optimize size
  ee582858c4 .azurepipelines: Add NOOPT to all package builds
  2d9d605714 .pytool/Plugin/UncrustifyCheck: Add Azure DevOps UI debug instructions
  b807174fec MdeModulePkg/GraphicsConsoleDxe: add modes
  5a17629902 OvmfPkg: clear PcdConOut{Row,Column}
  96e1d337e0 ArmVirtPkg: clear PcdConOut{Row,Column}
  483d3bb716 ShellPkg: Update smbiosview type 0 with SMBIOS 3.5 fields
  ecc79b092e OvmfPkg/VirtioGpuDxe: add VirtioGpuSendCommandWithReply
  182122914c OvmfPkg/VirtioGpuDxe: add GetDisplayInfo to virtio-gpu spec header.
  82c07f2cc7 OvmfPkg/VirtioGpuDxe: add VirtioGpuGetDisplayInfo
  5f6ecaa398 OvmfPkg/VirtioGpuDxe: use GopQueryMode in GopSetMode
  86de090b99 OvmfPkg/VirtioGpuDxe: move code to GopInitialize
  916f90baa5 OvmfPkg/VirtioGpuDxe: query native display resolution from host
  d372ab585a BaseTools/Conf: Fix Dynamic-Library-File template
  cabd96ad03 OvmfPkg: restore CompatImageLoaderDxe chunk
  4092f1d397 OvmfPkg/Bhyve: add support for QemuFwCfg
  daa6cd8763 ArmPlatformPkg: Fix error message in Scripts/Ds5/edk2_debugger.py
  5299568ce6 ArmPlatformPkg: Fix target initialisation in cmd_load_symbols.py
  101f4c7892 ArmPlatformPkg: Fix EDK2_DSC check in Scripts/Makefile
  a64b944942 BaseTools: Add FMMT Python Tool
  826527c9db UefiPayloadPkg: Add definition for PayloadCommandLine HOB
  d4eef3fe7c MdePkg: Add CpuLib to module INFs that depend on UefiCpuLib.
  a63b086e69 IntelFsp2Pkg: Add CpuLib to module INFs that depend on UefiCpuLib
  3afa0a2096 IntelFsp2WrapperPkg: Add CpuLib to module INFs that depend on UefiCpuLib.
  1783b099d3 OvmfPkg: Add CpuLib to module INFs that depend on UefiCpuLib.
  86d41c077e UefiCpuPkg: Add CpuLib to module INFs that depend on UefiCpuLib.
  2434f6f206 UefiPayloadPkg: Add CpuLib to module INFs that depend on UefiCpuLib.
  247a0fc65e OvmfPkg: Add README for TDVF
  8079d4dc4f MdePkg: add SmmCpuRendezvousLib.h and SmmCpuRendezvousLibNull implement.
  1a6c837638 UefiPayloadPkg: Fix the UPL build failure
  29ae55a0b8 PcAtChipsetPkg: Change the flow of PcRtcInit()
  a658ed30e5 MdeModulePkg/PCD: Pcd initialize DXE have assert
  0e31124877 .pytool: Fix python command error in self introduction doc
  43613b2fe8 CryptoPkg: Rename PCD about openssl EC configuration
  f753c36209 CryptoPkg: Separate auto-generated openssl config and edk2 openssl config
  499b0d5fa5 CryptoPkg: Update process_files.pl to automatically add PCD config option
  a332ffb6ef CryptoPkg/openssl: update generated files
  9dd964f5e5 CryptoPkg/openssl: disable codestyle checks for generated files
  b5cd30a79b UefiCpuPkg: Revert "UefiCpuPkg: Enable Tdx support in MpInitLib"
  ad629b5c5a OvmfPkg: Add MpInitLibDepLib related PPI/Protocol definitions
  2f06e5af47 OvmfPkg: Add MpInitLibDepLib
  b63a49e056 OvmfPkg/Sec: Install MpInitLibDepLib PPIs in SecMain.c
  73d6d41de0 OvmfPkg/TdxDxe: Install MpInitLibDepLib protocols
  deee7a100b OvmfPkg: Enable 2 different CpuMpPei and CpuDxe drivers
  17702186b5 MdeModulePkg: PiSmmCore: Inspect memory guarded with pool headers
  d0efa681b6 UefiPayloadPkg: Simplify code logic
  57ebb2994d UefiPayloadPkg: Add Serial IO device path according to related protocol
  ef01d63ef3 UefiPayloadPkg: Connect all root bridge in PlatformBootManagerBeforeConsole
  35d9b7ea2d ArmPkg: Remove RVCT support
  b55b6d33e4 ArmPlatformPkg: Remove RVCT support
  e9eeb0ad2b CryptoPkg: Remove RVCT support
  48b919cb14 MdePkg: Remove RVCT support
  5621d81edf FatPkg: Remove RVCT support
  cc070e9e0c NetworkPkg: Remove RVCT support
  a744199470 ArmVirtPkg: Remove RVCT support
  b7a446f224 EmbeddedPkg: Remove RVCT support
  57c84113a1 OvmfPkg: Remove RVCT support
  708620d29d BaseTools: Remove RVCT support
  2d1138a1a8 .azurepipelines: Fix cspell version to v5.20.0
  7b126978e1 .pytool/plugin/SpellCheck: Allow compound words
  2189c71026 .pytool/plugin/SpellCheck: Add more common words
  0903042b66 MdeModulePkg: Add Variable Flash Info HOB
  60b519456c MdeModulePkg/VariableFlashInfoLib: Add initial library
  4dbebc2d10 MdeModulePkg/Variable: Consume Variable Flash Info
  8db39c60cd MdeModulePkg/FaultTolerantWrite: Consume Variable Flash Info
  524a15c1fa ArmVirtPkg/ArmVirt.dsc.inc: Add VariableFlashInfoLib
  a69eac7578 EmulatorPkg: Add VariableFlashInfoLib
  a7d3d4e7c4 OvmfPkg: Add VariableFlashInfoLib
  1f026ababf UefiPayloadPkg: Add VariableFlashInfoLib
  a72d552f19 OvmfPkg/OvmfPkgX64: Use different CcProbeLib when SMM is on or off
  a21a3438f7 OvmfPkg: Make an Ia32/X64 hybrid build work with SEV
  9c733f0b90 OvmfPkg: TdxDxe: Fix AsmRelocateApMailBoxLoop
  07c0c2eb0a OvmfPkg: fix PcdFSBClock
  16779ede2d Removed prefix to match AsmRelocateApMailBoxLoopStart
  - Removed patches in ovmf-bsc1196879-sev-fix.patch which are merged to mainline:
  - OvmfPkg/AmdSev: reserve snp pages
  - de463163d9	edk2-stable202205-rc1~292
  - OvmfPkg/ResetVector: cache the SEV status MSR value
  - 63c50d3ff2	edk2-stable202205-rc1~291
  - OvmfPkg/BaseMemEncryptLib: use the SEV_STATUS MSR
  - f1d1c337e7	edk2-stable202205-rc1~290
- Add the following patches for building edk2-stable202205 with nasm-2.14 on
  SLE15-SP3/SP4 and Leap 15.3/15.4. Those patches add marco back because
  nasm-2.14 doesn't support corresponding instructions. (jsc#PED-1410)
  - ovmf-Revert-MdePkg-Remove-the-macro-definitions-regarding.patch
    ovmf-Revert-UefiCpuPkg-Replace-Opcode-with-the-correspond.patch
    ovmf-Revert-SourceLevelDebugPkg-Replace-Opcode-with-the-c.patch
    ovmf-Revert-MdePkg-Replace-Opcode-with-the-corresponding-.patch
    ovmf-Revert-MdeModulePkg-Replace-Opcode-with-the-correspo.patch
  - Then reverted 5 patches in 84338c0d49~..bbaa00dd01
    MdeModulePkg: Replace Opcode with the corresponding
    MdePkg: Replace Opcode with the corresponding
    SourceLevelDebugPkg: Replace Opcode with the
    UefiCpuPkg: Replace Opcode with the corresponding
    MdePkg: Remove the macro definitions regarding Opcode.
- Change the size of ovmf-x86_64 to 4MB, otherwise OBS exposes the following error:
    [  266s] GenFv: ERROR 3000: Invalid
    [  266s]   the required fv image size 0x1afed8 exceeds the set fv image size 0x1ac000
  - [ovmf-x86_64]="-p OvmfPkg/OvmfPkgX64.dsc -D FD_SIZE_4MB"
* Tue Jun 21 2022 Jiri Slaby <jslaby@suse.cz>
- add ovmf-tools_def-add-fno-omit-frame-pointer-to-GCC48_-IA32-.patch.
  It fixes crashes when linked using gcc 12 (bsc#1199597).
* Mon May  2 2022 jlee@suse.com
- Respin amd-sev and amd-sev-es features
  After more testing, we found that not all descriptors can support
  both amd-sev with amd-sev-es. So we removed all amd-sev and amd-sev-es
  feature tags but only keep them in ovmf-x86_64-2m.json and
  60-ovmf-x86_64.json. (bsc#1198246#c75)
* Sat Mar 26 2022 Martin Liška <mliska@suse.cz>
- Add GCC 12 workaround (ovmf-ignore-spurious-GCC-12-warning.patch)
  that handles: https://bugzilla.tianocore.org/show_bug.cgi?id=3816
  The same patch is already included in qemu package.
* Tue Mar 15 2022 Fabian Vogt <fvogt@suse.com>
- TPM_ENABLE got renamed to TPM2_ENABLE and TPM_CONFIG_ENABLE removed
  (except on ARM for some reason) (boo#1197104)
* Thu Mar 10 2022 jlee@suse.com
- Update to edk2-stable202202
  - Features (https://github.com/tianocore/edk2/releases):
  OvmfPkg Add new target for Cloud Hypervisor
  Add TDVF to OvmfPkg
  Add new APIs to UefiCpuPkg/UefiCpuLib
  Add AMD Secure Nested Paging Support
  Add SSDT PCI generator in DynamicTablesPkg
  Support ACPI 6.4 PPTT changes
  Add FdtHwInfoParser library
  Add DynamicPlatRepo library
  Make package and platform builds reproducible across source format changes
  Add Uncrustify CI Plugin
  Apply uncrustify changes to all package C and H files
  - Patches (git log --oneline --reverse edk2-stable202111~..edk2-stable202202):
  bb1bba3d77 NetworkPkg: Fix invalid pointer for DNS response token on error
  ef9a059cdb EmulatorPkg/Win/Host: Update CC_FLAGS
  69877614fd .pytool/Plugin/EccCheck: Remove RevertCode()
  854462bd34 .pytool/Plugin/EccCheck: Remove temp directory on exception
  3019f1bbab .pytool/Plugin/EccCheck: Add performance optimizations
  99f84ff473 .pytools/Plugin/LicenseCheck: Use temp directory for git diff output
  76a1ce4d5f .azurepipelines/templates: Update max pipeline job time to 2 hours
  365dced2c3 ArmPkg: Update YAML to ignore specific ECC files/errors
  1939fc9569 ArmPlatformPkg: Update YAML to ignore specific ECC files/errors
  c97fee87f0 ArmVirtPkg: Update YAML to ignore specific ECC files/errors
  d5744ecba8 CryptoPkg: Update YAML to ignore specific ECC files/errors
  d7d30e8f21 EmulatorPkg: Update YAML to ignore specific ECC files/errors
  9deb937076 MdeModulePkg: Update YAML to ignore specific ECC files/errors
  df790cd6b3 MdePkg: Update YAML to ignore specific ECC files/errors
  60fa40be45 SecurityPkg: Update YAML to ignore specific ECC files/errors
  9944508e85 ShellPkg: Update YAML to ignore specific ECC files/errors
  c30c40d6c6 StandaloneMmPkg: Update YAML to ignore specific ECC files/errors
  c057347977 UefiPayloadPkg: Update YAML to ignore specific ECC files/errors
  f0f3f5aae7 UnitTestFrameworkPkg: Update YAML to ignore specific ECC files/errors
  dfafa8e453 MdeModulePkg/DxeCorePerformanceLib:Variable Initial
  a4a582e180 ArmPkg: Change use of EFI_D_* to DEBUG_*
  1d2482e1e3 ArmPlatformPkg: Change use of EFI_D_* to DEBUG_*
  c5b3a56e4f ArmVirtPkg: Change use of EFI_D_* to DEBUG_*
  a1878955b2 EmbeddedPkg: Change use of EFI_D_* to DEBUG_*
  9c7da8d804 EmulatorPkg: Change use of EFI_D_* to DEBUG_*
  917e98f3e5 FatPkg: Change use of EFI_D_* to DEBUG_*
  87000d7708 MdeModulePkg: Change use of EFI_D_* to DEBUG_*
  5f289f3ae3 MdePkg: Change use of EFI_D_* to DEBUG_*
  c49ca4a29e NetworkPkg: Change use of EFI_D_* to DEBUG_*
  47719926e8 OvmfPkg: Change use of EFI_D_* to DEBUG_*
  ca56749b0e PcAtChipsetPkg: Change use of EFI_D_* to DEBUG_*
  e905fbb05a SecurityPkg: Change use of EFI_D_* to DEBUG_*
  4a1aee13d8 ShellPkg: Change use of EFI_D_* to DEBUG_*
  586fda4800 SourceLevelDebugPkg: Change use of EFI_D_* to DEBUG_*
  96e1cba5c1 UefiCpuPkg: Change use of EFI_D_* to DEBUG_*
  1871d28eaf ArmPkg: Change OPTIONAL keyword usage style
  2863ba97ca ArmPlatformPkg: Change OPTIONAL keyword usage style
  9607597a74 ArmVirtPkg: Change OPTIONAL keyword usage style
  c8f46130f8 CryptoPkg: Change OPTIONAL keyword usage style
  fe2d81892f DynamicTablesPkg: Change OPTIONAL keyword usage style
  792433088c EmbeddedPkg: Change OPTIONAL keyword usage style
  c69fc80c80 EmulatorPkg: Change OPTIONAL keyword usage style
  9c721071d3 FmpDevicePkg: Change OPTIONAL keyword usage style
  e3917e22e7 MdeModulePkg: Change OPTIONAL keyword usage style
  d0e2f8232a MdePkg: Change OPTIONAL keyword usage style
  8874fa199d NetworkPkg: Change OPTIONAL keyword usage style
  79d49e162e OvmfPkg: Change OPTIONAL keyword usage style
  237295f46d PcAtChipsetPkg: Change OPTIONAL keyword usage style
  dc8fe5ec95 RedfishPkg: Change OPTIONAL keyword usage style
  12710fe93b SecurityPkg: Change OPTIONAL keyword usage style
  9b8507cabe ShellPkg: Change OPTIONAL keyword usage style
  18908e6131 SignedCapsulePkg: Change OPTIONAL keyword usage style
  f9c9215b55 SourceLevelDebugPkg: Change OPTIONAL keyword usage style
  902e76de19 StandaloneMmPkg: Change OPTIONAL keyword usage style
  4ec586b9f6 UefiCpuPkg: Change OPTIONAL keyword usage style
  e35dd32821 UefiPayloadPkg: Change OPTIONAL keyword usage style
  78bc3bdd2a UnitTestFrameworkPkg: Change OPTIONAL keyword usage style
  ea85f0fe13 ArmVirtPkg: Change complex DEBUG_CODE() to DEBUG_CODE_BEGIN/END()
  e3b855f283 CryptoPkg: Change complex DEBUG_CODE() to DEBUG_CODE_BEGIN/END()
  4a9d411662 DynamicTablesPkg: Change complex DEBUG_CODE() to DEBUG_CODE_BEGIN/END()
  db52c7f755 MdeModulePkg: Change complex DEBUG_CODE() to DEBUG_CODE_BEGIN/END()
  098307e082 MdePkg: Change complex DEBUG_CODE() to DEBUG_CODE_BEGIN/END()
  ed7f7c9168 NetworkPkg: Change complex DEBUG_CODE() to DEBUG_CODE_BEGIN/END()
  8e875037bf OvmfPkg: Change complex DEBUG_CODE() to DEBUG_CODE_BEGIN/END()
  deba54761a PcAtChipsetPkg: Change complex DEBUG_CODE() to DEBUG_CODE_BEGIN/END()
  f9f4fb2329 SecurityPkg: Change complex DEBUG_CODE() to DEBUG_CODE_BEGIN/END()
  7c2a6033c1 UefiCpuPkg: Change complex DEBUG_CODE() to DEBUG_CODE_BEGIN/END()
  429309e0c6 ArmPkg: Apply uncrustify changes
  40b0b23ed3 ArmPlatformPkg: Apply uncrustify changes
  2b16a4fb91 ArmVirtPkg: Apply uncrustify changes
  7c34237831 CryptoPkg: Apply uncrustify changes
  731c67e1d7 DynamicTablesPkg: Apply uncrustify changes
  e7108d0e96 EmbeddedPkg: Apply uncrustify changes
  a550d468a6 EmulatorPkg: Apply uncrustify changes
  bcdcc4160d FatPkg: Apply uncrustify changes
  45ce0a67bb FmpDevicePkg: Apply uncrustify changes
  111f2228dd IntelFsp2Pkg: Apply uncrustify changes
  7c7184e201 IntelFsp2WrapperPkg: Apply uncrustify changes
  1436aea4d5 MdeModulePkg: Apply uncrustify changes
  2f88bd3a12 MdePkg: Apply uncrustify changes
  d1050b9dff NetworkPkg: Apply uncrustify changes
  ac0a286f4d OvmfPkg: Apply uncrustify changes
  5220bd211d PcAtChipsetPkg: Apply uncrustify changes
  39de741e2d RedfishPkg: Apply uncrustify changes
  c411b485b6 SecurityPkg: Apply uncrustify changes
  47d20b54f9 ShellPkg: Apply uncrustify changes
  b878648967 SignedCapsulePkg: Apply uncrustify changes
  c1e126b119 SourceLevelDebugPkg: Apply uncrustify changes
  91415a36ae StandaloneMmPkg: Apply uncrustify changes
  053e878bfb UefiCpuPkg: Apply uncrustify changes
  e5efcf8be8 UefiPayloadPkg: Apply uncrustify changes
  7c0ad2c338 UnitTestFrameworkPkg: Apply uncrustify changes
  dc453b5164 .pytool/Plugin/UncrustifyCheck: Add Uncrustify CI plugin
  1832eb15aa UefiPayloadPkg/UefiPayloadPkg.fdf: Update DXE Apriori list
  ca78281c25 UefiPayloadPkg/PayloadEntry: Inherit 4/5-level paging from bootloader
  b2f7ee2ded UefiPayloadPkg: Increase SystemMemoryUefiRegionSize from 32M to 64M
  94e0a7bddb UefiPayloadPkg: Add missing Guid gUefiAcpiBoardInfoGuid
  2527723de9 UefiPayloadPkg: Add performance measurement feature
  ffdde9d719 UefiPayloadPkg: Skip ModuleInfo HOB in Payload
  965292135b UefiPayloadPkg/UefiPayloadPkg.dsc:Add BootManagerLib for BootManagerMenuApp
  85a678bf76 UefiPayloadPkg: Add integration instruction for coreboot common error
  7b28310008 BaseTools: Increase the DevicePath length for support more PCD value.
  d25b803e51 MdeModulePkg/Bus/Pci/UhciDxe: Fix the UsbHc memory allocate and free issue
  c82ab4d8c1 BaseTools/VfrCompile: Correct Bit Field Flags for numeric/one of
  2ddacfb6b8 OvmfPkg/SecMain: move SEV specific routines in AmdSev.c
  e2289d19d8 UefiCpuPkg/MpInitLib: move SEV specific routines in AmdSev.c
  2fe8edfe55 OvmfPkg/ResetVector: move clearing GHCB in SecMain
  3053183d41 OvmfPkg/ResetVector: introduce SEV metadata descriptor for VMM use
  707c71a01b OvmfPkg: reserve SNP secrets page
  cca9cd3dd6 OvmfPkg: reserve CPUID page
  f2dc28f0b6 OvmfPkg/ResetVector: pre-validate the data pages used in SEC phase
  34819f2cac OvmfPkg/ResetVector: use SEV-SNP-validated CPUID values
  d9822304ce OvmfPkg/MemEncryptSevLib: add MemEncryptSevSnpEnabled()
  7c3b2892ea OvmfPkg/SecMain: register GHCB gpa for the SEV-SNP guest
  d2b998fbdc OvmfPkg/VmgExitLib: use SEV-SNP-validated CPUID values
  a19b648952 OvmfPkg/PlatformPei: register GHCB gpa for the SEV-SNP guest
  19914edc5a OvmfPkg/AmdSevDxe: do not use extended PCI config space
  ade62c18f4 OvmfPkg/MemEncryptSevLib: add support to validate system RAM
  d706f8fec2 OvmfPkg/MemEncryptSevLib: add function to check the VMPL0
  11b15336f0 OvmfPkg/BaseMemEncryptSevLib: skip the pre-validated system RAM
  d39f8d88ec OvmfPkg/MemEncryptSevLib: add support to validate > 4GB memory in PEI phase
  202fb22be6 OvmfPkg/SecMain: validate the memory used for decompressing Fv
  8eb79b5f4f OvmfPkg/PlatformPei: validate the system RAM when SNP is active
  26210f9436 MdePkg: Define ConfidentialComputingGuestAttr
  504ae26b80 OvmfPkg/PlatformPei: set PcdConfidentialComputingAttr when SEV is active
  b95908e043 UefiCpuPkg/MpInitLib: use PcdConfidentialComputingAttr to check SEV status
  f4e3ce5f53 UefiCpuPkg: add PcdGhcbHypervisorFeatures
  f5a6e1bab5 OvmfPkg/PlatformPei: set the Hypervisor Features PCD
  2c354252be MdePkg/GHCB: increase the GHCB protocol max version
  9c703bc0f1 UefiCpuPkg/MpLib: add support to register GHCB GPA when SEV-SNP is enabled
  d4d7c9ad5f UefiCpuPkg/MpInitLib: use BSP to do extended topology check
  b928eb44d5 OvmfPkg/MemEncryptSevLib: change the page state in the RMP table
  b7b8872031 OvmfPkg/MemEncryptSevLib: skip page state change for Mmio address
  ea3a12d970 OvmfPkg/PlatformPei: mark cpuid and secrets memory reserved in EFI map
  67484aed69 OvmfPkg/AmdSev: expose the SNP reserved pages through configuration table
  06544455d0 UefiCpuPkg/MpInitLib: Use SEV-SNP AP Creation NAE event to launch APs
  0f1d7477c0 OvmfPkg: Remove unused print service driver (PrintDxe)
  30631f0a26 MdePkg: Add missing Cache ID (in)valid define
  0077c22f6d MdePkg: Remove PPTT ID type structure
  a50b65ce22 ShellPkg: Update Acpiview PPTT parser to ACPI 6.4
  8cf2bdfcfb ShellPkg: Add Cache ID to PPTT parser
  b2bbe3df54 DynamicTablesPkg: Remove PPTT ID structure from ACPI 6.4 generator
  e139829dd6 DynamicTablesPkg: Update PPTT generator to ACPI 6.4
  e81a81e584 DynamicTablesPkg: Add CacheId to PPTT generator
  9afcd48a94 OvmfPkg: Handle Cloud Hypervisor host bridge
  2ccefa32a6 OvmfPkg: Create global entry point for SMBIOS parsing
  d8ef774346 OvmfPkg: Retrieve SMBIOS from Cloud Hypervisor
  66bce05f6d OvmfPkg: Generalize AcpiPlatformDxe
  7594c5bfe2 OvmfPkg: Install ACPI tables for Cloud Hypervisor
  f6df289a1c OvmfPkg/OvmfXen: Fix Xen build
  2b20a34fd5 OvmfPkg-EmuVariableFvbRuntimeDxe: Support Access To Memory Above 4G
  d5efc875ef MdePkg: Introduce CcMeasurementProtocol for CC Guest firmware
  a124cd4ef9 SecurityPkg: Support CcMeasurementProtocol in DxeTpm2MeasureBootLib
  8c06c53b58 SecurityPkg: Support CcMeasurementProtocol in DxeTpmMeasurementLib
  adf070ff56 OvmfPkg/Microvm: add PcdConfidentialComputingGuestAttr
  2686468c43 OvmfPkg/Bhyve: add MemEncryptSevLib
  61be49e0f7 OvmfPkg/PlatformCI: factor out PlatformBuildLib.py
  21ee379407 OvmfPkg/PlatformCI: add QEMU_SKIP
  64bccda534 OvmfPkg/PlatformCI: add BhyveBuild.py
  04eacd3943 OvmfPkg/PlatformCI: add MicrovmBuild.py
  8b8ae609a7 OvmfPkg/PlatformCI: add AmdSevBuild.py
  2722856a87 OvmfPkg/PlatformCI: dummy grub.efi for AmdSev
  1203eba58e OvmfPkg/PlatformCI: add XenBuild.py
  64ef0dd1d3 OvmfPkg/Microvm/fdt: add device tree support
  79dcaf7054 OvmfPkg/Microvm/fdt: load fdt from fw_cfg
  c802f8935c OvmfPkg/Microvm/fdt: add empty fdt
  2a68abf6ee OvmfPkg/Microvm/virtio: add virtio-mmio support
  e07d27e24d OvmfPkg/Microvm: add README
  7f1861be2b DynamicTablesPkg: AML Code generation for memory ranges
  0e7147fe75 DynamicTablesPkg: AML Code generation to create a named Package()
  fd5fc4bbb7 DynamicTablesPkg: AML Code generation to create a named ResourceTemplate()
  b2b8def4e3 DynamicTablesPkg: AML Code generation to add _PRT entries
  69ddfee1c3 DynamicTablesPkg: Add AmlAttachNode()
  ce306e48eb DynamicTablesPkg: Add Pci related objects
  e35a746cf5 DynamicTablesPkg: SSDT Pci express generator
  ec37fd9c1f DynamicTablesPkg: Fix multiple objects parsing
  557dede8a6 OvmfPkg/PlatformPei: ScanOrAdd64BitE820Ram improvements
  759e3c6d21 OvmfPkg/PlatformPei: prefer etc/e820 for memory detection
  41d8bb3038 OvmfPkg/PlatformPei: stop using cmos for memory detection
  7a6e6ae933 EmulatorPkg: Update lldbefi.py to work with current lldb which uses python3
  4d30352445 ArmPkg: Add SMC helper functions
  c039fa7ff0 ArmPkg: Update SMC calls to use the new ArmCallSmc0/1/2/3 functions
  90ad4b3b34 DynamicTablesPkg: Definition for HwInfoParser interface
  d59c5a20f8 DynamicTablesPkg: FdtHwInfoParser: CM Object descriptor helper
  5d8b5d171c DynamicTablesPkg: FdtHwInfoParser: Add FDT utility functions
  8d2691c3d5 DynamicTablesPkg: FdtHwInfoParser: Add Boot Arch parser
  3ebe1ff5c9 DynamicTablesPkg: FdtHwInfoParser: Generic Timer Parser
  51941f7558 DynamicTablesPkg: FdtHwInfoParser: Add Serial port parser
  e366a41ef0 DynamicTablesPkg: FdtHwInfoParser: Add GICC parser
  0fa1217726 DynamicTablesPkg: FdtHwInfoParser: Add GICD parser
  b04cf355a0 DynamicTablesPkg: FdtHwInfoParser: Add MSI Frame parser
  d250d408cf DynamicTablesPkg: FdtHwInfoParser: Add ITS parser
  7b6c8b30a5 DynamicTablesPkg: FdtHwInfoParser: Add GICR parser
  26bf034a59 DynamicTablesPkg: FdtHwInfoParser: Add GIC dispatcher
  c67bf628c8 DynamicTablesPkg: FdtHwInfoParser: Add PCI config parser
  deb01dfd7f DynamicTablesPkg: Add FdtHwInfoParser library
  9006967c8d DynamicTablesPkg: Handle 16550_WITH_GAS id
  b2d0ed20fd DynamicTablesPkg: Definition for DynamicPlatRepoLib interface
  2e2db65e39 DynamicTablesPkg: DynamicPlatRepo: Add TokenGenerator
  740e3bb634 DynamicTablesPkg: DynamicPlatRepo: Add TokenFixer
  5fe5b6f94f DynamicTablesPkg: DynamicPlatRepo: Add TokenMapper
  38f6d78c3b DynamicTablesPkg: Add DynamicPlatRepo library
  f14fff5135 StandaloneMmPkg/FvLib: Support large file with EFI_FFS_FILE_HEADER2.
  3a72ec71cd OvmfPkg: remove unused TPM options from MicrovmX64.dsc
  b47575801e OvmfPkg: move tcg configuration to dsc and fdf include files
  5711ff4d0b OvmfPkg: drop TPM_CONFIG_ENABLE
  b819388772 OvmfPkg: create Tcg12ConfigPei.inf
  4de8d61bce OvmfPkg: rework TPM configuration
  e6ea1464a8 OvmfPkg/PlatformPei: Revert "stop using cmos for memory detection"
  a6c0418651 ArmPkg/SmbiosMiscDxe: Remove duplicate HII string definition
  45e3842970 ArmPkg/SmbiosMiscDxe: Get full SMBIOS strings from OemMiscLib
  b451c69088 ArmPkg/ProcessorSubClassDxe: Get serial and part number from OemMiscLib
  8ed8568922 SecurityPkg: Debug code to audit BIOS TPM extend operations
  195f011973 SecurityPkg: Reallocate TPM Active PCRs based on platform support
  ab5ab2f603 SecurityPkg: TPM must go to Idle state on CRB command completion
  c63a10ecb7 EmbeddedPkg/AcpiLib: Add more helper functions
  f129b1f06f OvmfPkg/Bhyve: fix tls-enabled build
  ee1f8262b8 OvmfPkg: Call PlatformInitializeConsole for GPU passthrough case
  de9e5b7dc7 IntelFsp2WrapperPkg : FSPM/S UPD data address based on Build Type
  9ec2cc1f31 IntelFsp2WrapperPkg : Remove EFIAPI from local functions.
  ae8272ef78 MdeModulePkg/UsbBusDxe: fix NOOPT build error
  15c596aeeb OvmfPkg: Bhyve: Delete unused AcpiTables/Ssdt.asl file
  6612ff8561 UefiCpuPkg: Extend measurement of microcode patches to TPM
  e910f076ad BaseTools: Fix the bug of --cmd-len build option
  7935be0fbd IntelFsp2Pkg/FspSecCore: ExtendedImageRevision was not printed.
  c095122d4b MdeModulePkg/PciBusDxe: Enumerator to check for RCiEP before looking for RP
  d463c56ddd MdeModulePkg: Replace with UFS_UNIT_DESC to fix timeout problem
  45920941d9 MdeModulePkg: Refactoring UFS DME request and fix timing problem
  13d9e8ec98 MdeModulePkg: Put off UFS HCS.DP checking to fix timing problem
  079a58276b OvmfPkg/AmdSev/SecretPei: Mark SEV launch secret area as reserved
  9dd14fc91c MdePkg: Add registers of boot partition feature
  14a731096d UnitTestFrameworkPkg: CI YAML: Grant cmockery spell check exception
  6062002bd5 MdeModulePkg/PartitionDxe: Add break to handle invalid LBA0 in MBR
  7438a85bf1 BaseTools: Fix wrong variable header size
  c712ce2bb1 OvmfPkg/CloudHv: Add new target for Cloud Hypervisor
  a2da72b2ca OvmfPkg/CloudHv: Replace legacy 8254 PIT with local APIC timer
  6ecdda71fe OvmfPkg/CloudHv: Connect serial console
  1552050ce7 OvmfPkg/CloudHv: Remove legacy 8259 PIC support
  fdcea7ff6f OvmfPkg/CloudHv: Remove Q35 specifics
  71082d3d1b OvmfPkg/CloudHv: Reduce dependency on QemuFwCfg
  196be601f9 OvmfPkg/CloudHv: Remove video support
  7b6cbe0a81 OvmfPkg/CloudHv: Remove USB support
  e73d1bf96a OvmfPkg/CloudHv: Remove CSM support
  b66056ef21 OvmfPkg/CloudHv: add Maintainers.txt entry
  5302bd81d9 OvmfPkg: Add CloudHvX64 to the CI
  59c48c9314 UefiPayloadPkg: Change the user interface name of the Uiapp
  5801910013 UefiPayloadPkg: Not use BaseCpuTimerLib by default.
  772c5bb8dc FmpDevicePkg/FmpDxe: Update FmpDeviceCheckImageWithStatus() handling
  7709988dd8 RedfishPkg/RedfishRestExDxe:Simplify status check
  21320ef669 MdeModulePkg/Variable: Make only EFI_VARIABLE_NON_VOLATILE invalid
  7e5c603cba MdeModulePkg/SdMmcPciHcDxe: Robust improvements for SD card 1.8V switch
  ee67067f17 MdeModulePkg: VariableSmmRuntimeDxe: Fix Variable Policy Message Length
  5b39832e18 MdePkg: MmCommunication2: Update MM communicate2 function description
  ce37f45955 ArmPkg: MmCommunicationDxe: MM communicate function argument attributes
  541a077bd1 ArmPkg: MmCommunicationDxe: Update MM communicate `CommBuffer**` checks
  1aa1ec4574 ArmPkg: MmCommunicationDxe: Update MM communicate `CommSize` check
  8cc5590eab ArmPkg: MmCommunicationDxe: Update MM communicate `MessageLength` check
  6777e67383 EmbeddedPkg: Fix a build error in FwVol.c in X64 arch
  a867f3a704 UefiPayloadPkg: Use BaseCpuTimerLib for Universal Payload by default
  f4b7b473b4 MdeModulePkg/UefiBootManagerLib: Convert BmLoadOption to Variable Policy
  76b3d45b75 ShellPkg: Add the missing VariablePolicyHelperLib in ShellPkg.dsc
  8542fc5f95 NetworkPkg: Add the missing VariablePolicyHelperLib in NetworkPkg.dsc
  ae35314e7b Maintainers.txt: Add Sami Mujawar as reviewer for ArmPkg
  862ea6e836 OvmfPkg: change qemu default resolution to 1280x800
  e95b44c90e ArmVirtPkg: change qemu default resolution to 1280x800
  929804b172 OvmfPkg: add PcdVideoResolutionSource
  7f25ddbc03 OvmfPkg/QemuVideoDxe: simplify InitializeBochsGraphicsMode
  336da55ca8 OvmfPkg/QemuVideoDxe: drop QEMU_VIDEO_BOCHS_MODES->ColorDepth
  55c05427b9 OvmfPkg/QemuVideoDxe: factor out QemuVideoBochsAddMode
  49a2d8cbf5 OvmfPkg/QemuVideoDxe: parse edid blob, detect display resolution
  ba79becd55 OvmfPkg/BaseCachingPciExpressLib: Migrate BaseCachingPciExpressLib
  103fa647d1 ArmPkg: Replace CoreId and ClusterId with Mpidr in ARM_CORE_INFO struct
  742dafd2cc DynamicTablesPkg: Print specifier macro for CM_OBJECT_ID
  13136cc311 DynamicTablesPkg: FdtHwInfoParserLib: Parse Pmu info
  5751d60821 DynamicTablesPkg: AmlLib: AmlAddPrtEntry() to handle GSI
  5816bd3eab DynamicTablesPkg: AcpiSsdtPcieLibArm: Remove link device generation
  dc1118fa0d ArmVirtPkg: Add cspell exceptions
  0dbd356983 ArmVirtPkg/Kvmtool: Add DSDT ACPI table
  312ef7a0a4 ArmVirtPkg/Kvmtool: Add Configuration Manager
  17a02163bd ArmVirtPkg/Kvmtool: Enable ACPI support
  5b3c682d91 ArmVirtPkg/Kvmtool: Enable Acpiview
  017564d637 ArmPkg/ArmMmuLib AARCH64: avoid EL0 accessible mappings
  45b1612659 DynamicTablesPkg: Add Memory32Fixed function
  007a95055b DynamicTablesPkg: Remove redundant cast in AmlCodeGenReturn
  33189f0527 DynamicTablesPkg: Add AmlCodeGenMethodRetInteger function
  a4b7aa362d MdeModulePkg/Bus/Pci/PciBusDxe: Support platform PCI ROM override
  6fb09da89f ShellPkg: Fix incorrect PPTT FlagName dereference
  c09dbc92e9 BaseTools/Conf: Add new macro for customizing dll file reduction.
  d4ac53aa91 BaseTools: Fix error leg in DscBuildData.py
  f78b937c95 MdeModulePkg/RuntimeDxe: clear mVirtualMapMaxIndex
  96b8b5fd10 MdeModulePkg/UiApp: Fix spelling of 'FRONTPAGE'
  bd676f080a Maintainers.txt: add missing github IDs to OvmfPkf/Fdt reviewers
  1f54eaa725 Maintainers.txt: update email for Leif Lindholm
  b360b0b589 Maintainers.txt: Update email address
  c9b7c6e0cc BaseTools: Update CLANG{35,38}_WARNING_OVERRIDES to ignore unused vars
  42af706dfb BaseTools: Update brotli submodule
  1193aa2dfb MdeModulePkg: update brotli submodule
  85589ddbf6 OvmfPkg/VmgExitLib: Fix uninitialized variable warning with XCODE5
  c28e376edc OvmfPkg/FvbServicesSmm: use the VmgExitLibNull
  8a57673316 ShellPkg: Fix Ping GetTimerPeriod API failure
  b24306f15d NetworkPkg: Fix incorrect unicode string of the AKM/Cipher Suite
- Add amd-sev-es to the following descriptors because James Fehlig
  tested them (bsc#1196879):
    60-ovmf-x86_64.json
    60-ovmf-x86_64-2m.json
    60-ovmf-x86_64-ms.json
    60-ovmf-x86_64-2m-ms.json
- Backported patches in ovmf-bsc1196879-sev-fix.patch for fixing SEV:
    de463163d9 OvmfPkg/AmdSev: reserve snp pages
  63c50d3ff2 OvmfPkg/ResetVector: cache the SEV status MSR value in workarea
  f1d1c337e7 OvmfPkg/BaseMemEncryptLib: use the SEV_STATUS MSR value from workarea
* Thu Feb 17 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Sort file lists for reproducible build results
* Mon Jan  3 2022 Joey Lee <jlee@suse.com>
- Modified gdb_uefi.py.in for python3 (bsc#1192126)
  - change 'long' to 'int'
  - using
    print ('
    instead of
    print "
* Thu Dec 23 2021 jlee@suse.com
- Removed useless patch files because they are merged to edk2-stable202111
  - ovmf-OvmfPkg-OvmfXen-Fix-build-with-QemuKernelLoaderFsDxe.patch
  - ovmf-OvmfPkg-OvmfXen-add-QemuKernelLoaderFsDxe.patch
  - ovmf-OvmfPkg-OvmfXen-set-PcdAcpiS3Enable-at-initializatio.patch
- Updated URL to the edk2 repo on github
- Use downloaded edk2-edk2-stable%%{version}.tar.gz instead of the URL
  for Source0 because the edk2-edk2-stable202111 tarball is broken
  in tianocore repo which can not pass the "osc service runall download_files"
  testing.
  - We ill change it back to the following setting when upstream fixed tarball:
  Source0:        https://github.com/tianocore/edk2/releases/download/edk2-stable%%{version}/edk2-edk2-stable%%{version}.tar.gz
* Tue Dec 21 2021 Joey Lee <jlee@suse.com>
- Update to edk2-stable202111
  - Features (https://github.com/tianocore/edk2/releases):
  Add SSDT CPU topology generator
  Support ACPI 6.4 in GTDT parser and generator
  Support ACPI 6.4 in DynamicTables FADT parser
  Support ACPI 6.4 in Acpiview PCCT parser
  Support ACPI 6.4 in Acpiview HMAT parser
  Add support for the microvm machine type (qemu)
  OVMF/ArmVirt: add support for virtio-mmio 1.0
  IntelFsp2Pkg: adopt FSP 2.3 specification
  UefiCpuPkg VTF0 X64: Build page tables using Linear-Address Translation to a 1-GByte Page
  Enable wildcard host name matching in HTTPS/TLS implementation
  Add QuickSort function into BaseLib
  Add SMM NV variable support in universal UEFI payload
  Add TDVF to OvmfPkg
  Make package and platform builds reproducible across source format changes
  - Patches (git log --oneline --reverse edk2-stable202108~..edk2-stable202111):
  7b4a99be8a CryptoPkg: BaseCryptLib fix incorrect param order
  82f7e315d6 MdeModulePkg/PeiCore: Remove MigrateSecModulesInFv()
  8b15024dc7 Maintainers: Add kraxel as Reviewer to ArmVirtPkg and OvmfPkg
  80e67af9af OvmfPkg: introduce a common work area
  ab77b6031b OvmfPkg/ResetVector: update SEV support to use new work area format
  b9af5037b2 OvmfPkg/ResetVector: move the GHCB page setup in AmdSev.asm
  a82bad9730 ArmPkg/GicV3Dxe: Don't signal EOI on arbitrary interrupts
  94e465e5cb OvmfPkg/Virtio10: Add virtio-mmio 1.0 defines
  08293e43da OvmfPkg/VirtioMmioDeviceLib: Add virtio 1.0 detection.
  212a2b9bb8 OvmfPkg/VirtioMmioDeviceLib: virtio 1.0: Fix SetPageSize.
  537a724421 OvmfPkg/VirtioMmioDeviceLib: virtio 1.0: Fix SetQueueAddress
  6a3e9576b8 OvmfPkg/VirtioMmioDeviceLib: virtio 1.0: Add default QueueNum
  ae12188cf8 OvmfPkg/VirtioMmioDeviceLib: virtio 1.0: Adapt feature bit handling
  77d5fa8024 OvmfPkg/VirtioMmioDeviceLib: enable virtio 1.0
  b04453d36b MdeModulePkg/EbcDxe: Mitigate memcpy intrinsics
  dc995ce906 MdeModulePkg: Add BootDiscoveryPolicyOld variable.
  443300be46 MdePkg:Update IndustryStandard/Nvme.h with Nvme amdin controller data
  0f11537548 MdeModulePkg:Increase Nvme capacity display
  cae735f613 ArmPkg: Enable boot discovery policy for ARM package.
  cb0d24637d OvmfPkg/OvmfXen: set PcdAcpiS3Enable at initialization
  28152333bc OvmfPkg/LockBoxLib: use PcdAcpiS3Enable to detect S3 support
  52e2dabc0f OvmfPkg/PlatformBootManagerLib: use PcdAcpiS3Enable to detect S3 support
  5b5f10d746 OvmfPkg/SmmControl2Dxe: use PcdAcpiS3Enable to detect S3 support
  9f3eda177a OvmfPkg/OvmfXen: add QemuKernelLoaderFsDxe
  f0fe55bca4 UefiPayloadPkg: Fix the build error when enable Core ci for UefiPayloadPkg
  5d34cc49d5 UefiCpuPkg/PiSmmCpuDxeSmm: Update mPatchCetSupported set condition
  cdda3f74a1 UefiPayloadPkg/UefiPayloadEntry: Fix memory corruption
  3b3f882288 MdeModulePkg/PiSmmCore: Drop deprecated image profiling commands
  b170806518 UefiCpuPkg: Clean up save state boundary checks and comments.
  12e33dca4c IntelFsp2Pkg: Support Config File and Binary delta comparison
  63fddc98e0 UefiPayloadPkg: Create .yaml file in UefiPayloadPkg
  e3ee8c8dbd .azurepipelines: Add UefiPayloadPkg in gate-build-job.yml and CISetting.py
  b6bc203375 MdeModulePkg/HiiDatabaseDxe:remove dead code block
  c5e805ffe1 MdeModulePkg: Fix typo of "memory" in RamDiskDxe debug message
  81d71fb86e Maintainers.txt: Update maintainer/reviewer roles in MdeModulePkg
  edf8bc6d24 SecurityPkg/MemoryOverwriteControl: Add missing argument to DEBUG print
  4473834e7d OvmfPkg/OvmfXen: Fix build with QemuKernelLoaderFsDxe
  a7cf2c5664 RedfishPkg: Fix various typos
  851785ea67 UefiPayloadPkg: Include more modules in UefiPayloadPkg.
  d248516b3a UefiPayloadPkg: Include Network modules in UefiPayloadPkg.
  6c7d6d4a5e UefiCpuPkg: ResetVector Tool Support for Python 3
  cf7c650592 UefiCpuPkg: ResetVector Tool additional debug prints
  d96df7e993 UefiPayloadPkg: Fix the bug in dump guid HOB info functions
  dcd3d63f4f UefiPayloadPkg: Dump hob info from gEdkiiBootManagerMenuFileGuid
  610d8073f2 SecurityPkg/TPM: Import PeiDxeTpmPlatformHierarchyLib.c from edk2-platforms
  4d5f39cd22 SecurityPkg/TPM: Fix bugs in imported PeiDxeTpmPlatformHierarchyLib
  ebbc8ab2cd SecrutiyPkg/Tcg: Import Tcg2PlatformDxe from edk2-platforms
  2906e572c6 SecurityPkg/Tcg: Make Tcg2PlatformDxe buildable and fix style issues
  f108178c56 SecurityPkg: Introduce new PCD PcdRandomizePlatformHierarchy
  a4867dea2a SecurityPkg/Tcg: Import Tcg2PlatformPei from edk2-platforms
  2fa89c8e11 SecurityPkg/Tcg: Make Tcg2PlatformPei buildable and fix style issues
  3b69fcf5f8 SecurityPkg: Add references to header and inf files to SecurityPkg
  6c80564b89 MdeModulePkg/Core/Pei: Fix typo in function descriptions
  6f501a7c9b MdeModulePkg/Core/Pei: Make migrated PEIM message verbose
  c19d18136e MdeModulePkg/Core/Pei: Fix pointer size mismatch in EvacuateTempRam()
  f4e72cf9d6 UefiPayloadPkg: Add script to build UniversalPayload in UefiPayloadPkg
  bda3546c55 UefiPayloadPkg: Fix the warning when building UefiPayloadPkg with IA32+X64
  010753b7e7 UefiCpuPkg: Refactor initialization of CPU features during S3 resume
  89f7ed8b29 UefiCpuPkg: Prevent from re-initializing CPU features during S3 resume
  60d8bb9f28 UefiCpuPkg: VTF0 Linear-Address Translation to a 1-GByte Page till 512GB
  ac6388add4 ArmPkg/ProcessorSubClassDxe: Fix the format of ProcessorId
  e3e47d7963 UefiCpuPkg: SecCoreNative without ResetVector
  542cba73d2 SecurityPkg: Add debug log for indicating IBB verified OBB successfully
  f334c5a41d IntelFsp2WrapperPkg: Make PcdFspModeSelection dynamic
  79019c7a42 OvmfPkg: set a default value for the WorkAreaHeader PCD
  fdeff3fdae EmbeddedPkg: Remove duplicate libfdt.h include
  f2a7e24e38 EmbeddedPkg: AndroidBootImgBoot error handling updates
  c0cd26f43c EmbeddedPkg: Install FDT if UpdateDtb is not present
  7ea7f9c077 EmbeddedPkg: Add LoadFile2 for linux initrd
  d60915b751 UefiPayloadPkg: Add Macro to enable or disable some drivers.
  46b4606ba2 MdeModulePkg/PciBusDxe: Improve the flow of testing support attributes
  f57040b038 MdeModulePkg/BootManagerMenuApp: Limit string drawing within one line
  b0f1b1c5fd MdePkg: Fix DEVICE_SECURITY_EVENT_DATA_HEADER version definition
  cc5a67269e UefiPayloadPkg: Build a HOB from bootloader ACPI table
  dc430ccf3f UefiPayloadPkg: Use dummy constructor for PlatformHookLib
  4a1899dd79 UefiPayloadPkg: Add ".upld_info" in universal payload
  2ea0a0a414 BaseTools: Switch to downloading the ARM compiler from Arm's site
  1ce6ceb75b BaseTools: Switch to downloading the AARCH64 compiler from Arm's site
  c214128a38 BaseTools/GenMake: Use ToolDefinition as fallback option
  259c184c8f BaseTools/build: Set MakefileName
  445c39f757 BaseTools: Remove Makefile/MakefileName fields
  c7d5b046d9 BaseTools: Remove hard-coded strings for target and tools_def
  442e46d3b6 UefiPayloadPkg: Update maximum logic processor to 256
  499c4608b1 OvmfPkg/TPM PPI: Connect default consoles for user interaction
  b8675deaa8 OvmfPkg: Handle TPM 2 physical presence opcodes much earlier
  8ab8fbc016 OvmfPkg: Reference new Tcg2PlatformDxe in the build system for compilation
  bd298d7593 OvmfPkg: Reference new Tcg2PlatformPei in the build system
  f86de75862 MdePkg: MmCommunication: Added definition of MM Communication PPI
  8b4bb94f64 MdePkg: CI YAML: Added new GUID to ignore duplicate list
  9e950cda6a MdeModulePkg: CI YAML: Added new GUID to ignore duplicate list
  2273799677 SecurityPkg: Fix SecureBootDefaultKeysDxe failed to start
  422e5d2f7f UefiPayloadPkg: Remove asm code and sharing libraries
  0875443f7e DynamicTablesPkg: Extract AcpiHelperLib from TableHelperLib
  20775950c6 DynamicTablesPkg: Update TableHelperLib.inf
  1ad5182500 DynamicTablesPkg: Rename single char input parameter
  653113412f DynamicTablesPkg: Add HexFromAscii() to AcpiHelperLib
  72ab552554 DynamicTablesPkg: Add AmlGetEisaIdFromString() to AcpiHelperLib
  96e006b37e DynamicTablesPkg: Add Configuration Manager Object parser
  235ff9fcd1 DynamicTablesPkg: Use %%a formatter in AmlDbgPrint
  7a8c037e9e DynamicTablesPkg: Update DynamicTablesPkg.ci.yaml
  691c5f7762 DynamicTablesPkg: Deprecate Crs specific methods in AmlLib
  22873f58c4 DynamicTablesPkg: Rework AmlResourceDataCodegen.c/h
  4cc1458dbe IntelFsp2Pkg: Adopt FSP 2.3 specification.
  c49cb8f30e ArmPkg: SmbiosMiscDxe: Don't populate ExtendedBiosSize when size < 16MB
  282122ec5f ArmVirtPkg/TPM: Add a NULL implementation of TpmPlatformHierarchyLib
  b3685956d2 ArmVirtPkg: Reference new TPM classes in the build system for compilation
  c806b76865 ArmVirtPkg: Disable the TPM2 platform hierarchy
  606340fba3 OvmfPkg/Microvm: copy OvmfPkgX64 files as-is
  4932f05a00 OvmfPkg/Microvm: rename output files, fix includes
  2a49c19b9e OvmfPkg/Microvm: no smm
  60d55c4156 OvmfPkg/Microvm: no secure boot
  0569c52b15 OvmfPkg/Microvm: no tpm
  06fa1f1931 OvmfPkg/Microvm: no sev
  6073bf6cd8 OvmfPkg/Microvm: no csm
  b9dd64b80e OvmfPkg/Microvm: no emulated scsi
  27de86ae41 OvmfPkg/Microvm: use MdePkg/Library/SecPeiDxeTimerLibCpu
  76602f45dc OvmfPkg/Microvm: use XenTimerDxe (lapic timer)
  6a8e9ad24b OvmfPkg/Microvm: PlatformPei/MemDetect tweaks
  8583b57c5c OvmfPkg/Microvm: PlatformPei/Platform memory map tweaks
  bf02d73e74 OvmfPkg/Microvm: PlatformPei/Platform: add id.
  1d3e89f349 OvmfPkg/ResetSystemLib: add driver for microvm
  2c467c9be2 OvmfPkg/Microvm: BdsPlatform: PciAcpiInitialization tweak.
  8456785986 OvmfPkg/Microvm: use PciHostBridgeLibNull
  55f47d2299 OvmfPkg/Microvm: wire up serial console, drop super-io
  862e814de4 OvmfPkg/Microvm: add Maintainers.txt entry
  06a326caf1 DynamicTablesPkg: Update FADT generator to ACPI 6.4
  f09dbf20b9 DynamicTablesPkg: Rename SBSA generic watchdog
  942c9bd357 ShellPkg: Update Acpiview GTDT parser to ACPI 6.4
  80e67bcb23 ShellPkg: Update Acpiview PCCT parser to ACPI 6.4
  b4da6c29f1 ShellPkg: Add Type 5 PCC Subspace Structure parser
  5ece2ad36c MdeModulePkg/Core/Dxe: Add lock protection in CoreLocateHandleBuffer()
  30400318a2 ShellPkg: Update Acpiview HMAT parser to ACPI spec version 6.4
  71c3c9c0c4 DynamicTablesPkg: Remove unnecessary includes
  25cf58a163 DynamicTablesPkg: Add missing parameter check
  bfaf7c8b9e DynamicTablesPkg: Add AddSsdtAcpiHeader()
  28b2df475f DynamicTablesPkg: Add AmlRdSetEndTagChecksum()
  74addfeab6 DynamicTablesPkg: Add AmlSetRdListCheckSum()
  7b2022d39e DynamicTablesPkg: Set EndTag's Checksum if RdList is modified
  2dd7dd3952 DynamicTablesPkg: Clear pointer in node creation fcts
  37bd08176c DynamicTablesPkg: Update error handling for node creation
  6d2777d85f DynamicTablesPkg: Make AmlNodeGetIntegerValue public
  f995f8672b DynamicTablesPkg: AML Code generation for Register()
  9454d1ebcb DynamicTablesPkg: AML Code generation for Resource data EndTag
  1e33479b39 DynamicTablesPkg: AML code generation for a Package
  12e65fd258 DynamicTablesPkg: Helper function to compute package length
  ce15936f2f DynamicTablesPkg: AML code generation for a ResourceTemplate
  de62ccbf4f DynamicTablesPkg: AML code generation for a Method
  e2d7b4950b DynamicTablesPkg: AML code generation to Return a NameString
  3e958e93ce DynamicTablesPkg: AML code generation for a Method returning a NS
  018a962d92 DynamicTablesPkg: AML code generation for a _LPI object
  a5e36ad9bc DynamicTablesPkg: AML code generation to add an _LPI state
  f17ef10e63 DynamicTablesPkg: Add CM_ARM_LPI_INFO object
  769e63999f DynamicTablesPkg: SSDT CPU topology and LPI state generator
  19ee56c4b3 UefiPayloadPkg: Add a macro to select the SecurityStubDxe driver.
  782d018703 MdePkg: Add ProcessorUpgradeSocketLGA4677 from SMBIOS 3.5.0
  ba4ae92234 ShellPkg: Support ProcessorUpgradeSocketLGA4677 from SMBIOS 3.5.0
  f22feb0e3b CryptoPkg/BaseCryptLib: Eliminate extra buffer copy in Pkcs7Verify()
  4225a464c6 MdePkg/BaseLib: Add QuickSort function on BaseLib
  6ed6abd6c1 BaseTools: Change RealPath to AbsPath
  978d428ec3 UefiPayloadPkg: Add PCI root bridge info hob support for SBL
  43b3840873 MdeModulePkg/Sd: Corrections for Extra.uni files
  a7fcab7aa3 MdeModulePkg/Core/Dxe: Acquire a lock when iterating gHandleList
  e40fefafa9 ArmVirtPkg/FdtClintDxe: Move FdtClientDxe to EmbeddedPkg
  fb759b8b73 MdePkg: Add PcdPciIoTranslation PCD
  7d78a86ecf ArmPkg: Use PcdPciIoTranslation PCD from MdePkg
  77e9b3a7c6 ArmVirtPkg/FdtPciPcdProducerLib: Relocate PciPcdProducerLib to OvmfPkg
  d881c6ddf5 ArmVirtPkg/HighMemDxe: Relocate HighMemDxe to OvmfPkg
  47bd85e9f9 OvmfPkg/HighMemDxe: Add RISC-V in the supported arch.
  f8d0501ded ArmVirtPkg/QemuFwCfgLib: Relocate QemuFwCfgLib to OvmfPkg
  26aa241d2f OvmfPkg/QemuFwCfgLibMmio: Add RISC-V arch support
  c6770f4b88 MdePkg: Add PcdPciMmio32(64)Translation PCDs
  9a7509e465 ArmVirtPkg/FdtPciHostBridgeLib: Relocate FdtPciHostBridgeLib to OvmfPkg/Fdt
  b21c6794de OvmfPkg/FdtPciHostBridgeLib: Add RISC-V in the supported arch.
  e0c23cba5e ArmVirtPkg/VirtioFdtDxe: Relocate VirtioFdtDxe to OvmfPkg/Fdt
  f2400e06db BaseTools: add edk2-test repo to SetupGit.py
  785cfd3305 UefiPayloadPkg: Use SECURITY_STUB_ENABLE to control the SecurityStubDxe
  7e43d3e086 ArmPkg/Smbios: Fix max cache size 2 wrong issue
  f10a112f08 UefiPayloadPkg: Fix the build issue for coreboot
  2108698346 StandaloneMmPkg: Support CLANGPDB builds
  11a4af85a4 Ovmfpkg: update Ia32 build to use new work area
  36b561623a OvmfPkg/AmdSev: update the fdf to use new workarea PCD
  91a978ce7e UefiPayloadPkg: Replace MEMROY_ENTRY by MEMORY_ENTRY
  6ef5797447 UefiPayloadPkg: Fix ECC reported issues
  90246a6d9f UefiPayloadPkg: Fix the build failure for non-universal payload
  37a33f02aa UefiCpuPkg: Cpu feature data stored in memory may be migrated
  4fdf843c75 DynamicTablesPkg: Fix unitialized variable use
  6893865b30 DynamicTablesPkg: Fix void pointer arithmetic
  99325a8b65 MdeModulePkg/SortLib: Add QuickSort function on BaseLib
  305fd6bee0 UefiCpuPkg/CpuCacheInfoLib: Add QuickSort function on BaseLib
  2f286930a8 ShellPkg: Parse I/O APIC and x2APIC structure
  bd5ec03d87 NetworkPkg/HttpBootDxe: make file extension check case-insensitive
  6254037223 ArmPkg: Implement PlatformBootManagerLib for LinuxBoot
  f079e9b450 OvmfPkg: Copy Main.asm from UefiCpuPkg to OvmfPkg's ResetVector
  5a2411784b OvmfPkg: Clear WORK_AREA_GUEST_TYPE in Main.asm
  c9ec74a198 OvmfPkg: Add IntelTdxMetadata.asm
  8b76f23534 OvmfPkg: Enable TDX in ResetVector
  87a34ca0cf UefiPayloadPkg: Add a common SmmAccessDxe module
  e7e8ea27d4 UefiPayloadPkg: Add a common SMM control Runtime DXE module
  bed990aae6 UefiPayloadPkg: Add bootloader SMM support module
  1d66480aa4 UefiPayloadPkg: Add SpiFlashLib
  04714cef46 UefiPayloadPkg: Add FlashDeviceLib
  ae8acce8ae UefiPayloadPkg: Add a common FVB SMM module
  242dcfe30f UefiPayloadPkg: Add a SMM dispatch module
  b80c17b62d UefiPayloadPkg: Add SMM support and SMM variable support
  2f6f3329ad FmpDevicePkg/FmpDxe: Use new Variable Lock interface
  9a95d11023 IntelFsp2Pkg/SplitFspBin.py: adopt FSP 2.3 specification.
  bb146ce32d MdePkg Cpuid.h: Define CPUID.(EAX=7,ECX=0):EDX[30]
  1bc232aae3 RedfishPkg: Update link to staging/RedfishClientPkg in Readme.md
  e7663fdd82 UefiPayloadPkg: Remove SystemTableInfo GUID.
  91b772ab62 RedfishPkg: Add more information to Readme.md
  c8594a5311 SecurityPkg/FvReportPei: Remove the ASSERT to allow neither M nor V
  939c2355da IntelFsp2Pkg SplitFspBin.py: Correct file name in file header
  6f9e83f757 NetworkPkg/HttpDxe: Enable wildcard host name matching for HTTP+TLS.
  b258f12889 BaseTools/VrfCompile: Fix uninitialized field from unnamed field
  0f4cdad25b DynamicTablesPkg: Add missing BaseStackCheckLib instance
  e13e53cb2f NetworkPkg/NetworkPkg.dsc: Add RngLib mapping for ARM and RISCV64
  c1f2287635 SecurityPkg/SecurityPkg.dsc: Add missing RngLib for ARM and RISCV64
  b0a03ca4a9 SignedCapsulePkg/SignedCapsulePkg.dsc: Add RngLib mapping
  15e635d1b5 UefiCpuPkg/MtrrLib/UnitTest: Fix 32-bit GCC build issues
  4050c873b5 MdeModulePkg/Variable/RuntimeDxeUnitTest: Fix 32-bit GCC builds
  d79df34beb BaseTools: Fix StructurePcd offset error.
  b5d4a35d90 MdeModulePkg/XhciSched: Fix missing DEBUG arguments
  48452993ad MdePkg/Include: Enhance DebugLib to support reproduce builds
  5948ec3647 MdePkg: Reproduce builds across source format changes
  f331310a10 ArmPkg: Reproduce builds across source format changes
  77dcd03ecf MdeModulePkg: Reproduce builds across source format changes
  45137bca2f NetworkPkg: Reproduce builds across source format changes
  d939a25d41 SecurityPkg: Reproduce builds across source format changes
  fd42dcb1fc OvmfPkg: Reproduce builds across source format changes
  8c1b1fe634 ShellPkg: Add comment that ItemPtr is set after validation
  d6e6337cd6 MdePkg: Fix ACPI memory aggregator/device type mismatch
  c974257821 MdeModulePkg AtaAtapiPassThru: Always do S.M.A.R.T. check if device support
  aab6bb3d32 MdeModulePkg/DxeCapsuleLibFmp: Capsule on Disk file name capsule
  a7b35aae13 MdeModulePkg\UfsBlockIoPei: UFS MMIO address size support both 32/64 bits
  f826b20811 UefiCpuPkg/UefiCpuLib: Add GetCpuFamilyModel and GetCpuSteppingId
  8c8867c5da MdeModulePkg/DxeCapsuleLibFmp: Use new Variable Lock interface
  22c3b5a865 BaseTools: Add authenticated variable store support
  a92559671a OvmfPkg/Xen: Fix VS2019 build issues
  4c495e5e3d OvmfPkg/Bhyve/PlatformPei: Fix VS2019 X64 NOOPT build issue
  466ebdd2e0 MdeModulePkg/FPDT: Lock boot performance table address variable at EndOfDxe
  455b0347a7 UefiCpuPkg/PiSmmCpuDxeSmm: Use SMM Interrupt Shadow Stack
  e1e7306b54 OvmfPkg/Library/ResetSystemLib: Fix Microvm VS2019 NOOPT build issue
  4c7ce0d285 MdeModulePkg AtaAtapiPassThru: Skip the potential NULL pointer access
  bb1bba3d77 NetworkPkg: Fix invalid pointer for DNS response token on error
  - Removed patches which are merged to mainline:
  - ovmf-OvmfPkg-OvmfXen-set-PcdAcpiS3Enable-at-initializatio.patch to fix the
    S3 detection in ovmf-xen
  - cb0d24637d    edk2-stable202111-rc1~220
  - ovmf-OvmfPkg-OvmfXen-add-QemuKernelLoaderFsDxe.patch to add QemuKernelLoaderFsDxe
    to ovmf-xen to load kernel from qemu fw_cfg
  - 9f3eda177a    edk2-stable202111-rc1~216
  - ovmf-OvmfPkg-OvmfXen-Fix-build-with-QemuKernelLoaderFsDxe.patch
  - 4473834e7d    edk2-stable202111-rc1~203
  - The edk2-stable202111 includes the following patches for bsc#1192126
    to fix unlimited reset. (bsc#1192126)
    80e67af9af OvmfPkg: introduce a common work area
    ab77b6031b OvmfPkg/ResetVector: update SEV support to use new work area format
    b9af5037b2 OvmfPkg/ResetVector: move the GHCB page setup in AmdSev.asm
* Wed Dec  8 2021 jlee@suse.com
- For preparing push to SLE15-SP4, add more notes:
  - Drop upstreamed ovmf-jscSLE-16075-SEV-ES-fixes.patch from 15-SP4
  - All patches in the above big patch are in edk2-stable202011
  - Some changes in ovmf.spec file of 15-SP4:
  - brotli-v1.0.7-17-g666c328-c.tar.xz and "add brotli" section
  be removed because ovmf-disable-brotli.patch.
  - Using %%{_prefix} instead of /usr hard code.
  - Redundant %%defattr(-,root,root) are removed.
  - BuildRoot be removed because factory doesn't have it.
  - Sync some differences in the change log between 15-SP3 with openSUSE
    TW since "Wed Jan 24 06:31:21 UTC 2018":
  - Add TLS and IPv6 supports for ArmVirtQemu.
  - ovmf-bsc1119454-additional-scsi-drivers.patch to support more
  SCSI drivers (PvScsi, MptScsi, and LsiScsi) (bsc#1119454)
  - already in edk2-stable202008
  - Drop the build requirement of python2
* Mon Dec  6 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- cross-i386-binutils and cross-i386-gcc have been dropped from
  Factory, so use only cross-x86_64-* - boo#1193424
* Fri Dec  3 2021 jlee@suse.com
- Merge the difference from SLE for pushing back to SLE15-SP4
  - Add/Update 50-xen-hvm-x86_64.json in descriptors.tar.xz
  - Add the json descriptor for xen-hvm (bsc#1180050)
  - Add "nvram-template" and change the firmware file to
  ovmf-x86_64-ms-4m.bin (bsc#1180050, bsc#1181264)
  - The following patches in SLE are already in edk2-edk2-stable202108
    in factory, so they will be removed from 15-SP4
  - ovmf-bsc1177789-cryptopkg-fix-null-dereference.patch to fix
    the potential NULL dereference in AuthenticodeVerify()
    (bsc#1177789, CVE-2019-14584)
  - 26442d11e620a9	edk2-stable202011~124
  - ovmf-bsc1180079-amd-sev-es-mitigation.patch to mitigate the
  potential AMD SEV-ES security issues
  (bsc#1180079)
  - a91b700e385e74	edk2-stable202102~181
  - ovmf-jscSLE-16075-SEV-ES-use-physical-address.patch as the
  follow-up patch for SEV-ES to fix the flash writing
  (jsc#SLE-16075)
  - 3a3501862f7309	edk2-stable202102~105
  - ovmf-bsc1183578-lzma-catch-4GB.patch to fix the possible
  heap corruption
  (bsc#1183578, CVE-2021-28211)
  - e7bd0dd26db7e5	edk2-stable202011~7
  - ovmf-bsc1183579-fix-fv-recursion.patch to fix unlimited FV
  recursion
  (bsc#1183579, CVE-2021-28210)
  - b9bdfc72853fe9	edk2-stable202011~9
  - Add ovmf-bsc1186151-fix-iscsi-overflows.patch to fix the possible
  overflows in IScsiDxe
  (bsc#1186151)
  - 83761337ec91fb	edk2-stable202108-rc0~171
* Mon Nov  8 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update rpmlintrc (fixes aarch64 build)
* Tue Oct 26 2021 jlee@suse.com
- Removed patches which are merged to mainline:
    ovmf-bsc1186151-fix-iscsi-overflows.patch
    ovmf-xen-relocate-shared_info_page-map.patch
- Removed patches because replaced:
    ovmf-fix-xen-s3-detection.patch -> ovmf-OvmfPkg-OvmfXen-set-PcdAcpiS3Enable-at-initializatio.patch
    ovmf-xen-add-qemu-kernel-loader-fs.patch -> ovmf-OvmfPkg-OvmfXen-add-QemuKernelLoaderFsDxe.patch
* Fri Oct 22 2021 jlee@suse.com
- Removed edk2-stable202105.tar.gz because we updated to edk2-stable202108
* Thu Oct 14 2021 jlee@suse.com
- Update to edk2-stable202108
  - Features (https://github.com/tianocore/edk2/releases):
  OvmfPkg: remove Xen support from OvmfPkg*.dsc, in favor of OvmfXen.dsc
  Add CLANGDWARF toolchain for generating ELF+DWARF
  NetworkPkg/IScsiDxe: remotely exploitable buffer overflows
  NetworkPkg/IScsiDxe: add sha256 support to CHAP
  Create header files and multiple Hobs for Universal Payload
  Add search feature in config editor
  Add additional build option to treat Dynamic Pcd as DynamicEx Pcd
  Add a new MicrocodeLib for microcode loading
  Implement key enrolment from default key variables
  StandaloneMm support for 32bit Arm machines
  Add firmware support for Cloud Hypervisor on arm64
  Support architecture-specific openssl acceleration
  Support measured AMD SEV boot with kernel/initrd/cmdline
  Add ACPI 6.4 header
  Add new BootDiscoveryPolicyUiLib
  - Patches (git log --oneline --reverse edk2-stable202105~..edk2-stable202108):
  e1999b264f ArmPkg/ArmGic: Fix maximum number of interrupts in GICv3
  b8ed8c0fb2 Maintainers.txt: add Sami Mujawar as top-level ArmVirtPkg reviewer
  dbc22a1785 UefiCpuPkg/MpInitLib: Allocate a separate SEV-ES AP reset stack area
  0095070e70 MdePkg/Register/Amd: expand the SEV MSR to include the SNP definition
  f828fc9876 MdePkg/Register/Amd: realign macros with more space for future expansion
  34e16ff883 MdePkg/Register/Amd: define GHCB macros for hypervisor feature detection
  f0983b2074 MdePkg/Register/Amd: define GHCB macro for Register GPA structure
  4665fa6503 MdePkg/Register/Amd: define GHCB macro for the Page State Change
  dfd41aef78 MdePkg/Register/Amd: define GHCB macros for SNP AP creation
  5a7cbd54a1 MdePkg/BaseLib: add support for PVALIDATE instruction
  2b5b2ff04d MdePkg/BaseLib: add support for RMPADJUST instruction
  901a9bfc3a OvmfPkg/BaseMemEncryptSevLib: introduce MemEncryptSevClearMmioPageEncMask()
  c394fa4c9e OvmfPkg/AmdSevDxe: use MemEncryptSevClearMmioPageEncMask() to clear EncMask
  8ee4e52ba8 OvmfPkg/QemuFlashFvbServicesRuntimeDxe: use Mmio helper to clear enc mask
  b4a8de5d27 OvmfPkg/TpmMmioSevDecryptPei: use MemEncryptSevClearMmioPageEncMask()
  adfa3327d4 OvmfPkg/BaseMemEncryptSevLib: remove Flush parameter
  fe5da0927a IntelFsp2WrapperPkg: Remove microcode related PCDs
  d3ff5dbe1d MdePkg: MmControl: Fix function and structure definition mismatches
  197e27c90a MdePkg: Add new 16550-compatible Serial Port Subtypes to DBG2
  fdf3666f01 MdePkg: Update DBG2 and SPCR header with NVIDIA 16550 Subtype
  b233eb1849 EmbeddedPkg/RealTimeClockRuntimeDxe: Improve GetWakeupTime
  b5379899b3 MdeModulePkg/Xhci: Fix TRT when data length is 0
  039e07f626 MdePkg/MdeModulePkg: Move AML_NAME_SEG_SIZE definition
  1f515342d8 DynamicTablesPkg: Use AML_NAME_SEG_SIZE define
  75e9154f81 OvmfPkg/VirtioMmioDeviceLib: Add EFIAPI to VirtioMmioSetQueueAddress
  c410ad4da4 MdePkg/BaseLib: Fix AsmReadSs() with GCC toolchain
  c1aa3bab12 BaseTools: Add ClangBase.lds for CLANG8 tool chain with max-page-size
  c6b872c6ab BaseTools GenFw: Support CLANG8ELF with conversion ELF to PE/COFF image
  cf9959adff BaseTools: Update build_rule to skip CLANG resource section generation
  4b56ad2049 BaseTools: Add new CLANG8ELF tool chain for new LLVM/CLANG8
  e1636fe18f BaseTools: Update ClangBase.lds to keep dynamic section
  924c2b847f BaseTools: Change CLANG8ELF to CLANGDWARF
  e25566cd2b OvmfPkg: remove the Xen drivers from the IA32, IA32X64, and X64 platforms
  aa7f19f480 OvmfPkg: remove the Xen drivers from the AmdSev platform
  7bc04a75a7 OvmfPkg: switch IA32, IA32X64, X64 to the fw_cfg-only ACPI platform driver
  d697037446 OvmfPkg: switch the AmdSev platform to the fw_cfg-only ACPI platform driver
  ae4aa4a346 OvmfPkg/README: bump minimum QEMU version to 1.7.1, machine types to 1.7
  2a85d9b07e OvmfPkg/AcpiPlatformDxe: fix header file warts
  180f1908b3 OvmfPkg/AcpiPlatformDxe: sort #includes and [LibraryClasses]
  6d1e56e715 OvmfPkg/AcpiPlatformDxe/QemuLoader.h: remove QemuFwCfgLib class dependency
  747b1ef725 OvmfPkg/AcpiPlatformDxe: move "QemuLoader.h" to IndustryStandard
  cc302b799e OvmfPkg/AcpiPlatformDxe: consolidate #includes and [LibraryClasses]
  c9bba52fc7 OvmfPkg/XenAcpiPlatformDxe: create from AcpiPlatformDxe
  a31fcb5096 OvmfPkg/AcpiPlatformDxe: remove the "AcpiPlatformDxe.inf" driver
  4115840c28 OvmfPkg/XenAcpiPlatformDxe: remove the QEMU ACPI linker/loader client
  d6ba8aa6ef OvmfPkg/XenAcpiPlatformDxe: remove QEMU fw_cfg dependency
  3f975ee570 OvmfPkg/XenAcpiPlatformDxe: remove the InstallAcpiTable() helper function
  8f8d3d90c5 OvmfPkg/XenAcpiPlatformDxe: remove OVMF's built-in ACPI tables
  4174c5c787 OvmfPkg/Bhyve/AcpiPlatformDxe: fix file path typo in comment
  d491c88a0c OvmfPkg/AcpiTables: remove unused module
  e7641171b6 OvmfPkg/OvmfXen: make "PcdPciDisableBusEnumeration" Fixed-at-Build
  3357ac7380 OvmfPkg/XenAcpiPlatformDxe: remove delayed ACPI table installation
  d06eb2d1d9 OvmfPkg/PlatformPei: remove Xen support
  8899e3fe6a OvmfPkg: drop PcdPciDisableBusEnumeration from the IA32, IA32X64, X64 DSCs
  2833589ad0 OvmfPkg: drop PcdPciDisableBusEnumeration from the AmdSev platform
  e43cca74ad OvmfPkg/Bhyve: make "PcdPciDisableBusEnumeration" Fixed-at-Build
  b005f9f1f5 OvmfPkg/OvmfXen: remove IncompatiblePciDeviceSupport DXE driver
  8c8f886f27 OvmfPkg/Bhyve: remove IncompatiblePciDeviceSupport DXE driver
  984c93ece3 OvmfPkg/IncompatiblePciDeviceSupportDxe: remove PcdPciDisableBusEnumeration
  32fef03563 OvmfPkg/PciHostBridgeLib: consolidate #includes and INF file sections
  e120c962f5 OvmfPkg/PciHostBridgeLibScan: create from PciHostBridgeLib
  c2f24ba321 OvmfPkg/Bhyve: consume PciHostBridgeLibScan
  307763c3da OvmfPkg/OvmfXen: consume PciHostBridgeLibScan
  242678da2a OvmfPkg/PciHostBridgeLib: remove Bhyve and Xen support
  33d4f3e39e OvmfPkg/PciHostBridgeLibScan: remove QEMU (fw_cfg) support
  4c81178cf0 OvmfPkg/PciHostBridgeLibScan: remove PcdOvmfHostBridgePciDevId
  8af38170b5 OvmfPkg/PciHostBridgeLibScan: clean up file names and file-top comments
  7e25086a00 OvmfPkg/SmbiosPlatformDxe: clean up #includes and INF
  5072593738 OvmfPkg/SmbiosPlatformDxe: return EFI_NOT_FOUND if there is no SMBIOS data
  4db374562f OvmfPkg/SmbiosPlatformDxe: locate SMBIOS protocol in InstallAllStructures()
  a8ab14424e OvmfPkg/SmbiosPlatformDxe: split GetXenSmbiosTables() decl. to new header
  9d84e74ca0 OvmfPkg/SmbiosPlatformDxe: declare InstallAllStructures() in header file
  d4a8aaee73 OvmfPkg/SmbiosPlatformDxe: create Xen-specific module INF file
  ce270905bf OvmfPkg/SmbiosPlatformDxe: split Xen entry point from QEMU entry point
  51adb689e1 OvmfPkg: restrict XenPlatformLib to BdsDxe in the IA32, IA32X64, X64 DSCs
  ddb3fdbef3 BaseTools GenFw: Fix regression issue to convert the image to ACPI data
  558d83ab1a OvmfPkg/README: Fix typo in README
  beb443fde0 ShellPkg: Fix typo
  702ba436ed OvmfPkg/PlatformCI: bump QEMU choco package version to 2021.5.5
  83761337ec NetworkPkg/IScsiDxe: wrap IScsiCHAP source files to 80 characters
  29cab43bb7 NetworkPkg/IScsiDxe: simplify "ISCSI_CHAP_AUTH_DATA.InChallenge" size
  95616b8661 NetworkPkg/IScsiDxe: clean up "ISCSI_CHAP_AUTH_DATA.OutChallengeLength"
  e8f28b09e6 NetworkPkg/IScsiDxe: clean up library class dependencies
  cf01b2dc8f NetworkPkg/IScsiDxe: fix potential integer overflow in IScsiBinToHex()
  d90fff40cb NetworkPkg/IScsiDxe: assert that IScsiBinToHex() always succeeds
  dc469f1371 NetworkPkg/IScsiDxe: reformat IScsiHexToBin() leading comment block
  47b76780b4 NetworkPkg/IScsiDxe: fix IScsiHexToBin() hex parsing
  54e90edaed NetworkPkg/IScsiDxe: fix IScsiHexToBin() buffer overflow
  b8649cf2a3 NetworkPkg/IScsiDxe: check IScsiHexToBin() return values
  288bd74a22 Pytool: SpellCheck: Fix incorrect file mask across package matrices
  1ad794b627 MdeModulePkg: Fix device path when boot manager menu is from different FV
  11b1c1d4b9 SecurityPkg: TcgStorageOpalLib: Initialize SupportedAttributes parameter.
  d58016b768 UefiPayloadPkg: Get platform specific logic via protocol for BDS
  d8c18ba3f4 MdeModulePkg: Add Universal Payload general definition header file
  b597b6e24c MdeModulePkg: Add new structure for the PCI Root Bridge Info Hob
  99de2e7e03 UefiPayloadPkg: UefiPayload retrieve PCI root bridge from Guid Hob
  9d53e01efe MdeModulePkg: Add new structure for the Universal Payload SMBios Table Hob
  70e8c9c3bc MdeModulePkg/Universal/SmbiosDxe: Scan for existing tables
  302a8f353c UefiPayloadPkg: Create gUniversalPayloadSmbiosTableGuid Hob
  75293330ea MdeModulePkg: Add new structure for the Universal Payload ACPI Table Hob
  761329ee27 MdeModulePkg/ACPI: Install ACPI table from HOB.
  8c0d678063 UefiPayloadPkg: Create gUniversalPayloadAcpiTableGuid Hob
  fa24b6ed26 UefiPayloadPkg: Use DynamicEx instead of Dynamic to pass PCD across binary
  c511426abe MdeModulePkg/UniversalPayload: Add definition for extra info in payload
  fe471d4a57 UefiPayloadPkg: Add PayloadLoaderPeim which can load ELF payload
  ab2b389e7a PeiCore: Remove assertion when failing to load PE image
  1b380aa603 BaseTools GenFw: Keep read only alloc section as text when convert ELF
  9cf9de668f StandaloneMmPkg: Core: Spelling error in comment
  610385fa3b ArmPlatformPkg: SpellCheck: Switch spellcheck CI to AuditOnly
  04ddd1271e ArmPkg: SpellCheck: Update valid acronyms in ExtendedWords
  cdf7544703 MdeModulePkg PciBusDxe: Increase the width of data read during oprom shadow
  2847c72fda Maintainers.txt: Add Reviewers for Universal Payload definitions
  1162ae8297 Maintainers.txt: Add reviewers for ACPI and SMBIOS modules
  a63914d3f6 ArmPkg: Move cache defs used in Universal/Smbios into ArmCache.h
  6cfeeb71c4 UefiCpuPkg/CpuCommonFeaturesLib: Correct the CPU location check
  d9a7612f8d MdeModulePkg/BdsDxe: Update BdsEntry to use Variable Policy
  5959879e92 ArmVirtPkg: Add PCIe host bridge utility lib for ArmVirtPkg
  4dda0f7ab4 ArmVirtPkg: Enable PCIe support for Kvmtool
  1e5e58d39b UefiPayloadPkg/UefiPayloadEntry: Improve bootloader memrange parsing
  7471751a4d UefiPayloadPkg/UefiPayloadEntry: Remove 4GB memory WA
  20ca528828 CryptoPkg: BaseCryptLib: Update Salt length requirement for RSA-PSS scheme.
  18b2272e4d Azurepipeline: SpellCheck: Enforce Node dependency to use version 14.x
  eba32695ee CryptoPkg/BaseCryptLib: Enabled CryptSha512 for Smm/Runtime drivers
  12e34cd2f7 OvmfPkg/Bhyve: clean up TPM_ENABLE remnants
  82f727c4af UefiPayloadPkg: Add HobLib for UniversalPayload
  ea0bd5f6a7 MdeModulePkg: Add new structure for the Universal Payload Serial Port Info
  a75c029f60 UefiPayloadPkg: Add a separate PlatformHookLib for Universal Payload
  d63595c3c9 UefiPayloadPkg: Update the function definition of HobConstructor
  0ff6de9358 UefiPayloadPkg: Create separate Payload Entry for UniversalPayload
  b208d37c73 UefiPayloadPkg: Get and enter DxeCore for Universal Payload
  27cb64fffc UefiPayloadPkg: Fix up UPL Pcd database
  6b69f73b59 UefiPayloadPkg: Include UniversalPayLoad modules in UefiPayloadPkg.dsc
  86e6948cfb UefiPayloadPkg: Remove assert when reserve MMIO/IO resource for devices
  2db0ed93ff UefiPayloadPkg: Add macro to enable and disable some drivers
  3eb72b308a UefiPayloadPkg: Add PcdInstallAcpiSdtProtocol feature in UefiPayloadPkg
  caa139fe17 UefiPayloadPkg: Add PcdResetOnMemoryTypeInformationChange in UefiPayloadPkg
  8efd912baf UefiPayloadPkg: Add new structure for BootManagerMenuFile HOB
  19a541d70e UefiPayloadPkg: consume the BootManagerMenuFile HOB
  333a866106 BaseTools: Remove check for Split.exe in toolset.bat
  f0a3f6d9c3 BaseTools: Fix spelling of "overwrite" and "overwriting" in toolset.bat
  17143c4837 BaseTools: Reset ERRORLEVEL in toolsetup.bat after edk2basetools check
  abfff7c45d BaseTools GenFw: Add support for RISCV GOT/PLT relocations
  27b8a52957 MdePkg: MmConfiguration: Move definition of EFI_MM_RESERVED_MMRAM_REGION
  d1fc3d7ef3 MdePkg: MmConfiguration: Added definition of MM Configuration PPI
  5a2e030f73 OvmfPkg/GenericQemuLoadImageLib: plug cmdline blob leak on success
  932449710c OvmfPkg/X86QemuLoadImageLib: plug cmdline blob leak on success
  24b0e9d128 Revert "OvmfPkg/QemuKernelLoaderFsDxe: don't expose kernel command line"
  cf20302474 OvmfPkg/GenericQemuLoadImageLib: Read cmdline from QemuKernelLoaderFs
  9421f5ab8d OvmfPkg/X86QemuLoadImageLib: State fw_cfg dependency in file header
  b37cfdd280 OvmfPkg/XenPlatformPei: Relocate shared_info page mapping
  55dee4947b MdePkg : Add IPMI Macro and Structure Defintions to resolve build errors
  580b11201e IntelFsp2Pkg: Add Config Editor tool support
  939ed3a592 UefiPayloadPkg/PayloadLoader: Fix bug in locating relocation section
  3cde0d553d UefiPayloadPkg/PayloadLoader: Remove assertion
  49eeda113a NetworkPkg/IScsiDxe: re-set session-level authentication state before login
  7eba9f698e NetworkPkg/IScsiDxe: add horizontal whitespace to IScsiCHAP files
  7b6c2b2a26 NetworkPkg/IScsiDxe: distinguish "maximum" and "selected" CHAP digest sizes
  903ce1d8f8 NetworkPkg/IScsiDxe: support multiple hash algorithms for CHAP
  47fea2abcb NetworkPkg/IScsiDxe: support SHA256 in CHAP
  bb33c27fbe NetworkPkg: introduce the NETWORK_ISCSI_MD5_ENABLE feature test macro
  8697dc60cc Maintainers.txt: Update Maintainers and reviewers for UefiPayloadPkg
  fea7901dba UefiPayloadPkg: Fix the build failure
  1e0c441c92 OvmfPkg/Bhyve: add USB support
  44ced03798 OvmfPkg/Bhyve: use static PCI32Base address
  b3db0cb1f8 MdeModulePkg/PartitionDxe: Ignore PMBR BootIndicator per UEFI spec
  0a6b303dce UefiCpuPkg/ExceptionLib: Conditionally clear shadow stack token busy bit
  d10e058016 MdeModulePkg/RegularExpressionDxe: Fix memory assert in FreePool()
  4c051c2c65 MdeModulePkg: Update YAML file to fix CI error
  31fcee6d99 ArmVirtPkg: Add PlatformHasAcpiDtDxe for Cloud Hypervisor
  c28fc8ab3b ArmVirtPkg: Install Acpi tables for Cloud Hypervisor
  0e3b6bd0ee ArmVirtPkg: support Cloud Hypervisor in edk2
  b560e9d9b6 IntelFsp2Pkg: PatchFv parseInfFile function modification
  f47c4676dd Pytool: SpellCheck: Defer path expansion in cspell parameters
  cc89d245f9 Maintainers.txt: remove Laszlo Ersek's entries
  84af6ea320 BaseTools/Scripts: Ignore Mergify merge commits in PatchCheck.py
  b491eace37 .mergify: Simplify Mergify rules using GitHub status checks
  5ef08a49e3 .azurepipelines: Remove FINISHED and FAILED states
  ad1009ec62 MdePkg/Include: Add STATIC_ASSERT for L'' and L"" strings
  3de3c24755 BaseTools: Remove non-ascii character of StructurePcd comment
  40a9066439 BaseTools: Enable the flag to treat dynamic pcd as dynamicEx
  22fe311bd2 .pytool/EccCheck: Locate BaseTools dir with EDK_TOOLS_PATH
  a050c599df .pytool/EccCheck: Rename edk2_path as workspace_path
  50672d2692 .pytool/EccCheck: Check ecc_csv exists
  fb5b6220a9 .pytool/EccCheck: Set PACKAGES_PATH env var in Ecc
  fda5226aa3 UefiPayloadPkg: Dump hob information from boot loader
  7d748705b1 MdeModulePkg: Change the PldHeader to Header in ExtraData.h
  9bf4aee734 UefiPayloadPkg: Assign the length of UniversalPayload ExtraData
  d0b6596b8e MdeModulePkg/RamDiskDxe: Init list head before registering RamDisk protocol
  91f5d3b410 IntelFsp2Pkg: BaseCacheLib EfiProgramMtrr MtrrNumber Should be UINT32
  be282b1493 UefiPayloadPkg: Add PCD_DYNAMIC_AS_DYNAMICEX and set to True
  cac83b6f3b IntelFsp2Pkg: Add search function for Config Editor
  4bac086e8e UefiPayloadPkg: Add FV Guid for DXEFV and PLDFV
  fddb8d24ec ArmPlatformPkg/Scripts: Infer dll load address from console output
  885efcd3f9 MdePkg/Include: Smbios Specification 3.4.0 changes
  83b43c4cb1 MdeModulePkg PCD: Print which PCD was unable to be found
  c32c5911c4 BaseTools GenFw: Add support for R_RISCV_PCREL_LO12_S relocation
  097aeeb119 MdePkg/BaseLib: Add MemoryFence implementation for RiscV64
  391cffcb61 MdeModulePkg PiSmmCore: Change MemoryAttributes message to DEBUG_VERBOSE
  8781b143de BaseTools/Scripts: Fix GetMaintainer.py line endings
  28ef05ce10 BaseTools/Scripts: Allow GitHub ID at end Maintainers.txt lines
  2f5ad3f451 Maintainers.txt: Add GitHub IDs
  332632abf3 Maintainers.txt: Add Jiewen Yao as OvmfPkg Maintainer
  4d28a1c2fd BaseTools: Remove COMMON section from the GCC discard list
  878a92a887 CryptoPkg/OpensslLib: Add native instruction support for X64
  147f34b56c CryptoPkg/OpensslLib: Commit the auto-generated assembly files for X64
  ac70e71b1f NetworkPkg: Making the HTTP IO timeout value programmable with PCD
  ab796d3e2a NetworkPkg: Add HTTP Additional Event Notifications
  b461d67639 OvmfPkg/ResetVector: move SEV specific code in a separate file
  7f05102f65 OvmfPkg/ResetVector: add the macro to invoke MSR protocol based VMGEXIT
  dc485c556d OvmfPkg/ResetVector: add the macro to request guest termination
  f05eb2dfe5 OvmfPkg/AmdSev/SecretDxe: fix header comment to generic naming
  35e267cb34 OvmfPkg/AmdSev: use GenericQemuLoadImageLib in AmdSev builds
  a26a08dc1f OvmfPkg: PlatformBootManagerLibGrub: Allow executing kernel via fw_cfg
  0cb48007f7 OvmfPkg: add library class BlobVerifierLib with null implementation
  c73e31f54d OvmfPkg: add BlobVerifierLibNull to DSC
  6bf5580a3d ArmVirtPkg: add BlobVerifierLibNull to DSC
  d10ad8444f OvmfPkg/QemuKernelLoaderFsDxe: call VerifyBlob after fetch from fw_cfg
  5ace477f34 OvmfPkg/AmdSev/SecretPei: build hob for full page
  0deeab36d1 OvmfPkg/AmdSev: reserve MEMFD space for for firmware config hashes
  385b9d80a0 OvmfPkg/AmdSev: add BlobVerifierLibSevHashes
  514b3aa08e OvmfPkg/AmdSev: Enforce hash verification of kernel blobs
  8e6bb64fe4 EmbeddedPkg/VirtualRealTimeClockLib: Fix SetTime issues
  610bcc69ed ArmVirtPkg: Remove meaningless comment
  3445058aea MdeModulePkg/CapsuleApp: Fix typo in error message
  2e1fb41339 build: Fix python3.10 threading DeprecationWarnings
  0b1b0a9674 python: Replace distutils.utils.split_quotes with shlex.split
  fc50df0d8e BaseTools: Drop check for distutils.utils
  03e77558d4 BaseTools: use shutil.copyfile instead shutil.copy2
  2b47aaecef MdeModulePkg: Add BootDiscoveryPolicyUiLib.
  bb806a6e88 SecurityPkg: Create SecureBootVariableLib.
  9732659698 SecurityPkg: Create library for enrolling Secure Boot variables.
  12a4d0cb9d ArmVirtPkg: add SecureBootVariableLib class resolution
  3d427c5f83 OvmfPkg: add SecureBootVariableLib class resolution
  b926956418 EmulatorPkg: add SecureBootVariableLib class resolution
  db959018b6 SecurityPkg: Remove duplicated functions from SecureBootConfigDxe.
  a97e9e327e ArmPlatformPkg: Create include file for default key content.
  94e065582b SecurityPkg: Add SecureBootDefaultKeysDxe driver
  19107590b6 SecurityPkg: Add EnrollFromDefaultKeys application.
  45f3dd2ce9 SecurityPkg: Add new modules to Security package.
  55266a9b8a SecurityPkg: Add option to reset secure boot keys.
  6355287206 Maintainers.txt: Add new maintainer and reviewer to EmbeddedPkg/
  9abc60f9f7 EmbeddedPkg/libfdt: Add strcmp and strncpy to libfdt_env.h
  0856cdc89e MdePkg: add definition of LINUX_EFI_INITRD_MEDIA_GUID
  97fdcbda4e OvmfPkg: Remove Initrd LINUX_EFI_INITRD_MEDIA_GUID
  4de77ae989 UefiCpuPkg/CpuCacheInfoLib: Sort CpuCacheInfo array
  3c6107758b SecurityPkg: Fix GetSupportedAndActivePcrs counter calculation
  b40bdd6ecd UefiPayloadPkg: Add Fixed PCDs and use Macro to define the default value.
  d497eace3b UefiPayloadPkg: define some PCD as DynamicEX PCD
  ac6e5d6b41 UefiPayloadPkg: change the default value of some PCDs.
  672bd1c711 UefiPayloadPkg: Add a macro to enable or diable the serial driver.
  d02dbb53cd UefiPayloadPkg: Fix the non-ascii character in UniversalPayloadEntry.c
  a7ddc7847c RedfishPkg/JsonLib: Add more JsonLib functions
  5963ce5d28 MdePkg: Add ACPI 6.4 header file
  4d7137f261 MdePkg: Increment FADT version
  d910e83299 MdePkg: Rename SBSA Generic Watchdog to Arm Generic Watchdog
  ad3dea9861 MdePkg: Update PMTT to ACPI 6.4
  ced4cb7609 MdePkg: Add SPA Location Cookie field to SPA Range structure
  c82d6dd4a3 MdePkg: Remove DPPT table
  357383bc4f MdePkg: Add flags and MinTransferSize to Generic Initiator
  7b17bcd9a0 MdePkg: Add 'Type 5' PCC structure
  0938f9235c MdePkg: Add Multiprocessor Wakeup structure
  75c4a8e10d MdePkg: Add the Platform Health Assessment Table (PHAT)
  1803757a9b MdePkg: Add Secure Access Components in the SDEV table
  605c4a1ff2 MdePkg: Add Cache ID to PPTT
  3d359ff905 MdePkg: Fix broken coding style in Acpi64.h
  7311e96417 RedfishPkg/RefishCrtLib: Public RefishCrtLib
  03e19e6bc8 ArmPkg/IndustryStandard: 32b/64b agnostic FF-A, Mm SVC and Std SMC IDs
  aee0098faf ArmPkg: prepare 32bit ARM build of StandaloneMmPkg
  ca1773878d GenFv: Arm: support images entered in Thumb mode
  b7f0226a46 StandaloneMmPkg: fix pointer/int casts against 32bit architectures
  a776bbabd9 StandaloneMmPkg: build for 32bit arm machines
  ac826886c9 MdeModulePkg/UefiSortLib:Add UefiSortLib unit test
  6fdd1c13a7 MdeModulePkg PCD: Reinstall PCD service PPIS when memory available
  ef56f55d19 EmbeddedPkg/NonCoherentDmaLib: Avoid dereferencing unset Map field
  8dd4fc5be6 UefiCpuPkg/CpuCacheInfoLib: Correct logical for identifying cache type
  7b4a99be8a CryptoPkg: BaseCryptLib fix incorrect param order
  - Removed patches which are merged to mainline:
  ovmf-bsc1186151-fix-iscsi-overflows.patch
  ovmf-xen-relocate-shared_info_page-map.patch
  - Updated patches
  ovmf-fix-xen-s3-detection.patch -> ovmf-OvmfPkg-OvmfXen-set-PcdAcpiS3Enable-at-initializatio.patch
  ovmf-xen-add-qemu-kernel-loader-fs.patch -> ovmf-OvmfPkg-OvmfXen-add-QemuKernelLoaderFsDxe.patch
  - Added patches
  ovmf-OvmfPkg-OvmfXen-Fix-build-with-QemuKernelLoaderFsDxe.patch
* Fri Jul  9 2021 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-fix-xen-s3-detection.patch to fix the S3 detection in
  ovmf-xen
- Add ovmf-xen-add-qemu-kernel-loader-fs.patch to add
  QemuKernelLoaderFsDxe to ovmf-xen to load kernel from qemu fw_cfg
* Fri Jul  2 2021 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-xen-relocate-shared_info_page-map.patch to fix the
  save/restore/migrate in ovmf-xen
* Wed Jun  9 2021 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-bsc1186151-fix-iscsi-overflows.patch to fix the possible
  overflows in IScsiDxe (bsc#1186151)
* Thu Jun  3 2021 Gary Ching-Pang Lin <glin@suse.com>
- Correct the path to copy the Xen flavor
* Mon May 31 2021 Gary Ching-Pang Lin <glin@suse.com>
- Update to edk2-stable202105
  * MdeModulePkg/UfsPassThruDxe: Improve Device initialization
    polling Loop
  * MdePkg: MmUnblockMemoryLib: Added definition and null instance
  * OvmfPkg: resolve MmUnblockMemoryLib (mainly for
    VariableSmmRuntimeDxe)
  * MdeModulePkg: VariableSmmRuntimeDxe: Added request unblock
    memory interface
  * SecurityPkg: Tcg2Smm: Switching from gSmst to gMmst
  * SecurityPkg: Tcg2Smm: Separate Tcg2Smm into 2 modules
  * SecurityPkg: Tcg2Smm: Added support for Standalone Mm
  * SecurityPkg: Tcg2Acpi: Added unblock memory interface for NVS
    region
  * UefiCpuPkg/MpInitLib: Use NASM struc to avoid hardcode offset
  * UefiCpuPkg/MpInitLib: Remove unused Lock from
    MP_CPU_EXCHANGE_INFO
  * UefiCpuPkg/SmmCpuFeaturesLib: Move multi-instance function decl
    to header
  * UefiCpuPkg/SmmCpuFeaturesLib: Rename SmmCpuFeaturesLib.c
  * UefiCpuPkg/SmmCpuFeaturesLib: Cleanup library constructors
  * UefiCpuPkg/SmmCpuFeaturesLib: Abstract PcdCpuMaxLogicalProcessorNumber
  * UefiCpuPkg/SmmCpuFeaturesLib: Add Standalone MM support
  * UefiCpuPkg/PiSmmCpu: Don't allocate Token for SmmStartupThisAp
  * RedfishPkg/Library: RedfishLib
  * OvmfPkg/CpuHotplugSmm: refactor hotplug logic
  * OvmfPkg/CpuHotplugSmm: collect hot-unplug events
  * OvmfPkg/CpuHotplugSmm: add Qemu Cpu Status helper
  * OvmfPkg/CpuHotplugSmm: introduce UnplugCpus()
  * OvmfPkg: define CPU_HOT_EJECT_DATA
  * OvmfPkg/SmmCpuFeaturesLib: init CPU ejection state
  * OvmfPkg/SmmCpuFeaturesLib: call CPU hot-eject handler
  * OvmfPkg/CpuHotplugSmm: add EjectCpu()
  * OvmfPkg/CpuHotplugSmm: do actual CPU hot-eject
  * OvmfPkg/SmmControl2Dxe: negotiate CPU hot-unplug
  * EmbeddedPkg/PrePiHobLib: replace duplicate GUID
  * MdePkg/UefiLib: Correct the arguments passed to
    IsLanguageSupported()
  * UefiCpuPkg/CpuCacheInfoLib: Collect cache associative type
  * UefiCpuPkg/MpInitLib: avoid printing debug messages in AP
  * UefiCpuPkg/CpuDxe: Rename variables to follow EDKII coding
    standard
  * UefiCpuPkg/CpuDxe: Guarantee GDT is below 4GB
  * BaseTools/Ecc: Make Ecc only check first include guard
  * ShellPkg/SmbiosView: add more items for smbiosview -t 3
  * MdePkg: Support standalone MM Driver Unload capability
  * OvmfPkg/X86QemuLoadImageLib: Handle allocation failure for
    CommandLine
  * ShellPkg/Pci: Add valid check for PCI extended config space
    parser
  * CryptoPkg/OpensslLib: Upgrade OpenSSL to 1.1.1j
  * OvmfPkg: strip build paths in release builds
  * MdeModulePkg: Initialize local variable value before they are
    used
  * UefiCpuPkg/SmmCommunication: Remove out-dated comments
  * MdePkg: use CpuPause() in CpuDeadLoop()
  * MdePkg/Include: EFI Redfish Discover protocol
  * ShellPkg/UefiHandleParsingLib: Support EFI Redfish protocols
  * MdePkg/Include/Protocol: EFI_HII POPUP_PROTOCOL duplicate
    declaration
  * MdePkg/Include/Protocol: EFI_RESET_NOTIFICATION_PROTOCOL
    duplicate
  * CryptoPkg/Private/Protocol/Crypto.h: Remove duplicate function
    type
  * MdePkg/BaseLib: Add support for the XSETBV instruction
  * MdeModulePkg/PiDxeS3BootScriptLib: Rename mAcpiS3Enable to
    avoid dup symbol
  * MdePkg/IoLib: Filter/trace port IO/MMIO access
  * MdePkg/Baseib: Filter/trace MSR access for IA32/X64
  * UefiCpuPkg: Remove PEI/DXE instances of CpuTimerLib.
  * UefiCpuPkg: Add MicrocodeLib for loading microcode
  * OvmfPkg: Add MicrocodeLib in DSC files.
  * UefiPayloadPkg/UefiPayloadPkg.dsc: Consume MicrocodeLib
  * UefiCpuPkg/MpInitLib: Consume MicrocodeLib to remove duplicated
    code
  * UefiCpuPkg/PiSmmCpuDxeSmm: Support detect SMM shadow stack
    overflow
  * ShellPkg: Fix smbiosview system enclosure type table
  * UefiCpuPkg/CpuTimerLib: Update LIBRARY_CLASS of Base instance.
  * RedfishPkg/RedfishDiscoverDxe: EFI Redfish Discover Protocol
  * RedfishPkg/RedfishConfigHandler: EDKII RedfishConfigHandler
    Protocol
  * UefiCpuPkg: PiSmmCpuDxeSmm: Check buffer size before accessing
  * BaseTools/Conf: Fix MAKE_FLAGS typos in tools_def.template
  * MdeModulePkg: Initialize temp variable in VarCheckPolicyLib
  * SecurityPkg/Tcg2Smm: Initialize local Status variable
  * DynamicTablesPkg: add validation for PcdNonBsaCompliant16550SerialHid
  * OvmfPkg/XenResetVector: Silent a warning from nasm
  * MdePkg: Allow PcdFSBClock to by Dynamic
  * OvmfPkg/IndustryStandard/Xen: Apply EDK2 coding style to
    XEN_VCPU_TIME_INFO
  * OvmfPkg/IndustryStandard: Introduce PageTable.h
  * OvmfPkg/XenPlatformPei: Map extra physical address
  * OvmfPkg/XenPlatformPei: Calibrate APIC timer frequency
  * OvmfPkg/OvmfXen: Set PcdFSBClock
  * DynamicTablesPkg: Re-order GicItsIdentifierArray struct
  * DynamicTablesPkg: Remove EArmObjExtendedInterruptInfo
  * MdePkg: Fix AsmReadMsr64() and AsmWriteMsr64() with GCC
    toolchain
  * BaseTools/PlatformAutoGen: MAKE_FLAGS and MAKE_PATH fixes
  * RedfishPkg/RestJsonStructureDxe: Fix typo in function header
  * MdePkg/Include: Allow CPU specific defines to be predefined
  * CryptoPkg/Library/Include: Allow CPU specific defines to be
    predefined
  * ArmPlatformPkg: Fix Ecc error 8001
  * ArmPlatformPkg: Fix Ecc error 9001
  * ArmPlatformPkg: Remove package dependency in
    NorFlashStandaloneMm
  * ArmPkg: Fix Ecc error 8001 in Chipset
  * ArmPkg: Fix Ecc error 8001 in SemihostLib
  * ArmPkg: Fix Ecc error 8001 in ArmArchTimerLib
  * ArmPkg: Fix Ecc error 9005 in CpuDxe
  * ArmPkg: Fix Ecc error 10006 in ArmPkg.dsc
  * ArmPkg: Fix Ecc error 10016 in StandaloneMmMmuLib
  * ArmPkg: Fix Ecc error 10014 in ArmScmiDxe
  * ArmPkg: Fix Ecc error 10014 in GenericWatchdogDxe
  * ArmPkg: Fix Ecc error 10014 in MmCommunicationDxe
  * ArmPkg: Fix Ecc error 10014 in SemihostLib
  * ArmPkg: Remove ArmGic/ArmGicSecLib.c
  * ArmPkg: Fix Ecc error 5003 in ArmExceptionLib
  * ArmPkg: Fix Ecc error 6001 in MmCommunicationDxe
  * ArmPkg: Fix Ecc error 6001 in ArmSoftFloatLib
  * ArmPkg: Rename include guard in ArmGicLib.h
  * ArmPkg: Fix Ecc error 7008 for SCMI_CLOCK_RATE
  * ArmPkg: Fix Ecc error 7008 for OPTEE_MESSAGE_PARAM
  * ArmPkg: Fix Ecc error 8005/8007 in ArmDisassemblerLib
  * ArmPkg: Fix Ecc error 8005 for SCMI_PROTOCOL_ID
  * ArmPkg: Fix Ecc error 8005 for SCMI_MESSAGE_TYPE
  * ArmPkg: Fix Ecc error 8005 for SCMI_STATUS
  * ArmPkg: Fix Ecc error 8005 for SCMI_MESSAGE_ID
  * ArmPkg: Fix Ecc error 8005 for SCMI_MESSAGE_ID_BASE
  * ArmPkg: Fix Ecc error 8005 for SCMI_MESSAGE_ID_CLOCK
  * ArmPkg: Fix Ecc error 8005 for SCMI_CLOCK_RATE_FORMAT
  * ArmPkg: Fix Ecc error 8005 for SCMI_MESSAGE_ID_PERFORMANCE
  * RedfishPkg: Add EDK2 Redfish Foundation diagrams
  * SecurityPkg/FvReportPei: remove redundant sizeof
  * ShellPkg: Rename Address Size to Access size
  * DynamicTablesPkg: Add access size to CM_ARM_SERIAL_PORT_INFO
  * DynamicTablesPkg: Set the Access size for the SPCR table
  * DynamicTablesPkg: Set the Access size for the DBG2 table
  * UefiCpuPkg: PiSmmCpuDxeSmm: Not to Change Bitwidth During
    Static Paging
  * MdePkg/Cpuid.h: Define new element in CPUID Leaf(07h) data
    structure.
  * SecurityPkg: Add constraints on PK strength
  * ArmPkg: Allow platforms to supply more data for SMBIOS Type3
    record
  * ArmPkg: Allow platforms to report their boot status via
    OemMiscLib call
  * ArmPkg: Fix calculation of offset of chassis SKU Number in
    SmbiosMiscDxe
  * ArmPkg: Fix typo of Manufacturer in comment in SmbiosMiscDxe
  * ArmPkg: Fix Ecc error 8003
  * ArmPkg: Fix Ecc error 3002 in StandaloneMmMmuLib
  * ArmPkg: Add missing library headers to ArmPkg.dec
  * ArmPlatformPkg: Document libraries in ArmPlatformPkg.dec
  * ArmPkg: Add OemMiscLibNull library to ArmPkg.dsc
  * ArmPkg: Correct small typos
  * ArmPlatformPkg: Add ArmPlatformPkg.ci.yaml
  * OvfmPkg/VmgExitLib: Properly decode MMIO MOVZX and MOVSX
    opcodes
  * OvmfPkg/VmgExitLib: Add support for new MMIO MOV opcodes
  * OvmfPkg: Define a new PPI GUID to signal TPM MMIO accessability
  * OvmfPkg/TpmMmioSevDecryptPei: Mark TPM MMIO range as
    unencrypted for SEV-ES
  * OvmfPkg/Tcg2ConfigPei: Update Depex for IA32 and X64
  * ArmPkg: Update SCMI Base Protocol version to 0x20000
  * MdePkg/BaseRngLib: Add support for ARMv8.5 RNG instructions
  * SecurityPkg: Add support for RngDxe on AARCH64
  * UefiCpuPkg/MpInitLib: Properly cast from PCD to SEV-ES jump
    table pointer
  * BaseTools: Add support for version 3 of FMP Image Header
    structure
  * CryptoPkg: BaseCryptLib: Add RSA PSS verify support
  * ShellPkg/UefiShellCommandLib: suppress incorrect gcc warning
  * OvmfPkg/VirtioFsDxe: suppress incorrect gcc warnings
  * UefiCpuPkg/CpuExceptionHandler: Add missing comma to exception
    name array
  * UefiCpuPkg/PiSmmCpu: Remove hardcode 48 address size limitation
  * MdeModulePkg: Retrieve boot manager menu from any fv
  * ShellPkg/HttpDynamicCommand: Fix possible uninitialized use
  * MdeModulePkg/PciBusDxe: Fix possible uninitialized use
  * CryptoPkg/BaseCryptLib: Fix possible uninitialized use
  * MdeModulePkg/PlatformDriOverrideDxe: Fix overflow condition
    check
  * MdeModulePkg/VariableLock: downgrade compatibility warnings to
    DEBUG_WARN
  * ArmPkg/ArmGic: Fix maximum number of interrupts in GICv3
- Update openssl to 1.1.1j
- Drop upstreamed patch: ovmf-bsc1184801-fix-sev-with-tpm.patch
- Add the new Xen flavor for x86_64
  + Update 50-xen-hvm-x86_64.json to use ovmf-x86_64-xen-4m.bin as
    the default firmware for Xen
* Tue May  4 2021 Gary Ching-Pang Lin <glin@suse.com>
- Update the descriptors to add "acpi-s4" tag to allow libvirt
  enable hibernation (bsc#1182886#c31)
* Mon May  3 2021 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-bsc1184801-fix-sev-with-tpm.patch to fix SEV-ES guest
  crash with TPM (bsc#1184801)
* Mon Apr 19 2021 Gary Ching-Pang Lin <glin@suse.com>
- Build ovmf-x86_64-smm against Ia32X64 to enable S3 support
  (bsc#1184938)
- Update ovmf-add-exclude-shell-flag.patch to include Ia32X64
* Tue Apr  6 2021 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-disable-brotli.patch to remove brotli since there is no
  real user and it requires extra effort to maintain the brotli
  submodule tarball
  + Drop ovmf-bsc1183713-fix-gcc10-brotli-errors.patch and
    brotli-v1.0.7-17-g666c328-c.tar.xz
* Fri Mar 26 2021 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-bsc1183713-fix-gcc10-brotli-errors.patch to fix the
  gcc10 error from brotli (bsc#1183713)
* Thu Mar 11 2021 Gary Ching-Pang Lin <glin@suse.com>
- Update to edk2-stable202102
  * ArmVirtPkg: support extra pci root bridges (pxb)
  * SEV Encrypted Boot for Ovmf (remote attestation)
  * virtio-fs driver for OvmfPkg and ArmVirtPkg
  * Apply SEV-ES mitigations for encryption bit position and MMIO
  * Add Core CI support for StandaloneMmPkg
  * Update LZMA module to LZMA SDK latest version 19.00
  * Port open source JSON library (jansson)
  * add file buffering to the UEFI shell's COMP command
  * Shell: pathname / filename sorting
  * Extend support of peripheral x64 MM_STANDALONE drivers
  * BaseTools: Convert the Split tool from C language to Python
  * ArmPkg: Add Universal/Smbios
  * Move to Pip based Basetools python
  * Add support for use of FF-A callsw
- Drop upstreamed patches:
  + ovmf-jscSLE-16075-SEV-ES-use-physical-address.patch
  + ovmf-bsc1180079-amd-sev-es-mitigation.patch
* Thu Jan 28 2021 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-jscSLE-16075-SEV-ES-use-physical-address.patch as the
  follow-up patch for SEV-ES to fix the flash writing
  (jsc#SLE-16075)
- Update 50-xen-hvm-x86_64.json to add "nvram-template" and change
  the firmware file to ovmf-x86_64-ms-4m.bin
  (bsc#1180050, bsc#1181264)
- Refresh ovmf-bsc1180079-amd-sev-es-mitigation.patch
  + Use "git format-patch --no-renames" to generate the patch to
    avoid confusing quilt with the renamed files
* Mon Jan 11 2021 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-bsc1180079-amd-sev-es-mitigation.patch to mitigate the
  potential AMD SEV-ES security issues (bsc#1180079)
- Add the json descriptor for xen-hvm (bsc#1180050)
* Fri Nov 27 2020 Gary Ching-Pang Lin <glin@suse.com>
- Update to edk2-stable202011
  * MdeModulePkg/VariablePolicyLib: Fix runtime panic in
    ValidateSetVariable()
  * CryptoPkg: BaseCryptLib: Fix buffer double free in
    CryptPkcs7VerifyEku
  * Revert "SecurityPkg: Add RPMC Index to the RpmcLib"
  * MdeModulePkg/LzmaCustomDecompressLib: catch 4GB+ uncompressed
    buffer sizes (bsc#1183578, CVE-2021-28211)
  * MdeModulePkg/Core/Dxe: limit FwVol encapsulation section
    recursion (bsc#1183579, CVE-2021-28210)
  * MdeModulePkg/Core/Dxe: assert SectionInstance invariant in
    FindChildNode() (bsc#1183579, CVE-2021-28210)
  * SecurityPkg: Add RPMC Index to the RpmcLib
  * BaseTools: Resolve index out of range errors.
  * UefiCpuPkg/PiSmmCpuDxeSmm: Reflect page table depth with page
    table address
  * UefiCpuPkg/PiSmmCpuDxeSmm: Correct the Cr3 typo
  * CryptoPkg: Make the MD5 disable as default for security
  * NetworkPkg/Defines: Make iSCSI disable as default
  * OvmfPkg/OvmfXen.dsc: Enable MD5 while enable iSCSI
  * OvmfPkg/OvmfPkgX64.dsc: Enable MD5 while enable iSCSI
  * OvmfPkg/OvmfPkgIa32X64.dsc: Enable MD5 while enable iSCSI
  * OvmfPkg/OvmfPkgIa32.dsc: Enable MD5 while enable iSCSI
  * ArmVirtPkg/ArmVirtQemuKernel.dsc: Enable MD5 while enable iSCSI
  * ArmVirtPkg/ArmVirtQemu.dsc: Enable MD5 while enable iSCSI
  * NetworkPkg: Enable MD5 while enable iSCSI
  * CryptoPkg/dsc: Enable MD5 when CRYPTO_SERVICES enable MD5
  * SecurityPkg/Hash2DxeCrypto: Remove SHA1 support
  * SecurityPkg/Hash2DxeCrypto: Remove MD5 support
  * MdeModulePkg: Drop VarLock from RuntimeDxe variable driver
  * MdeModulePkg: Change TCG MOR variables to use VariablePolicy
  * SecurityPkg: Allow VariablePolicy state to delete authenticated
    variables
  * MdeModulePkg: Allow VariablePolicy state to delete protected
    variables
  * MdeModulePkg: Connect VariablePolicy business logic to
    VariableServices
  * ArmVirtPkg: Add VariablePolicy engine to ArmVirtPkg platform
  * OvmfPkg: Add VariablePolicy engine to OvmfPkg platform
  * BaseTools: Fix BrotliCompress tool issue
  * MdePkg/BaseRngLibDxe: Add DXE_RUNTIME_DRIVER class to RngLib
  * MdeModulePkg DisplayEngineDxe: Correct the local variable name.
  * MdeModulePkg/AtaAtapiPassThru: Trace ATA packets
  * MdeModulePkg/AtaAtapiPassThru: Restart failed packets
  * MdeModulePkg/AtaAtapiPassThru: Add SATA error recovery flow
  * MdeModulePkg/AtaAtapiPassThru: Check IS to check for command
    completion
  * MdeModulePkg/DriverSampleDxe: Add HII sample options
  * MdeModulePkg/Library: Revise HiiLib to check REST_STYLE
  * BaseTools/VfrCompile: VFR compiler supports REST_STYLE in HII
    option
  * MdePkg: Add GUID for REST Style Formset
  * UefiCpuPkg/MpInitLib: For SEV-ES guest, set stack based on
    processor number
  * UefiCpuPkg, OvmfPkg: Disable interrupts when using the GHCB
  * OvmfPkg/QemuFlashFvbServicesRuntimeDxe: Fix erase blocks for
    SEV-ES
  * OvmfPkg/QemuFlashFvbServicesRuntimeDxe: Set the SwScratch valid
    bit
  * UefiCpuPkg/MpInitLib: Set the SW exit fields when performing
    VMGEXIT
  * OvmfPkg/VmgExitLib: Set the SwScratch valid bit for MMIO events
  * OvmfPkg/VmgExitLib: Set the SwScratch valid bit for IOIO events
  * OvmfPkg/VmgExitLib: Set the SW exit fields when performing
    VMGEXIT
  * OvmfPkg/VmgExitLib: Implement new VmgExitLib interfaces
  * UefiCpuPkg/VmgExitLib: Add interfaces to set/read GHCB
    ValidBitmap bits
  * MdePkg: Clean up GHCB field offsets and save area
  * BaseTools: Limit command line length.
  * BaseTools: Update report map file format
  * BaseTools: Add image type into generate map file
  * BaseTools: Incremental build issue for included ASI file's
    deletion.
  * MdeModulePkg/Core/Dxe: log memory base and length, after lib
    ctors again
  * BaseTools: Fix BaseTools nmake cleanall hang issue
  * ShellPkg:Fix bug in FileBuffer.c
  * BaseTools: Enable Module Scope Structure Pcd
  * MdeModulePkg/Gcd: Check memory allocation when initializing
    memory
  * BaseTools: Remove the dependency on the build intermediate file
  * DynamicTablesPkg: Add SSDT CMN-600 Table generator
  * MdePkg: Definitions for Extended Interrupt Flags
  * BaseTools: Update the FV Space Information to display decimal
    and Hex
  * MdePkg/Include: Definitions of EFI REST JSON Structure Protocol
  * MdeModulePkg/XhciDxe: Retry device slot init on failure
  * MdeModulePkg/AcpiTableDxe: use pool allocation for RSDP if
    possible
  * MdeModulePkg/AcpiTableDxe: use pool allocation for RSDT/XSDT
    if possible
  * MdeModulePkg/AcpiTableDxe: use pool allocations when possible
  * MdePkg: Fix SmBios.h PROCESSOR_CHARACTERISTIC_FLAGS to be
    UINT16
  * MdePkg: Update SmBios.h to add SMBIOS 3.4.0 ARM64 SoC ID field
  * ShellPkg: Add ARM64 SoC ID to Processor Characteristics in
    smbiosview
  * ShellPkg: Fix smbiosview string definition name for "boot from CD"
  * ShellPkg: Fix a couple of typos in smbiosview
  * MdeModulePkg/Core: Support standalone MM in FV2 protocol
    GetNextFile().
  * MdePkg/SystemResourceTable.h: Add vendor range values
  * MdePkg/Include: Fix wrong spelling in http11.h
  * BaseTools/Ecc: Fix ECC check MetaFile Copyright information
    issue
  * MdeModulePkg/XhciDxe: Error handle for USB slot initialization
    failure
  * ArmPkg/ArmMmuLib: Explicitly cast function pointer argument
  * ArmPkg/ArmMmuLib: Explicitly cast UINT32 data conversions
  * DynamicTablesPkg: SsdtSerialPortFixupLib fix ECC errors
  * DynamicTablesPkg: AmlEncoding change debug macro
  * DynamicTablesPkg: AmlLib\AmlDbgPrint fix ECC error
  * DynamicTablesPkg: AmlLib fix ECC errors
  * DynamicTablesPkg: AcpiSratLibArm fix ECC error
  * DynamicTablesPkg: SsdtSerialPortLibArm fix ECC error
  * DynamicTablesPkg: Fix order of assert checks
  * CryptoPkg/BaseCryptLib: fix NULL dereference (CVE-2019-14584)
    (bsc#1177789)
  * Revert "MdeModulePkg/PartitionDxe: Fix the incorrect LBA size
    in child ..."
  * UefiCpuPkg/MpInitLib: Reduce reset vector memory pressure
  * SecurityPkg/Tcg2PhysicalPresenceLib: Fix incorrect TCG VER
    comparision
  * CryptoPkg: BaseCryptLib: Add unit tests (Host and Shell based)
  * ArmVirtPkg: Add kvmtool to package dictionary
  * ArmVirtPkg: Package dependency for MC146818 RTC
  * ArmVirtPkg: Support for kvmtool virtual platform
  * ArmVirtPkg: Add Kvmtool Platform Pei Lib
  * ArmVirtPkg: 16550 UART Platform hook library
  * ArmVirtPkg: GUID Hob for 16550 UART base address
  * MdeModulePkg: Fix constructor invocation ordering
  * ArmVirtPkg: Add Kvmtool NOR flash lib
  * ArmVirtPkg: kvmtool platform memory map
  * ArmVirtPkg: Add kvmtool platform driver
  * ArmPlatformPkg: Dynamic flash variable base
  * ArmVirtPkg: Add Kvmtool RTC Fdt Client Library
  * PcAtChipsetPkg: Add MMIO Support to RTC driver
  * MdePkg/Include: Add HTTP definitions
  * BaseMemoryLibSse2: Take advantage of write combining buffers
  * RedfishPkg/Include: PCD definitions of Host Interface EFI
    device path
  * MdePkg/Include: Definitions of EFI REST EX Protocol
  * ShellPkg/SmbiosView: Add DDR5 support
  * MdePkg/BaseLib: Fix invalid memory access in AArch64
    SetJump/LongJump
  * BaseTools: Add EDKII_DSC_PLATFORM_GUID MACRO
  * MdeModulePkg: Remove code wrapped by
    DISABLE_NEW_DEPRECATED_INTERFACES
  * MdePkg: Remove code wrapped by
    DISABLE_NEW_DEPRECATED_INTERFACES
  * BaseTools Build_Rule: Add the missing ASM16_FLAGS for ASM16
    source file
  * BaseTools: Move C tool flags before the common flags
  * BaseTools: Copy PACKED definition from MdePkg Base.h
  * MdeModulePkg/Core/Dxe: expose SP and CRYPTO capabilities in
    UEFI memmap
  * MdePkg/UefiSpec: separate page access bitmask from SP and
    CRYPTO caps
  * MdePkg: SMBIOS 3.4.0 Update "adding DDR5 definitions".
  * NetworkPkg: Fix possible infinite loop in HTTP msg body
    parser
  * NetworkPkg/HttpDxe: TlsChildHandle is not cleared when reset
  * NetworkPkg: Add RngLib entry to .dsc file.
  * MdeModulePkg/HiiDatabase: Do not modify CONST string
  * OvmfPkg: enable HttpDynamicCommand
  * ArmVirtPkg: enable HttpDynamiCommand
  * ShellPkg/DynamicCommand: add HttpDynamicCommand
  * CryptoPkg/BaseCryptLib: add crypto algorithms needed by
    variable protection
  * BaseTools: Add RISCV64 binding
  * MdeModulePkg/XhciDxe: Fix Broken Timeouts
  * BaseTools: Set section alignment as zero if its type is Auto
  * BaseTools: Remove CanSkip calling for incremental build
  * BaseTools: Normalize case of pathname when evaluating Macros.
  * BaseTools: Clean the ffs folder before generating files in it
  * BaseTools: Add included files to deps_target file.
  * OvmfPkg/README: HTTPS Boot: describe host-side TLS cipher
    suites forwarding
  * MdeModulePkg/NonDiscoverablePciDeviceDxe: Add NULL pointer
    check
  * CryptoPkg: OpensslLib: Use RngLib to generate entropy in
    rand_pool
  * ArmVirtPkg: Add RngLib based on TimerLib for CryptoPkg
  * OvmfPkg: Add RngLib based on TimerLib for Crypto
  * MdePkg: BaseRngLibDxe: Add RngLib that uses RngDxe
  * MdePkg: TimerRngLib: Added RngLib that uses TimerLib
  * MdePkg: Correct EFI_BLOCK_IO_PROTOCOL_REVISION3 value
  * OvmfPkg: drop redundant VendorID check in VirtioMmioDeviceLib
  * MdePkg: PciExpressLib support variable size MMCONF
  * UefiPayloadPkg: Store the size of the MMCONF window
  * SecurityPkg/PeiTpmMeasurementLib: remove
    gEfiTpmDeviceSelectedGuid
  * BaseTools: update IASL extdep to more modern version
  * UefiCpuPkg/RegisterCpuFeaturesLib: Support MpServices2 only
    case.
  * BaseTools: Sort the Pcd set when generating the VPD binary
  * SecurityPkg/DxeImageVerificationLib: Disable SHA1 base on MACRO
- Refresh ovmf-add-exclude-shell-flag.patch
- Drop upstreamed ovmf-jscSLE-16075-SEV-ES-fixes.patch
* Thu Nov 26 2020 Gary Ching-Pang Lin <glin@suse.com>
- Cosmetic changes in the spec file suggested by spec-cleaner
* Tue Nov 17 2020 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-jscSLE-16075-SEV-ES-fixes.patch to merge upstream SEV-ES
  fixes (jsc#SLE-16075)
* Thu Nov  5 2020 Gary Ching-Pang Lin <glin@suse.com>
- Update the json descriptors to address all x86_64 firmware files
  (jsc#SLE-15915)
- Remove the executable bit from brotli source code files
* Fri Oct 30 2020 Gary Ching-Pang Lin <glin@suse.com>
- Add _constraints to request at least 6GB disk (bsc#1178244)
- Remove the build files after finishing the build to reduce the
  disk usage (bsc#1178244)
* Mon Sep  7 2020 Gary Ching-Pang Lin <glin@suse.com>
- Update to edk2-stable202008
  + MdeModulePkg/Library: add PEIM and SEC module type to
    TpmMeasurementLibNull
  + SecurityPkg/DxeImageVerificationLib: catch alignment overflow
    (CVE-2019-14562) (bsc#1175476)
  + OvmfPkg/CpuHotplugSmm: fix CPU hotplug race before and after
    SMI broadcast
  + SecurityPkg/Tcg2: handle PRE HASH and LOG ONLY
  + MdePkg/Include: Add missing definition of SMBIOS type 42h in
    SmBios.h
  + MdePkg: UefiFileHandleLib: fix buffer overrun in
    FileHandleReadLine()
  + OvmfPkg: Add SEV-ES support
  + MdeModulePkg/PartitionDxe: Fix the incorrect LBA size in child
    hander
  + MdeModulePkg/PartitionDxe: Revert changes for the special MBR
  + MdeModulePkg/PartitionDxe: Put the UDF check ahead of MBR
  + ShellPkg: smbiosview - Change some type 17 field values format
  + CryptoPkg/OpensslLib: Upgrade OpenSSL to 1.1.1g
  + MdeModulePkg: Upon BootOption failure, Destroy RamDisk memory
    before RSC.
  + OvmfPkg/LsiScsiDxe: Add support for LSI 53C895A
  + MdeModulePkg/DisplayEngine: Add Debug message to show mismatch
    menu info
  + Add New Memory Attributes
  + MdeModulePkg/PartitionDxe: Add already start check for child
    hanldes
  + MdeModulePkg/PartitionDxe: Skip the MBR that add for CD-ROM
  + MdeModulePkg/PartitionDxe: Correct the MBR last block value
  + MdeModulePkg/Variable/RuntimeDxe: Fix return status from
    Reclaim()
  + SecurityPkg/Tcg2Pei: Add missing PCRIndex in FvBlob event.
  + SecurityPkg/Tcg2Dxe: Add PcdTcgPfpMeasurementRevision in
    SpecId event.
  + CryptoPkg/BaseCryptLib: Add MARCO to disable the deprecated
    SHA1 and MD5
  + ArmVirtPkg/NorFlashQemuLib: disable NOR flash DT nodes upon
    discovery
  + UefiCpuPkg/SecCore: Add pre-memory AP vector
  + OvmfPkg: End timer interrupt later to avoid stack overflow
    under load
  + ArmPkg/PlatformBootManagerLib: regenerate boot options on
    boot failure
  + MdeModulePkg/StatusCodeHandler: do not output \n\r for string
    data
  + Revert "OvmfPkg: use generic QEMU image loader for secure boot
    enabled ..."
  + ArmVirtPkg/PrePi: use standard PeCoff routines for
    self-relocation
  + ArmVirtPkg: add FDF rule for self-relocating PrePi
  + ArmPkg/ArmExceptionLib: use static buffer for sp_el0
  + MdeModulePkg/SetupBrowserDxe: Do not reconnect driver with
    form-update
  + OvmfPkg/X86QemuLoadImageLib: handle EFI_ACCESS_DENIED from
    LoadImage()
  + OvmfPkg/Tcg2ConfigPei: generalize TPM2-only file-top comments
  + ArmPkg: only attempt buildin MmCommunicationDxe for AArch64
  + ArmPkg/PlatformBootManagerLib: don't connect all devices on
    each boot
  + ArmPkg/PlatformBootManagerLib: hide UEFI Shell as a regular
    boot option
  + MdeModulePkg/BootManagerUiLib: show inactive boot options
  + ArmPkg/PlatformBootManagerLib: fall back to the UiApp on
    boot failure
  + ArmPkg/PlatformBootManagerLib: register 's' as UEFI Shell
    hotkey
  + ArmPkg/PlatformBootManagerLib: connect non-discoverable USB
    hosts
  + ArmPkg/ArmSvcLib: prevent speculative execution beyond svc
  + ArmPkg/PlatformBootManagerLib: reject 'default' parity and
    stop bit count
  + ArmPkg/PlatformBootManagerLib: use static assertion for
    console type
- Update openssl to 1.1.1g
- Drop openssl-fix-syntax-error.patch
  + The new openssl already includes the fix.
- Refresh ovmf-pie.patch and ovmf-disable-ia32-firmware-piepic.patch
* Wed Jul 22 2020 Kai Liu <kai.liu@suse.com>
- Fixed TPM support. TPM2_ENABLE & TPM2_CONFIG_ENABLE build flags
  were changed to TPM_* since upstream commit 07952a962a40.
* Tue Jun  9 2020 Gary Ching-Pang Lin <glin@suse.com>
- Use the reduced source tarballs since ovmf only needs a portion
  of the code.
  + brotli-v1.0.7-17-g666c328.tar.xz ->
    brotli-v1.0.7-17-g666c328-c.tar.xz
  - We only need the "c" directory, not the whole tarball.
  + oniguruma-v6.9.4_mark1.tar.xz ->
    oniguruma-v6.9.4_mark1-src.tar.xz
  - We only need the "src" directory, not the whole tarball.
* Fri Jun  5 2020 Gary Ching-Pang Lin <glin@suse.com>
- Update to edk2-stable202005
  + RegularExpressionDxe: Use submodule way to access third party
    Oniguruma
  + BrotliCustomDecompressLib: Use submodule way to access third
    party brotli
  + BaseTools: Use submodule way to access third party brotli
  + RISC-V architecture on EDK2
  + Disabling safe string constraint assertions
  + ArmVirtPkg Implement support for TPM2 measured boot
  + OVMF Implement support for Linux v5.7+ initrd and mixed mode
    loading
  + OVMF Use loadimage/startimage for loading the kernel passed
    via the QEMU command line
  + OVMF Support booting from Fusion-MPT SCSI controllers
  + OVMF Support booting from VMware PVSCSI controllers
  + OVMF RFE: VCPU hotplug with SMM
  + OVMF PEI phase variable driver / MemoryTypeInfo tracking
  + ArmVirtPkg, OvmfPkg: Pass parameter from QEMU to control PXE
    IPv4/v6 boot
  + Remove deprecate APIs in BaseCryptLib
  + Add UEFI 2.8/2.8a definition in MdePkg
  + Add PI1.7/PI1.7a definition into MdePkg
  + BaseCryptoLib MD4, ARC4, TDES, AES ECB MODE, HMAC MD5, HMAC
    SHA1 API have been deprecated.
  + SecurityPkg Tcg2PhysicalPresenceLib library class removes two
    macros TCG2_BIOS_TPM_MANAGEMENT_FLAG_DEFAULT and
    TCG2_BIOS_STORAGE_MANAGEMENT_FLAG_DEFAULT.
- Add 2 tarballs from the submodules of edk2:
  + brotli-v1.0.7-17-g666c328.tar.xz
  + oniguruma-v6.9.4_mark1.tar.xz
- Refresh patches:
  + ovmf-add-exclude-shell-flag.patch
  + ovmf-gdb-symbols.patch
- Drop upstream patch: ovmf-bsc1163927-fix-ping-and-ip6dxe.patch
- Drop ovmf-bsc1171643-workaround-outline-atomics.patch since
  upstream fixed it in another way.
* Thu May 21 2020 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-bsc1171643-workaround-outline-atomics.patch to disable
  gcc10 outline-atomics in AArch64 (bsc#1171643)
* Mon Apr 20 2020 Gary Ching-Pang Lin <glin@suse.com>
- Build all non-native firmware files on x86_64 and aarch64 with
  cross-compilers (bsc#1159134)
  + Exclude i586 and armv7hl due to the availability of
    cross-compilers
  + Move some bash functions to ovmf-build-funcs.sh
- Clean up PKG_TO_REMOVE
  + Only EmulatorPkg still exists.
* Mon Apr  6 2020 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-bsc1163927-fix-ping-and-ip6dxe.patch to fix crash and
  hang in ShellPkg and Ip6Dxe (bsc#1163927, CVE-2019-14559)
* Fri Mar  6 2020 Gary Ching-Pang Lin <glin@suse.com>
- Update to edk2-stable202002
  + UefiCpuPkg/MpInitLib: Skip reading PlatformId on AMD processors.
  + BaseTools: Remove invalid leading space before !INCLUDE in Makefile
  + OvmfPkg/QemuVideoDxe: unbreak "secondary-vga" and "bochs-display" support
  + NetworkPkg/ArpDxe: Recycle invalid ARP packets (CVE-2019-14559)
  + ShellPkg: acpiview: Prevent infinite loop if structure length is 0
  + CryptoPkg/BaseHashApiLib: Change PcdHashApiLibPolicy type to FixedAtBuild
  + CryptoPkg/BaseHashApiLib: Align BaseHashApiLib with TPM 2.0 Implementation
  + MdeModulePkg: Make retval in UninstallMultipleProtocol follow Spec
  + SecurityPkg/DxeImageVerificationLib: change IsCertHashFoundInDatabase
    name (CVE-2019-14575)
  + SecurityPkg/DxeImageVerificationLib: Differentiate error/search
    result (2) (CVE-2019-14575)
  + SecurityPkg/DxeImageVerificationLib: plug Data leak in
    IsForbiddenByDbx() (CVE-2019-14575)
  + SecurityPkg/DxeImageVerificationLib: tighten default result
    (CVE-2019-14575)
  + SecurityPkg/DxeImageVerificationLib: Differentiate error/search
    result (1) (CVE-2019-14575)
  + SecurityPkg/DxeImageVerificationLib: refactor db/dbx fetching
    code (CVE-2019-14575)
  + SecurityPkg/DxeImageVerificationLib: avoid bypass in fetching
    dbx (CVE-2019-14575)
  + SecurityPkg/DxeImageVerificationLib: fix wrong fetch dbx in
    IsAllowedByDb (CVE-2019-14575)
  + SecurityPkg/DxeImageVerificationLib: reject
    CertStack.CertNumber==0 per DBX (CVE-2019-14575)
  + SecurityPkg/DxeImageVerificationLib: Fix memory leaks
    (CVE-2019-14575)
  + NetworkPkg/Ip4Dxe: Check the received package length
    (CVE-2019-14559).
  + ShellPkg: acpiview: Validate ACPI table 'Length' field
  + ShellPkg: acpiview: Remove duplicate ACPI structure size definitions
  + UefiCpuPkg RegisterCpuFeaturesLib: Match data type and format specifier
  + MdeModulePkg/SdMmcPciHcDxe: Fix double PciIo Unmap in TRB creation
    (CVE-2019-14587)
  + MdeModulePkg/DisplayEngine: Zero memory before free (CVE-2019-14558)
  + MdeModulePkg/String.c: Zero memory before free (CVE-2019-14558)
  + MdeModulePkg/HiiDB: Remove configuration table when it's freed
    (CVE-2019-14586)
  + MdePkg: Remove FIT table industry standard header file.
  + UefiCpuPkg: Remove FIT based microcode shadow logic from MpInitLib.
  + UefiCpuPkg/CpuFeature: Introduce First to indicate 1st unit.
  + UefiCpuPkg/RegisterCpuFeaturesLib: Rename [Before|After]FeatureBitMask
  + UefiCpuPkg/RegisterCpuFeaturesLib: Delete CPU_FEATURE_[BEFORE|AFTER]
  + MdePkg: Add PCCT table signature definition
  + BaseTools: Fixed build failure when using python38
  + BaseTools:fix Ecc tool issue for check StructPcd
  + BaseTools: Remove caret in NASM_INC macro
  + BaseTools: Rationalise makefile generation
  + MdePkg: Add PCI Express 5.0 Header File
  + MdePkg: Disable EBC for unit tests in MdePkg.dsc
  + MdePkg/SmBios.h: Add two additional DWORD for smbios 3.3.0 type17
  + UefiCpuPkg/MpInitLib: Not pass microcode info between archs in CPU_MP_DATA
  + Revert UefiCpuPkg/MpInitLib: Relocate microcode patch fields in CPU_MP_DATA
  + ShellPkg: acpiview: Validate global pointers before use
  + ShellPkg: acpiview: Validate System Locality count
  + ShellPkg: acpiview: Set ItemPtr to NULL for unprocessed table fields
  + ShellPkg: Document UpdateArgcArgv returns EFI_INVALID_PARAMETER
  + ShellPkg: Document ParseCommandLineToArgs returns EFI_INVALID_PARAMETER
  + ShellPkg/UefiShellAcpiViewCommandLib: Fix FADT Parser
  + SecurityPkg: Fix incorrect return value when File is NULL
  + BaseTools: Fixed a Incremental build issue
  + CryptoPkg/CryptoPkg.dsc: Add build of Crypto libraries/modules
  + CryptoPkg/Library: Add BaseCryptLibOnProtocolPpi instances
  + CryptoPkg/Driver: Add Crypto PEIM, DXE, and SMM modules
  + CryptoPkg: Add EDK II Crypto Protocols/PPIs/PCDs
  + CryptoPkg/BaseCryptLib: Add X509ConstructCertificateStackV().
  + MdeModulePkg/PiDxeS3BootScriptLib: Fix potential numeric truncation
    (CVE-2019-14563)
  + MdeModulePkg/Capsule: Remove RT restriction in UpdateCapsule service.
  + SecurityPkg/TcgPhysicalPresenceLib: Replace the ASSERT with error code
  + BaseTools/PcdValueCommon: Fix 64-bit host compiler error
  + BaseTools/Build: Do not use Common.lib in Structured PCD app
  + MdeModulePkg/BaseSerialPortLib16550: Fix Serial Port Ready
  + BaseTools: Script for converting .aml to .hex
  + MdeModulePkg: Perform test only if not ignore memory test
  + UefiCpuPkg/MpInitLib: Always get CPUID & PlatformID in MicrocodeDetect()
  + OvmfPkg/PlatformPei: detect SMRAM at default SMBASE (for real)
  + OvmfPkg: introduce PcdCsmEnable feature flag
  + OvmfPkg/SmmAccess: close and lock SMRAM at default SMBASE
  + OvmfPkg/SEV: don't manage the lifecycle of the SMRAM at the default SMBASE
  + OvmfPkg/PlatformPei: reserve the SMRAM at the default SMBASE, if it exists
  + OvmfPkg/PlatformPei: assert there's no permanent PEI RAM at default SMBASE
  + OvmfPkg/PlatformPei: detect SMRAM at default SMBASE (skeleton)
  + OvmfPkg/PlatformPei: factor out Q35BoardVerification()
  + OvmfPkg/IndustryStandard: add MCH_DEFAULT_SMBASE* register macros
  + OvmfPkg/IndustryStandard: increase vertical whitespace in Q35 macro defs
  + OvmfPkg: introduce PcdQ35SmramAtDefaultSmbase
  + CryptoPkg/BaseCryptLibNull: Add missing HkdfSha256ExtractAndExpand()
  + BaseTools/DscBuildData: Fix PCD autogen include file conflict
  + CryptoPkg/BaseHashApiLib: Implement Unified Hash Calculation API
  + CryptoPkg: Add CryptoPkg Token Space GUID
  + BaseTools/Conf/gitattributes: fix "--function-context" for C source code
  + SecurityPkg/DxeImageVerificationHandler: fix "defer" vs. "deny" policies
  + SecurityPkg/DxeImageVerificationHandler: fix imgexec info on memalloc fail
  + SecurityPkg/DxeImageVerificationHandler: fix retval for (FileBuffer==NULL)
  + SecurityPkg/DxeImageVerificationHandler: eliminate "Status" variable
  + SecurityPkg/DxeImageVerificationHandler: unnest AddImageExeInfo() call
  + SecurityPkg/DxeImageVerificationHandler: remove superfluous Status setting
  + SecurityPkg/DxeImageVerificationHandler: fix retval on memalloc failure
  + SecurityPkg/DxeImageVerificationHandler: narrow down PE/COFF hash status
  + SecurityPkg/DxeImageVerificationHandler: keep PE/COFF info status internal
  + SecurityPkg/DxeImageVerificationHandler: remove "else" after return/break
  + SecurityPkg/DxeImageVerificationHandler: simplify "VerifyStatus"
  + OvmfPkg/PlatformPei: rewrite MaxCpuCountInitialization() for CPU hotplug
  + OvmfPkg/IndustryStandard: define macros for QEMU's CPU hotplug registers
  + OvmfPkg/OvmfXen.dsc: remove PcdCpu* dynamic defaults
  + CryptoPkg/BaseCryptLib: remove HmacXxxGetContextSize interface
  + CryptoPkg/BaseCryptLib: replace HmacXxxInit API with HmacXxxSetKey
  + BaseTools: Fixed a incremental build bug
  + UefiCpuPkg/MpInitLib: Fix possible uninitialized 'InitFlag' field
  + FmdDevicePkg/FmpDxe: Support Fmp Capsule Dependency.
  + MdeModulePkg/CapsuleApp: Enhance CapsuleApp for Fmp Capsule Dependency
  + MdePkg: Add definition for Fmp Capsule Dependency.
  + MdeModulePkg/SdMmcPciHcDxe: Add retries for async commands
  + MdeModulePkg/SdMmcPciHcDxe: Add retries for sync commands
  + MdeModulePkg/SdMmcPciHcDxe: Refactor command error detection
  + MdeModulePkg/SdMmcPciHcDxe: Fix DAT lane SW reset
  + UefiCpuPkg/PiSmmCpuDxeSmm: fix 2M->4K page splitting regression for PDEs
  + MdeModulePkg/Variable: Fix VarErrorFlag RT cache offset calculation
  + MdePkg Base.h: Use correct style to check the defined macro
  + ShellPkg: acpiview: Update SRAT parser to ACPI 6.3
  + BaseTools/Capsule: Add capsule dependency support
  + MdeModulePkg/Setup: Update opcode number variable type to UINTN
  + ArmPlatformPkg/PrePeiCore: enable VFP at startup
  + ArmPkg/ArmSmcPsciResetSystemLib: remove EnterS3WithImmediateWake ()
  + NetworkPkg/HttpDxe: fix 32-bit truncation in HTTPS download
  + MdeModulePkg/UefiBootManagerLib: log reserved mem allocation failure
  + BaseTools/Scripts/PatchCheck: Address false error conditions
  + BaseTools:Fix GenFds issue for BuildOption replace GenFdsOption
  + BaseTools:Change the case rules for ECC check pointer names
  + MdeModulePkg/SdMmcPciHcDxe: Fix unknown doxygen tag error
  + ArmVirtPkg: remove EnterS3WithImmediateWake () from ResetSystemLib
  + OvmfPkg: remove EnterS3WithImmediateWake () from ResetSystemLib
  + UefiPayloadPkg: remove EnterS3WithImmediateWake () from ResetSystemLib
  + PcAtChipsetPkg: remove EnterS3WithImmediateWake () from ResetSystemLib
  + MdeModulePkg: remove EnterS3WithImmediateWake () from ResetSystemLib
  + UefiCpuPkg: Shadow microcode patch according to FIT microcode entry.
  + MdePkg: Add header file for Firmware Interface Table specification.
  + UefiCpuPkg/CpuCommonFeaturesLib: SMXE bit of CR4 should set
  + MdePkg BaseLib.h: Update IA32_CR4 strut to include all public fields
  + MdePkg: Do not use CreateEventEx unless required
  + UefiCpuPkg/PiSmmCpuDxeSmm: Add missed comments for parameter.
  + OvmfPkg: use HII type PCDs for TPM2 config related variables
  + OvmfPkg: reorganize TPM2 support in DSC/FDF files
  + BaseTools/PatchCheck.py: Ignore CR and LF characters in subject length
  + MdeModulePkg: Add EDK2 Platform Boot Manager Protocol
  + CryptoPkg: Support for SHA384 & SHA512 RSA signing schemes
  + UefiCpuPkg: Always load microcode patch on AP processor.
  + UefiCpuPkg: Remove alignment check when calculate microcode size.
  + Revert "UefiCpuPkg/PiSmmCpuDxeSmm: Fix buffer overflow issue."
  + MdeModulePkg/UsbMouseAbsolutePointer: Fix endpoint selection
  + MdeModulePkg/Usb/UsbMouse: Fix endpoint selection
  + MdeModulePkg/Usb/EfiKey: Fix endpoint selection
  + SecurityPkg/Tcg2Pei: Add TCG PFP 105 support.
  + MdeModulePkg/Smbios: Add TCG PFP rev 105 support.
  + MdeModulePkg/dec: add PcdTcgPfpMeasurementRevision PCD
  + MdeModulePkg/Smbios: Done measure Smbios multiple times.
  + SecurityPkg/Tcg2Dxe: Add Tcg2Dxe to support 800-155 event.
  + SecurityPkg/Guid: Add TCG 800-155 event GUID definition.
  + MdeModulePkg/SdMmcPciHcDxe: Add function to start SD clock
  + MdeModulePkg/SdMmcPciHcDxe: Hook SwitchClockFreq after SD clock start
  + UefiCpuPkg/PiSmmCpuDxeSmm: Pre-allocate PROCEDURE_TOKEN buffer
  + UefiPayloadPkg/BootManager: Add PS2 keyboard support
  + UefiCpuPkg/MpInitLib: Remove redundant microcode fields in CPU_MP_DATA
  + UefiCpuPkg/MpInitLib: Relocate microcode patch fields in CPU_MP_DATA
  + UefiCpuPkg/MpInitLib: Produce EDKII microcode patch HOB
  + UefiCpuPkg: Add definitions for EDKII microcode patch HOB
  + UefiCpuPkg/MpInitLib: Reduce the size when loading microcode patches
  + UefiCpuPkg/MpInitLib: Collect processors' CPUID & Platform ID info
  + BaseTools/Scripts: Add sendemail.transferEncoding to SetupGit.py
  + UefiCpuPkg/PiSmmCpuDxeSmm: Fix buffer overflow issue.
  + UefiCpuPkg/PiSmmCpuDxeSmm: Remove dependence between APs
  + edksetup.bat stuck on unicode locale Windows
  + MdePkg/Tcg: Add new definition in TCG PFP spec.
  + MdePkg: Use __builtin_offset with CLANGPDB toolchain
  + MdePkg PciExpress21: PCI_REG_PCIE_DEVICE_CONTROL2 struct has 17 bits
  + ShellPkg/ShellProtocol: Return error code while fail parsing cmd-line
  + MdePkg/Spdm: fix Nonce structure error.
  + BaseTools: Resolve a issue of Incremental build
  + Maintainers.txt: Update email address and role
  + BaseTools:replaces the two offending quotes by ascii quotes
  + BaseTools: Fix build failure when multiple build targets given
  + MdePkg/Include: Add DCC and BCM2835 SPCR UART types
  + ArmPkg/MmCommunicationDxe: relay architected PI events to MM context
  + SecurityPkg/Tcg2Smm: Measure the table before patch.
  + BaseTools: Remove redundant binary cache file
  + BaseTools: Leverage compiler output to optimize binary cache
  + BaseTools: enhance the CacheCopyFile method arg names
  + BaseTools: store more complete output files in binary cache
  + BaseTools: Enhance Basetool for incremental build
  + BaseTools: Update build_rule.txt to generate dependent files.
  + BaseTools: Generate dependent files for ASL and ASM files
  + BaseTools: Add build option for dependency file generation
  + UefiCpuPkg/PiSmmCpuDxeSmm: Avoid allocate Token every time
  + BaseTools: Avoid "is" with a literal Python 3.8 warnings
  + ArmPkg: Dispatch deferred images after EndOfDxe
  + ShellPkg/UefiHandleParsingLib: Fix error allocate pool
  + ShellPkg/edit: typo "%%d Lines Wrote"
  + ShellPkg: acpiview: IORT Spec Rev D updates
  + ShellPkg: acpiview: Add support for parsing FACS
  + MdeModulePkg: Add ARM/Aarch64 support which were missing
  + MdeModulePkg: LzmaCustomDecompressLib.inf don't support EBC anymore
  + BaseTools:Enhance the way to handling included dsc file
  + UefiCpuPkg/UefiCpuPkg.uni: Add missing strings for PCD
  + NetworkPkg/NetworkPkg.uni: Add missing strings for PCD
  + MdeModulePkg/MdeModulePkg.uni: Add missing strings for PCD
  + NetworkPkg: Fixes to static code analysis hits
  + CryptoPkg/OpensslLib.inf: list OpenSSL local header "ms/uplink.h"
  + CryptoPkg/OpensslLib: improve INF file consistency
  + MdeModulePkg/VariableSmmRuntimeDxe.inf: list local header "Variable.h"
- Drop upstreamed fixes
  + ovmf-bsc1163927-fix-ip4dxe-and-arpdxe.patch
  + ovmf-bsc1163959-PiDxeS3BootScriptLib-fix-numeric-truncation.patch
  + ovmf-bsc1163969-fix-DxeImageVerificationHandler.patch
- Refresh ovmf-gdb-symbols.patch
* Mon Feb 24 2020 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-bsc1163969-fix-DxeImageVerificationHandler.patch to fix
  dbx signature check (bsc#1163969, CVE-2019-14575)
  + Also change the order of several patches to distinguish the
    openssl patch
- Add ovmf-bsc1163927-fix-ip4dxe-and-arpdxe.patch to fix memory
  leakage in Ip4Dxe and ArpDxe (bsc#1163927, CVE-2019-14559)
* Tue Feb 18 2020 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-bsc1163959-PiDxeS3BootScriptLib-fix-numeric-truncation.patch
  to fix the numeric truncation to avoid the potential memory
  corruption (bsc#1163959, CVE-2019-14563)
* Mon Feb  3 2020 Gary Ching-Pang Lin <glin@suse.com>
- Build the unified firmware with preloaded keys for backward
  compatibility (bsc#1159793)
* Fri Dec 20 2019 Dirk Mueller <dmueller@suse.com>
- only build -aarch32 Cortex-A15 EFI on armv7hl
* Tue Dec  3 2019 Gary Ching-Pang Lin <glin@suse.com>
- Update to edk2-stable201911
  + SecurityPkg: Fix TPM2 ACPI measurement
  + MdeModulePkg: Enable variable runtime cache by default
  + OvmfPkg: Disable variable runtime cache
  + MdeModulePkg/Variable: Add RT GetVariable() cache support
  + CryptoPkg: Upgrade OpenSSL to 1.1.1d
  + MdePkg-UefiSpec.h: Add UEFI 2.8 new memory attributes
  + MdePkg/UefiFileHandleLib: Fix potential NULL dereference
  + NetworkPkg/HttpDxe: Set the HostName for the verification
    (CVE-2019-14553)
  + NetworkPkg/TlsDxe: Add the support of host validation to TlsDxe
    driver (CVE-2019-14553)
  + CryptoPkg/TlsLib: TlsSetVerifyHost: parse IP address literals
    as such (CVE-2019-14553)
  + CryptoPkg/TlsLib: Add the new API "TlsSetVerifyHost"
    (CVE-2019-14553)
  + MdePkg/Include/Protocol/Tls.h: Add the data type of
    EfiTlsVerifyHost (CVE-2019-14553)
  + MdeModulePkg/BdsDxe: Fix PlatformRecovery issue
  + NetworkPkg/SnpDxe: Add PCD to remove ExitBootServices event
    from SNP driver
  + MdeModulePkg: Update to support SmBios 3.3.0
  + UefiCpuPkg/MpInitLib: honor the platform's boot CPU count in AP
    detection
  + SecurityPkg/Tcg2: Add Support Laml, Lasa for TPM2 ACPI
  + OvmfPkg/PlatformDxe: fix EFI_HII_HANDLE parameters of internal
    functions
  + OvmfPkg/VirtioNetDxe: fix SignalEvent() call
  + OvmfPkg/XenBusDxe: fix UninstallMultipleProtocolInterfaces()
    call
  + NetworkPkg/Ip4Dxe: fix NetLibDestroyServiceChild() call
  + MdeModulePkg/ScsiDiskDxe: Support Storage Security Command
    Protocol
  + MdePkg: Implement SCSI commands for Security Protocol In/Out
  + MdeModulePkg/TerminalDxe: Enhance the arrow keys support
  + MdeModulePkg/UefiBootManager: Unload image on
    EFI_SECURITY_VIOLATION
  + MdeModulePkg/DxeCapsuleLibFmp: Unload image on
    EFI_SECURITY_VIOLATION
  + MdeModulePkg: Extend the support keyboard type of Terminal
    console
  + UefiCpuPkg/CpuExceptionHandlerLib: Fix split lock
  + UefiCpuPkg: Fix potential spinLock issue in SmmStartupThisAp
  + UefiCpuPkg/PiSmmCpu: Enable 5L paging only when phy addr line
    > 48
  + OvmfPkg/EnrollDefaultKeys: clean up Base64Decode() retval
    handling
  + ArmVirtPkg/PlatformBootManagerLib: unload image on
    EFI_SECURITY_VIOLATION
  + ShellPkg/ShellPkg.dsc AARCH64: enable stack protector
  + ArmVirtPkg/ArmVirtPrePiUniCoreRelocatable: revert to PIE
    linking
  + BaseTools/GenFw AARCH64: fix up GOT based relative relocations
  + ShellPkg/Pci.c: Update supported link speed to PCI5.0
  + PcAtChipsetPkg: add PcdRealTimeClockUpdateTimeout
  + UefiCpuPkg: Add PcdCpuSmmRestrictedMemoryAccess
  + ShellPkg/CommandLib: avoid NULL derefence and memory leak
  + MdePkg/DxeHstiLib: Added checks to improve error handling
  + BaseTools: Support more file types in build cache
  + UefiCpuPkg/SecCore: get AllSecPpiList after SecPlatformMain
- Update openssl to 1.1.1d
  + Add openssl-fix-syntax-error.patch to fix a syntax error
- Drop ovmf-bsc1153072-fix-invalid-https-cert.patch
  + Already upstreamed
* Fri Nov  8 2019 Gary Ching-Pang Lin <glin@suse.com>
- Use the same x86 4MB firmware names as the ones in the previous
  version (< stable201905) for backward compatibility
* Wed Nov  6 2019 Gary Ching-Pang Lin <glin@suse.com>
- Disable TLS for IA32(i586) to avoid exceeding the size limitation
  while using the tool chain from SLE15-SP2/openSUSE Leap 15.2
* Mon Nov  4 2019 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-bsc1153072-fix-invalid-https-cert.patch to reject the
  invalid server certificates for HTTPS Boot
  (bsc#1153072, CVE-2019-14553)
* Thu Oct 17 2019 Gary Ching-Pang Lin <glin@suse.com>
- Add the firmware descriptors for QEMU
- Tweak the install commands
* Tue Sep  3 2019 Gary Ching-Pang Lin <glin@suse.com>
- Update to edk2-stable201908
  + OvmfPkg: Introduce platform OvmfXen
  + OvmfPkg/ResetSystemLib: Add missing dependency on PciLib
  + MdeModulePkg DxeCore: Fix for missing Memory Attributes Table
    (MAT) update
  + BaseTools: Fixed issue of incorrect Module Unique Name
  + CryptoPkg/OpensslLib: Add missing header files in INF file
  + SecurityPkg/SecurityPkg.uni: Add missing strings for new PCDs
  + MdeModulePkg/DxeIplPeim: Initialize pointer PageMapLevel5Entry
  + MdeModulePkg/MdeModulePkg.dec: Remove gEfiDpcProtocolGuid
  + Readme.md: add submodule policy and clone commands
  + MdeModulePkg/DxeIplPeim: Relocate operation of
    PageMapLevel5Entry++
  + MdeModulePkg: Add missing header files in INF files
  + MdePkg: Add MmAccess and MmControl definition.
  + CryptoPkg/BaseCryptLib: Wrap OpenSSL HKDF algorithm
  + MdeModulePkg/DxeIpl: Create 5-level page table for long mode
  + MdeModulePkg/DxeIpl: Introduce PCD PcdUse5LevelPageTable
  + UefiCpuPkg/CpuDxe: Support parsing 5-level page table
  + UefiCpuPkg/MpInitLib: Enable 5-level paging for AP when BSP's
    enabled
  + OvmfPkg/PlatformPei: Change referenced MSR name.
  + UefiCpuPkg/PiSmmCpuDxeSmm: Add check for pointer Pml5Entry
  + SecurityPkg/SecurityPkg.dec: Remove trailing white space
  + MdeModulePkg/PiSmmCore: Use unique structure signatures
  + UefiCpuPkg/MpInitLib: don't shadow the microcode patch twice.
  + ShellPkg: improve acpiview
  + MdePkg: Add PI 1.5 SmramMemoryReserve HOB file
  + MdePkg/PciExpress21.h: Fix the PCI industry standard register
    defines
  + CryptoPkg/BaseCryptLib: Use cmp-operator for non-Boolean
    comparisons
  + ArmPkg: DebugPeCoffExtraActionLib: fix trivial comment typos
  + ArmPkg: DebugPeCoffExtraActionLib: debugger commands are not
    errors
  + UefiCpuPkg/RegisterCpuFeaturesLib: Start all processors
    simultaneously.
  + UefiCpuPkg: Add new EDKII_PEI_MP_SERVICES2_PPI
  + list module-internal header files in INF [Sources]
  + SecurityPkg: introduce the SM3 digest algorithm
  + BaseTools: Fix python3.8 SyntaxWarning
  + BaseTools: Add HOST_APPLICATION module type.
  + UefiCpuPkg/PiSmmCpu: Enable 5 level paging when CPU supports
  + MdePkg/BaseLib.h: Update IA32_CR4 structure for 5-level paging
  + UefiCpuPkg RegisterCpuFeaturesLib: Fix an ASSERTION issue
  + ArmPlatformPkg: Actually disable PL031 interrupts
  + UefiCpuPkg/PiSmmCpu: Change variable names and comments to follow
    SDM
  + OvmfPkg: use DxeTpmMeasurementLib if and only if TPM2_ENABLE
  + ArmPlatformPkg: Fix various typos
  + ArmPkg: Fix various typos
  + Remove IntelFrameworkPkg
  + Remove IntelFrameworkModulePkg
  + MdeModulePkg/BdsDxe: Use a pcd to control PlatformRecovery
  + MdeModulePkg: Add a pcd to set the OS indications bit
  + SecurityPkg: Remove DxeDeferImageLoadLib in DSC
  + BaseTools:Linux changes the way the latest version is judged
  + Fix indentation in edksetup.sh SetupPython3
  + MdeModulePkg/SdMmcHcDxe: Implement revision 3 of
    SdMmcOverrideProtocol
  + MdeModulePkg/SdMmcOverride: Add GetOperatingParam notify phase
  + MdeModulePkg/UfsPassThruDxe: Fix unaligned data transfer
    handling
  + ArmVirtPkg: handle NETWORK_TLS_ENABLE in ArmVirtQemu*
  + UefiCpuPkg/MpInitLib: MicrocodeDetect: Ensure checked range is
    valid
  + MdeModulePkg/UfsPassThruDxe: Refactor UFS device presence
    detection
  + PcAtChipsetPkg: Remove framework modules
  + SecurityPkg: add FvReportPei.inf in dsc for build validation
  + SecurityPkg/FvReportPei: implement a common FV verifier and
    reporter
  + SecurityPkg: add definitions for OBB verification
  + OvmfPkg: don't assign PCI BARs above 4GiB when CSM enabled
  + OvmfPkg: Don't build in QemuVideoDxe when we have CSM
  + OvmfPkg/LegacyBbs: Add boot entries for VirtIO and NVME
    devices
  + OvmfPkg/LegacyBios: set NumberBbsEntries to the size of
    BbsTable
  + SecurityPkg: Add missing instances for build only
  + BaseTools: Move Build Cache related function out of
    CreateAsBuiltInf
  + BaseTools: refine CreateAsBuiltInf function
  + BaseTools:Add DetectNotUsedItem.py to Edk2\BaseTools\Scripts
  + BaseTools:Add import in FvImageSection
  + MdeModulePkg/PeiMain: PeiAllocatePool: output NULL if HOB
    creation fails
  + MdePkg: Add Generic Initiator Affinity Structure definitions
    to SRAT
  + BaseTools:Introduce CopyFileOnChange() function to copy cache
    files
  + MdeModulePkg: Add missing instances for build only
  + SourceLevelDebugPkg: Add missing instances for build only
  + CryptoPkg: Add missing instance for build only
  + MdeModulePkg: Introduce EDKII_SERIAL_PORT_LIB_VENDOR_GUID
  + MdeModulePkg/GraphicsConsoleDxe: Initialize the output mode
  + MdeModulePkg/ConSplitterDxe: Optimize the
    ConSplitterTextOutSetMode
  + BaseTools: add script to configure local git options
  + BaseTools: add centralized location for git config files
  + OvmfPkg/QemuVideoDxe: Shouldn't assume system in VGA alias
    mode.
- Refresh ovmf-gdb-symbols.patch
- Enable NETWORK_TLS_ENABLE for AArch64
* Fri Jul  5 2019 Gary Ching-Pang Lin <glin@suse.com>
- Reset BootOrder after enrolling the default keys (boo#1140195)
* Mon Jun 17 2019 Gary Ching-Pang Lin <glin@suse.com>
- Update to edk2-stable201905
  + Update OpenSSL version to upcoming 1.1.1
  + Delete EdkCompatibilityPkg from edk2/master
  + Remove .S assembly code for IA32 and X64 arch
  + Replace BSD 2-Clause License with BSD + Patent Licence
  + Recovery PEI BlockIO support for ATA device
  + Add PCD to Enabled/Disabled IPv4/IPv6 PXE Support in NetworkPkg
  + Remove NetworkPkg/IpSecDxe
  + Add api to DebubLib to expose a print routine with VaList
    parameter
  + Introduce DebugPpi to save the image size with the debug
    message
  + ResetSystemLib Adds a new API ResetSystem
  + ResetUtilityLib Add a new API ResetSystemWithSubtype
  + Add support for get organization name to x509 in BaseCryptLib
  + Add support for checking x509 EKUs in BaseCryptLib
  + Add support for PKCS 1v2 RSAES-OAEP PKI encryption in
    BaseCryptLib
  + Remove ShellBinPkg from edk2/master
  + Enable multiple thread /MP option for MSVC compiler
  + Upstream the EnrollDefaultKeys application to OvmfPkg
  + Share code for BaseUefiDecompressLib in MdePkg and MdeModulePkg
  + Move network related components from MdeModulePkg to NetworkPkg
  + Move BeagleBoardPkg and Omap35xxPkg from edk2 to edk2-platforms
    repo
  + Move MinnowMax and Quark platform to edk2-platforms repo
  + Move OptionRomPkg into new Drivers directory edk2-platforms
    repo
  + Add ACPI6.3 definition
  + Remove Nt32Pkg from edk2/master
  + update ArmSoftFloatLib to latest upstream version (= 3e)
- Update openssl to 1.1.1b
  + Add berkeley-softfloat-3-b64af41c3276f.tar.xz since arm7 needs
    the softfloat implementation for openssl 1.1.1b
- Build the varstore templates with EnrollDefaultKeys.efi
  + Create the iso files for key enrollment
  - Add gen-key-enrollment-iso.sh to generate the iso file
  + Drop the non-upstream ovmf-embed-default-keys.patch
  - Also drop owner-guid-zero.h
  + Drop the MS keys and dbx since they are already in
    EnrollDefaultKeys.efi: MicCorKEKCA2011_2011-06-24.crt,
    MicCorUEFCA2011_2011-06-27.crt, MicWinProPCA2011_2011-10-19.crt,
    and dbxupdate.zip
  - Also drop the related script strip_authinfo.pl
  + Add ovmf-set-fixed-enroll-time.patch to set the fixed enrolling
    time to make the varstore template reproducible
  + Require qemu 3.0.0 for fw_cfg
- Update the build flags for network functions
  + For x86_64, only enable TLS for the 4MB image since the code
    size exceeds the boundary of 2MB image
- Refresh patches:
  + ovmf-add-exclude-shell-flag.patch
  + ovmf-disable-ia32-firmware-piepic.patch
  + ovmf-pie.patch
- Drop the requirement of xxd
- Update README
- Update the License tag to BSD-2-Clause-Patent
* Mon May  6 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Build SecureBoot firmwares for aarch64
* Wed Mar 20 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable debug for aarch32
- Add aavmf-aarch32-code.bin and aavmf-aarch32-vars.bin files
* Tue Mar 12 2019 Gary Ching-Pang Lin <glin@suse.com>
- Update to 2019+git1552059899.89910a39dcfd (edk2-stable201903)
  + MdeModulePkg/HiiImage: Fix stack overflow when corrupted BMP
    is parsed (bsc#1128503, CVE-2018-12181)
  + MdeModulePkg/HiiDatabase: Fix potential integer overflow
    (bsc#1128503, CVE-2018-12181)
  + UefiCpuPkg/Microcode.c: Add verification before calculate
    CheckSum32
  + UefiCpuPkg/Microcode: Fix InComplete CheckSum32 issue
  + UefiCpuPkg: restore strict page attributes via #DB in nonstop
    mode only
  + IntelFrameworkModulePkg/FwVolDxe: Ensure FfsFileHeader 8 bytes
    aligned (bsc#1127822, CVE-2018-3630)
  + MdeModulePkg/DxeCore: Ensure FfsFileHeader 8 bytes aligned
    (bsc#1127822, CVE-2018-3630)
  + MdeModulePkg/PeiCore: Ensure FfsFileHeader 8 bytes aligned
    (bsc#1127822, CVE-2018-3630)
  + NetworkPkg: Add WiFi Connection Manager to NetworkPkg
  + UefiCpuPkg/PiSmmCpu: Add Shadow Stack Support for X86 SMM
  + MdePkg/BaseLib: Add Shadow Stack Support for X86
  + NetworkPkg/DnsDxe: Check the received packet size before
    parsing the message (bsc#1127821, CVE-2018-12178)
  + MdeModulePkg/RamDiskDxe: Restrict on RAM disk size
    (bsc#1127820, CVE-2018-12180)
  + MdeModulePkg/PartitionDxe: Ensure blocksize holds MBR
    (bsc#1127820, CVE-2018-12180)
  + ArmVirtPkg/PlatformBootManagerLib: display boot option
    loading/starting
  + ArmVirtPkg/ArmVirtQemu*: enable minimal Status Code Routing
    in DXE
  + OvmfPkg/PlatformBootManagerLib: display boot option
    loading/starting
  + OvmfPkg: add library to track boot option loading/starting on
    the console
  + MdeModulePkg/UefiBootManagerLib: fix LoadImage/StartImage
    status code rep
  + MdeModulePkg/AhciPei: Add AHCI mode ATA device support in PEI
  + MdeModulePkg: Add definitions for EDKII PEI ATA PassThru PPI
  + MdeModulePkg: Add definitions for ATA AHCI host controller PPI
  + MdePkg/UefiDevicePathLib: Add sanity check for FilePath device
    path
  + UefiCpuPkg/Microcode: Fix incorrect checksum issue for
    extended table
  + SecurityPkg/TcgConfigDxe: Allow enabling TPM 1.2 device from
    disabled state
  + UefiCpuPkg/SecCore: Wrong Debug Information for SecCore
  + Various bug fixes in BaseTools
  + DynamicTablesPkg: Dynamic Tables Framework
  + MdeModulePkg: Remove EmuVariableRuntimeDxe
  + UefiCpuPkg/MtrrLib: Fix a bug that may wrongly set memory <1MB
    to UC
  + MdeModulePkg/BmBoot: Report status when fail to load/start
    boot option
  + MdeModulePkg/ReportStatusCodeLib: Avoid using AllocatePool if
    possible
  + NetworkPkg/Ip6Dxe: Clean the invalid IPv6 configuration during
    driver start
* Thu Feb 21 2019 Gary Ching-Pang Lin <glin@suse.com>
- Add TPM2_CONFIG_ENABLE build flag to enable TPM2 config menu
* Mon Feb 18 2019 Gary Ching-Pang Lin <glin@suse.com>
- Update to 2019+git1550452308.c417c1b33d06
  + BaseTools: Fixed an issue about StructurePcd
  + UefiCpuPkg/SecCore: Support EFI_PEI_CORE_FV_LOCATION_PPI
  + OvmfPkg: Add TCG2 Configuration menu to the Device Manager menu
  + FatPkg/FatPei/Gpt.c: Fix uninitialized variable issue
  + Make BaseTools compatible with python3
  + CryptoPkg/BaseCryptLib: split CryptPkcs7Verify.c on behalf
    of runtime
  + MdeModulePkg/UefiBootManagerLib: Match the nested partitions
  + ArmPkg/ArmMmuLib AARCH64: get rid of needless TLB invalidation
  + Upgrade UEFI supporting TCG spec info
  + MdeModulePkg Variable: Add emulated variable NV mode support
  + Code clean-up in the network packages
  + OvmfPkg: add MmServicesTableLib resolution
  + ArmPkg/ArmMmuLib AARCH64: fix out of bounds access
  + BaseTools/VfrCompile: report error for Integer overflow
  + OvmfPkg: require GCC48 or later
  + MdePkg/BaseLib: Introduce new SpeculationBarrier API
  + Remove the obsolete network packages in MdeModulePkg
  + Upgrade OpenSSL to 1.1.0j
  + MdePkg/Base: introduce MAX_ALLOC_ADDRESS
  + MdeModulePkg/PciBus: Fix system hang when no PCI Option ROM exists
  + BaseTools/tools_def AARCH64 RELEASE: move GCC49/GGC5 to 4 KB
    alignment
  + SecurityPkg: Remove dead code and inf redundant definitions
  + UefiCpuPkg/Cpuid.h: Sync CPUID definition to latest SDM
  + MdeModulePkg/PciBus: Shadow option ROM after BARs are programmed
  + ArmVirtPkg/QemuVirtMemInfoLib: trim the MMIO region mapping
  + ArmVirtPkg/XenVirtMemInfoLib: refactor reading of the PA space
    size
  + ArmVirtPkg/QemuVirtMemInfoLib: remove 1:1 mapping of top of
    PA range
  + ArmVirtPkg/NorFlashQemuLib: discover NOR flash banks dynamically
  + ArmPkg/ArmSmcPsciResetSystemLib: add missing call to
    ExitBootServices()
  + SecurityPkg: Update TCG PFP spec revision.
  + OvmfPkg: simply use the Bochs interface for vmsvga
  + ArmPlatformPkg & ArmVirtPkg: clear frame pointer in startup
    code
  + Remove unused DuetPkg, EdkShellBinPkg, and UnixPkg
  + ArmPkg/ArmGicDxe ARM: fix encoding for GICv3 interrupt
    acknowledge
  + MdePkg/BaseIoLibIntrinsicArmVirt ARM: avoid double word loads
    and stores
- Refresh patches
  + ovmf-add-exclude-shell-flag.patch
  + ovmf-disable-ia32-firmware-piepic.patch
- Enable Python3 support in BaseTools (bsc#1075770)
* Thu Dec 27 2018 Gary Ching-Pang Lin <glin@suse.com>
- Add a new "smm" flavor to enable System Management Mode
  + Also add ovmf-add-exclude-shell-flag.patch to exclude shell
    from the resultant SMM firmware files
- Retire the old openSUSE 4096 bit certificates since all those
  programs are unmaintained.
- Amend the numbering of patches and sources
- Update README to reflect the current status
* Mon Dec  3 2018 Gary Ching-Pang Lin <glin@suse.com>
- Update ovmf-embed-default-keys.patch and add owner-guid-zero.h to
  set the default owner of PK/KEK/db/dbx and make the
  auto-enrollment only happen at the very first boot. (bsc#1117998)
- Change the group of qemu-ovmf-x86_64-debug to Development/Sources
  since there is no Development/Debug anymore
* Thu Nov 15 2018 Gary Ching-Pang Lin <glin@suse.com>
- Update to 2018+git1542164568.85588389222a (edk2-stable201811)
  + UefiCpuPkg/CommonFeature: Always set FEATURE_CONTROL.Lock
  + MdeModulePkg/NvmExpressPei: Refine data buffer & len check in
    PassThru
  + OvmfPkg/QemuVideoDxe: list "UnalignedIoInternal.h" in the INF
    file
  + OvmfPkg/QemuVideoDxe: VMWare SVGA device support
  + OvmfPkg/QemuVideoDxe: Helper functions for unaligned port I/O
  + OvmfPkg: VMWare SVGA display device register definitions
  + Fix UEFI and Tiano Decompression logic issue
  + MdePkg: Fix incorrect check for DisplayOnly text format in
    AcpiEx
  + UefiCpuPkg/PiSmmCpuDxeSmm: Separate semaphore container
  + UefiCpuPkg/RegisterCpuFeaturesLib: Separate semaphore container
  + UefiCpuPkg/RegisterCpuFeaturesLib: Adjust Order
  + MdePkg/BaseSynchronizationLib: Fix InternalSync[De|In]crement
  + UefiCpuPkg/SmmCpu: Block access-out only when static paging is
    used
  + MdeModulePkg/Core: fix ineffective guard page issue
  + MdeModulePkg/Core: fill logic hole in
    MemoryProtectionCpuArchProtocolNotify
  + MdeModulePkg/Mtftp4Dxe: Fix invalid configuration of MTFTP
    local port
  + OvmfPkg: Replace obsoleted network drivers from platform DSC/FDF
  + MdePkg/Base.h: Implement BASE_CR() via OFFSET_OF()
  + MdeModulePkg/PiSmmIpl: Do not reset SMRAM to UC when CPU driver
    runs
  + NetworkPkg/TlsDxe: Fix failure to process multiple TLS records
  + BaseTools ConvertFceToStructurePcd: Fix the array value with
    empty string
  + CryptoPkg/BaseCryptLib: Fix potential integer overflow issue
  + ArmPkg/OpteeLib: Add APIs to communicate with OP-TEE
  + UefiCpuPkg/PiSmmCpuDxeSmm: Fix ASSERT for success
  + UefiCpuPkg/MpInitLib: Fix ASSERT for success
  + MdeModulePkg/Core: fix an issue of potential NULL pointer access
  + NetworkPkg/Mtftp6Dxe: Correct the total received and saved
    block number
  + MdeModulePke/Mtftp4Dxe: Correct the total received and saved
    block number
  + MdeModulePkg EhciDxe: Extract new EhciInsertAsyncIntTransfer
    function
  + MdeModulePkg XhciDxe: Extract new XhciInsertAsyncIntTransfer
    function
  + BaseTools: Sync the DevicePath Function update from MdePkg
  + MdeModulePkg/HiiDB: Make sure database update behaviors are
    atomic
  + MdeModulePkg/HiiDB: Reorganize codes of exporting HII settings
  + UefiCpuPkg/RegisterCpuFeaturesLib: Support combo CPU feature
    style
  + UefiCpuPkg/RegisterCpuFeaturesLib: Fix ECC issues
  + MdeModulePkg/Core: add freed-memory guard feature
  + MdeModulePkg/Core: prevent re-acquire GCD memory lock
  + UefiCpuPkg/CpuDxe: prevent recursive calling of
    InitializePageTablePool
  + UefiCpuPkg/CpuDxe: consider freed-memory guard in non-stop mode
  + MdeModulePkg: introduce UEFI freed-memory guard bit in HeapGuard
    PCD
  + MdeModulePkg/NvmExpressDxe: Refine PassThru IO queue creation
    behavior
  + MdeModulePkg/NvmExpressDxe: Always copy CQ entry to PassThru
    packet
  + MdeModulePkg/NvmExpressDxe: Refine data buffer & len check in
    PassThru
  + MdePkg: Handle various device path when optional para is not
    specified
  + FatPkg: Correct the line ending to CRLF
  + MdePkg-BaseLib: Fix PathCleanUpDirectories() issue with
    "\\..\\.."
  + FatPkg/EnhancedFatDxe Fix Double Cluster Allocation
  + FatBinPkg: Remove FatBinPkg and refresh document
  + ShellPkg/dmem: Only dump sizeof (EFI_SYSTEM_TABLE) bytes for gST
  + MdeModulePkg/UsbMass: Fix USB key write failure
  + IntelFrameworkModulePkg: Add more checker in
    UefiTianoDecompressLib (CVE FIX)
  + MdePkg: Add more checker in UefiDecompressLib to access the
    valid buffer only (CVE FIX)
  + MdeModulePkg/PartitionDxe: Add check for underlying device
    block size (bsc#1130267, CVE-2019-0160)
  + MdeModulePkg Xhci: Handle value 5 in Port Speed field of PORTSC
  + MdeModulePkg XhciDxe: Assign Usb2Hc.XXXRevision based on SBRN
  + MdePkg/BaseLib: AsciiStrToUnicodeStr(S) not handle EASCII
    properly
  + UefiCpuPkg/CpuCommonFeaturesLib: Register MSR base on scope Info
  + UefiCpuPkg/CpuS3DataDxe: Keep old data if value already existed
  + UefiCpuPkg/PiSmmCpuDxeSmm: Add logic to support semaphore type
  + UefiCpuPkg/RegisterCpuFeaturesLib: Add logic to support
    semaphore type
  + UefiCpuPkg/RegisterCpuFeaturesLib.h: Add new dependence types
  + UefiCpuPkg/Include/AcpiCpuData.h: Add Semaphore related
    Information
  + NetworkPkg/IpSecDxe: Fix issue to parse SA Payload
  + NetworkPkg: Correct the time stamp and fix the integer overflow
    issue
  + NetworkPkg/TlsDxe: Remove the redundant library class
  + MdePkg UefiLib: Check Table against NULL in ScanTableInSDT
  + MdeModulePkg BrotliDecompressLib: Add the checker to avoid array
    out of bound
  + UefiCpuPkg/CpuExceptionHandlerLib: always clear descriptor data
    in advance
  + fix InternalSyncCompareExchange*()
  + MdeModulePkg Variable: Fix Timestamp zeroing issue on
    APPEND_WRITE
  + MdeModulePkg/Bus/Ufs: Ensure device not return more data than
    expected
  + MdeModulePkg/AbsPointer: Don't access key codes when length is
    wrong
  + MdeModulePkg BrotliCustomDecompressLib: Don't build it for EBC
    arch
  + MdeModulePkg RegularExpressionDxe: Enable STDARG for variable
    arguments
  + MdeModulePkg/RegularExpressionDxe: Miss null pointer check
  + MdeModulePkg PcdDxe: ASSERT PcdSetNvStoreDefaultId set
  + UefiCpuPkg/S3Resume2Pei: disable paging before creating new
    page table
  + MdeModulePkg/SdMmcPciHcDxe: Allow additional SDHCI versions
  + MdeModulePkg/SdMmcPciHcDxe: Add controller version defines
  + MdePkg: Use VENDOR_DEVICE_PATH structure for Debug Port device
    path
  + ShellPkg-Cd: Ensure all valid cd targets are handled properly
  + MdePkg-BaseLib: Fix PathCleanUpDirectories() error involving
    "\..\.."
  + MdeModulePkg/NonDiscoverablePciDeviceDxe: expose unique B/D/F
    identifiers
  + MdeModulePkg: Update Brotli DecompressLib to the latest v1.0.6
  + BaseTools: Update Brotli Compress to the latest one 1.0.6
  + MdePkg: Add PciRoot/PcieRoot text for ACPI Expanded Device Path
  + MdePkg: Correct condition check for AcpiExp text format
  + MdePkg: Correct the string order of ACPI Expanded Device Path
  + MdePkg: Correct the string expression of UTF8 vendor device path
  + MdeModulePkg/HiiDB: Fix incorrect structure convention for
    checkbox
  + Lzma: Update LZMA SDK version to 18.05
  + OvmfPkg/PlatformPei: clear CPU caches
  + Various BaseTools clean up and fixes
  + Various UDF fixes
  + Various USB fixes
- Drop upstreamed patches
  + ovmf-bsc1115916-fix-timestamp-zeroing.patch
  + ovmf-bsc1115917-bounds-checking-for-ueficompress.patch
* Wed Nov 14 2018 Gary Ching-Pang Lin <glin@suse.com>
- Add ovmf-bsc1115916-fix-timestamp-zeroing.patch to fix Timestamp
  zeroing issue on APPEND_WRITE (bsc#1115916, CVE-2018-3613)
- Add ovmf-bsc1115917-bounds-checking-for-ueficompress.patch for
  the bound checking of ueficompress (bsc#1115917, CVE-2017-5731,
  CVE-2017-5732, CVE-2017-5733, CVE-2017-5734, CVE-2017-5735)
* Fri Oct  5 2018 Gary Ching-Pang Lin <glin@suse.com>
- Update to 2018+git1538590187.c0b1f749ef13
  + ShellPkg: Create a homefilesystem environment variable
  + NetworkPkg/HttpUtilitiesDxe: fix read memory access overflow
  + NetworkPkg/HttpDxe: fix read memory access overflow in HTTPBoot
  + PcAtChipsetPkg PcRtc: Use new EfiLocateFirstAcpiTable()
  + MdeModulePkg S3SaveStateDxe: Use new EfiLocateFirstAcpiTable()
  + MdePkg UefiLib: Add new EfiLocateXXXAcpiTable() APIs
  + NetworkPkg/UefiPxeBcDxe: Add the clarification compared to
    UefiPxeBcDxe in MdeModulePkg
  + NetworkPkg/IScsiDxe: Add the clarification compared to
    IScsiDxe in MdeModulePkg
  + NetworkPkg/TcpDxe: Add the clarification compared to Tcp4Dxe
    in MdeModulePkg
  + MdeModulePkg/UefiPxeBcDxe: Add the clarification compared
    to UefiPxeBcDxe in NetworkPkg
  + MdeModulePkg/IScsiDxe: Add the clarification compared to
    IScsiDxe in NetworkPkg
  + MdeModulePkg/Tcp4Dxe: Add the clarification compared to TcpDxe
    in NetworkPkg
  + NetworkPkg/UefiPxeBcDxe: Use the specified MTFTP windowsize
  + NetworkPkg: Define one PCD for PXE to specify MTFTP windowsize
  + NetworkPkg/Mtftp6Dxe: Support windowsize in read request
    operation
  + MdeModulePke/Mtftp4Dxe: Support windowsize in read request
    operation
  + MdePkg/BaseSynchronizationLib: fix XADD operands in GCC
    IA32/X64 assembly
  + MdeModulePkg/PciHostBridge: Fix a bug that prevents PMEM
    access
  + MdeModulePkg/PciHostBridge: Enhance boundary check in
    Io/Mem.Read/Write
  + MdeModulePkg/DxeIpl: support more NX related PCDs
  + MdeModulePkg: XhciDxe: Prevent illegal memory access in
    XhcSetHsee
  + SecurityPkg/TcgStorageOpalLib: Fixed correct user password
    not works issue
  + MdeModulePkg/SdMmcPciHcDxe: Execute card detect only for
    RemovableSlot
  + MdeModulePkg/SdMmcPciHcDxe: Fix SdMmcHcReset to set only
    necesery bits
  + NetworkPkg: UefiPxeBcDxe: Add EXCLUSIVE attribute when opening
    SNP protocol installed by PXE
  + BaseTools: Check GUID C structure format
  + MdeModulePkg: Avoid key notification called more than once
  + IntelFrameworkModulePkg: Avoid key notification called more
    than once
  + MdeModulePkg/Library/DxeHttpLib: Handle the blank value in
    HTTP header
  + MdeModulePkg/Ip4Dxe: Sync the direct route entry setting
  + MdeModulePkg XhciDxe: Set HSEE Bit if SERR# Enable Bit is set
  + BaseTools: Correct DXE_PCD_DATABASE_INIT
  + BaseTools: Check PcdNvStoreDefaultValueBuffer
  + BaseTools: Involve Dec default value to calculate Maxsize
  + BaseTools: Structure Pcd value override incorrect
  + BaseTools: Report error for incorrect hex value format
  + MdeModulePkg/ConPlatform: Support short-form USB device path
  + UefiCpuPkg/CpuDxe: fix an incorrect bit-wise operation
  + UefiCpuPkg/CpuDxe: fix ECC reported issues
  + UefiCpuPkg/CpuMpPei: support stack guard feature
  + UefiCpuPkg/MpInitLib: fix register restore issue in AP wakeup
  + UefiCpuPkg/CpuExceptionHandlerLib: support stack switch for
    PEI exceptions
  + MdeModulePkg/DxeIpl: disable paging before creating new page
    table
  + MdeModulePkg PeiCore: Always use PeiImageRead() function to
    load PEI image
  + MdeModulePkg/EhciDxe: factor out EhcIsDebugPortInUse()
  + BaseTools/PatchCheck.py: Fix error when run with Python3
  + BaseTools: Report more clear error message for PCD used in
    expression
  + BaseTools: Fix a bug about list the PCD in "not used" section
  + UefiCpuPkg/MpInitLib: Fix ECC issues
  + MdeModulePkg/EhciDxe: fix host controller reset condition in
    BindingStart
  + BaseTools: Extend the keyword "!include"/"!if" to
    case-insensitive
  + MdeModulePkg/Setup: Fix incorrect size used in AllocateCopyPool
  + MdeModulePkg DxeCore: Handle multiple FV images in one FV file
  + MdeModulePkg PeiCore: Handle multiple FV images in one FV file
  + UefiCpuPkg/CpuExceptionHandlerLib: Avoid calling PEI services
    from AP
  + CpuExceptionHandlerLib: Add comments to make code more readable
  + BaseTools: Fixed the PcdValue trailing zero issue
  + BaseTools: Dynamic Pcd value override from command line
  + BaseTools: Check pcd DefaultValue and SkuId EBNF
  + ShellPkg: Update Ifconfig command to accept 32bit subnet mask
  + MdeModulePkg/Network: Add 32bit subnet mask support for IP4
    PXE boot
  + BaseTools: Clarify a DSC parsing error about PCDs
  + BaseTools: minimize assignment processing
  + BaseTools: Refactor to remove functionally equivalent
    functions
  + BaseTools: include variable namespace GUIDs of HII PCDs in
    Guid.xref
  + ShellPkg/SmbiosView: Update SmbiosView for SMBIOS3.2.0
  + UefiCpuPkg/CpuDxe: change level of DEBUG message
  + UefiCpuPkg/CpuDxe: implement non-stop mode for uefi
  + UefiCpuPkg/CpuExceptionHandlerLib: Setup single step in #PF
    handler
  + MdeModulePkg/MdeModulePkg.dec: add new settings for PCDs
  + MdePkg: Add the missing spec version information for header
    files
  + BaseTools: Fix one expression bug to support ~ operate
  + BaseTools: Add check only VOID* type Pcd need the maxsize info
  + MdeModulePkg: Update SMBIOS PCDs to 3.2.0
  + MdePkg SmBios.h: Add SMBIOS 3.2.0 definitions
  + MdeModulePkg/PciBus: Restrict one VGA per HostBridge not
    Segment
  + MdeModulePkg/PciBus: Refine ActiveVGADeviceOnTheRootBridge
  + ArmPkg/PlatformBootManagerLib: fix hotkey of boot option
  + BaseTools: Use hashlib instead of md5
  + BaseTools: remove cmp due to deprecated in python3
  + BaseTools: Modify class OrderedListDic
  + BaseTools: Update Makefile for ECC tool
  + BaseTools/VfrCompile: honor EXTRA_LDFLAGS
  + NetworkPkg/TlsAuthConfigDxe: fix TlsCaCertificate attributes
    retrieval
  + IntelFrameworkPkg/FrameworkUefiLib: don't special-case
    EFI_FILE_MODE_CREATE
  + MdePkg/UefiLib: don't special-case EFI_FILE_MODE_CREATE in
    OpenMode
  + Remove redundant variables, functions, library clesses, and
    GUIDs
* Mon Aug 20 2018 glin@suse.com
- Update to 2018+git1534736099.43fe4c405292
  + BaseTools: AutoGen refactor ModuleAutoGen caching
  + OvmfPkg: link Sha384 and Sha512 support into Tcg2Pei and Tcg2Dxe
  + MdePkg/UefiLib: introduce EfiOpenFileByDevicePath()
  + BaseTools: Update the rule to remove .lib before link it for GCC
  + BaseTools: Add Dns and BluetoothLE DevicePath
  + MdeModulePkg SmmLockBox: Return actual data length in
    SmmLockBoxRestore
  + UefiCpuPkg/RegisterCpuFeaturesLib: Combine implementation
  + UefiCpuPkg/CpuS3DataDxe: Remove below 4G limitation
  + UefiCpuPkg/CpuS3DataDxe: Change Memory Type and address
    limitation
  + UefiCpuPkg/AcpiCpuData.h: Remove AcpiNVS and Below 4G limitation
  + UefiCpuPkg/PiSmmCpuDxeSmm: Use GDT/IDT saved in Smram
  + SecurityPkg/TcgStorageCoreLib.h: Use ascii instead of unicode
  + BaseTool: Fixed the bug of Boolean Hii Pcd packing
  + SecurityPkg: HashLib: Update HashLib file GUID
  + SecurityPkg/Library/Tpm2DeviceLibDTpm: fix s/Constructor/CONSTRUCTOR
  + OvmfPkg/PlatformDebugLibIoPort: fix port detection for use in
    the DXE Core
  + NetworkPkg/HttpDxe: Strip square brackets in IPv6 expressed
    HostName
  + MdeModulePkg/BdsDxe: Move display of test key usage into BDS
    module
  + ArmPkg: Add initial OpteeLib implementation
  + SecurityPkg: HashLib: Add SHA384, SHA512 HashLib
  + MdeModulePkg/BdsDxe: Call PlatformBootManagerUnableToBoot()
  + MdeModulePkg/BdsDxe: Revert "fall back to UI loop before hanging"
  + ArmVirtPkg/PlatformBDS: Implement PlatformBootManagerUnableToBoot
  + OvmfPkg/PlatformBds: Implement PlatformBootManagerUnableToBoot
  + MdeModulePkg/PciBusDxe: Fix small memory leak in FreePciDevice
  + MdeModulePkg/DxeCore: Not update RtCode in MemAttrTable after
    EndOfDxe
  + UefiCpuPkg/MpInitLib: Not use disabled AP when call StartAllAPs
  + UefiCpuPkg/MpInitLib: Remove redundant CpuStateFinished State
  + MdeModulePkg/DxeLoadFunc: Add use case for new Perf macro
  + SecurityPkg/Tcg: Add use case for new Perf macro
  + ArmVirtPkg: remove wrong and superfluous ResourcePublicationLib
    resolution
  + OvmfPkg: Correct ResourcePublicationLib class name in DSC/INF
    file
  + MdeModulePkg CapsuleApp: Do not parse bits in CapsuleFlags of
    ESRT
  + MdeModulePkg, TpmMeasureLib: Variable: Re-prioritize TCG/TCG2
    protocol
  + SecurityPkg: TcgSmm: Handle invalid parameter in MOR SMI handler
  + OvmfPkg/XenPvBlkDxe: remove gEfiDevicePathProtocolGuid from
    [Protocols]
  + StandaloneMmPkg/Core: Implementation of Standalone MM Core Module
  + UefiCpuPkg/CpuDxe: fix incorrect check of SMM mode
  + UefiCpuPkg/MpInitLib: Optimize get processor number performance
  + OvmfPkg/AcpiPlatformDxe: clean up libs and protos in
    "AcpiPlatformDxe.inf"
  + UefiCpuPkg/MpInitLib: Fix S3 resume hang issue
  + UefiCpuPkg/MpInitLib: Use BSP uCode for APs if possible
  + UefiCpuPkg/MpInitLib: Relocate uCode to memory to save time
  + Update BaseTools for the preparation of python3 adoption
- Refresh ovmf-pie.patch and ovmf-gdb-symbols.patch
* Fri Jul 13 2018 glin@suse.com
- Update to 2018+git1531464032.ae08ea246fe9
  + ArmVirtPkg/ArmVirtQemu: enable the IPv6 stack
  + SecurityPkg: Fix assert when setting key from eMMC/SD/USB
  + UefiCpuPkg/MpInitLib: Avoid calling PEI services from AP
  + NetworkPkg/HttpDxe: Fix the bug when parsing HTTP(S) message
    body
  + SecurityPkg/OpalPassword: Fixed input correct password not
    works issue
  + SecurityPkg/TcgStorageOpalLib: Return AUTHORITY_LOCKED_OUT error
  + OvmfPkg/QemuFlashFvbServicesRuntimeDxe: Restore C-bit when SEV
    is active
  + OvmfPkg/QemuFlashFvbServicesRuntimeDxe: Do not expose MMIO in
    SMM build
  + OvmfPkg/QemuFlashFvbServicesRuntimeDxe: mark Flash memory
    range as MMIO
  + MdeModulePkg/Variable: Check EFI_MEMORY_RUNTIME attribute
    before setting it
  + MdeModulePkg SataControllerDxe: Calculate ChannelCount based
    on PI value
  + SecurityPkg Tpm2DeviceLibDTpm: Update enum type name to match
    the one in lib
  + MdeModulePkg UsbBusDxe: Fix wrong buffer length used to read
    hub desc (bsc#1131361, CVE-2019-0161)
  + SecurityPkg: Tpm2DeviceLib: Enable CapCRBIdleBypass support
  + SecurityPkg: Cache TPM interface type info
  + FatPkg/FatPei: Add the recognition of recovery capsule on NVME
    device
  + MdeModulePkg/NvmExpressPei: Add the NVME device PEI BlockIo
    support
  + MdeModulePkg: Add definitions for EDKII PEI NVME host
    controller PPI
  + ArmPkg/ArmMmuLib ARM: fix Mva to use idx instead of table base
  + ArmPkg/ArmMmuLib ARM: assume page tables are in writeback
    cacheable memory
  + ArmPkg/ArmMmuLib ARM: remove cache maintenance of block mapping
    contents
  + MdeModulePkg: Enable SATA Controller PCI mem space
  + MdeModulePkg/NetworkPkg: Checking for NULL pointer before use
  + MdeModulePkg/Core: remove SMM check for Heap Guard feature
    detection
  + UefiCpuPkg/CpuDxe: allow accessing (DXE) page table in SMM mode
  + BaseTools/tools_def IA32: drop -no-pie linker option for GCC49
  + SecurityPkg/SecureBootConfigDxe: Fix invalid NV data issue
  + ArmVirtPkg: add QemuRamfbDxe
  + OvmfPkg: add QemuRamfbDxe
  + BaseTools/tools_def IA32: disable PIE code generation explicitly
  + MdePkg UefiLib: Use comparison logic to check UINTN parameter
  + ArmVirtPkg: switch to KVM safe IoLib implementation
  + MdePkg/BaseIoLibIntrinsic: make BaseIoLibIntrinsic safe for
    ArmVirt/KVM
  + ArmPkg/CompilerIntrinsicsLib: fix GCC8 warning for
    __aeabi_memcpy aliases
- The IP6 stack of AAVMF is enabled
* Mon Jun 11 2018 glin@suse.com
- Update to 2018+git1528497654.eb5943134630
  + CryptoPkg PeiCryptLib: Enable SHA384/512 support
  + MdePkg/UefiRuntimeLib: Do not allow to be linked by DXE driver
  + CryptoPkg: Remove deprecated function usage in
    X509GetCommonName()
  + PlatformBootManagerLib: add missing report status code call
  + OvmfPkg: raise DXEFV size to 11 MB
  + SignedCapsulePkg/PlatformFlashAccessLib: Add progress API
  + MdeModulePkg: Add DisplayUpdateProgressLib class
  + PcAtChipsetPkg/PcRtc: Add two new PCD for RTC Index/Target
    registers
  + OvmfPkg/Virtio10Dxe: convert to PciCapLib
  + OvmfPkg/PciHotPlugInitDxe: convert to PciCapLib
  + ArmVirtPkg: resolve PciCapLib, PciCapPciSegmentLib,
    PciCapPciIoLib
  + OvmfPkg: resolve PciCapLib, PciCapPciSegmentLib, PciCapPciIoLib
  + OvmfPkg: introduce PciCapPciIoLib
  + OvmfPkg: introduce PciCapPciSegmentLib
  + OvmfPkg: introduce PciCapLib
  + BaseTools/tools_def: add "-fno-unwind-tables" to
    GCC_AARCH64_CC_FLAGS
  + OvmfPkg/PlatformBootManagerLib: process TPM PPI request
  + OvmfPkg: add Tcg2PhysicalPresenceLibQemu
  + OvmfPkg/IndustryStandard: add QemuTpm.h header
  + OvmfPkg: add Tcg2PhysicalPresenceLibNull when !TPM2_ENABLE
  + MdePkg/SmmPeriodicSmiLib: Get Periodic SMI Context More Robustly
  + OvmfPkg/PlatformBootManagerLib: connect Virtio RNG devices again
  + ArmVirtPkg/PlatformBootManagerLib: connect Virtio RNG devices
    again
  + OvmfPkg/QemuVideoDxe: Enable DISPLAY_OTHER pci class for qemu
    stdvga
  + OvmfPkg/QemuVideoDxe: Add SubClass field to QEMU_VIDEO_CARD
  + OvmfPkg/PlatformBootManagerLib: connect consoles unconditionally
  + BaseTools: Fix generating array's size is incorrect in AutoGen.c
  + BaseTools: incorrect calculation for 16M
* Fri May 18 2018 glin@suse.com
- Enable TLS support correctly
* Thu May 17 2018 glin@suse.com
- Enable TPM 2.0 support
* Thu May 10 2018 glin@suse.com
- Update to 2018+git1525854636.13e3f8c03339
  + BaseTools/VfrCompile: Avoid using uninitialized pointer
  + MdeModulePkg/PciHostBridge: Count the (mm)io overhead when polling
  + UefiCpuPkg/SecMain: Add NORETURN decorator to SecStartup()
  + CryptoPkg/CrtLibSupport: add secure_getenv() stub function
  + MdeModulePkg/AcpiPlatformDxe: Unload after execution
  + SecurityPkg/OpalPassword: Add support for pyrite 2.0 devices
  + NetworkPkg/NetworkPkg.dsc: Add the instance of library class
    [SafeIntLib]
  + ArmVirtPkg: use protocol-based DevicePathLib instance for most
    DXE modules
  + OvmfPkg/QemuVideoDxe: round up FrameBufferSize to full page
  + ArmVirtPkg: reinstate timer unmask quirk for Xen
  + ArmPkg/TimerDxe: remove workaround for KVM timer handling
  + FatPkg/EnhancedFatDxe: Ensure traverse of subtasks is
    delete-safe
  + OvmfPkg/PlatformBootManagerLib: add USB keyboard to ConIn
  + CryptoPkg/OpensslLib: Update OpenSSL version to 1.1.0h
    (bsc#1094289, CVE-2018-0739)
  + OvmfPkg/TlsAuthConfigLib: configure trusted cipher suites for
    HTTPS boot
  + ArmVirtPkg/ArmVirtQemu: hook NvVarStoreFormattedLib into
    VariableRuntimeDxe
  + ArmPlatformPkg/NorFlashDxe: cue the variable driver with
    NvVarStoreFormatted
  + ArmPlatformPkg/NorFlashDxe: initialize varstore headers eagerly
  + OvmfPkg: remove BLOCK_MMIO_PROTOCOL and BlockMmioToBlockIoDxe
  + OvmfPkg/TlsAuthConfigLib: configure trusted CA certs for
    HTTPS boot
  + MdeModulePkg/Variable/RuntimeDxe: introduce
    PcdMaxVolatileVariableSize
  + NetworkPkg/TlsAuthConfigDxe: preserve TlsCaCertificate variable
    attributes
  + NetworkPkg/HttpDxe: drop misleading comment / status code in
    cert config
  + NetworkPkg/HttpDxe: use error handler epilogue in
    TlsConfigCertificate()
  + NetworkPkg/HttpBootDxe: fix typo in DHCPv4 packet parsing
  + OvmfPkg/QemuVideoDxe: handle invalid BltOperation gracefully
  + NetworkPkg/UefiPxeBcDxe: Configure the ARP Instance/RouteTable
    with new address
  + NetworkPkg/HttpDxe: Handle the large data request via HTTPS
    channel
  + NetworkPkg/TlsDxe: Handle the multiple TLS record messages
    encryption/decryption
  + SecurityPkg Tpm12CommandLib: Fix TPM12 GetCapability response
    error
  + SecurityPkg Tpm2CommandLib: Fix TPM2.0 response memory overflow
  + MdeModulePkg/DxeMain: Fix BSP interrupts reenabled in
    ExitBootServices
  + UefiCpuPkg/MpInitLib: Disable interrupt at ExitBootServices AP
    Mwait
  + OvmfPkg/PlatformBootManagerLib: process "-kernel" before boot
    devices
  + OvmfPkg/PlatformBootManagerLib: hoist PciAcpiInitialization()
  + ArmVirtPkg/PlatformBootManagerLib: return to "-kernel before
    boot devices"
  + MdeModulePkg/Core: allow HeapGuard even before CpuArchProtocol
    installed
  + UefiCpuPkg CpuExceptionHandlerLib: use FixedPcdGetSize() as the
    macro value
  + remove TrEE
  + MdeModulePkg/PciBus: return CPU address for GetBarAttributes
  + MdeModulePkg/PciBus: convert host address to device address
  + MdeModulePkg/PciHostBridgeDxe: Add support for address translation
  + OvmfPkg/PciHostBridgeLib: clear PCI aperture vars for (re)init
  + ArmPkg/TimerDxe: Add ISB for timer compare value reload
  + BaseTools code refactoring
* Thu Mar 15 2018 glin@suse.com
- Update to 2018+git1521096615.b3fa393f477a
  + OvmfPkg/QemuBootOrderLib: add ConnectDevicesFromQemu()
  + NetworkPkg/IScsiDxe: Fix the ISCSI connection failure in
    certain case
  + OvmfPkg/QemuFlashFvbServicesRuntimeDxe: Clear C-bit when SEV is
    active (bsc#1099193)
  + OvmfPkg: include Tcg2Dxe module
  + OvmfPkg: simplify SecurityStubDxe.inf inclusion
  + OvmfPkg/AmdSevDxe: decrypt the pages of the initial SMRAM save
    state map
  + OvmfPkg/SmmCpuFeaturesLib: SEV: encrypt+free pages of init.
    save state map
  + OvmfPkg/PlatformPei: SEV: allocate pages of initial SMRAM save
    state map
  + OvmfPkg/MemEncryptSevLib: find pages of initial SMRAM save
    state map
  + MdeModulePkg/UsbMass: Retry CMD for MediaChanged sense key
  + NetworkPkg/HttpDxe: Support HTTP Delete Method
  + NetworkPkg/HttpBootDxe: Fix the incorrect error message output
  + MdeModulePkg: Add Boot Logo 2 Protocol
  + MdeModulePkg/UsbMass: Fix hot-plug USB CDROM can't be recognized
  + NetworkPkg: Read HttpTlsCipherList variable and configure it
    for HTTPS session
  + NetworkPkg: Define one private variable for HTTPS to set Tls
    CipherList
  + ArmVirtPkg: Add SafeIntLib and BmpSupportLib to DSC files
  + OvmfPkg: Add SafeIntLib and BmpSupportLib to DSC files
  + UefiCpuPkg/PiSmmCpuDxeSmm: fix infinite loop issue in SMM profile
  + MdeModulePkg Ppi/IoMmu.h: Add EFI_NOT_AVAILABLE_YET return
    status code
  + MdeModulePkg/Core: fix feature conflict between NX and heap guard
  + ReadKeyStrokeEx always return key state
  + SecurityPkg: Tcg2Smm: Enable TPM2.0 interrupt support
  + MdeModulePkg/Partition: Fix media probe
  + NetworkPkg/HttpBootDxe: Avoid to corrupt HttpBootDxe setup screen
  + MdeModulePkg/UefiBootManagerLib: Skip the DNS device path node check
  + MdeModulePkg/Core: fix a logic hole in page free
  + OvmfPkg/BaseMemEncryptSevLib: Enable protection for newly
    added page table
  + MdeModulePkg/Ip4Dxe: Add an independent timer for reconfig checking
  + NetworkPkg: Fix a memory leak issue in UDP6 driver
  + UefiCpuPkg/MtrrLib: Fix bug that may calculate wrong MTRR result
  + MdeModulePkg/DxeNetLib: Fix an error in packet length counting
  + NetworkPkg: Fix memory leak problem in PXE driver
  + MdeModulePkg/DxeHttpLib: Add boundary condition check
  + CryptoPkg/OpensslLib: Update OpenSSL version to 1.1.0g
  + MdeModulePkg/Core: Fix heap guard issues
  + NetworkPkg/HttpBootDxe: Break the HttpBoot Callback function
    when meet redirect status
  + NetworkPkg/HttpBootDxe: Avoid the potential memory leak when
    eror happen
  + MdeModulePkg/DxeIplPeim: fix incorrect page table split during
    protecting
  + NetworkPkg/UefiPxeBcDxe: Allow the NULL configuration for
    NewStationIP/NewSubnetMask
  + NetworkPkg/UefiPxeBcDxe: Fix Pxe.Dhcp() return status code
  + MdeModulePkg/Dhcp*: Check Media status before starting DHCP process
  + MdeModulePkg/Ip4Dxe: fix ICMP echo reply memory leak
  + NetworkPkg/DnsDxe: Update RetryCount/RetryInterval to comply
    with UEFI spec
  + MdeModulePkg/TcpIoLib: Cancel TCP token if connect/accept is
    timeout
  + MdeModulePkg/TcpIoLib: Check input Timeout before calling
    CheckEvent() service
  + MdeModulePkg/DxeIpl: Mark page table as read-only
  + SecurityPkg:Tcg2Smm:Enabling TPM SIRQ interrupt support
  + MdeModulePkg/ScsiDisk: Return EFI_NO_MEDIA when no media presents
  + BaseTool/tools_def GCC5: enable optimization for ARM/AARCH64
    DEBUG builds
  + UefiCpuPkg/CpuDxe: Initialize stack switch for MP
  + UefiCpuPkg/CpuExceptionHandlerLib: Add stack switch support
  + UefiCpuPkg PiSmmCpuDxeSmm: SMM profile and static paging mutual
    exclusion
  + MdeModulePkg/NetLib: Fix an error when AIP doesn't support
    network media state detection
  + MdeModulePkg/NetLib: Add NetLibDetectMediaWaitTimeout() API to
    support EFI_NOT_READY media state detection
  + MdeModulePkg/Core/Dxe: log informative memprotect msgs at
    DEBUG_INFO level
  + ArmVirtPkg/ArmVirtXen: move from Intel to generic BDS
  + MdeModulePkg/SerialDxe: Do not fail reset when SetAttributes is
    not supported
  + MdeModulePkg/DxeCorePerformanceLib: add lock protection
  + OvmfPkg/QemuBootOrderLib: let an OFW devpath match multiple
    UEFI boot opts
  + OvmfPkg/QemuBootOrderLib: skip already matched / appended UEFI
    boot opts
  + MdeModulePkg/Core: Merge memory map after filtering paging
    capability
  + ArmVirtPkg/PrePi: don't export PE/COFF and LZMA libraries via HOBs
  + MdeModulePkg/BdsDxe: fall back to a Boot Manager Menu loop
    before hanging
  + SecurityPkg/SecureBootConfigDxe: Fix deleting signature data issue
  + CryptoPkg/IntrinsicLib: Fix the warning on memset
  + MdeModulePkg/DxeCore: Filter out all paging capabilities
    (bsc#1092943)
  + CryptoPkg/TlsLib: Change the return type of TlsInitialize()
  + NetworkPkg/HttpDxe: Fix the incorrect SizeofHeaders in
    HttpTcpReceiveHeader()
  + ArmVirtPkg: introduce ArmVirtMemInfoLib library class
  + ArmVirtPkg/PrePi: remove bogus primary core check
  + BaseTools/tools_def AARCH64 ARM: suppres PIE sections via
    linker script
  + PcAtChipsetPkg: Define FixePCD's for RTC register values
  + MdeModulePkg EhciPei: Minor refinement about IOMMU
  + MdeModulePkg/UefiBootManagerLib: Remove assertion
  + MdeModulePkg EhciPei: Also check Buf against NULL to return error
  + MdeModulePkg/UsbMassStorageDxe: Check Get Max LUN status/value
  + MdeModulePkg/UsbBusDxe: Add UsbControlTransfer() error check
  + BaseTools: Fix a bug for single module build with GenC/GenMake option
  + MdeModulePkg/PiSmmCore: Fix an assert issue in pool free
  + BaseTools: Fix the bug to collect source files per build rule family
  + MdeModulePkg/UdfDxe: Avoid possible loss track of allocated buffer
  + MdeModulePkg/PartitionDxe: Merge the discovery of ElTorito into UDF
- Refresh ovmf-gdb-symbols.patch and ovmf-pie.patch
- Modify openssl tarball unpacking to fit the change in ovmf
* Wed Jan 24 2018 glin@suse.com
- Only use SLES-UEFI-CA-Certificate-2048.crt for the suse flavor to
  provide the better compatibility (bsc#1077330)
* Mon Nov 20 2017 glin@suse.com
- Update to 2017+git1510945757.b2662641d5
  + ArmPlatformPkg/ArmPlatformLibNull: remove bogus PCD dependencies
  + MdeModulePkg/UsbMassStorageDxe: Enhance Request Sense Handling
  + OvmfPkg: save on I/O port accesses when the debug port is not
    in use
  + OvmfPkg: create a separate PlatformDebugLibIoPort instance for
    SEC
  + OvmfPkg: make PlatformDebugLibIoPort a proper BASE library
  + OvmfPkg: restore temporary SEC/PEI RAM size to 64KB
  + OvmfPkg/Sec/X64: seed the temporary RAM with PcdInitValueInTempStack
  + ArmVirtPkg: switch to new PL011UartLib implementation
  + OvmfPkg/XenHypercallLib: enable virt extensions for ARM
  + MdeModulePkg/PiSmmCore: Implement heap guard feature for SMM mode
  + MdeModulePkg/DxeCore: Implement heap guard feature for UEFI
  + ArmVirtPkg/ArmVirtQemu: use non-accelerated CopyMem for
    VariableRuntimeDxe
  + NetworkPkg: Fix incorrect SizeofHeaders returned from
    HttpTcpReceiveHeader()
  + NetworkPkg: Print error message to screen if error occurs
    during HTTP boot
  + MdeModulePkg/PartitionDxe: Fix UDF fs access on certain CD/DVD
    medias
  + MdeModulePkg/UsbMassStorageDxe: Fix USB Mass Storage detection
  + MdeModulePkg SerialDxe: Handle Timeout change more robustly
  + CryptoPkg/BaseCryptLib: Fix mismatched memory allocation/free
  + CryptoPkg/BaseCryptLib: Fix buffer overflow issue in realloc
    wrapper
  + ArmPlatformPkg/PlatformPeim: allow PlatformPeiLib to set the
    boot mode
  + Deprecate EFI_VARIABLE_AUTHENTICATED_WRITE_ACCESS
  + SecurityPkg: Remove Counter Based AuthVariable support
  + BaseTools/tools_def AARCH64 ARM: disable PIE linking
  + NetworkPkg/TlsAuthConfigDxe: Remove the extra FreePool
  + NetworkPkg/HttpBootDxe: Add IPv6 support condition check
  + NetworkPkg/IScsiDxe: Fix the incorrect/needless DHCP process
  + MdeModulePkg/PciBus: Fix bug that PCI BUS claims too much resource
  + UefiCpuPkg/MtrrLib: Use SetMem instead of SetMem64 to fix hang
  + NetworkPkg: Remove ping6 and ifconfig shell application
  + OvmfPkg: fix dynamic default for oprom verification policy PCD
    without SB
  + OvmfPkg/PlatformPei: DENY_EXECUTE_ON_SECURITY_VIOLATION when
    SEV is active
  + SecurityPkg\Tcg2Pei: FV measure performance enhancement
  + SecurityPkg:AuthVariableLib:Implement ECR1707 for Private Auth
    Variable
  + ArmPlatformPkg: Store initial timer value
  + ArmVirtPkg ArmVirtDxeHobLib: Implement BuildFv3Hob
  +  MdeModulePkg/Variable/RuntimeDxe: delete and lock OS-created
    MOR variable
  + ArmPkg/PlatformBootManagerLib: fix bug in ESRT invocation
  + OvmfPkg/PciHotPlugInitDxe: translate QEMU's resource
    reservation hints
  + OvmfPkg/PciHotPlugInitDxe: generalize RESOURCE_PADDING
    composition
  + OvmfPkg/IndustryStandard: define PCI Capabilities for QEMU's
    PCI Bridges
  + MdeModulePkg/BdsDxe: Don't delete "BootNext" until booting it
  + Clarify the usage of HttpConfigData in HTTP protocol
  + SecurityPkg/SecureBootConfigImpl.c: Secure Boot DBX UI
    Enhancement
  + MdeModulePkg/UDF: Fix creation of UDF logical partition
  + CryptoPkg: Add new API to retrieve commonName of X.509 certificate
  + OvmfPkg/VirtioNetDxe: log debug message in VirtioNetExitBoot()
  + OvmfPkg/QemuBootOrderLib: recognize "usb-storage" devices in
    XHCI ports
  + MdeModulePkg/Core: Fix out-of-sync issue in GCD
  + UefiCpuPkg/CpuDxe: Fix out-of-sync issue in page attributes
  + OvmfPkg/QemuVideoDxe/VbeShim: handle PAM1 register on Q35
    correctly
  + OvmfPkg/QemuVideoDxe/VbeShim: rename Status to
    Segment0AllocationStatus
  + OvmfPkg/CsmSupportLib: move PAM register addresses to
    IndustryStandard
  + NetworkPkg/IScsiDxe: Remove redundant call to StrLen
  + BaseTools/tools_def AARCH64: enable frame pointers for RELEASE
    builds
  + ArmPkg/PlatformBootManagerLib: process pending capsules
  + MdeModulePkg/Udf: Avoid declaring and initializing local GUID
    variable
  + MdeModulePkg/UdfDxe: Avoid short (single character) variable name
  + MdeModulePkg/UdfDxe: Use compare operator for non-boolean
    comparisons
  + MdeModulePkg/UdfDxe: Fix operands of different size in bitwise
    OP
  + MdeModulePkg/UdfDxe: Add checks to ensure no possible NULL ptr
    deref
  + MdeModulePkg/SerialDxe: Fix not able to change serial attributes
  + NetworkPkg: Remove the redundant '/' in the end of returned
    ISCSIMacAddr keyword
  + MdeModulePkg/UdfDxe: Fix NULL pointer dereference
  + OvmfPkg/VirtioNetDxe: negotiate VIRTIO_F_IOMMU_PLATFORM
  + OvmfPkg/VirtioNetDxe: map caller-supplied Tx packet to
    device-address
  + OvmfPkg/VirtioNetDxe: add Tx packet map/unmap helper functions
  + OvmfPkg/VirtioNetDxe: update TechNotes
  + OvmfPkg/VirtioNetDxe: dynamically alloc transmit header
  + OvmfPkg/VirtioNetDxe: alloc RxBuf using AllocateSharedPages()
  + OvmfPkg/VirtioNetDxe: map VRINGs using VirtioRingMap()
  + OvmfPkg/VirtioNetDxe: add helper VirtioNetUninitRing()
- Update openssl to 1.1.0g
* Mon Oct 16 2017 glin@suse.com
- Update ovmf-gdb-symbols.patch to avoid some symbols from being
  removed (bsc#1063463)
- Add needssslcertforbuild back. It's useful for the devel projects.
* Thu Sep 14 2017 glin@suse.com
- Update to 2017+git1505340320.5afa5b8159
  + MdeModulePkg/UdfDxe: suppress incorrect compiler warning in
    ReadFile()
  + MdeModulePkg/UdfDxe: reject reserved values in ICB.Flags[2:0]
  + MdeModulePkg: Add UdfDxe to the dsc file
  + MdeModulePkg: Update PiDxeS3BootScriptLib Internal function name
  + MdeModulePkg/UdfDxe: Remove negative comparison of unsigned
    number
  + ArmVirtPkg/ArmVirtQemu: port HTTP_BOOT_ENABLE from OvmfPkg
  + ArmVirtPkg: don't build the network stack uselessly for Xen
  + MdeModulePkg/PartitionDxe: remove always false comparison
  + MdeModulePkg/PartitionDxe: don't divide 64-bit values with C
    operators
  + MdeModulePkg/UdfDxe: replace zero-init of local variables with
    ZeroMem()
  + MdeModulePkg/UdfDxe: don't return unset Status if INLINE_DATA
    req succeeds
  + MdeModulePkg/UdfDxe: ASSERT() valid ReadFileInfo Flags for
    INLINE_DATA req
  + MdeModulePkg/UdfDxe: Initialize the array after declaration
  + ShellPkg/Ifconfig6: Update error message and add a new line
  + NetworkPkg/IScsiDxe: Fix the incorrect max length of IP_ADDRESS
  + OvmfPkg/SataControllerDxe: log informative message at
    DEBUG_INFO level
  + OvmfPkg/PlatformBootManagerLib: log informative message at
    DEBUG_INFO lvl
  + OvmfPkg/PlatformPei: log informative message at DEBUG_INFO level
  + UefiCpuPkg/CpuDxe: log informative message at DEBUG_INFO level
  + MdeModulePkg/UsbBusDxe: log warning message at DEBUG_WARN level
  + OvmfPkg/PlatformDebugLibIoPort: write messages with IoWriteFifo8()
  + MdePkg/BaseIoLibIntrinsic: fix SEV (=unrolled) variants of IoWriteFifoXX()
  + MdeModulePkg Xhci: Correct description of Timeout param in XhciReg.h
  + BaseTools/GCC: set -Wno-unused-const-variable on RELEASE builds
  + ArmVirtPkg: Enable UDF file system support
  + OvmfPkg: Enable UDF file system support
  + MdeModulePkg/PartitionDxe: Add UDF file system support
  + OvmfPkg/IoMmuDxe: unmap all IOMMU mappings at ExitBootServices()
  + OvmfPkg/IoMmuDxe: generalize IoMmuUnmap() to IoMmuUnmapWorker()
  + OvmfPkg/IoMmuDxe: track all mappings
  + OvmfPkg/VirtioScsiDxe: don't unmap VRING at ExitBootServices()
  + OvmfPkg/VirtioRngDxe: don't unmap VRING at ExitBootServices()
  + OvmfPkg/VirtioGpuDxe: don't unmap VRING & BackingStore at ExitBootServices
  + OvmfPkg/VirtioBlkDxe: don't unmap VRING at ExitBootServices()
  + MdeModulePkg/AtaAtapiPassThru: disable the device at ExitBootServices()
  + MdeModulePkg/AtaAtapiPassThru: unmap DMA buffers after disabling
    BM DMA
  + MdeModulePkg/AtaAtapiPassThru: cache EnabledPciAttributes
  + OvmfPkg/SecMain: Fix stack switching to permanent memory
  + ArmPkg: add ArmCrashDumpDxe driver
  + MdeModulePkg, NetworkPkg: Fix GCC build error
  + NetworkPkg/Ip6Dxe: fix a bug in IP6 driver for IpSec protocol
    notify
  + MdeModulePkg/Ip4Dxe: fix a bug in IP4 driver for IpSec protocol
    notify
  + MdePkg: Add UEFI 2.7 defined GUID and structure for AIP network
    media type
  + MdeModulePkg/UefiBootManagerLib: Generate boot description for
    SD/eMMC
  + Pkcs7VerifyDxe: Don't allow Pkcs7Verify to install protocols twice
  + SecurityPkg/Pkcs7Verify: Complete the Pkcs7VerifyDxe protocol
  + MdePkg PeiMemoryAllocationLib: Update InternalAllocateAlignedPages
  + MdePkg PeiMemoryAllocationLib: Update Free(Aligned)Pages
  + MdeModule PeiCore: Support pre memory page allocation
  + OvmfPkg/VirtioGpuDxe: negotiate VIRTIO_F_IOMMU_PLATFORM
  + OvmfPkg/VirtioGpuDxe: map backing store to bus master device address
  + OvmfPkg/VirtioGpuDxe: helpers for backing store (de)allocation+(un)mapping
  + OvmfPkg/VirtioGpuDxe: take EFI_PHYSICAL_ADDRESS in ResourceAttachBacking()
  + OvmfPkg/VirtioGpuDxe: map virtio GPU command objects to device
    addresses
  + OvmfPkg/VirtioGpuDxe: map VRING for bus master common buffer
    operation
  + OvmfPkg/IoMmuDxe: IoMmuFreeBuffer(): clean up DEBUG message
  + OvmfPkg/IoMmuDxe: IoMmuAllocateBuffer(): nicer and more
    informative DEBUGs
  + OvmfPkg/IoMmuDxe: IoMmuUnmap(): clean up DEBUG message
  + OvmfPkg/IoMmuDxe: IoMmuMap(): log nicer and more informative
    DEBUG msgs
  + OvmfPkg/BaseMemEncryptSevLib: clean up upper-case / lower-case
    in DEBUGs
  + OvmfPkg/BaseMemEncryptSevLib: promote DEBUG_WARN levels to
    DEBUG_ERROR
  + OvmfPkg/BaseMemEncryptSevLib: clean up debug logging of
    PhysicalAddress
  + OvmfPkg/BaseMemEncryptSevLib: clean up DEBUG prefixes
  + OvmfPkg/BaseMemEncryptSevLib: break DEBUG calls to multiple lines
  + OvmfPkg/BaseMemEncryptSevLib: unify encrypt/decrypt DEBUG messages
  + ArmPkg: remove ArmDmaLib
  + OvmfPkg/VirtioScsiDxe: negotiate VIRTIO_F_IOMMU_PLATFORM
  + OvmfPkg/VirtioScsiDxe: map virtio-scsi request and response buffers
  + OvmfPkg/VirtioScsiDxe: add helper to create a fake host adapter error
  + OvmfPkg/VirtioScsiDxe: map VRING using VirtioRingMap()
  + ArmPkg: remove UncachedMemoryAllocationLib
  + BaseTools/Gcc ARM AARCH64: add support for building device tree
    binaries
  + BaseTools: Enable --whole-archive in GCC tool chain as the
    default option
  + UefiCpuPkg/Mplib.c: Perform complete initialization when enable AP
  + OvmfPkg/VirtioBlkDxe: Check the return status of unmap data buffer
  + ArmVirtPkg: remove DmaLib library class resolution
  + ShellPkg: Update CWD and current mapping when commands return
  + ShellPkg: Fix bug that fails to change CWD after "map -r"
  + SecurityPkg: Add ARM/AARCH64 arch to enable RngTest module build
  + OvmfPkg/QemuFwCfgDxeLib: SEV: zero FW_CFG_DMA_ACCESS before
    decrypting it
  + ArmPkg/ArmDmaLib: implement DmaAllocateAlignedBuffer()
  + MdeModulePkg/UefiHiiLib: Fix incorrect check for string length
  + OvmfPkg/VirtioBlkDxe: negotiate VIRTIO_F_IOMMU_PLATFORM
  + Ovmfpkg/VirtioBlkDxe: map virtio-blk request and response buffers
  + OvmfPkg/VirtioBlkDxe: map VRING using VirtioRingMap()
  + MdePkg/S3PciSegmentLib: Add S3PciSegmentLib class and instance
  + MdePkg/PciSegmentLib: Add instances that consumes PciSegmentInfoLib
  + MdePkg/PciSegmentInfoLib: Add PciSegmentInfoLib class and instance
  + UefiCpuPkg/CpuCommonFeaturesLib: Add CPUID MCA support check
  + UefiCpuPkg: Update default for PcdCpuProcTraceMemSize/PcdCpuProcTraceOutputScheme
  + UefiCpuPkg/CpuCommonFeaturesLib: Use MSR data structure when
    change MSR value
  + UefiCpuPkg/ArchitecturalMsr.h: Add RTIT TOPA table entry
    definition
  + UefiCpuPkg/MpLib: fix potential overflow issue
  + UefiCpuPkg/PiSmmCpuDxeSmm: Fix memory protection crash
  + BaseTools/EfiRom: Add multiple device id support
  + OvmfPkg/VirtioRngDxe: negotiate VIRTIO_F_IOMMU_PLATFORM
  + OvmfPkg/Virtio10: define VIRTIO_F_IOMMU_PLATFORM feature bit
  + MdeModulePkg XhciDxe: Fix Map and Unmap inconsistency
  + SecurityPkg/Tcg2Dxe: Properly shutdown TPM before reset
  + OvmfPkg/VirtioRngDxe: map host address to device address
  + OvmfPkg/VirtioLib: change the parameter of VirtioAppendDesc()
    to UINT64
  + OvmfPkg/VirtioLib: alloc VRING buffer with AllocateSharedPages()
  + OvmfPkg/VirtioLib: add function to map VRING
  + OvmfPkg/Virtio10Dxe: add the RingBaseShift offset
  + OvmfPkg/Virtio: take RingBaseShift in SetQueueAddress()
  + OvmfPkg/VirtioLib: take VirtIo instance in VirtioRingInit/VirtioRingUninit
  + OvmfPkg/VirtioLib: add VirtioMapAllBytesInSharedBuffer() helper
    function
  + OvmfPkg/VirtioMmioDeviceLib: implement IOMMU-like member functions
  + OvmfPkg/VirtioPciDeviceDxe: implement IOMMU-like member functions
  + OvmfPkg/Virtio10Dxe: implement IOMMU-like member functions
  + OvmfPkg: introduce IOMMU-like member functions to VIRTIO_DEVICE_PROTOCOL
  + BaseTools: Add the missing -pie link option in GCC tool chain
  + ArmPkg/ArmDmaLib: remove dependency on UncachedMemoryAllocationLib
  + OvmfPkg/QemuVideoDxe: remove AARCH64/ARM support
  + ArmVirtPkg: remove QemuVideoDxe from ArmVirtQemu and ArmVirtQemuKernel
  + BaseTools: Roll back GenFw Change to keep unknown field in RSDS
    debug entry
  + MdeModulePkg/DisplayEngine: Add implementation of HiiPopup protocol
  + MdeModulePkg/Library: Remove the self-reference in
    UdpIoLib/TcpIoLib/IpIoLib
  + ShellPkg/mkdir: support creating nested directories
  + MdeModulePkg/ScsiBusDxe: don't produce ScsiIo for nonexistent LUNs
  + UefiCpuPkg/PiSmmCpuDxeSmm: Add CPUID MCA support check
  + ArmPkg/ArmDmaLib: use double buffering only for bus master write
  + ArmVirtPkg/FdtPL011SerialPortLib: call PL011UartLib in all
    SerialPortLib APIs
  + UefiCpuPkg RegisterCpuFeaturesLib: Fix buffer pointer error usage
  + NetworkPkg/Ip6Dxe: Fix the bug when checking the DataSize
  + MdePkg/BaseLib: Update internal LinkedList verifications
  + MdePkg/BaseLib: Add IsNodeInList() function
  + MdeModulePkg: Delete useless case code
  + MdeModulePkg: Delete never touched code
  + UefiCpuPkg/BaseUefiCpuLib.inf: Remove unnecessary library class
  + UefiCpuPkg RegisterCpuFeaturesLib: Enhance debug messages.
* Mon Aug 28 2017 glin@suse.com
- Update ovmf-embed-default-keys.patch to handle the empty
  certificate files correctly
* Thu Aug 17 2017 glin@suse.com
- Update to 2017+git1502826981.a136bc3ccf
  + OvmfPkg/Protocol/VirtioDevice: fix comment style
  + OvmfPkg/VirtioMmioDeviceLib: add missing IN and OUT decoration
  + OvmfPkg/VirtioPciDeviceDxe: add missing IN and OUT decoration
  + OvmfPkg/Virtio10Dxe: supply missing BUS_MASTER attribute
  + OvmfPkg/VirtioPciDeviceDxe: supply missing BUS_MASTER attribute
  + UefiCpuPkg MpInitLib: Save/restore original WakeupBuffer for
    DxeMpLib
  + ShellPkg UefiDpLib: Init CustomCumulativeData.MinDur
  + MdeModulePkg DxeCore: Enhance "ConvertPages: Incompatible
    memory types"
  + MdeModulePkg DxeCore: Fix double free pages on LoadImage
    failure path
  + NetworkPkg/HttpBootDxe: Update device path node to include DNS
    information
  + MdeModulePkg/UefiBootManagerLib: Support DNS device path
    description
  + MdePkg/UefiDevicePathLib: Add DevPathFromTextDns and
    DevPathToTextDns libraries
  + MdePkg/DevicePath.h: Add DNS Device Path definition
  + NetworkPkg/HttpDxe: Handle the HttpVersionUnsupported in the
    HttpConfigData
  + BaseTools: Support TabSpace between section tag in DEC file
  + BaseTools: Don't need to add extra quotes when UI string from
    file
  + BaseTools/UPT: Support Multiple Installation
  + BaseTools/Scripts: Add sample makefile for use with
    RunMakefile.py
  + BaseTools/Scripts: Add python script to run a makefile
  + BaseTools/build: Expand PREBUILD/POSTBUILD DSC actions
  + NetworkPkg/Ip6Dxe: Support SetData interface to clear specific
    configuration
  + MdeModulePkg/Ip4Dxe: Support SetData interface to clear
    specific configuration
  + ShellPkg/drivers: Fix GCC build failure
  + BaseTools/edksetup.sh: fix invalid test for current working
    directory
  + ShellPkg/driver: Show "-" in non-SFO mode
  + ShellPkg/drivers: Show Image Name in non-SFO mode
  + MdeModulePkg: Variable: Fix typo in variable measure
  + MdeModulePkg/NvmExpressDxe: Notify NVME HW when system reset
    happens
  + MdePkg/Nvme: Add NVME shutdown notification related macros
  + NetworkPkg/HttpBootDxe: Refine the coding style.
  + OvmfPkg/AcpiPlatformDxe: short-circuit the transfer of an empty
    S3_CONTEXT
  + MdeModulePkg SerialDxe: Process timeout consistently in
    SerialRead
  + UefiCpuPkg MtrrLib: Remove deprecated micro.
  + UefiCpuPkg CpuDxe: Remove reference deprecated macro.
  + UefiCpuPkg CpuDxe: Enhance get mtrr mask logic.
  + BaseTools/Conf: apply nasmb, asm16 build rule order
  + NetworkPkg/HttpDxe: Support HTTP Patch method
  + OvmfPkg/PlatformPei: support >=1TB high RAM, and discontiguous
    high RAM
  + OvmfPkg/QemuFwCfgLib: Use BusMasterCommonBuffer to map
    FW_CFG_DMA_ACCESS
  + OvmfPkg/IoMmuDxe: Unmap(): recycle MAP_INFO after
    BusMasterCommonBuffer[64]
  + OvmfPkg/IoMmuDxe: abort harder on memory encryption mask
    failures
  + OvmfPkg/IoMmuDxe: implement in-place decryption/encryption for
    Map/Unmap
  + OvmfPkg/IoMmuDxe: rework setup of "MapInfo->PlainTextAddress"
    in Map()
  + OvmfPkg/IoMmuDxe: zero out pages before releasing them
  + OvmfPkg/IoMmuDxe: clean up used library classes
  + OvmfPkg/IoMmuDxe: propagate errors from AmdSevInstallIoMmuProtocol()
  + OvmfPkg/IoMmuDxe: don't initialize local variables
  + OvmfPkg/IoMmuDxe: convert UINTN arguments to UINT64 for the
    %%Lx fmt spec
  + OvmfPkg/IoMmuDxe: rename HostAddress to CryptedAddress in
    MAP_INFO
  + OvmfPkg/IoMmuDxe: rename DeviceAddress to PlainTextAddress in
    MAP_INFO
  + OvmfPkg/IoMmuDxe: rewrap source code to 79 characters
  + OvmfPkg/IoMmuDxe: Fix header guard macro
  + MdeModulePkg/DisplayEngine: Fix incorrect display issue
  + BaseTools/VfrCompile: Remove the MAX_PATH limitation
  + BaseTools/VfrCompile: Fix segmentation fault issues
  + NetworkPkg: iSCSI should allow to set 6 or 12 length of ISID
    keyword.
  + UefiCpuPkg: Enable Processor Trace feature.
  + UefiCpuPkg: Add Processor Trace feature definition.
  + UefiCpuPkg: Add Pcds used by processor trace feature.
  + UefiCpuPkg/Msr: Add a missing IvyBridge processor signature
  + MdeModulePkg PeiCore: Install SEC HOB data
  + MdePkg: Add definition for SecHobData PPI
  + UefiCpuPkg PiSmmCpuDxeSmm: Check LMCE capability when wait for
    AP.
  + UefiCpuPkg CpuCommonFeaturesLib: Enable LMCE feature.
  + UefiCpuPkg: Add definition for LMCE feature.
  + NetworkPkg: Display HTTP redirection info to the screen if need.
  + ShellPkg/dblk: Honor the BlockIo alignment requirement.
  + MdeModulePkg/Ufs: Set 'Data Segment Length' field for Write
    Descriptor
  + MdeModulePkg/UfsPassThruDxe: Add impl of UFS Device Config
    Protocol
  + UefiCpuPkg SecCore: Fix operands of different size in bitwise
    operation
  + MdePkg/Ftp4: Fix wrong function pointer declaration
  + NetworkPkg/HttpDxe: Destroy the TLS instance when cleaning up
    the HTTP child
  + CryptoPkg/TlsLib: Remove the redundant free of BIO objects
  + NetworkPkg/Ip6Dxe: Fix the IPv6 PXE boot option goes missing
    issue
  + Fix spelling typo in EFI_HTTP_STATUS_CODE
  + NetworkPkg/HttpDxe: Refine the coding style.
  + MdePkg/Http.h: Refine the coding style.
  + ArmPkg: Move IS_DEVICE_PATH_NODE for sharing
  + MdeModulePkg FirmwarePerfPei: Remove SEC performance data
    getting code
  + UefiCpuPkg SecCore: Add SecPerformancePpiCallBack
  + UefiCpuPkg SecCore: Adjust PeiTemporaryRamBase&Size to be
    8byte aligned
  + MdeModulePkg PeiCore: Handle notification PPI from SEC
  + MdePkg PiPeiCis.h: Add description for notification PPI from
    SEC
  + MdeModulePkg PiSmmCoreMemoryAllocLib: Fix a FreePool()
    assertion issue
  + BaseTools/GenCrc32: Fix a bug to hand empty file for decode
  + BaseTools/EfiLdrImage: Fix a segmentation fault from
    vfprintf()
  + BaseTools/EfiRom: Fix a segmentation fault from
    vsprintf()/vfprintf()
  + BaseTools/GenFfs: Fix a segmentation fault from
    vsprintf()/vfprintf()
  + BaseTools/GenSec: Fix a segmentation fault in main()
  + BaseTools/Split: Fix the segmentation fault in GetSplitValue()
  + BaseTools: Fix the bug to correctly check Pcd type that in FDF
    file
  + MdeModulePkg/PciBus: Avoid hang when BUS pad resource is not
    in top
  + ShellPkg: Avoid buffer out-of-bound access
  + ShellPkg/setvar: Check the duplicate flag
  + ShellPkg/ShellLib: Remove unused macros
  + MdePkg: Follow UEFI 2.7 spec to deprecate SMM Communication
    ACPI Table
  + UefiCpuPkg PiSmmCommunicationSmm: Deprecate SMM Communication
    ACPI Table
  + MdeModulePkg/BMMUiLib: Check reset requirement before exiting
    UiApp
  + MdeModulePkg/BMUiLib: Check reset requirement before exiting
    UiApp
  + MdeModulePkg/SetupBrowser: Record the reset status in all
    SendForm
  + ShellPkg/map: Recognize CDROM change
  + MdeModulePkg Xhci: Also RecoverHaltedEndpoint for BABBLE_ERROR
  + MdeModulePkg SmmLockBoxDxeLib: Get SmmCommRegion for COMM
    buffer
  + MdePkg/ResetNotification: Rename to UnregisterResetNotify
  + MdePkg: Add UEFI 2.7 defined GUID and structure for KMS
    protocol.
  + ShellPkg/ls: Display the file time in local time.
  + BaseTools: Fix the bug that warn() function with only 1
    argument
  + BaseTools: add some comment for .PrebuildEnv file's usage
  + UefiCpuPkg: Update RegisterCpuFeaturesLib to consume
    PcdGetSize with UINTN
  + UefiCpuPkg: Update RegisterCpuFeaturesLib module UNI to match
    it
  + MdeModulePkg: Update NonDiscoverableDeviceRegistrationLib file
    header format
  + MdePkg UsbFunctionIo.h: Update comments for GetDeviceInfo
    return status
  + UefiCpuPkg: Remove deprecated CPU feature.
  + MdeModulePkg SmmAccess: Update comments to follow PI spec.
  + MdePkg SmmAccess2: Update comments to follow PI spec.
  + UefiCpuPkg RegisterCpuFeaturesLib: Add error handling.
  + MdeModulePkg/DxeCore: Avoid accessing non-owned memory
  + MdePkg DxeHstiLib: Fix memory leak issue
  + MdePkg Hsti.h: Update version info to 1.1a
  + ArmPlatformPkg: Support different PL011 reg offset
  + CryptoPkg/OpensslLib AARCH64: clear XIP CC flags
  + BaseTools/tools_def AARCH64: avoid SIMD registers in XIP code
  + BaseTools/tools_def AARCH64: mark register x18 as reserved
  + BaseTools/Build: Support python scripts in PREBUILD/POSTBUILD
  + UefiCpuPkg CpuCommonFeaturesLib: Fix smx/vmx enable logic
    error.
  + UefiCpuPkg RegisterCpuFeaturesLib: Add error handling code.
  + OvmfPkg/QemuFwCfgLib: Suppress GCC49 IA32 build failure
  + MdePkg: Declare _ReturnAddress() in Base.h for MSFT tool chain
  + OvmfPkg: update PciHostBridgeDxe to use PlatformHasIoMmuLib
  + OvmfPkg/QemuFwCfgLib: Add SEV support
  + OvmfPkg: Add IoMmuDxe driver
  + OvmfPkg: Add PlatformHasIoMmuLib
  + OvmfPkg: Add AmdSevDxe driver
  + OvmfPkg/PlatformPei: Set memory encryption PCD when SEV is
    enabled
  + OvmfPkg/BaseMemcryptSevLib: Add SEV helper library
  + OvmfPkg: Update dsc to use IoLib from BaseIoLibIntrinsicSev.inf
  + OvmfPkg/ResetVector: Set C-bit when building initial page table
  + MdeModulePkg/XhciDxe: Make comments align with function
  + MdeModulePkg/PartitionDxe: Add impl of Partition Information
    Protocol
  + MdePkg: Add EFI Partition Information Protocol definitions
  + BaseTools: Report Fd File Path in build log
  + BaseTools: Fix FDF file parse !include file issue
  + BaseTools: Add PCDs conditional operator function
  + BaseTools/Eot: register MM Module types with FFS class.
  + BaseTools/Workspace: check MM module type compatibility with
    PI version.
  + BaseTools/build: register MM module types with build tools.
  + BaseTools/GenFds: register MM Modules and MM FV file types.
  + BaseTools/CommonDataClass: register MM Modules.
  + BaseTools/Common: add support in FDF Parser to parse MM
    Modules.
  + BaseTools/Common: add MM Module data types.
  + BaseTools/AutoGen: auto generate MM template APIs and
    dependencies.
  + BaseTools/GenFw: recognize MM file types as EFI Boot Service
    Drivers.
  + BaseTools/GenFfs: add FFS file types for MM modules.
  + UefiCpuPkg MpInitLib: Update return status to follow spec.
  + UefiCpuPkg CpuMpPei: Update return status to follow spec.
  + UefiCpuPkg CpuDxe: Update return status to follow spec.
  + MdePkg MpServices: Update return status to follow spec.
  + BaseTools/GenFw: disregard payload in PE debug directory entry
    size
  + MdeModulePkg/NvmExpressDxe: Handle timeout for blocking
    PassThru req
  + OvmfPkg: mention the extended TSEG near the PcdQ35TsegMbytes
    declaration
  + OvmfPkg/PlatformPei: honor extended TSEG in PcdQ35TsegMbytes
    if available
  + OvmfPkg/SmmAccess: support extended TSEG size
  + OvmfPkg/IndustryStandard/Q35MchIch9.h: add extended TSEG size
    macros
  + OvmfPkg: make PcdQ35TsegMbytes dynamic
  + OvmfPkg/SmmAccess: prepare for PcdQ35TsegMbytes becoming dynamic
  + OvmfPkg/PlatformPei: prepare for PcdQ35TsegMbytes becoming dynamic
  + OvmfPkg: widen PcdQ35TsegMbytes to UINT16
  + OvmfPkg: update -D E1000_ENABLE from Intel PROEFI v.07 to
    BootUtil v.22
  + OvmfPkg: disable build-time relocation for DXEFV modules
  + ArmVirtPkg: remove status code support
  + ArmPlatformPkg: convert VExpress ResetSystemLib to
    ResetSystemLib
  + MdeModulePkg/XhciDxe: Check timeout URB again after stopping
    endpoint
  + MdeModulePkg/XhciDxe: Separate common logic to XhcTransfer
  + MdeModulePkg/XhciDxe: Dump the CMD/EVENT/INT/BULK ring
    information
  + MdeModulePkg/XhciDxe: Refine IsTransferRingTrb and
    IsAsyncIntTrb
  + BaseTools: suppress usage instructions with rebuild options
  + ArmVirtPkg: switch to generic ResetSystemRuntimeDxe
  + ArmPkg: implement ResetSystemLib using PSCI 0.2 calls
  + MdeModulePkg CapsuleApp: Fix print info in BuildGatherList()
  + MdeModulePkg ResetSystem: Update the comments of ResetSystem()
  + MdeModulePkg/ResetSystem: Implement ResetNotification protocol
  + MdeModulePkg/ResetSystem: Remove unnecessary global variable
  + MdePkg: Add ResetNotification protocol definition
  + MdeModulePkg PeiCore: Correct the comments of PeiResetSystem2
  + MdePkg: Correct the comments of EFI_PEI_RESET2_SYSTEM
  + ShellPkg: Update dh command to reflect correct driver field
    information
  + MdeModulePkg/AtaAtapiPassThru: relax PHY detect timeout
  + MdePkg/IndustryStandard: update ACPI/IORT definitions to
    revision C
  + ShellPkg DmpStore: Make NameSize to be consistent with name
    buffer
  + MdeModulePkg/BdsDxe: Report Status Code when booting from
    BootOrder list
  + MdePkg/PiStatusCode: Add new Status Code for BDS when
    attempting BootOrder
  + Revert "MdeModulePkg/DxeCore: Fixed Interface returned by
    CoreOpenProtocol"
  + UefiCpuPkg: Modify GetProcessorLocationByApicId() to support
    AMD.
  + UefiCpuPkg: Add CPUID definitions for AMD.
  + UefiCpuPkg: Define AMD Memory Encryption specific CPUID and MSR
  + MdeModulePkg DxeCore: Only free ScratchBuffer when it is not
    NULL
  + MdeModulePkg/DxeCore: Fixed Interface returned by
    CoreOpenProtocol
  + BaseTools/PatchCheck.py: Add warning info for new binary files
  + BaseTools/PatchCheck.py: Fix misreport for binary changes in
    patch
  + BaseTools: support building the same INF more than once with
  - m option
  + BaseTools: report error HiiString in HII format PCD must not
    be empty
  + BaseTools: Fix the bug that use '|' or '||' in DSC file's Pcd
    value
  + BaseTools: Enhance the report to not show the empty section
  + BaseTools: Enhance DEC Defines section format check
  + BaseTools: Copy "TianoCore" userextensions into As Built Inf
  + BaseTools: Copy "MODULE_UNI_FILE" file into OUTPUT directory
  + MdePkg/Cper.h: Update Firmware Error Record per UEFI 2.7
  + MdeModulePkg: Enhance the debug message for
    InstallProtocolInterface
  + MdePkg: update Base.h in MdePkg to check the _MSC_VER
  + BaseTools: add /Gw to CC_FLAGS for VS2013 and higher tool
    chain tags
  + NetworkPkg: Fix GCC build issue.
  + BaseTools/tools_def: AARCH64: disable LTO type mismatch
    warnings
  + BaseTools/tools_def GCC: ARM/AARCH64: drop -save-temps from
    command line
  + MdeModulePkg Variable: Add missing change in dd59d95e1994
  + MdeModulePkg: Minor update to the Data parameter for PEI
    GetVariable()
  + MdePkg: Minor update to the Data parameter for PEI
    GetVariable()
  + NetworkPkg/HttpBootDxe: Add HTTP Boot Callback protocol
    support.
  + MdePkg: Add header file for HTTP Boot Callback protocol
    in UEFI 2.7.
  + MdeModulePkg: Return invalid param in LocateProtocol for
    Protocol==NULL
  + MdePkg: Add EFI UFS Device Config Protocol definitions
  + MdeModulePkg: Fix use-after-free error in
    InstallConfigurationTable()
  + MdeModulePkg: Clean ACPI 2.0 characters in UEFI spec
  + MdePkg: Clean ACPI 2.0 characters in UEFI spec
  + UefiCpuPkg/SmmCpuFeatureLib: Add more CPU ID for
    SmmFeatureControl.
  + ShellBinPkg: Ia32/X64 Shell binary update.
  + MdeModulePkg/BMMUiLib: Fix incorrect variable name
  + SecurityPkg TcgDxe: Simplify debug msg when "TPM not working
    properly"
  + ShellPkg: Fix typo errors in ifconfig help output
  + Shell/alias: Print detailed error when deleting alias
  + OvmfPkg/AcpiPlatformDxe: fix spurious uninitialized var warning
  + NetworkPkg/HttpBootDxe: Handle new #define in HttpBootDxe
  + MdeModulePkg/DxeHttpLib: Handle new #define in
    HttpMappingToStatusCode
  + MdePkg/Http.h: Add #define for 308 redirect
  + ShellPkg/ifconfig: Update help message
  + MdeModulePkg/PciHostBridgeDxe: Make bitwise operands of the
    same size
  + OvmfPkg/AcpiPlatformDxe: alloc blobs from 64-bit space unless
    restricted
  + BaseTools: Fix the bug use same FMP_PAYLOAD in different
    capsule file
  + BaseTools: Fix incremental build failure that override file be
    removed
  + ShellBinPkg: Ia32/X64 Shell binary update.
  + ShellPkg/parse: Handle Unicode stream from pipe correctly
  + ShellPkg/alias: Return status for alias deletion
  + MdePkg SmmIoLib: Use NULL pointer check instead of useless
    Status check
  + MdePkg SmmMemLib: Remove ASSERT in SmmIsBufferOutsideSmmValid
  + MdeModulePkg/UefiPxeBcDxe: Refine the PXE boot displayed
    information
  + MdeModulePkg/UefiPxeBcDxe: Fix the PXE BootMenu selection issue
- Build x86_64 4MB images since upstream switched to 4MB by for a
  larger space for variables. Also update README to reflect the
  change.
- Remove License-fat-driver.txt since FatPkg uses the same license
  as the root license.
- Add the OVMF license file
- Disable the PIE/PIC warning for the debug files since all object
  files will be converted to PE/COFF, so it's pointless to enable
  PIE/PIC.
- Remove Default_DB_EX and Default_DBX correctly
* Mon Jun  5 2017 glin@suse.com
- Update to 2017+git1496630893.7ec69844b8
  + ShellPkg/alias: Fix bug to support upper-case alias
  + BaseTools/GCC ARM/AARCH64: Force disable PIE
  + BaseTools/Scripts: discard .gnu.hash section in GCC builds
  + OvmfPkg: make the 4MB flash size the default
  + MdeModulePkg/BDS: Fix a buffer overflow bug
  + CryptoPkg/BaseCryptLib: Add NULL pointer checks in DH and P7Verify
  + UefiCpuPkg/BaseUefiCpuLib: Use NASM read-only data section name
  + OvmfPkg/PlatformPei: align EmuVariableNvStore at any page boundary
  + OvmfPkg/EmuVariableFvbRuntimeDxe: change block size to 4KB
  + OvmfPkg/EmuVariableFvbRuntimeDxe: correct NumOfLba vararg type
    in EraseBlocks()
  + ArmPlatformPkg/NorFlashDxe: correct NumOfLba vararg type in
    EraseBlocks()
  + OvmfPkg/EmuVariableFvbRuntimeDxe: always format an auth
    varstore header
  + MdeModulePkg/PciBus: Add IOMMU support
  + MdeModulePkg/PciHostBridge: Add IOMMU support
  + MdeModulePkg/Include: Add IOMMU protocol definition
  + ShellPkg/HandleParsingLib: Show LoadedImageProtocol file path
    as text
  + NetworkPkg: Fix issue in dns driver when building DHCP packet
  + Addressing TCP Window Retraction when window scale factor is used
  + Add wnd scale check before shrinking window
  + UefiCpuPkg/MtrrLib: Don't report OutOfResource when MTRR is enough
  + MdePkg DxeServicesLib: Handle potential NULL FvHandle
  + OvmfPkg/PlatformPei: handle non-power-of-two spare size for
    emu variables
  + SecurityPkg/Pkcs7VerifyDxe: Add format check in DB list contents
  + OvmfPkg: raise max variable size (auth & non-auth) to 33KB for
    FD_SIZE_4MB
  + OvmfPkg: introduce 4MB flash image (mainly) for Windows HCK
  + OvmfPkg/OvmfPkg.fdf.inc: extract VARS_LIVE_SIZE and
    VARS_SPARE_SIZE macros
  + OvmfPkg: introduce the FD_SIZE_IN_KB macro / build flag
  + ArmVirtPkg: install EdkiiPlatformHasDeviceTree proto in the
    32-bit builds
  + NetworkPkg: Fix PXEv6 boot failure when DhcpBinl offer received
  + NetworkPkg: Fix bug in iSCSI mode ipv6 when enabling target DHCP
  + Fix issue the iSCSI client can not send reset packet
  + CryptoPkg/SmmCryptLib: Enable HMAC-SHA256 support for SMM
  + ShellPkg/Shell: eliminate double-free in RunSplitCommand()
  + ShellPkg/Shell: clean up bogus member types in SPLIT_LIST
  + MdeModulePKg/BDS: Build meaningful description for Wi-Fi boot
    option
  + MdeModulePkg/DeviceManagerUiLib: Fix the network device MAC
    display issue
  + MdeModulePkg/Mtftp4Dxe: Add invalid ServerIp check during MTFTP
    configuration
  + NetworkPkg/TlsAuthConfigDxe: Close and free the file related
    resource
  + NetworkPkg: Correct the proxy DHCP offer handing
  + NetworkPkg/HttpDxe: Fix HTTP download OS image over 4G size
    failure
  + MdeModulePkg/UefiBootManagerLib: Avoid buggy USB short-form
    expanding
  + NetworkPkg: Fix bug related DAD issue in IP6 driver
  + NetworkPkg: Add check logic for iSCSI driver
  + MdeModulePkg PiSmmCore: Enhance SMM FreePool to catch buffer
    overflow
  + UefiCpuPkg/PiSmmCpuDxeSmm: Lock should be acquired
  + MdeModulePkg/BootManagerMenu: Add assertion to indicate no DIV
    by 0
  + CryptoPkg: Correct some minor issues in function comments
  + MdePkg/UefiLib: Avoid mis-calculate of graphic console size
  + MdeModulePkg/PiSmmCore: Fix potentially uninitialized local
    variable
  + MdeModulePkg DxeCore: Fix issue to print GUID value %%g without
    pointer
  + ArmVirtPkg/ArmVirtXen: remove ARM BdsLib library class resolution
- Add ovmf-disable-ia32-firmware-piepic.patch to disable pic/pie
  explicitly since gcc7 in Factory enables pic/pie by default but
  GenFw cannot handle the GOT sections and failed the build.
* Sat May  6 2017 meissner@suse.com
- ovmf-pie.patch: add -fPIE to the Common build Makefile to
  allow a global PIE build.
* Thu Apr 13 2017 glin@suse.com
- Update to 2017+git1492060560.b6d11d7c46 (fate#322331, bsc#1032659)
  + MdePkg: BaseIoLibIntrinsic (IoLib class) library
  + MdeModulePkg/IdeBusPei: Fix undefined behavior in signed left
    shift
  + MdeModulePkg/ScsiDiskDxe: Fix undefined behavior in signed left
    shift
  + OvmfPkg/QemuVideoDxe: VMWare SVGA device support
  + MdeModulePkg/UefiBootManagerLib: Enhance short-form expanding
    logic
  + CryptoPkg/BaseCryptLib: Adding NULL checking in time() wrapper
  + CryptoPkg: Fix possible unresolved external symbol issue.
  + CryptoPkg/OpensslLib: Suppress extra build warnings in openssl
    source
  + CryptoPkg: Move openssl and CRT headers to private include
    section
  + BaseTools: Update tools_def.template to add -fno-builtin in GCC
    tool chain
  + SecurityPkg: SecureBootConfigDxe: Support AUTH_2 enrollment to
    DBX
  + MdeModulePkg/UefiHiiLib:Fix incorrect comparison expression
  + ArmVirtPkg/ArmVirtQemuKernel: increase slack space for DTB
  + ArmVirtPkg/FdtClientDxe: honor memory DT node 'status' property
  + NetworkPkg: Fix some bugs related to iSCSI keyword configuration
  + MdeModulePkg/DxeHttpLib: Avoid the pointless comparison of
    UINTN with zero
  + BaseTools: Enhance expression to support some more operation
  + MdePkg/Shell.h: Update Shell version from 2.1 to 2.2
  + UefiCpuPkg/PiSmmCpuDxeSmm: Update saved SMM ranges check in
    SmmProfile
  + ArmVirtPkg/PlatformHasAcpiDtDxe: allow guest level ACPI disable
    override
  + BaseTools/GCC AARCH64: force disable PIC code generation
  + UefiCpuPkg/MtrrLib: Use a better algorithm to calculate MTRR
  + MdeModulePkg/SmmCore: Fix memory leak on Profile unregistered
  + OvmfPkg: Allow multiple add-pointer linker commands to same
    ACPI table
- Drop upstream patch: ovmf-bsc1031336-fix-hii-gcc7-build.patch
* Wed Apr  5 2017 glin@suse.com
- Add ovmf-bsc1031336-fix-hii-gcc7-build.patch to fix gcc7 build
  (bsc#1031336)
* Thu Mar 30 2017 glin@suse.com
- Update to 2017+git1490844769.d3017dd96b
  + MdeModulePkg/DxeHttpLib: Fix the incorrect return status if URI
    port is invalid
  + NetworkPkg/DnsDxe: Fix zero StationIp configuration failure of
    DNSv6
  + CryptoPkg: Clean-up CRT Library Wrapper
  + CryptoPkg: Fix handling of &strcmp function pointers
  + CryptoPkg/OpensslLib: Update INF files to support OpenSSL-1.1.0x
    build
  + ArmVirtPkg/PlatformHasAcpiDtDxe: don't expose DT if QEMU
    provides ACPI
  + ArmVirtPkg: enable AcpiTableDxe and EFI_ACPI_TABLE_PROTOCOL
    dynamically
  + ArmVirtPkg: add XenPlatformHasAcpiDtDxe
  + ArmVirtPkg: add PlatformHasAcpiDtDxe
  + UefiCpuPkg/AcpiCpuData.h: Support >4GB MMIO address
  + NetworkPkg/IScsiDxe: Fix the incorrect error handling in
    DriverEntryPoint
  + Fix potential ASSERT if NetIp4IsUnicast is called
  + ArmPkg/PlatformBootManagerLib: move to BootLogoLib for boot
    splash support
  + UefiCpuPkg: Add CPU Features PEI/DXE drivers
  + ArmVirtPkg/HighMemDxe: use CPU arch protocol to apply memprotect
    policy
  + MdeModulePkg/BootGraphicsResourceTableDxe: don't allocate below
    4 GB
  + MdeModulePkg/DxeCore: deal with allocations spanning several
    memmap entries
  + MdeModulePkg/AcpiTableDxe: Not make FADT.{DSDT,X_DSDT} mutual
    exclusion
  + NetworkPkg: Fix service binding issue in TCP dxe
  + MdeModulePkg: Fix service binding issue in TCP4 and Ip4 dxe
  + MdeModulePkg: Fix bug in DxeHttplib when converting port number
  + MdeModulePkg/Ip4Dxe: Add Ip/Netmask pair check for Ip4Config2
  + ArmPkg/UncachedMemoryAllocationLib: set XP bit via CPU arch
    protocol
  + MdeModulePkg DxeCore: Remove unreferenced symbol for memory
    profile
  + MdeModulePkg PiSmmCore: Remove unreferenced symbol for SMRAM
    profile
  + NetworkPkg: Fix potential bug if the iSCSI use dns protocol
  + MdePkg/UefiDevicePathLib: Fix the wrong MAC address length
  + OvmfPkg/AcpiPlatformDxe: save fw_cfg boot script with QemuFwCfgS3Lib
  + ArmVirtPkg, OvmfPkg: retire QemuFwCfgS3Enabled() from QemuFwCfgLib
  + OvmfPkg: resolve QemuFwCfgS3Lib
  + ArmVirtPkg: resolve QemuFwCfgS3Lib
  + OvmfPkg/QemuFwCfgS3Lib: add initial PEI and DXE fw_cfg library
    instances
  + OvmfPkg: introduce QemuFwCfgS3Lib class
  + MdeModulePkg/SmmCore: Add Context in SmiHandlerProfileUnregister
  + MdeModulePkg/UefiBootManagerLib: Generate boot description for
    NVME
  + ArmVirtPkg/ArmVirtPL031FdtClientLib: unconditionally disable DT
    node
  + ArmVirtPkg/FdtClientDxe: supplement missing EFIAPI calling conv
    specifiers
  + MdeModulePkg/AcpiTableDxe: improve FADT.{DSDT,X_DSDT} mutual
    exclusion
  + ArmPkg/CpuDxe: handle implied attributes in EfiAttributeToArmAttribute
  + ArmVirtPkg: apply PE/COFF memory protection to DxeCore as well
  + ArmPkg/UncachedMemoryAllocationLib: map uncached allocations
    non-executable
  + ArmPkg/UncachedMemoryAllocationLib: use CWG value to align pool
    allocations
  + ArmPkg/UncachedMemoryAllocationLib: restore mapping attributes
    after free
- Update openssl to 1.1.0e
* Wed Mar  8 2017 glin@suse.com
- Update to 2017+git1488934948.29e9bf10dc
  + ArmVirtPkg: enable non-executable DXE stack for all platforms
  + ArmVirtPkg: enable PE/COFF image and memory protection for ARM
    platforms
  + ArmPkg/CpuDxe ARM: honour RO/XP attributes in SetMemoryAttributes()
  + ArmPkg/CpuDxe ARM: avoid unnecessary cache/TLB maintenance
  + ArmPkg/CpuDxe ARM: avoid splitting page table sections
    unnecessarily
  + Refine casting expression result to bigger size
  + NetworkPkg/Dhcp6Dxe: Handle the Nil UUID case
  + ArmVirtPkg AARCH64: enable NX memory protection for all platforms
  + ArmVirtPkg/HighMemDxe: preserve non-exec permissions on newly
    added regions
  + SecurityPkg: Fix potential bug in Security Boot dxe
  + MdeModulePkg/EbcDxe: use EfiBootServicesCode memory for thunks
  + CryptoPkg/OpensslLib: Upgrade OpenSSL version to 1.0.2k
    (bsc#1030565)
  + ArmVirtPkg: clear PcdPerformanceLibraryPropertyMask PCD
  + Ignore duplicated DNS address check
  + MdeModulePkg/DxeCore: base code protection on permission
    attributes
  + OvmfPkg: exclude libssl functionality from OpensslLib if
    TLS_ENABLE=FALSE
  + CryptoPkg/OpensslLib: introduce OpensslLibCrypto instance
  + ArmVirtPkg/ArmVirt.dsc.inc: AARCH64: enable DXE image
    protection feature
  + OvmfPkg/XenBusDxe: Use EFIAPI for XenStoreVSPrint
  + Update the Ethernet interface name
  + NetworkPkg:Add scriptable configuration to iSCSI driver by
    leveraging x-UEFI
  + ArmPkg/ArmMmuLib: AARCH64: enable stack alignment checking
  + ArmPlatformPkg/ArmPlatformStackLib: use callee preserved
    registers
  + MdeModulePkg/DxeCore: Add UEFI image protection
  + UefiCpuPkg/CpuDxe: Add memory attribute setting
  + OvmfPkg/QemuFwCfg: introduce FW_CFG_IO_SELECTOR, FW_CFG_IO_DATA,
    and FW_CFG_IO_DMA_ADDRESS
  + UefiCpuPkg/ExceptionHandlerAsm.S: Fix code length issue with
    GCC 5.4
  + ArmPkg/ArmMmuLib: AARCH64: add support for modifying only
    permissions
  + ArmPkg/CpuDxe: ARM: ignore page table updates that only change
    permissions
  + ArmPkg/CpuDxe: translate invalid memory types in
    EfiAttributeToArmAttribute
  + ArmPkg/CpuDxe: Correct EFI_MEMORY_RO usage
  + OvmfPkg/AcpiPlatformDxe: implement the QEMU_LOADER_WRITE_POINTER
    command
  + MdeMoudlePkg/DisplayEngine: Fix incorrect index used in array
    "InputText"
  + MdeModulePkg: Add the EFI_PRINT2S_PROTOCOL
  + MdePkg/BasePrintLib: Add safe print functions [A|U]ValueToStringS
  + Refine the SPrint functions
  + SecurityPkg: enhance secure boot Config Dxe & Time Based
    AuthVariable
  + Generate the correct operational state of the interface
  + NetworkPkg/HttpBootDxe: Update to check specified media type
  + NetworkPkg/HttpBootDxe: Request HTTP token notify as a DPC at
    TPL_CALLBACK
  + NetworkPkg/iSCSIDxe: Update the condition for IScsiStart Abort
  + MdePkg ACPI: Incorrect definition name for ACPI IORT Table
    signature
  + MdeModulePkg/PciBus: Accept Spec values as BarIndex and
    Alignment
  + NetworkPkg/NetworkPkg.uni: Define the prompt and help
    information for PcdAllowHttpConnections
  + MdeModulePkg/DxeHttpLib: Correct the return status for the
    HTTP Port/ContentLength
  + MdeModulePkg/UefiBootManagerLib: Initialize Handle before
    using it
  + OvmfPkg/SmmControl2Dxe: select broadcast SMI if available
  + OvmfPkg: dynamic defaults for PcdCpuSmmApSyncTimeout,
    PcdCpuSmmSyncMode
  + ArmVirtPkg/QemuFwCfgLib: implement QemuFwCfgSkipBytes() API
  + ArmVirtPkg/QemuFwCfgLib: use DMA for QemuFwCfgWriteBytes() if
    available
  + ArmVirtPkg/QemuFwCfgLib: extract generic DmaTransferBytes()
    function
  + OvmfPkg/QemuFwCfgLib: add QemuFwCfgSkipBytes()
  + OvmfPkg/QemuFwCfgLib: generalize InternalQemuFwCfgDmaBytes()
    to SKIP op
  + SecurityPkg: Tcg2Dxe: Update PCR[4] measure logic
  + MdePkg: Add definitions for SMBIOS spec 3.1.1
  + OvmfPkg/QemuVideoDxe: Frame buffer config size may change in
    new mode
- Update openssl to 1.0.2k
* Tue Jan 24 2017 glin@suse.com
- update to 2017+git1485224553.6671cd7444
  + NetworkPkg: Fix protocol handler service in HttpDxe
  + OvmfPkg: Allow HTTP connections if HTTP Boot enabled
  + NetworkPkg: Add PCD to enable the HTTP connections switch
  + MdePkg: Add definitions for SMBIOS spec 3.1.0
  + ArmPlatformPkg/NorFlashDxe: Change Flash memory attributes
    before writes
  + MdePkg DxeHobLib: Make GetHobList working before Constructor
    is called
  + NetworkPkg: Add dns support for target URL configuration in
    ISCSI
  + MdeModulePkg/FileExplorer: Enable functionality of creating
    new file/folder
  + OvmfPkg: pull in TLS modules with -D TLS_ENABLE (also enabling
    HTTPS)
  + OvmfPkg: correct the IScsiDxe module included for the IPv6 stack
  + OvmfPkg: always resolve OpenSslLib, IntrinsicLib and
    BaseCryptLib
  + OvmfPkg: Modify QemuFwCfgLib to use new IoLib class library
  + OvmgPkg/PlatformBootManagerLib: Add Debug Agent console
  + OvmfPkg/SmmControl2Dxe: correct PCI_CONFIG_READ_WRITE in S3
    boot script
  + OvmfPkg: Install BGRT ACPI table
  + MdeModulePkg/Bds: Fix a bug that may causes S4 fails to resume
  + MdePkg, MdeModulePkg: S3BootScriptSaveMemPoll(): accept 64-bit
    LoopTimes
  + NetworkPkg/HttpDxe: Fix the potential NULL dereference
  + NetworkPkg/HttpDxe: HTTPS support over IPv4 and IPv6
  + NetworkPkg/TlsAuthConfigDxe: Provide the UI to support TLS
    auth configuration
  + NetworkPkg/TlsDxe: TlsDxe driver implementation over OpenSSL
  + MdePkg: Add TLS related protocol definition
  + MdePkg/MemoryLib: Refine InternalMemSetMem16|32|64 functions
    logic
  + NetworkPkg: Replace ASSERT with error return code in PXE and
    HTTP boot driver
  + MdeModulePkg: Replace ASSERT with error return code in PXE
    driver
  + UefiCpuPkg/Cpuid.h: Update CPUID definitions with SDM (Sep.2016)
  + UefiCpuPkg/Include: Update MSR header files with SDM (Sep.2016)
  + UefiCpuPkg/PiSmmCpuDxeSmm: Always initialze PSD
  + MdeModulePkg/PiSmmCore: MemoryAttributeTable need keep non-PE
    record
  + MdeModulePkg/PiSmmCore: AllocatePool should use MemoryType
  + OvmfPkg/XenHypercallLib: Add EFIAPI
  + OvmfPkg/QemuFwCfgLib: support QEMU's DMA-like fw_cfg access
    method
  + ArmVirtPkg/QemuFwCfgLib: rebase lib instance to updated lib
    class header
  + OvmfPkg/QemuFwCfgLib: extend lib class header with more
    definitions
  + ArmVirtPkg, OvmfPkg: QemuFwCfgLib: move DMA-related defs to lib
    class
  + OvmfPkg/QemuFwCfgLib: move InternalQemuFwCfgIsAvailable() to
    lib instances
  + ArmVirtPkg/QemuFwCfgLib: remove superfluous InternalQemuFwCfgIsAvailable()
  + OvmfPkg: Remove use of IntelFrameworkModulePkg legacy libs
  + UefiCpuPkg/PiSmmCpuDxeSmm: Remove MTRRs from PSD structure
  + UefiCpuPkg/PiSmmCpuDxeSmm: Clear some semaphores on S3 boot
    path
  + ArmPkg/ArmDmaLib: add support for fixed host-to-device DMA
    offset
  + ArmPkg/ArmDmaLib: clean up abuse of device address
  + ArmPkg/ArmDmaLib: fix incorrect device address of double buffer
  + ArmPkg/ArmDmaLib: use DMA buffer alignment from CPU arch
    protocol
  + ArmPkg/ArmMmuLib: support page tables in cacheable memory only
  + UefiCpuPkg/PiSmmCpu: relax superpage protection on page split
  + OvmfPkg/PlatformPei: take VCPU count from QEMU and configure
    MpInitLib
  + UefiCpuPkg/MpInitLib: wait no longer than necessary for initial
    AP startup
- Enable TLS support by default (for HTTPS)
* Tue Nov 29 2016 glin@suse.com
- update to 2017+git1480394913.2b2efe3:
  + UefiCpuPkg/PiSmmCpuDxeSmm: handle dynamic
    PcdCpuMaxLogicalProcessorNumber
  + SecurityPkg Tcg2ConfigDxe: Align Attempt TPM Device help with
    options
  + SecurityPkg Tcg2ConfigDxe: Remove BlockSID actions and related
    strings
  + SecurityPkg OpalPasswordDxe: Use PP actions to enable BlockSID
  + SecurityPkg Tcg2PPLib: Support BlockSID related actions
  + MdeModulePkg/NetLib: Handle an invalid IPv6 address case
  + UefiCpuPkg/DxeMpLib: Fix bug when getting target C-State from
    eax
  + UefiCpuPkg/DxeMpLib: Make sure APs in safe loop code
  + UefiCpuPkg/DxeMpLib: Allocate new safe stack < 4GB
  + UefiCpuPkg/DxeMpLib: Get safe AP loop handler from global
    variable
  + ArmPlatformPkg: Fix VE RTSM mem map descriptor count
  + ArmPlatformPkg: Reformat VE Memory Map code
  + ArmPkg: remove the LinuxLoader application
  + MdeModulePkg/SetupBrowser:Don't support password without
    interactive flag
  + MdeModulePkg/DisplayEngine: Popup dialogue when password is
    not supported
  + MdeModulePkg/AtaAtapiPassThru: Ensure GHC.AE bit is always set
    in Ahci
  + MdeModulePkg/Xhci: Add 10ms delay before sending SendAddr cmd
    to dev
  + UefiCpuPkg/PiSmmCpu: Correct exception message
  + UefiCpuPkg: fix feature test for Extended Topology CPUID leaf
  + SecurityPkg DxeTcg2PPLib: Lock Tcg2PhysicalPresenceFlags
    variable on S4
  + MdeModulePkg/DxeNetLib: Allow the IPv4/prefix case when
    AsciiStrToIp4
  + ShellPkg: update ping6 to use timer service instead of timer
    arch protocol
  + MdeModulePkg/DisplayEngine: Return the selectable menu
    correctly
  + SecurityPkg Tcg2Dxe: ASSERT to ensure 'VarData' is not NULL
  + SecurityPkg TcgStorageCoreLib: ASSERT to ensure 'ByteSeq' is
    not NULL
  + UefiCpuPkg/PiSmmCpuDxeSmm: dynamic PcdCpuSmmApSyncTimeout,
    PcdCpuSmmSyncMode
  + MdeModulePkg/PiSmmCore: Cache CommunicationBuffer info before
    using it
  + Check for the max DHCP packet length before use it
  + OvmfPkg: Add 4K PE alignment to enable SMM page level
    protection
  + UefiCpuPkg/PiSmmCpu: Check XdSupport before set NX
  + MdeModulePkg/BdsDxe: Avoid overwriting PlatformRecovery####
  + MdeModulePkg/BdsDxe: Fix bug to run non-first
    PlatformRecovery####
  + PcAtChipsetPkg/PcRtc: Handle NULL table entry in RSDT/XSDT
  + UefiCpuPkg/SecCore: Correct print format for stack information
  + MdeModulePkg/PiSmmCpuDxeSmm: Check RegisterCpuInterruptHandler
    status
  + MdeModulePkg/CpuExceptionHanderLibNull:
    RegisterCpuInterruptHandler()
  + UefiCpuPkg/PiSmmCpuDxeSmm: Add volatile to mNumberToFinish
  + UefiCpuPkg/PiSmmCpuDxeSmm: TransferApToSafeState() use UINTN
    params
  + MdePkg/BaseSynchronizationLib: Fix function names in function
    headers
  + MdePkg/BaseSynchronizationLib: Add volatile Interlocked*() APIs
  + MdePkg/Include: Add volatile to SynchronizationLib parameters
  + UefiCpuPkg/MpInitLib: support 64-bit AP stack addresses
  + UefiCpuPkg/MpInitLib/X64/MpFuncs.nasm: fix fatal typo
  + UefiCpuPkg/MpInitLib/X64/MpFuncs.nasm: remove superfluous
    instruction
  + UefiCpuPkg/DxeMpInitLib: remove duplicate HobLib class
    dependency
  + MdeModulePkg/Include: Add PiSmmMemoryAttributesTable.h
  + MdeModulePkg HiiDatabase: Remove extra memory initialization
  + UefiCpuPkg/PiSmmCpuDxeSmm: Add paging protection
  + UefiCpuPkg/dec: Add PcdCpuSmmStaticPageTable
  + MdeModulePkg/PiSmmCore: Add MemoryAttributes support
  + ArmVirtPkg DxeHobLib: Update func header description of
    BuildFv(2)Hob()
  + IntelFrameworkPkg PeiHobLib: Check FV alignment when building
    FV HOB
  + MdePkg HobLib: Check FV alignment when building FV HOB
  + MdeModulePkg DxeCore: Show error message on unaligned FvImage
    issue
  + MdeModulePkg/Ip4Dxe: Correct the return status
  + MdeModulePkg/Ip4Dxe: Add wrong/invalid subnet check
  + OvmfPkg AcpiTables: Use PcdDebugIoPort to describe QEMU debug
    console
  + MdePkg/BaseLib: Add one wrapper on RdRand access for parameter
    check
  + UefiCpuPkg/MpInitLib: Update AP information when BSP switched
  + UefiCpuPkg/MpInitLib: Program AP stack in fixed address
  + UefiCpuPkg/MpInitLib: Add InitFlag and CpuInfo in
    MP_CPU_EXCHANGE_INFO
  + UefiCpuPkg/MpInitLib: Remove CPU information from CPU_AP_DATA
  + UefiCpuPkg/MpInitLib: Force sending INIT-SIPI-SIPI to reset APs
  + UefiCpuPkg/MpInitLib: Fixed offset error on Cr3Location
  + UefiCpuPkg/PiSmmCpuDxeSmm: Free SmramRanges to save SMM space
  + ShellPkg/dmpstore: Support "-sfo"
  + ArmPkg/Library/ArmDmaLib: Deallocate Map buffer in case of
    error
  + UefiCpuPkg/PiSmmCpuDxeSmm: Decrease mNumberToFinish in AP safe
    code
  + UefiCpuPkg/PiSmmCpuDxeSmm: Place AP to 32bit protected mode on
    S3 path
  + UefiCpuPkg/PiSmmCpuDxeSmm: Put AP into safe hlt-loop code on S3
    path
  + UefiCpuPkg/DxeMpLib: Place APs to suitable state on Legacy OS
    boot
  + UefiCpuPkg/DxeMpLib: Allocate below 4GB mem for
    AsmRelocateApLoopFunc
  + CryptoPkg/BaseCryptLib: Make comments consistent with the
    function
  + OvmfPkg/PlatformBds: Dispatch deferred images after EndOfDxe
  + ArmVirPkg/PlatformBds: Dispatch deferred images after EndOfDxe
  + MdeModulePkg/BdsDxe: Check deferred images before booting to OS
  + UefiCpuPkg/MpInitLib: Do not wakeup AP if only one processor
    supported
  + BaseTools/EfiRom: Fix potential memory leak
  + OvmfPkg/ResetVector: Depend on PCD values of the page tables
  + CryptoPkg: Add HMAC-SHA256 cipher support
  + CryptoPkg: Add xxxxHashAll APIs to facilitate the digest
    computation
  + NetworkPkg: Fix the wrong Timer event check
  + NetworkPkg: Update IP4 stack drivers for classless address
    unicast check
  + PcAtChipsetPkg/HpetTimerDxe: Fix race condition in
    SetTimerPeriod()
  + OvmfPkg: Make more use of ARRAY_SIZE()
  + rebase to ARRAY_SIZE()
  + ArmPlatformPkg: remove ARM BDS
  + OvmfPkg/XenConsoleSerialPortLib: don't include
    <Uefi/UefiBaseType.h>
  + NetworkPkg: Support bracketed IPv6 address during a redirection
    in iSCSI
  + NetworkPkg: Enhance the code in DNS driver
  + NetworkPkg: Add dns support for pxe boot based on IPv6
  + disable deprecated interfaces
  + OvmfPkg/QemuVideoDxe: drop useless variables
    QEMU_VIDEO_MODE_DATA.RefreshRate
    QEMU_VIDEO_CIRRUS_MODES.RefreshRate
    QEMU_VIDEO_PRIVATE_DATA.CurrentMode
    QEMU_VIDEO_PRIVATE_DATA.LineBuffer
  + ArmVirtPkg: undo bogus component name and driver diagnostics
    disablement
  + NetworkPkg: Record user configured TargetIP/Port in iBFT
- Use GCC5 in Tumbleweed
* Thu Oct 13 2016 glin@suse.com
- update to 2017+git1476331065.08354c3:
  + OvmfPkg: add NOOPT build target for source level debugging
  + OvmfPkg: QemuVideoDxe uses MdeModulePkg/FrameBufferLib
  + BaseTools: support the NOOPT target with the GCC tool chains
  + BaseTools Makefile: Enable O2 option for GCC tool chain
  + CryptoPkg/OpensslLib: Upgrade OpenSSL version to 1.0.2j
    (bsc#1013603)
  + MdeModulePkg/Logo: Add LogoDxe module
  + MdeModulePkg/HiiDatabase: Add HiiImageEx implementation
  + MdeModulePkg/PciBusDxe: make OPROM BAR degradation configurable
  + NetworkPkg: Correct the DNS token return status by RCODE
  + BaseTools/EfiRom: supply missing machine type lookup strings
  + ArmVirtPkg: restrict mapping attributes of normal memory to
    EFI_MEMORY_WB
  + OvmfPkg/QemuBootOrderLib: drop too strict "/HD(" suffix from
    vblk prefix (bsc#1009707)
  + NetworkPkg/DnsDxe: Handle CNAME type responded from the name
    server
  + ArmVirtPkg/FdtPciHostBridgeLib: enable 64-bit PCI DMA
  + MdeModulePkg: Support classless IP for DHCPv4 TransmitReceive()
  + ArmVirtPkg: implement FdtPciHostBridgeLib
  + OvmfPkg: Use MdeModulePkg/ResetSystemRuntimeDxe
  + OvmfPkg/VirtioGpuDxe: implement EFI_GRAPHICS_OUTPUT_PROTOCOL
  + include VirtioGpuDxe in the platform DSC/FDF files
  + OvmfPkg/Virtio10Dxe: don't bind virtio-vga
  + OvmfPkg/QemuVideoDxe: don't incorrectly bind virtio-gpu-pci
  + BaseTools/GenFw: ignore dynamic RELA sections
  + Add implementations of API IsZeroBuffer()
  + ArmVirtPkg: Add Ramdisk support to ArmVirtPkg platforms
  + ArmVirtPkg: Move inclusion of AcpiTableDxe.inf to ArmVirt.dsc.inc
- Drop upstreamed ArmVirtPkg-Enable-PCI-bus-probing-again.patch
* Wed Sep 14 2016 dmueller@suse.com
- update to 2017+git1472049752.ea2f21e:
  + switches git branch from an (outdated) master tree
  to the UDK2017 branch, which provides an insane amount of
  changes. for details please look at https://github.com/tianocore/edk2/commits/UDK2017
- unify build flags with aarch64 build for increased compatibility with
  openSUSE installation medias
* Fri Aug 19 2016 glin@suse.com
- Update to 2015+git1471575292.00bcb5c
  + NetworkPkg/IpSecDxe: Fix UEFI IKE Initial Exchange failure
  + MdeModulePkg: Fix potential failure if UseDefaultAddress
    configured
  + OvmfPkg: Add MpInitLib reference in DSC files
  + SecurityPkg: AuthVariableLib: Fix inconsistent CertDB case
  + OvmfPkg: use StatusCode Router and Handler from MdeModulePkg
  + ArmVirtPkg/ArmVirtPrePiUniCoreRelocatable: deal with relaxed
    XIP alignment
  + BaseTools GCC: introduce GCC5 toolchain to support GCC v5.x in
    LTO mode
  + BaseTools GCC: use 'gcc' as the linker command for GCC44 and
    later
  + ArmVirtPkg/ArmVirtPrePiUniCoreRelocatable: ignore .hash and
    .note sections
  + OvmfPkg/Sec: Support SECTION2 DXEFV types
  + Preserve hii section in GCC binaries
  + Fix IPv6 HTTPClient vendor class data
  + CryptoPkg/OpensslLib: Upgrade OpenSSL version to 1.0.2h
  + NetworkPkg: Fix bug in TCP which not sending out ACK in
    certain circumstance
  + OvmfPkg: include UefiCpuPkg/CpuMpPei
  + OvmfPkg/PlatformPei: rebase and resize the permanent PEI memory
    for S3
  + SecurityPkg SecureBootConfigDxe: Add check for the external
    PE/COFF image
  + ArmVirtPkg/PlatformBootManagerLib: remove stale FvFile boot
    options
  + OvmfPkg/PlatformPei: add missing auto variable initialization
  + OvmfPkg: add PciHotPlugInitDxe
  + MdeModulePkg/PciBusDxe: recognize hotplug-capable PCIe ports
  + OvmfPkg/PlatformBootManagerLib: remove stale FvFile boot
    options
  + OvmfPkg: add a Name GUID to each Firmware Volume
  + CryptoPkg BaseCryptLib: Init the content of struct 'CertCtx'
    before use
  + CryptoPkg BaseCryptLib: Avoid passing NULL ptr to function
    BN_bn2bin()
  + MdeModulePkg/Bds: MemoryTypeInformation excludes boot option
    mem use
  + MdeModulePkg: Fix IPv4 stack potential disappeared issue
  + NetworkPkg: Stop the HTTP Boot service after the boot image
    download complete
  + ArmVirtPkg: Re-add the Driver Health Manager
  + OvmfPkg: Re-add the Driver Health Manager
  + ArmVirtPkg/ArmVirtXen: Add ACPI support for Virt Xen ARM
  + Massive conversion of assembly code to NASM
  + MdeModulePkg/UefiBootManagerLib: Fix data in
    MemoryTypeInformation
  + ArmVirtPkg: add FDF definition for empty varstore
  + ArmVirtPkg/ArmVirtQemu: switch secure boot build to NorFlashDxe
  + NetworkPkg: Handling timeout case in httpboot driver
  + NetworkPkg: HttpDxe response/cancel issue fix
  + NetworkPkg: Support TCP Cancel function
  + MdeModulePkg/RamDiskDxe: Add Memory Type selection support in
    Ramdisk HII
  + MdeModulePkg RamDiskDxe: Do not save 'Size' numeric value by
    varstore
  + MdeModulePkg: Fix IPv4 UseDefaultAddress failure case
  + MdeModulePkg/AtaBusDxe: Fix some ATA hard drives cannot be
    discovered
  + ArmVirtPkg/PlatformBootManagerLib: rebase boot logo display to
    BootLogoLib
  + OvmfPkg: set SMM stack size to 16KB
  + OvmfPkg/PlatformBootManagerLib: Connect the Xen drivers before
    loading NvVars
  + MdeModulePkg: Fix SNP.Initialize() spec conformance issue
  + OvmfPkg: raise DXEFV size to 10 MB
  + MdeModulePkg: Stop the timer before clean IP service
  + OvmfPkg/PlatformBootManagerLib: rebase boot logo display to
    BootLogoLib
  + OvmfPkg/SerializeVariablesLib: Relax check for the read-only
    variable
  + OvmfPkg: prevent 64-bit MMIO BAR degradation if there is no CSM
  + OvmfPkg, ArmVirtPkg: rename QemuNewBootOrderLib to
    QemuBootOrderLib
  + MdeModulePkg/PciBus: do not improperly degrade resource
  + NetworkPkg/HttpDxe: Don't free Wrap in HttpTcpReceiveNotifyDpc
  + NetworkPkg/TcpDxe: Remove the status check of
    SockProcessRcvToken
  + UefiCpuPkg/SmmCpuFeaturesLib: Add SMRR PhysBase/PhysMask
    fields check
  + MdeModulePkg: Skip invalid bus number scanning in PciBusDxe
    driver
  + OvmfPkg/PlatformPei: provide 10 * 4KB of PCI IO Port space on
    Q35
  + OvmfPkg: introduce ICH9_PMBASE_VALUE
  + OvmfPkg: replace PcdAcpiPmBaseAddress with PIIX4_PMBA_VALUE
  + OvmfPkg/AcpiTimerLib: don't use possibly unset PMBA register
    (PEI phase)
  + MdeModulePkg: Refine the code for DxeHttpLib
  + OvmfPkg/XenBusDxe: duplicate twice-iterated VA_LIST in
    XenStoreVSPrint()
  + SecurityPkg: Use PcdGet32() to access PcdPeiCoreMaxFvSupported
  + UefiCpuPkg/PiSmmCpuDxeSmm/SmmProfile: Fix BTS support check bug
  + NetworkPkg:HttpDxe: Code changes to support HTTP PUT/POST
    operations
  + CryptoPkg/SmmCryptLib: Enable AES support for SMM
  + MdePkg: Add NFIT definition from ACPI 6.1
  + BaseTools/GenFw: enhance to use Magic Field to identify the
    image
  + MdeModulePkg-DxeCore: rename CoreGetMemoryMapPropertiesTable
  + MdeModulePkg Variable: return error for empty str VariableName
    to GetVariable
  + PcAtChipsetPkg AcpiTimerLib: Fix a logic error
  + MdeModulePkg UiApp: change code for easy customization
  + MdePkg: Add HII definitions from UEFI 2.6
  + NetworkPkg: Make HttpBootGetBootFile return
    EFI_BUFFER_TOO_SMALL
  + MdeModulePkg:DxeHttpLib: Add checks in HttpGenRequestMessage
    API
  + ArmPkg/ArmLib: don't invalidate entire I-cache on range
    operation
  + OvmfPkg/PlatformBootManagerLib: Postpone the shell registration
  + OvmfPkg/QemuNewBootOrderLib: adapt Q35 SATA PMPN to UEFI spec
    Mantis 1353
  + MdeModulePkg Ata: Use the new (incompatible) PortMultiplierPort
    semantics
  + NetworkPkg: Bug fix of iSCSI to support MPIO
- Drop upstreamed patches
  + ovmf-dxe-10mb.patch
  + ovmf-bsc976253-postpone-shell.patch
  + ovmf-bsc980635-fix-http-crash.patch
  + ovmf-bsc982193-dont-restore-readonly-var.patch
  + ovmf-bsc982193-connect-xen-drivers.patch
  + ovmf-bsc990612-update-openssl-1.0.2h.patch
  + ovmf-bsc990773-remove-stale-boot-options.patch
- Update dbxupdate.zip since there are new hashes added into dbx
* Wed Jul 27 2016 glin@suse.com
- Update openssl to 1.0.2h (bsc#990612)
  + Add the patch: ovmf-bsc990612-update-openssl-1.0.2h.patch
  + Update the openssl tarball
- Add ovmf-bsc990773-remove-stale-boot-options.patch to remove the
  stale boot options (bsc#990773)
* Tue Jun 14 2016 glin@suse.com
- Generate the varstore template for AArch64 (bsc#983747,
  bsc#981836)
* Mon Jun  6 2016 jengelh@inai.de
- Keep %%prep minimal to shorten quilt setup run.
  Adjust RPM group. Drop redundant 4th defattr argument.
* Fri Jun  3 2016 glin@suse.com
- Add ovmf-bsc982193-dont-restore-readonly-var.patch and
  ovmf-bsc982193-connect-xen-drivers.patch to fix the file-based
  NvVars restoring. (bsc#982193)
* Tue May 24 2016 glin@suse.com
- Add the commands to remove irrelevant packages in %%prep to make
  sure those source code will never build. (bsc#973038)
* Fri May 20 2016 glin@suse.com
- Add ovmf-bsc980635-fix-http-crash.patch to fix the crash when
  downloading files from the http server (bsc#980635)
* Wed May 11 2016 glin@suse.com
- Update to 2015+git1462940744.321151f
  + BaseTools: Fix bug in GenFds to handle FV image alignment
  + SecurityPkg: SecureBootConfigDxe: Add NULL pointer check
  + OvmfPkg/PciHostBridgeLib: Scan for root bridges when running
    over Xen
  + OvmfPkg/PciHostBridgeLib: Change InitRootBridge prototype
  + MdeModulePkg/PciHostBridgeDxe: Honor ResourceAssigned
  + OvmfPkg/PciHostBridgeLib: Set correct Base/Limit for absent
    resource
  + MdeModulePkg/PciHostBridgeDxe: Fix a Base/Limit comparing bug
  + MdeModulePkg/PciHostBridgeDxe: Don't miss prefetchable MMIO
    aperture
  + ArmVirtPkg: set PcdMaxVariableSize and PcdMaxAuthVariableSize
  + ArmPkg/AArch64Mmu: don't let table entries inherit XN
    permission bits
  + ArmPkg/ArmDmaLib: do not remap arbitrary memory regions as
    uncached
  + ArmPkg/ArmDmaLib: reject consistent DMA mappings of cached
    memory
  + MdeModulePkg/PciSioSerialDxe: Do not flush the UART
  + MdeModulePkg RamDiskDxe: Fix wrong HII behavior for more than 8
    RAM disks
  + OvmfPkg: Modify FDF/DSC files for RamDiskDxe's adding NFIT
    report feature
  + MdeModulePkg RamDiskDxe: Report ACPI NFIT for reserved memory
    RAM disks
  + ArmVirtPkg/ArmVirtQemu: use MdeModulePkg/BDS
  + Ignore BootFileName if it is overloaded (HTTP Boot/PXE)
  + NetworkPkg: Fix a memory leak in HTTP boot driver
  + NetworkPkg/HttpBootDxe: Fix for the issue that the HTTP boot
    option can't be booted more than once
  + deModulePkg NvmExpressDxe: Initialize IoAlign info for an NVMe
    device
  + MdeModulePkg: Refine SNP driver's media status check logic
  + MdeModulePkg: ScsiDiskDxe: cope with broken "Supported VPD Pages"
    VPD page
  + MdeModulePkg FileExplorerLib: Add UefiHiiServicesLib dependency
  + SecurityPkg: SecureBootConfigDxe: Disable SecureBoot
    Enable/Disable in some case
  + Do not use hard coded TTL/ToS in PXE driver
  + NetworkPkg: Use UefiBootManagerLib API to create load option
  + Remove DeployedMode/AuditMode
  + OvmfPkg: Use MdeModulePkg/BDS
  + ArmPlatformPkg/PrePi: allow unicore version to be used on MP
    hardware
  + ArmPkg: implement CpuIo2 protocol driver specific for PCI
  + ArmPlatformPkg: move PCI related PCD definitions to ArmPkg
  + MdeModulePkg/DxeCore: set ImageContext Handle and ImageRead()
    fields
  + MdeModulePkg/PciBusDxe: don't create bogus descriptor if no
    resources needed
  + MdeModulePkg: Add new driver to publish EDKII_PI_SMM_COMMUNICATION_REGION_TABLE
  + SecuritPkg: DxeImageVerificationLib: Fix wrong verification
    logic in DBX & DBT
  + UefiCpuPkg/MtrrLib: Reduce the loop time to get fixed-MTRR MSR
    index
  + MdeModulePkg: PiDxeS3BootScriptLib: honor PcdAcpiS3Enable
  + NetworkPkg: Fix incorrect buffer free in HttpDxe
  + NetworkPkg: Avoid the indefinite wait case in HttpDxe
  + MdeModulePkg: DxeCore MemoryPool Algorithm Update
  + MdeModulePkg: Export ConfigResp only for form Package after
    ReadyToBoot
  + NetworkPkg:HttpDxe:Consume DxeHttpLib API changes
  + MdeModulePkg:DxeHttpLib: Update to DxeHttpLib API
  + NetworkPkg: Allow user to create a HTTP corporate boot option
    in setup page
  + MdePkg:Http11.h: Add defines for "Expect" header
  + BaseTools: Update FMP Capsule support to follow FDF spec
  + OvmfPkg: SataControllerDxe: SataControllerStop: fix use after
    free
  + OvmfPkg: SataControllerDxe: SataControllerStop: remove useless
    null check
  + MdeModulePkg DxeCore: Check free memory type by CoreUpdateProfile()
  + MdeModulePkg/NvmExpress: Fix bug of handling not
    null-terminated strings
  + ShellPkg: Enahance 'dh' command to add more protocols decoding
    support
  + MdeModulePkg/DxeCore: Avoid assertion in CoreLocateProtocol
  + MdeModulePkg: Correct PlatformHookLibSerialPortPpi module type
  + FatPkg: Update License.txt to have the full license text
  + refine codes of iSCSI driver
  + MdeModulePkg DxeCore: Enhance MemoryAttributesTable installation
  + MdeModulePkg DxeCore: Return memory type from internal free
    pool/pages
  + MdeModulePkg DxeCore: Fix a memory leak in
    InstallMemoryAttributesTable()
  + MdeModulePkg DxeCore: Call PeCoffExtraActionLib member after
    Constructor
  + MdeModulePkg/Usb: Fix wrong condition judgment to support
    usb3.1 dev
  + MdeModulePkg/UsbKbDxe: don't assert when the key read is
    invalid
  + BaseTools: Add mixed PCD support feature
  + OvmfPkg: AcpiPlatformDxe: Don't enable unsupported PCI
    attributes
  + MdeModulePkg/HiiDatabaseDxe: Support EfiVarStore to get AltCfg
    from Driver
  + MdeModulePkg/HiiDatabaseDxe: Correct the ReallocatePool size
  + MdeModulePkg/SetupBrowserDxe: Get default from callback for
    orderedList
  + SecurityPkg: AuthVariableLib & SecureBootConfigDxe:
    Fix SecureBootEnable & PK inconsistency issue
  + ShellPkg: Update ping command options to sync with Spec
  + MdeModulePkg NvmExpressDxe: Ensure write-through for NVMe write
    command
  + ShellPkg: Cache the environment variable into memory to enhance
    the performance.
  + BaseTools: Update to handle PE image with .code section only
  + ArmPkg/AArch64Mmu: disable MMU during page table manipulations
  + ArmPkg/AArch64Mmu: Fix XN attribute for device memory
  + NetworkPkg: Fix issue in Ip6Dxe SetData
- The updated tarball includes the PCI host bridge fix for Xen
  (bsc#976253)
- Add ovmf-dxe-10mb.patch to raise DXEFV to 10MB to avoid build
  error.
- Add ovmf-bsc976253-postpone-shell.patch to postpone the creation
  of the shell boot option so that the firmware will try the block
  devices first. (bsc#976253)
- Update README for Xen debugging.
* Thu Apr 21 2016 agraf@suse.com
- Add patch to enable PCI BAR probing on ARM again:
  * ArmVirtPkg-Enable-PCI-bus-probing-again.patch
* Fri Apr 15 2016 glin@suse.com
- Change the fat driver license to the BSD license in FatPkg
  instead of the proprietary license in FatBinPkg since OvmfPkg and
  ArmVirtPkg now use FatPkg (bsc#973038)
* Thu Apr 14 2016 glin@suse.com
- Update to 2015+git1460599637.f70cfe7
  + MdeModulePkg S3SaveStateDxe: Add protocol usage for gEfiLockBoxProtocolGuid
  + ArmVirtPkg/VirtFdtDxe: remove Xenio handling and rename to VirtioFdtDxe
  + ArmVirtPkg/ArmVirtXen: move from VirtFdtDxe to new XenioFdtDxe driver
  + OvmfPkg/XenIoMmioLib: add missing MemoryAllocationLib dependency to INF
  + ArmVirtPkg/VirtFdtDxe: move FDT config table installation to FdtClientDxe
  + ArmVirtPkg/VirtFdtDxe: remove unused PL011 DT node type
  + ArmVirtPkg: get rid of A PRIORI DXE declarations for VirtFdtDxe
  + ArmVirtPkg/VirtFdtDxe: drop RTC handling
  + ArmVirtPkg: move QEMU based platforms to ArmVirtPL031FdtClientLib
  + ArmVirtPkg: implement ArmVirtPL031FdtClientLib
  + ArmVirtPkg/RelocatableVirtHelper: use correct FindMemNode argument order
  + IntelFrameworkModulePkg: Remove unused PCD/Protocol
  + IntelFrameworkModulePkg/KeyboardDxe: Use PCD defined in MdeModulePkg
  + IntelFrameworkModulePkg/Ps2Mouse: Use PCD defined in MdeModulePkg
  + IntelFrameworkModulePkg/Ps2AbsPointer: Use PCD defined in MdeModulePkg
  + IntelFrameworkModulePkg/Ps2Kbd: use PCD/Protocol in MdeModulePkg
  + MdeModulePkg/MdeModulePkg.uni: Add PS2 related PCD description
  + MdeModulePkg/Ps2MouseDxe: Use a different FILE_GUID
  + MdeModulePkg/Ps2KeyboardDxe: Use a different FILE_GUID
  + MdeModulePkg/Ps2Mouse: Fix potential buffer overflow issue.
  + MdeModulePkg: Update Guid/Protocol usages in INF files.
  + ShellPkg: Update Guid/Protocol usages in INF files.
  + SecurityPkg: Update protocol usage in module INF files.
  + MdePkg: Add EFI Erase Block Protocol definitions
  + MdeModulePkg/Ps2MouseDxe: Fix build failure of GCC tool chain
  + ArmVirtPkg/VirtFdtDxe: drop PCI host bridge handling
  + ArmVirtPkg/PciHostBridgeDxe: move to FDT client protocol
  + ArmVirtPkg/BaseCachingPciExpressLib: depend on PciPcdProducerLib
  + ArmVirtPkg: implement FdtPciPcdProducerLib
  + ArmVirtPkg/VirtFdtDxe: remove handling of fw_cfg DT node
  + ArmVirtPkg/QemuFwCfgLib: move to FDT client protocol
  + BaseTools: use unsigned chars on ARM architectures
  + BaseTools: generate hash value in build report for each output EFI image
  + BaseTools/VolInfo: generate HASH value for each PE image
  + ArmVirtPkg/VirtFdtDxe: remove timer DT node handling
  + ArmVirtPkg: move TimerDxe to FDT client library
  + ArmVirtPkg: implement ArmVirtTimerFdtClientLib
  + ArmVirtPkg/VirtFdtDxe: drop detection of PSCI method
  + ArmVirtPkg/ArmVirtPsciResetSystemLib: move to FDT client protocol
  + ArmVirtPkg/VirtFdtDxe: remove GIC discovery
  + ArmVirtPkg/ArmGicArchLib: move to FdtClient protocol
  + ArmVirtPkg: add FdtClientDxe to the ArmVirtPkg platforms
  + ArmVirtPkg/FdtClientDxe: implement new driver
  + ArmVirtPkg: introduce FdtClientProtocol
  + UefiCpuPkg: CpuIo2Dxe: optimize FIFO reads and writes of IO ports
  + MdeModulePkg: Update PerformanceLib instances not to check Identifier.
  + MdePkg: Update PerformanceLib comments not to check Identifier.
  + Update edksetup.bat to check EDK_TOOLS_PATH before set it.
  + MdeModulePkg/Ps2Keyboard: Add missing PCD and protocol to DEC file
  + UefiCpuPkg/CpuMpPei: Fix potential AP mwait wakeup issue
  + NetworkPkg: Add RAM disk boot support to HTTP Boot driver.
  + ShellPkg: Fix Shell ASSERT when mv file with cwd is NULL.
  + MdeModulePkg BootScriptExecutorDxe: Consume PcdAcpiS3Enable to control the code
  + MdeModulePkg SmmS3SaveStateDxe: Consume PcdAcpiS3Enable to control the code
  + MdeModulePkg: Add new macros and refine codes
  + NetworkPkg: Add new macros and refine codes
  + MdeModulePkg: Add Ps2MouseDxe driver
  + MdeModulePkg: Add Ps2KeyboardDxe driver.
  + MdeModulePkg/UefiBootManagerLib: API BmIsValidLoadOptionVariableName
  + SecurityPkg OpalPasswordDxe: Clean up debug message in OpalHii.c
  + SecurityPkg TcgStorageOpalLib: Fix wrong condition judgment.
  + SecurityPkg OpalPasswordDxe: Suppress option for special device.
  + OvmfPkg: remove PciHostBridgeDxe fork
  + OvmfPkg: remove USE_OLD_PCI_HOST build option
  + OvmfPkg: Convert to using FatPkg in the EDK II tree
  + ArmVirtPkg: Convert to build FatPkg from source
  + ArmVirtPkg: drop dependency on PeiPcdLib for PEI Pcd.inf
  + ArmVirtPkg: drop dependency on DxePcdLib for DXE Pcd.inf
  + IntelFrameworkModulePkg AcpiS3SaveDxe: Remove S3Ready() functional code
  + IntelFrameworkModulePkg AcpiS3SaveDxe: Consume PcdAcpiS3Enable to control the code
  + OvmfPkg: Retire AcpiS3SaveDxe
  + MdeModulePkg S3SaveStateDxe: Move S3Ready() functional code from AcpiS3SaveDxe
  + MdeModulePkg S3SaveStateDxe: Consume PcdAcpiS3Enable to control the code
  + OvmfPkg: Install LockBox protocol in constructor of LockBoxDxeLib
  + OvmfPkg: Set PcdAcpiS3Enable according to QemuFwCfgS3Enabled()
  + MdeModulePkg: Introduce new PCD PcdAcpiS3Enable
  + ArmVirtPkg: drop bogus ArmPlatformSecExtraActionLib resolution
  + ArmVirtPkg: remove linux loader from ARM builds
  + Merge 2-clause BSD licensed FatPkg
  + BaseTools: Add support to merge Prebuild and Postbuild into build Process
  + BaseTools: Enhance --Pcd which override by build option
  + MdeModulePkg/Bds: Fix build failures of VS tool chain
  + OvmfPkg: disable PcdHiiOsRuntimeSupport
  + OvmfPkg: remove PcdMaxHardwareErrorVariableSize from the DSC files
  + ArmVirtPkg: include Virtio10Dxe from OvmfPkg
  + OvmfPkg: include Virtio10Dxe
  + OvmfPkg: Virtio10Dxe: non-transitional driver for virtio-1.0 PCI devices
  + OvmfPkg: VirtioNetDxe: adapt virtio-net packet header size to virtio-1.0
  + OvmfPkg: VirtioScsiDxe: adapt feature negotiation to virtio-1.0
  + OvmfPkg: VirtioRngDxe: adapt feature negotiation to virtio-1.0
  + OvmfPkg: VirtioNetDxe: adapt feature negotiation to virtio-1.0
  + OvmfPkg: VirtioBlkDxe: adapt feature negotiation to virtio-1.0
  + OvmfPkg: VirtioLib: add Virtio10WriteFeatures() function
  + OvmfPkg: IndustryStandard: add definitions from the VirtIo 1.0 spec
  + OvmfPkg: IndustryStandard: factor out Virtio095Net.h
  + OvmfPkg: IndustryStandard: factor out Virtio095.h
  + OvmfPkg: VirtioRngDxe: clear all feature bits more explicitly
  + OvmfPkg: VirtioBlkDxe: don't clear non-negotiable feature bits
  + OvmfPkg: VIRTIO_DEVICE_PROTOCOL: pass VRING object to SetQueueAddress()
  + OvmfPkg: VIRTIO_DEVICE_PROTOCOL: remove GetQueueAddress() member
  + OvmfPkg: VIRTIO_DEVICE_PROTOCOL: widen the Features bitmap to 64 bits
  + MdeModulePkg/Bds: Fix a boot hang due to Ram Disk boot support
  + BaseTools: cache the defined Guid tool to improve the performance
  + MdeModulePkg/Bds: Memory Bins don't count the memory used by RAM Disk
  + MdeModulePkg/Bds: Free resources after ram disk boot finishes
  + MdeModulePkg/Bds: Allocate reserved memory for RAM Disk boot media
  + SecurityPkg OpalPasswordSupportLib: Add comments for the used protocol in inf file.
  + SecurityPkg OpalPasswordSupportLib: Remove the hard code debug build option.
  + SecurityPkg OpalPasswordSupportLib: Fixed gcc build failure.
  + SecurityPkg TcgStorageOpalLib: Fixed gcc build failure.
  + SecurityPkg OpalPasswordDxe: Check the pointer before use it.
  + SecurityPkg TcgStorageOpalLib: Remove the hard code debug build option.
  + SecurityPkg OpalPasswordDxe: Remove the hard code debug build option.
  + SecurityPkg OpalPasswordSmm: Remove the hard code build option.
  + MdePkg Cper.h: Add missing structure for 'Processor Error Record'
  + SourceLevelDebugPkg/SmmDebugAgent: mMailboxPointer is used before set
  + MdePkg/MdePkg.uni: Add description for PcdUartDefaultReceiveFifoDepth
  + MdePkg/BaseSynchronizationLib: Add spin lock alignment for IA32/x64
  + MdePkg/BaseSynchronizationLib: Do not check timeout if lock released
  + BaseTools/GenFds: Fix the bug for wrong alignment generate for RAW file
  + MdeModulePkg/UiApp: Correct the total RAM calculation
  + IntelFrameworkModulePkg/Bds: Correct the total RAM calculation
  + MdeModulePkg: DxeUdpIoLib: fix non-empty payload path in UDP reception
  + OvmfPkg: Add RAM disk support
  + ArmPkg/ArmArchTimerLib: correct typos
  + ArmPkg/ArmArchTimerLib: fix unused variable in RELEASE builds
  + EmbeddedPkg/AcpiLib: fix SBSA Generic Watchdog helper definition
  + ArmPlatformPkg: Add PCD for Pl011 UART Interrupt
  + MdePkg: Add ARM Serial Port Subtypes to DBG2
  + MdePkg: Add ARM Serial Port Subtype definitions
  + ArmVirtPkg: disable PcdHiiOsRuntimeSupport
  + ArmPkg/ArmArchTimerLib: add GetTimeInNanoSecond() to ArmArchTimerLib
  + ArmPkg/ArchArmTimerLib: refactor MultU64xN and TimerFreq definitions
  + NetworkPkg: Check received packet size before use it.
  + MdeModulePkg: Check received packet size before use it.
  + NetworkPkg: Check pointer for NULL before use.
  + Revert "TerminalDxe: select the UART's default receive FIFO depth"
  + ArmVirtPkg/ArmVirtQemu: gate FDT config table install with build option
  + ArmVirtPkg/VirtFdtDxe: make installation of FDT as config table optional
  + MdeModulePkg RamDiskDxe: Fix incorrect RAM disk memory address calculation
  + MdeModulePkg EmmcDxe: Fix GCC build failure with set but unused variables
  + SecurityPkg: Tcg2Dxe: Fix undersized TempBuf
  + MdeModulePkg/UefiBootManagerLib: BmGetActiveConsoleIn code cleanup
  + MdeModulePkg/SdMmc: Add EDKII SD/MMC stack
  + MdePkg/IndustryStandard: Add SD/EMMC common definitions
  + MdePkg/DevicePath: Add EMMC device path definition
  + MdePkg: Add EFI_SD_MMC_PASS_THRU_PROTOCOL definition
  + UefiCpuPkg/Cpuid.h: Display Intel SGX Resource Enumeration Leaves
  + UefiCpuPkg/Cpuid.h: Add CPUID defines and structures for Intel SGX
  + ShellPkg: Refine the comparisons code in ShellPkg.
  + MdeModulePkg PartitionDxe: Add Re-entry handling logic for BindingStop
  + SecurityPkg: Enable Opal password solution build.
  + SecurityPkg: OpalPasswordSmm: Add Opal password Smm driver.
  + SecurityPkg: OpalPasswordDxe: Add Opal password dxe driver.
  + SecurityPkg: OpalPasswordSupportLib: Add Opal password support library.
  + SecurityPkg: TcgStorageOpalLib: Add TCG storage opal library.
  + SecurityPkg: TcgStorageCoreLib: Add TCG storage core library.
  + MdePkg: Add definition for TCG Storage Core and Opal specs.
  + BaseTools: Add two new sections for PCD in the build report
  + MdeModulePkg/SerialDxe: Set FIFO depth with PCD
  + MdePkg: Add PCD for UART default receive FIFO depth
  + MdeModulePkg DiskIoDxe: Media status check not be done at DiskIo level
  + MdeModulePkg PartitionDxe: Some ISO images cannot be recognized properly
  + MdeModulePkg ScsiDiskDxe: Fix hang issue when reconnecting an ISCSI device
  + PcAtChipsetPkg/PciHostBridge: Remove PciHostBridge driver
  + ShellPkg/UefiDpLib: Fix a memory leak issue in Dp.
  + PerformancePkg/Dp_App: Fix a memory leak issue in Dp.
  + BaseTools: Remove the unnecessary check for RAW File
  + BaseTools: generate alignment when the FV content come from the filesystem
  + BaseTools: Extend the RAW format to support multiple binary files
  + ShellPkg AARCH64: remove DEBUG BuildOptions override
  + BaseTools AARCH64: move DEBUG GCC49 to the small code model
  + OvmfPkg: Increase the maximum size for Authenticated variables
  + BaseTools/GCC: set -Wno-unused-but-set-variables only on RELEASE builds
  + UefiCpuPkg: CpuMpPei: remove set but unused variables
  + UefiCpuPkg: PiSmmCpuDxeSmm: remove set but unused variables
  + UefiCpuPkg/MtrrLib: remove unused but set variable
  + NetworkPkg: IpSecDxe: remove set but unused variables
  + MdeModulePkg: DeviceManagerUiLib: remove set but unused variables
  + MdeModulePkg: BootMaintenanceManagerUiLib: remove set but unused variables
  + MdeModulePkg: UfsPassThruDxe: remove set but unused variables
  + MdeModulePkg: BootManagerMenuApp: remove set but unused variables
  + MdeModulePkg/PciHostBridgeDxe: remove unused but set variables
  + IntelFspWrapperPkg: PeiFspHobProcessLibSample: remove set but unused variables
  + IntelFrameworkModulePkg: LegacyBootMaintUiLib: remove set but unused variables
  + IntelFrameworkModulePkg: DxeCapsuleLib: remove set but unused variables
  + IntelFrameworkModulePkg: BiosVideo: remove set but unused variable
  + EmulatorPkg: CpuRuntimeDxe: remove set but unused variables
  + EdkCompatibilityPkg: SmmBaseHelper: remove set but unused variables
  + EdkCompatibilityPkg: EdkIIGlueLib: remove set but unused variables
  + EdkCompatibilityPkg: BsSerialStatusCode: remove set but unused variable
  + EdkCompatibilityPkg: UefiEfiIfrSupportLib: remove set but not used variables
  + ArmPkg|EmbeddedPkg: make PcdCpuVectorBaseAddress 64 bits wide
  + ArmPlatformPkg: fixups for 64-bit pointers
  + ArmPkg: apply Cortex-A57 errata
  + NetworkPkg:Fix bug when parsing the dhcp6 option 16
  + NetworkPkg:Fix Http boot download issue.
  + ShellPkg/UefiHandleParsingLib: Fix GUID reference
  + BaseTools: Updated BuildNotes URLs
  + MdeModulePkg/RamDiskDxe: Fix typo in HII message
  + SecurityPkg/SecureBootConfigDxe: Remove type casting from the ChooseFile handlers
  + SecurityPkg/SecureBootConfigDxe: Declare EFIAPI for the ChooseFile handlers
  + ShellPkg/UefiShellDebug1CommandsLib: remove unused but set variable
  + MdeModulePkg/PciBus: Should reserve enough bus number for HPC
  + MdeModulePkg/Bds: Fix VS2012 build failure.
  + ShellPkg: Modify the 'dh' Shell command to dump the Firmware Management Protocol Image Descriptor Information.
  + MdePkg: Move SMBIOS data into the IndustryStandard header.
  + ShellPkg: Make the USB mouse behavior in 'edit' consistent with 'hexedit'.
  + NetworkPkg: Fix HII related problem in HTTP boot driver.
  + MdeModulePkg/FileExplorerLib.h: Remove the redefinition of typedefs
  + OvmfPkg: PciHostBridgeLib: install 64-bit PCI host aperture
  + OvmfPkg: PlatformPei: determine the 64-bit PCI host aperture for X64 DXE
  + OvmfPkg: PlatformPei: factor out GetFirstNonAddress()
  + OvmfPkg: AcpiPlatformDxe: enable PCI IO and MMIO while fetching QEMU tables
  + OvmfPkg: AcpiPlatformDxe: when PCI is enabled, wait for Platform BDS's cue
  + ArmVirtPkg: PlatformIntelBdsLib: signal gRootBridgesConnectedEventGroupGuid
  + OvmfPkg: PlatformBdsLib: signal gRootBridgesConnectedEventGroupGuid
  + OvmfPkg: introduce gRootBridgesConnectedEventGroupGuid
  + OvmfPkg: OvmfPkg.dec: add horizontal whitespace under Guids and Protocols
  + OvmfPkg/PlatformBdsLib: rebase to EfiEventGroupSignal
  + ArmVirtPkg/PlatformIntelBdsLib: rebase to EfiEventGroupSignal
  + IntelFrameworkPkg/FrameworkUefiLib: implement EfiEventGroupSignal
  + IntelFrameworkPkg/FrameworkUefiLib: move InternalEmptyFunction to UefiLib.c
  + MdePkg/UefiLib: introduce EfiEventGroupSignal
  + MdePkg/UefiLib: move InternalEmptyFunction to UefiLib.c
  + BaseTools: not include the undefined macro in response file
  + MdeModulePkg/BootMaintenanceManagerUiLib: Remove type casting in ChooseFile
  + MdeModulePkg/BootMaintManagerUiLib: Declare EFIAPI for ChooseFile handler
  + MdeModulePkg RamDiskDxe: Remove unnecessary TPL raise operations
  + MdeModulePkg RamDiskDxe: Uninstall DEVICE_PATH_PROTOCOL with correct param
  + MdeModulePkg RamDiskDxe: Remove unnecessary 'DisconnectController' calls
  + MdeModulePkg/Bds: BDS hotkey shouldn't work on inactive consoles
  + ArmPkg/AArch64Mmu: use correct AP[] bits in ArmClearMemoryRegionReadOnly
  + ArmPkg/ArmExceptionLib: reimplement register stack/unstack routines
  + ArmPkg/ArmExceptionLib: avoid indirect call if using vector table in place
  + ArmPkg/ArmExceptionLib: make build time define visible to the compiler
  + ArmPkg/ArmExceptionLib: don't restore ESR and FAR upon exception return
  + ArmPkg/ArmExceptionLib: stack FPSR on common path
  + ArmPkg/ArmExceptionLib: fold exception handler prologue into vector table
  + ArmPkg/AsmMacroIoLibV8: remove undocumented assumption from ELx macros
  + BaseTools: Fix nmake failure due to command-line length limitation
  + MdePkg/Pci22.h: Fix a coding style issue
  + MdeModulePkg DxeCore: Address boundary check for Type AllocateAddress
  + MdeModulePkg DxeCore: Check Start consistently in CoreConvertPagesEx
  + OvmfPkg/PlatformPei: suppress wrong VS2008 warning (use of uninited local)
  + MdeModulePkg PlatformVarCleanupLib: Locate VarCheck protocol when using
  + ArmPkg: update CpuDxe to use CpuExceptionHandlerLib
  + ArmVirtPkg/ArmVirtQemu: move to ARM version of CpuExceptionHandlerLib
  + ShellPkg: Remove the unused local variable.
  + MdeModulePkg: Fixed incorrect return value of MatchString
  + MdeModulePkg: ConSplitterDxe: use U64 mult/div wrappers in AbsPtr scaling
  + ArmPkg: ARM/AArch64 implementation of CpuExceptionHandlerLib
  + ArmPkg/ArmLib: add ArmReadHcr to enable read-modify-write of HCR
  + MdeModulePkg: Rescale ConSplitter Absolute Pointer.
  + ShellPkg: Per UEFI Shell 2.2 SPEC to make Shell supports 'NoNesting'.
  + NetworkPkg: Fix the driver model issue in HTTP Boot driver.
  + MdeModulePkg: Coding style update for DxeHttpLib.inf
  + IntelFrameworkModulePkg/LegacyBootMaintUiLib: Refine the code
  + MdeModulePkg: Refine the UI code
  + MdeModulePkg/DriverSampleDxe: Uninstall the ConfigAccess protocol
  + BaseTools: add new command line option to support override PCD value
- The fix for bsc#973625 is also included in the update tarball
- Remove upstreamed patches:
  ovmf-fix-choose-handlers-crash.patch
  ovmf-fix-httpboot-driver-option-16.patch
  ovmf-fix-httpboot-driver-model.patch
* Fri Apr  1 2016 glin@suse.com
- Add ovmf-fix-httpboot-driver-option-16.patch to fix the parsing
  of DHCPv6 option 16
* Wed Mar 23 2016 glin@suse.com
- Add ovmf-fix-choose-handlers-crash.patch to fix the crash while
  selecting files from BootMaintenanceManager and SecureBootConfig
* Wed Mar 16 2016 glin@suse.com
- Update to 2015+git1458029440.db27e9f
  + OvmfPkg/LegacyRegion: Support legacy region manipulation of Q35
  + CryptoPkg: Fix the potential system hang issue
  + CryptoPkg/OpensslLib: Upgrade OpenSSL version to 1.0.2g
  + ArmVirtPkg/VirtFdtDxe: set /chosen/linux,pci-probe-only to 1
    in DTB
  + OvmfPkg: match PCI config access to machine type
    (if not USE_OLD_PCI_HOST)
  + OvmfPkg: add DxePciLibI440FxQ35
  + OvmfPkg: Enable Network2 Shell Commands for IPv6
  + MdeModulePkg AcpiTableDxe: Use Rsdt to check against NULL
  + MdePkg: Fix ACPI NFIT GUID definitions
  + NetworkPkg: Add URI configuration form to HTTP boot driver
  + CryptoPkg/OpensslLib: Switch to upstream fix for OpenSSL
    RT#3628, RT#3674, RT#3951, RT#3955, RT#3964, RT#3969, RT#3992,
    RT#4175, RT#4310
  + CryptoPkg/OpensslLib: Include complete copy of opensslconf.h
  + SecurityPkg/SecureBootConfigDxe: Handle allocation failure
    gracefully
  + MdeModulePkg/Bds: Support booting from remote file system
  + MdeModulePkg/Bds: Wide match HTTP boot option
  + MdeModulePkg: Fix IPv4 double free
  + UefiCpuPkg: Add dynamic type for PcdCpuMaxLogicalProcessorNumber
  + ArmPkg: Configure TTBCR register
  + OvmfPkg: switch to MdeModulePkg/Bus/Pci/PciHostBridgeDxe
  + MdeModulePkg: PciHostBridgeDxe: don't assume extended config
    space
  + ShellPkg: Update 'ifconfig -r' implementation
  + NetworkPkg: Change the default IPv6 config policy
  + MdeModulePkg: Change the default IPv4 config policy
  + OvmfPkg: copy log level comments from DebugLib.h
  + ArmVirtPkg: sync log level comments to DebugLib.h
  + MdeModulePkg: DxeCore: fully initialize image context before
    passing it on
  + MdeModulePkg/NvmExpress: Fix uninitialized field used in NVMe
    DiskInfo
  + MdeModulePkg: Add new API HttpUrlGetPath() to HttpLib.h
  + MdeModulePkg: Add RamDiskDxe driver implementation
  + SecurityPkg: Tcg2Smm: Change TPM2.0 MMIO range attribute
  + MdeModulePkg:Fix a robustness issue of Mnp Driver
  + MdeModulePkg: RegularExpressionDxe: support free(NULL)
  + MdeModulePkg/PciHostBridge: Don't assume resources are fully
    NonExistent
  + SecurityPkg: Use FileExplorerLib in SecureBootConfigDxe
  + MdeModulePkg: Add ASSERT to make sure pointer 'OptionalData'
    not be NULL
  + MdeModulePkg: Add ASSERT to make sure pointer 'MemoryMap' is
    not NULL
- Update openssl to 1.0.2g
- Add ovmf-fix-httpboot-driver-model.patch to fix the crash caused
  by the httpboot driver.
* Wed Mar  2 2016 glin@suse.com
- Add ovmf-tools to package EfiRom (FATE#319531)
* Fri Feb 26 2016 glin@suse.com
- Update to 2015+git1456452471.ba33c80
  + CryptoPkg: RuntimeCryptLib: support realloc(NULL, size)
  + CryptoPkg: support free(NULL)
  + MdePkg: Add EFI RAM Disk Protocol definitions
  + MdePkg: Update Http11 with additional useful definitions
  + NetworkPkg: Use Http11 definitions in HttpDxe and HttpBootDxe
  + Add new HII action type EFI_BROWSER_ACTION_SUBMITTED
  + UefiCpuPkg/Cpuid: Add UEFI CPUID application
  + BaseTools/tools_def.txt: Add -march=i586 for IA32 GCC targets
  + MdeModulePkg: Fix Memory Attributes table type issue
  + MdePkg: Add definition for new warning code
    EFI_WARN_FILE_SYSTEM
  + OvmfPkg: add driver for Virtio-RNG device
  + ArmVirtPkg: ArmVirtQemu: add driver for Virtio-RNG device
  + OvmfPkg: implement UEFI driver for Virtio RNG devices
  + OvmfPkg: VirtioFlush(): return the number of bytes written by
    the host
  + ArmPlatformPkg/IntelBds: call BdsLibConnectAll()
  + ArmVirtPkg/ArmVirtQemu: limit ACPI support to v5.0 and higher
  + MdeModulePkg: AcpiTableDxe: make 4 GB table allocation limit
    optional
  + ShellPkg: Support finding help message embedded in resource
    section
  + MdeModulePkg/UsbBusDxe: Fix memory leak
  + MdePkg: BaseLib: fix AArch64 DAIF interrupt mask definitions
  + ArmPkg: CpuDxe: don't track interrupt state in a global
    variable
  + ArmPkg: CpuDxe: fix AArch64 interrupt read masks
  + MdeModulePkg: Refine the code in BootMaintenanceManagerUiLib
  + MdeModulePkg: HiiDatabaseDxe: HiiStringToImage() should not
    overwrite BltX
  + CryptoPkg/OpensslLib: Upgrade OpenSSL version to 1.0.2f
  + UefiCpuPkg/PiSmmCpuDxeSmm: Enable/Restore XD in SMM
  + UefiCpuPkg/PiSmmCpuDxeSmm: Add EFIAPI to CheckFeatureSupported()
  + ArmVirtPkg: ArmVirtQemu: make ACPI support AARCH64 only
  + SecurityPkg: TcgConfigDxe: Move TPM state string update to
    CallBack function
  + MdePkg: Fix incorrect PCIe Extended Capabilities definition
  + MdeModulePkg/Partition: Use proper partition number for MBR
  + MdePkg: Change PcdPropertiesTableEnable default value to FALSE
  + ArmVirtPkg: ArmVirtQemu: expose only 64-bit entry point for
    v3.0+ SMBIOS
  + NetworkPkg: Replace the internal function with exposed one
  + MdeModulePkg: Define a general function to create DNS QName
  + MdePkg: Add invocation register support in SMM Communication
    ACPI Table
  + MdeModulePkg: SNP should check Cdb.StatCode with
    PXE_STATCODE_SUCCESS
  + MdeModulePkg: Make the DEBUG info consistent in SNP driver
  + Add UEFI2.6 MemoryAttributes Table
  + OvmfPkg: simplify VARIABLE_STORE_HEADER generation
  + Minor comments update to AllocatePages() and AllocatePool()
  + MdeModulePkg DxeCore: Missing change for OEM reserved memory
    type at R17460
  + ArmPkg: DefaultExceptionHandler fixes for use with DxeCore
  + BaseTools/GenFw AARCH64: add support for relative data
    relocations
- Update openssl to 1.0.2f
  Feb 15 09:17:12 UTC 2016 - glin@suse.com
- edk2 upstream switched the repo from svn to git, so the naming
  has to change to use the git hash. The most recent stable release
  of edk2 is UDK 2015, so the base version changes to 2015.
- update to ovmf-2015+git1454310736.ed5e386
  + MdePkg: Update the UEFI version to reflect new revision
  + MdePkg: Add EFI Supplicant Protocol definitions
  + MdePkg: Add EFI Wireless MAC Connection II Protocol definitions
  + MdePkg: Add ACPI6.1 definition
  + NetworkPkg: better sanity check on Ipv6 prefix length
  + NetworkPkg: Reword PXE download message
  + ShellPkg: ShellFileHandleReadLine must return UCS2 lines
  + ArmPlatformPkg/Bds: Early Console Initialization
  + ShellBinPkg: Arm/AArch64 Shell binary update
  + ShellPkg: Fix ASCII and UNICODE file pipes
  + ArmVirtPkg: implement ArmVirtQemuKernel
  + ArmVirtPkg: introduce new ArmQemuRelocatablePlatformLib
  + MdeModulePkg: Update DxeCore dispatcher to ignore PEI and SMM
    depex for FV
  + ArmPkg: Add isb when setting SCR
  + MdeModulePkg/PcRtc: Still create timezone variable when
    Daylight != 0
  + MdeModulePkg/UsbAbsPointer:Fix GetState() to return absolute
    value
  + MdeModulePkg: Correct one return status code in SNP Transmit
    function
  + MdeModulePkg: Update the default size of MNP TX buffer pool
  + MdeModulePkg: Update DBsize in SNP GetStatus command
  + NetworkPkg:Add a new error status code EFI_HTTP_ERROR
  + MdePkg:Add a new error status code EFI_HTTP_ERROR
  + NetworkPkg: Fix suspicious dereference of pointer 'Mode.Ia'
  + OvmfPkg: QemuBootOrderLib: recognize NVMe devices
  + OvmfPkg: include NvmExpressDxe driver
  + SecurityPkg: AuthVariableLib: Add new cert database for
    volatile time based Auth variable
  + MdeModulePkg: Add BS+RT+AT variable attribute definition
  + MdePkg: Add new enum EfiPlatformConfigurationActionUnsupportedGuid
  + PcAtChipsetPkg/Rtc: Don't unnecessarily create timezone
    variable
  + Correct inconsistent function descriptions in DNS
  + OvmfPkg: Increase default RELEASE build image size to 2MB
  + Minor update to the Data parameter for GetVariable()
  + MdeModulePkg: NvmExpressDxe: clean up NvmeRead() / NvmeWrite()
    debug msgs
  + MdePkg:Add new traffic statistics definition for Wireless NIC
  + NetworkPkg:Fix Network memory leak when calling GetModeData
    interface
  + SecurityPkg: Correct data copy in Tpm2NvReadPublic
  + SecurityPkg: Add TPM PTP detection in Tpm12SubmitCommand
  + MdeModulePkg DxeCore: Avoid the closed event to be signaled
    wrongly
  + SecurityPkg: SecureBootConfigDxe: Fix potential NULL pointer
    dereference
  + CryptoPkg: Fix function qsort for non 32-bit machines
- update _service to fetch git repo
* Tue Jan 26 2016 glin@suse.com
- update to R19743
  + NetworkPkg: Removing or adding some ASSERT statement
  + MdeModulePkg:Fix the potential memory leak issue in Display
    Engine
  + MdeModulePkg: Add error DEBUG statements in ATA passthru driver
  + NetworkPkg: DnsDxe: fix return type of DnsFillinQNameForQueryIp()
  + MdeModulePkg/Ide: return correct status when DRQ is not ready
    for ATAPI
  + MdeModulePkg/ScsiDisk: Increase the value of SCSI_DISK_TIMEOUT
    to 30s
  + OvmfPkg: inherit Image Verification Policy defaults from
    SecurityPkg
  + OvmfPkg: execute option ROM images regardless of Secure Boot
  + Rename TisTpmCommand to avoid name collision
  + MdeModulePkg: update SNP.GetStatus to handle multiple recycled
    TX buffer.
  + MdeModulePkg: Update MNP driver to recycle TX buffer
    asynchronously.
  + Refine error handle code, avoid assert when load this module
    twice.
  + MdeModulePkg: DeleteLoadOptionVariable() removes Boot####
  + MdeModulePkg: Fix GraphicsConsole driver resolution out of
    sync issue
  + SecurityPkg: MOR drivers use Tcg2Protocol instead of TrEE.
  + SecurityPkg: Add Tpm2Startup return code check.
  + SecurityPkg: Clear AuthSession content after use.
  + BaseTools/VfrCompile: honor CC if it is set
  + BaseTools AARCH64: add separate GCC build rule for XIP objects
  + BaseTools AARCH64: build XIP modules with strict alignment
  + SecurityPkg: TcgDxe,Tcg2Dxe,TrEEDxe: New PCD for TCG event log
    and TCG2 final event log area
  + NetworkPkg: Fix some typos in Http boot driver.
  + MdeModulePkg: Add DNS QType and QClass values definition
  + NetworkPkg: Remove DNS QType and QClass definition
  + SecurityPkg: SecureBootConfigDxe: Change
    KEY_TRANS_SECURE_BOOT_MODE value
  + SecurityPkg: SecureBootConfigDxe: Enhance secure boot string
    update logic
  + MdeModulePkg:Fix the potential memory leak issue in Display
    Engine
  + ShellPkg: Update 'dh' command to reflect correct driver handle
    information
  + NetworkPkg: Fix IpSec SPD and SAD mapping issue when SPD is
    updated
  + NetworkPkg: Fix SPD entry edit policy issue in IPSecConfig.
  + MdeModulePkg: Add new library class PciHostBridgeLib
  + MdeModulePkg: Add PciHostBridgeLibNull
  + MdePkg: Add PciSegmentLib instance based on PciLib
  + MdeModulePkg: Add generic PciHostBridgeDxe driver.
  + Add NOOPT target
  + ShellPkg UefiDpLib: Use Image->FilePath to get name for SMM
    drivers
  + MdeModulePkg/.../IdeMode: actualize DRQReady*() comment blocks
  + MdeModulePkg/.../IdeMode: report early finish of packet read
    as success
  + MdeModulePkg: SerialDxe: lay out mSerialIoMode initializer more
    nicely
  + MdeModulePkg: SerialDxe: sync EFI_SERIAL_IO_MODE.Timeout with
    the spec
  + MdeModulePkg: TerminalDxe: select the UART's default receive
    FIFO depth
  + BaseTools: make build report tolerant of FVs specified by name
  + Replace TpmCommLib with Tpm12DeviceLib
  + Add TPM 1.2 commands used by TCG modules
  + SecurityPkg: Update TCG PPI "1.3" for TCG2.
  + Add TPM PTP support
- Remove upstreamed ovmf-fix-signedness.patch
* Wed Jan  6 2016 glin@suse.com
- update to R19584
  + NetworkPkg: Support DNS4/6 GeneralLookUp feature
  + SecurityPkg AuthVariableLib: Correct comment/error log about
    CleanCertsFromDb
  + NetworkPkg: Fix suspicious dereference of pointer before NULL
    check
  + NetworkPkg: Update module inf to include the missing uni file
  + NetworkPkg: Remove a CopyMem to speed up the HTTP boot download
  + NetworkPkg: Remove unused EFI_HTTP_PROTOCOL definition
  + MdePkg : Update SPCR to use ACPI5 definition
  + MdeModulePkg ScsiDiskDxe: Raise the Tpl of async IO callback
    to TPL_NOTIFY
  + ScsiDiskDxe: Close event when SCSI command fails
  + MdeModulePkg ScsiBusDxe: Only signal caller event when
    PassThru() succeeds
  + MdeModulePkg DiskIoDxe: Check for MediaPresent in
    DiskIo2ReadWriteDisk()
  + MdeModulePkg ScsiDiskDxe: Modify WriteBlocks(Ex)() to follow
    UEFI spec
  + MdeModulePkg ScsiDiskDxe: Modify FlushBlocksEx() to follow UEFI
    spec
  + MdeModulePkg ScsiDiskDxe: Set block I/O media of SCSI CDROM to
    read-only
  + PcAtChipsetPkg/Rtc: Fix a UEFI Win7 boot hang issue
  + MdeModulePkg:Clear the screen before booting the boot option
  + NetworkPkg : Remove unused local variables to fix gcc build
    errors
  + MdePkg: Add HTTP 1.1 industry standard definitions
  + SecurityPkg: SecureBootConfigDxe: Remove useless code in VFR
  + NetworkPkg:Fix a bug the 2nd httpboot fail issue
  + NetworkPkg: Update iSCSI driver to check existing AIP instances
  + UefiCpuPkg/CpuMpPei: Fix pack(1) issue on x64 arch
  + MdeModulePkg:Fix bug that get the password width info
    incorrectly
  + NetworkPkg:Fix the issue Http boot hang when network failed
  + DxeTpmMeasureBootLib: Change global variable name to avoid
    name conflict
  + ArmVirtPkg/ArmVirtXen: add ARM support
  + ArmVirtPkg/XenRelocatablePlatformLib: rewrite DTB memory node
    retrieval in C
  + OvfmPkg/XenHypercallLib: add missing GCC_ASM_EXPORT to
    XenHypercall2
  + Shell update
  + MdeModulePkg:Fix a bug HttpLib can't parse last chunked data
    well
  + MdeModulePkg/PciSioSerialDxe:add non-null pointer dereference
    assertion
  + ArmPkg: rewrite vector table population macros
  + BootManagerLib: Check the pointer to avoid use NULL pointer
  + MdeModulePkg: Fix RegularExpressionDxe memcpy intrinsic
- Add ovmf-fix-signedness.patch to fix the build error
* Wed Dec 16 2015 glin@suse.com
- Update R19289
  + MdePkg: Add missing SMBIOS definitions for SATA and SAS Ports
  + MdePkg: Add GIC version to ACPI 5.1/6 definitions
  + MdePkg: Add Ipmi2.0 definitions head file
  + MdeModulePkg: Add NULL pointer check for RegularExpressionDxe
  + Convert all .uni files to utf-8
  + BaseTools/Scripts: Add ConvertUni.py script
  + Fix >4G issue on IDT not restored correctly
  + MdeModulePkg: Improved SetupBrowser handling to failed GOTO
    callback
  + ArmPlatformPkg/Sec: fix return_from_exception code and comment
  + ArmPlatformPkg/ArmPlatformLibNull: use declared PPI rather than
    module local var
  + ArmVirtPkg RVCT: build DXE_RUNTIME_DRIVER modules with 4 KB
    alignment
  + BaseTools/GenFw RVCT: fix relocation processing of PT_DYNAMIC
    sections
  + BaseTools RVCT: use scatter file to enforce minimum section
    alignment
  + MdePkg/BaseIoLibIntrinsic: Add EBC support
  + MdePkg: Add 3 macro defined in latest TPM2 specification
  + ShellPkg: Initialize the local pointer to avoid potential
    suspicious dereference
  + CryptoPkg/OpensslLib: upgrade OpenSSL version to 1.0.2e
  + MdeModulePkg ScsiDiskDxe: Add BlockIO2 Support
  + MdePkg UefiScsiLib: Add non-blocking support for SCSI
    Read/Write command
  + NetworkPkg: Fix the potential NULL pointer dereferenced issue
  + ShellPkg: Make 'dh' support showing all spec defined protocols
  + BaseTools GCC: avoid the use of COMMON symbols
  + ArmPkg/PrePeiCore: adhere to architectural stack alignment
    requirement
  + UefiCpuPkg/MtrrLib: Add PCD PcdCpuNumberOfReservedVariableMtrrs
  + ArmPkg/BdsLib: Send RemainingDevicePath to PXE Load File
    protocol
  + CryptoPkg/BaseCryptLib: make mVirtualAddressChangeEvent STATIC
  + CryptoPkg ARM: add ArmSoftFloatLib resolution to CryptoPkg.dsc
  + SecurityPkg: AuthVariableLib: Customized SecureBoot Mode
    transition
  + MdePkg: DebugAssert enhancement
  + ArmVirtPkg: HighMemDxe: add memory space for the high memory
    nodes
  + ArmVirtPkg: ArmVirtPlatformLib: find the lowest memory node
- Update openssl to 1.0.2e
- Update ovmf-embed-default-keys.patch to include one more db key
- Add MicWinProPCA2011_2011-10-19.crt, the Windows Product key
* Fri Dec  4 2015 glin@suse.com
- Update to R19110
  + ShellPkg: Fix wrong return status for Ifconfig.c
  + OvmfPkg: pull in SMM-based variable driver stack
  + OvmfPkg: any AP in SMM should not wait for the BSP for more
    than 100 ms
  + OvmfPkg: use relaxed AP SMM synchronization mode
  + OvmfPkg: SmmCpuFeaturesLib: implement SMRAM state save map
    access
  + OvmfPkg: import SmmCpuFeaturesLib from UefiCpuPkg
  + OvmfPkg: set gUefiCpuPkgTokenSpaceGuid.PcdCpuSmmEnableBspElection
    to FALSE
  + OvmfPkg: LockBox: use SMM stack with -D SMM_REQUIRE
  + OvmfPkg: introduce -D SMM_REQUIRE and PcdSmmSmramRequire
  + ArmVirtPkg: add secure boot support to 32-bit ARM targets
  + MdeModulePkg/BDS: Do not pass unnecessary option to boot option
  + NetworkPkg: Fix a bug in HttpBootDriverBindingStop() when
    destroying child
  + ArmPlatformPkg/PrePiHobListPointerLib: use thread ID register
  + ArmPlatformPkg/PrePeiCore: add missing entries to AArch64
    vector table
- Refresh ovmf-gdb-symbols.patch
- Run fdupes on /usr/share/qemu
* Fri Nov 27 2015 glin@suse.com
- Update to R18975
  + ArmVirtPkg: Use SerialDxe in MdeModulePkg instead of
    EmbeddedPkg
  + OvmfPkg XenConsoleSerialPortLib: Implement
    Get(Set)Control/SetAttributes
  + NetworkPkg:Fix NULL pointer dereference issues
  + Always set WP in CR0
  + ArmPkg/UncachedMemoryAllocationLib: fix warning about
    uninitialized local var
  + UefiCpuPkg/CpuS3DataDxe: Add module to initialize ACPI_CPU_DATA
    for S3
  + Move CommunicationBuffer from stack to global variable
  + Move SmmDebug feature from ASM to C
  + Install LoadedImage protocol for PiSmmCore
  + Uninstall LoadedImage protocol if SMM driver returns error and
    is unloaded
  + ArmLib/ArmV7Mmu: use 64-bit type for mapping region size
  + ArmVirtPkg/ArmVirtPlatformLib: reduce ID map size to GCD region
    size
  + ArmVirtPkg/ArmVirtQemu: limit the (I)PA space to 40 bits
  + MdeModulePkg/UefiBootManagerLib: Always create MemoryTypeInfo
    variable
  + ShellBinPkg: Arm/AArch64 Shell binary update
  + MdeModulePkg:Create Boot Maintenance Manager Library
  + MdeModulePkg:Create Device Manager Library
  + MdeModulePkg:Create Boot Manager Library
  + ArmPkg: Invalidate cache after allocating UC memory
  + MdeModulePkg FileExplorerDxe: Create file explorer Protocol
  + ArmPkg: ArmLib: purge incorrect ArmDrainWriteBuffer () alias
  + UefiCpuPkg/CpuDxe: Don't use gBS->Stall
  + UefiCpuPkg/SmmFeatureLib: Check SmmFeatureControl by
    Code_Access_Chk
  + UefiCpuPkg: Not touch SmmFeatureControl if Code_Access_Chk not
    Set
  + ArmPkg/ArmPlatformPkg: position vectors relative to base
  + ArmPkg: correct TTBR1_EL1 settings in TCR_EL1
  + ShellPkg: Corrected CatSPrint usage to prevent memory leaks
  + ArmPkg/ArmV7Mmu: handle memory regions over 4 GB correctly
  + ArmPkg/ArmV7Lib: take MP extensions into account when
    programming TTBR
  + ArmPkg/ArmV7Lib: fix definition of TTBR_NON_INNER_CACHEABLE
  + ArmPkg/ArmV7Mmu: introduce feature PCD to map normal memory
    non-shareable
  + ArmPkg/ArmV7Mmu: make cached translation table accesses
    shareable
  + ArmPkg/ArmV7Lib: add function to test for presence of MP
    extensions
  + ArmPkg/ArmV7Lib: add support for reading the ID_MMFR0 system
    register
  + ArmPkg/ArmV7Mmu: fix write-through translation table accesses
  + ArmPkg/Mmu: set required XN attributes for device mappings
  + ArmVirtPkg/ArmVirtPlatformLib: map executable NOR region as
    normal memory
  + ArmPkg/AArch64Mmu: remove unused GcdAttributeToArmAttribute()
* Wed Nov 18 2015 glin@suse.com
- Update to R18868
  + ArmPkg: ensure DebugAgentVectorTable is 2K-aligned
  + MdeModulePkg: Add Platform recovery support
  + MdePkg: Add Platform Recovery definitions
  + MdeModulePkg: SmmLockBoxPeiLib: work without
    EFI_PEI_SMM_COMMUNICATION_PPI
  + NetworkPkg: Httpboot will fail the 2nd time result by wrong
    TCP state
  + MdeModulePkg PeiCore: PEI dispatcher need retry to process
    NOT_DISPATCHED FV
  + ArmPkg/ArmLib: mark all cached mappings as (inner) shareable
  + ArmPlatformPkg: bring DS-5 scripts in line with linker script
    changes
  + MdeModulePkg: Add BootLogoLib to provide interfaces about logo
    display
  + MdeModulePkg: Add ImageDecoderLib to provide image decoding
    service
  + MdeModulePkg: Add PlatformLogo protocol definition
* Thu Nov 12 2015 glin@suse.com
- Update to R18768
  + MdePkg: Add more DataBits support to Port80 output
  + MdeModulePkg PeiCore: Fix issue AuthenticationStatus is not
    propagated correctly
  + NetworkPkg: Report Http Errors to screen when http layer
    occurs an error
  + Add error handling for TPM in S3 resume failure
  + ArmPkg/ArmDmaLib: use the cache writeback granularity for
    alignment
  + ArmPkg/ArmLib: fix barriers in AArch64 ArmEnableMmu
  + NetworkPkg:Enable Http Boot over Ipv6 stack
  + NetworkPkg:Missing CloseEvent() in HttpResponseWorker
  + CryptoPkg: Add one new API (Pkcs7GetCertificatesList) for certs
    retrieving
  + SourceLevelDebugPkg: DebugAgent: Set Local APIC SoftwareEnable
  + UefiCpuPkg: LocalApicLib: Add API to set SoftwareEnable bit
  + UefiCpuPkg: CpuDxe: Update GDT to be consistent with DxeIplPeim
  + NetworkPkg: HttpDxe sometimes free a pointer twice
  + CryptoPkg/OpensslLib: Move OPENSSL_NO_xxx defines into
    opensslconf.h
  + CryptoPkg/OpensslLib: Eliminate GETPID_IS_MEANINGLESS
    definition
  + CryptoPkg: Fix OpenSSL BN wordsize and OPENSSL_SYS_UEFI
    handling
  + CryptoPkg/OpensslLib: Undefine NO_BUILTIN_VA_FUNCS to fix
    varargs breakage
  + CryptoPkg/BaseCryptLib: Use X509_V_FLAG_NO_CHECK_TIME
  + CryptoPkg/BaseCryptLib: Use X509_V_FLAG_PARTIAL_CHAIN
  + CryptoPkg/BaseCryptLib: Clean up checking of PKCS#7 contents
    type
  + CryptoPkg/BaseCryptLib: Use accessor functions for ASN1_OBJECT
  + CryptoPkg/BaseCryptLib: Use accessor functions for
    X509_ATTRIBUTE
  + CryptoPkg/BaseCryptLib: Use i2d_X509_NAME() instead of abusing
    X509_NAME
  + CryptoPkg/BaseCryptLib: Add missing OpenSSL includes
  + UefiCpuPkg: PiSmmCpuDxeSmm: Replace PcdSet## with PcdSet##S
  + MdePkg/BaseSynchronizationLib: fix AArch64 return values
  + Fix issue that calling GetS3MemoryInfo() with wrong order
  + Do not deadloop if Microcode not found in FspTempRamInit
  + Move Smbios measurement from TCG driver to Smbios driver
  + Add suppressif around TCG hash seleciton checkbox in TCG2
  + UefiCpuPkg: PiSmmCpuDxeSmm: Remove unused references to SmmLib
  + OvmfPkg: QemuFlashFvbServicesRuntimeDxe: split out runtime DXE
    specifics
  + OvmfPkg: QemuFlashFvbServicesRuntimeDxe: no dual addressing
    needed
  + MdeModulePkg Variable: Enhance variable performance by reading
    from existed memory cache
* Thu Oct 22 2015 glin@suse.com
- Update to R18651
  + OvmfPkg: XenPvBlkDxe: handle empty cdrom drives
  + MdeModulePkg SetupBrowserDxe: Save global variable values
    before nest function called
  + UefiCpuPkg: Add CPU Hot Plug Data include file
  + UefiCpuPkg: Add ACPI CPU Data include file
  + UefiCpuPkg: Add SMM CPU Service Protocol
  + UefiCpuPkg: CpuDxe: broadcast MTRR changes to APs
  + UefiCpuPkg: CpuDxe: Wait for APs to enter idle loop
  + UefiCpuPkg: CpuDxe: Use PCD for AP detection timeout
  + UefiCpuPkg: Update CPU MP drivers to support single CPU
    configuration
  + MdeModulePkg VarCheckLib: R18611 was thoughtless for property
    set
  + SecurityPkg : Fix Rsa2048Sha256GuidedSectionExtractLib issue
  + OvmfPkg: VirtioBlkDxe: reset device at ExitBootServices()
  + OvmfPkg: VirtioScsiDxe: reset device at ExitBootServices()
  + OvmfPkg: Sec: Fix SOURCE_DEBUG_ENABLE ASSERT()
  + MdeModulePkg: SmbiosDxe: soften DEBUG messages about table
    reallocation
  + MdeModulePkg: FaultTolerantWriteDxe: clean up some "success"
    messages
  + MdeModulePkg: FaultTolerantWriteDxe: mellow DEBUGs about
    workspace reinit
  + ArmPlatformPkg: NorFlashDxe: mellow DEBUG messages about flash
    reinit
  + ArmVirtPkg: include BaseStackCheckLib also for AARCH64
  + NetworkPkg: reset DHCP child when leaving PXE LoadFile
  + MdeModulePkg: reset DHCP child when leaving PXE LoadFile
  + SecurityPkg AuthVariableLib: Add the missing
    gEfiAuthenticatedVariableGuid
  + MdeModulePkg VariableRuntimeDxe: Add the missing
    gEfiImageSecurityDatabaseGuid
  + MdeModulepkg VarCheckLib: Return NULL when no property set to
    variable with wildcard name
  + NetworkPkg: remove unnecessary timeout event when setting IPv6
    address
  + ShellPkg: Print error message when Shell set environment
    variable fail
  + BaseTools/PeCoffLoader: fix handling of ARM MOVW/MOVT
    instruction relocs
  + UefiCpuPkg: Add ASSERT to handle local APIC not config properly
  + SecurityPkg: Integrate new RngLib into RngDxe
  + MdePkg: Create GetRandomNumber128 in RngLib
  + ArmVirtPkg/ArmVirtQemu: enable non-exec DXE stack for AARCH64
  + MdeModulePkg/DxeIplPeim: implement non-exec stack for
    ARM/AARCH64
  + ArmPkg/ArmLib MMU: add functions to set/clear RO and XN bits on
    regions
  + ArmPkg/AArch64Mmu: move page table traversal code to separate
    function
  + ArmPkg/AArch64Mmu: use architecturally correct definitions for
    XN/UXN
* Thu Oct  8 2015 glin@suse.com
- Update to R18577
  + OvmfPkg: raise DXEFV size to 9 MB
  + MdeModulePkg: exit pci function loops early if device is not
    multi-function
  + NetworkPkg: HttpDxe: Remove unused local variables
  + ArmPkg/AArch64Mmu: remove cache maintenance for page tables
  + BaseTools/AARCH64: use large code model for GCC <= 4.8
  + ArmPkg/Mmu: do not configure block translations at level 0
  + ArmVirtPkg: use 4 KB section alignment for
    ARM DXE_RUNTIME_DRIVER modules
  + BaseTools/ARM: move to unified GCC linker script
- Enable HttpBoot for i586 and x86_64
- Drop patches since upstream fixes the issues
  + ovmf-use-non-default-gcc48.patch
  + 0001-Revert-BaseTools-AARCH64-use-tiny-code-model-by-defa.patch
  + 0010-avoid-potentially-uninitialized-variable.diff
* Thu Oct  1 2015 glin@suse.com
- Update to R18564
  + OvmfPkg: set 4 KB section alignment for DXE_RUNTIME_DRIVER
    modules
  + MdeModulePkg Ip4Dxe: Ip4Config2 to request DHCP Option6 DNS
    server IP
  + MdeModulePkg: Add SMBIOS 3.0 support in NetLibGetSystemGuid
  + ArmVirtPkg: build the TFTP command into the UEFI shell
  + OvmfPkg: build the TFTP command into the UEFI shell
  + ArmVirtPkg: reduce preallocation of boot services data pages
  + OvmfPkg: enable SATA controller
  + OvmfPkg: QemuBootOrderLib: recognize Q35 SATA disks / CD-ROMs
  + MdePkg: Add RngLib into MdePkg
  + MdeModulePkg: Remove event from protocol database only if
    registered
  + ArmVirtPkg: PlatformIntelBdsLib: signal ReadyToBoot on direct
    kernel boot
  + ShellPkg: Added SMBIOS 2.8 Type 17 changes to smbiosview
  + ShellPkg: Added SMBIOS 3.0 support in dmem
  + MdeModulePkg: Enhance PCI capability looking up logic to avoid
    hang
  + OvmfPkg: disable no-exec DXE stack by default
  + OvmfPkg: make PcdPropertiesTableEnable dynamic
  + OvmfPkg: make PcdSetNxForStack dynamic
  + MdeModulePkg: Change the algorithm in SNP to use the first
    found BAR index
  + NetworkPkg: Update Http driver to use DPC mechanism
  + NetworkPkg: RxToken event not closed in Http.Response()
  + NetworkPkg: Avoid memory allocation for each HTTP message
    exchange
  + NetworkPkg: Update cache management in HTTP boot driver
  + NetworkPkg: Enlarge receive block size of HTTP boot driver
  + PXE Driver's LoadFile protocol should check FilePath
  + ArmVirtPkg: set max physical address width to 40 bits
  + ArmVirtPkg/ArmVirtMemoryInitPeiLib: handle memory above 4 GB
    on 32-bit ARM
  + ArmPkg/Mmu: Fix potential page table memory leak
  + ArmPkg/Mmu: Increase PageLevel when table found at the targeted
    level
  + ArmPkg/Mmu: Fix literal number left shift bug
  + ArmPkg/Mmu: Fix page level calculation bug
  + ArmPkg/Mmu: Fix bug of aligning new allocated page table
  + MdeModulePkg: Fix a performance data buffer overrun issue
  + ShellPkg: Fix 'for' command fail with multiple fields
  + MdeModulePkg: Regular expression protocol
  + NetworkPkg: Fix suspicious dereference of pointer 'FieldCount'
  + Handle extra module patchable PCD variable in Linux map
  + NetworkPkg: Fix the HttpCloseConnection fail issue
  + UefiCpuPkg/MtrrLib: MtrrValidBitsMask and MtrrValidAddressMask
    wrong
- Add ovmf-use-non-default-gcc48.patch: gcc5 generates the larger
  code size and causes the x86_64 final image exceeds the size
  limit if we enable Secure Boot and IPv6 at the same time. As a
  workaround, we use the non-default gcc48.
- Drop ovmf-gcc5-conf.patch and use GCC49 as TOOL_CHAIN_TAG for
  the distro with gcc5
- Limit 0001-Revert-BaseTools-AARCH64-use-tiny-code-model-by-defa.patch
  to the distro with gcc lower than 5
- Refresh ovmf-embed-default-keys.patch and ovmf-gdb-symbols.patch
* Thu Sep  3 2015 glin@suse.com
- Update to R18393
  + OvmfPkg: PlatformPei: force 32-bit MMIO aperture above 3 GB
  on Q35
  + OvmfPkg: AcpiTables: serialize control methods that create
    named objects
  + OvmfPkg: PlatformPei: clear CMOS 0xF after setting mBootMode
  + CryptoPkg: Fix one wrong parameter for weak key checking
  + CryptoPkg: Replace string wrapper functions with safe string
    functions
  + ArmPlatformPkg/PlatformIntelBdsLib: add splash screen support
  + ArmPlatformPkg/PlatformIntelBdsLib: fix and clean up error
    handling
  + ArmPlatformPkg/PlatformIntelBdsLib: remove ARM BDS dependency
  + Locate IpSec on IP packet processing only if it's installed
  + ShellPkg: Get media status in ifconfig command
  + OvmfPkg: prevent code execution from DXE stack
  + MdePkg: Modify string expression of Wi-Fi device path to
    follow UEFI spec
  + NetworkPkg: Fix IpSec run into infinite loop issue in some case
  + FatBinPkg: Update EBC/IA32/X64/IPF binaries
  + SecurityPkg: Fix one returned code issue in P7Verify Protocol
  + Add VarCheckLib library
  + BaseTools: Add NULL pointer check in AutoGen code
  + Follow PI spec to update ExtendedSize in EFI_FFS_FILE_HEADER2
  + NetworkPkg: Add HTTP utilities driver
  + OvmfPkg: Add HttpBoot support
  + NetworkPkg: Remove the hostname from the http request URL
  + MdeModulePkg:Full support F10 hot key in UiApp
  + NetworkPkg: Fix DHCP TransmitReceive EFI_NO_MAPPING return in
    DnsDxe
  + MdeModulePkg: Fix default router table and interface missing
    error
  + ShellPkg: Fix 'ifconfig' can't get the address from dhcp in
    some case
  + ArmPkg: remove ARMv6 support code
  + MdeModulePkg: Update UiApp to handle terminal type TtyTerm
  + MdeModulePkg/Xhci: make all timeout values be consistent with
    comments
  + SecurityPkg: Fixed build error due to FixedAtBuild
    PcdTcg2HashAlgorithmBitmap
  + MdeModulePkg: IP4 should re-initiate a DHCP if it detects
    network reconnection
  + NetworkPkg: Stop and release DHCP4 child after boot info is
    ready
  + Add restriction that HashFinal() must be after at least one
    HashUpdate()
  + SecurityPkg: Update SignatureSize to comply UEFI spec
  + NetworkPkg: Fix hang issue after system reconnected when IPSec
    has set up
  + Add TPM2 definition in trusted computing group
  + BaseTools IA32/X64: prevent .eh_frame sections from being
    generated
  + MdeModulePkg:Use safe string functions in UiApp
  + MdeModulePkg: Add codes to support trailer parse in HttpLib
  + OvmfPkg/Xen: use lower case x in hex immediate value
  + ArmVirtPkg: use global section alignment in custom linker
    script
  + ArmVirtPkg: avoid relocated immediates in AARCH64 asm
  + MdeModulePkg: Fix issue about current Ip4Dxe implementation
    for DHCP DORA process
  + BaseTools/GenFw: allow AArch64 tiny and small code model
    relocations
- Add 0001-Revert-BaseTools-AARCH64-use-tiny-code-model-by-defa.patch
  to use the large model for aarch64 since ld/binutils couldn't
  calculate the sections properly and GenFw would fail due to the
  section offset.
- Drop arm patches
  + 0001-ArmPlatformPkg-ArmVirtualizationPkg-enable-DEBUG_VER.patch
  + 0002-ArmPlatformPkg-Bds-generate-ESP-Image-boot-option-if.patch
  + 0003-ArmPlatformPkg-Bds-check-for-other-defaults-too-if-u.patch
  + 0005-ArmPlatformPkg-Bds-initialize-ConIn-ConOut-ErrOut-be.patch
  + 0006-ArmPlatformPkg-Bds-let-FindCandidate-search-all-file.patch
  + 0007-ArmPlatformPkg-Bds-FindCandidateOnHandle-log-full-de.patch
  + 0008-ArmPlatformPkg-Bds-fall-back-to-Boot-Menu-when-no-de.patch
  + 0009-ArmPlatformPkg-Bds-always-connect-drivers-before-loo.patch
* Mon Aug 10 2015 glin@suse.com
- Update to R18191
  + UefiCpuPkg CpuDxe: Sync up the settings of Execute Disable to APs
  + MdeModulePkg DxeIpl: Fix IA32 build failure with GCC 5.1.1
  + ArmPlatformPkg/PlatformPeim: constify EFI_PEI_PPI_DESCRIPTOR
    globals
  + ArmPlatformPkg/PrePeiCore: constify PPI globals
  + MdeModulePkg: Use monotonic count to initialize the NetLib
    random seed
  + OvmfPkg: SmbiosVersionLib: recognize SMBIOS 3.x entry point
  + OvmfPkg: SmbiosPlatformDxe: eliminate duplicate entry point
    validation
  + ArmVirtPkg/ArmVirtQemu.dsc: set default for
    PcdQemuSmbiosValidated
  + OvmfPkg: introduce PcdQemuSmbiosValidated
  + ArmVirtPkg: set SMBIOS version in DetectSmbiosVersionLib
    instead of QemuFwCfgToPcdDxe
  + OvmfPkg: set SMBIOS version in DetectSmbiosVersionLib instead
    of PlatformPei
  + OvmfPkg: SmbiosVersionLib: add "plugin" for detecting SMBIOS
    version
  + OvmfPkg: PlatformDebugLibIoPort: fix AsciiSPrint() format
    string
  + ShellPkg: Fix issue about ping fail with IPv4
  + MdeModulePkg DxeIpl: Add stack NX support
  + NetworkPkg: Fix assert caused by wrong parameter in
    AsciiStrCpyS()
  + ArmVirtPkg/ArmVirtQemu: add LinuxLoader UEFI app to ARM build
  + ArmVirtPkg/ArmVirtXen: remove unused PcdFirmwareVendor PCD
  + ArmVirtPkg/ArmVirtQemu: drop ARM BDS and make Intel BDS the
    default
  + BaseTools GCC: move AutoGen.obj contents to .text section
  + BaseTools GCC: align start of .data to .text alignment
  + BaseTools GCC: add unified GCC linker script for all archs and
    versions
  + BaseTools IA32/X64: get header size and alignment from ld
    commandline
  + BaseTools IA32/X64: move .got contents to the PE/COFF .text
    section
  + BaseTools IA32/X64: drop redundant alignment from linker script
  + BaseTools IA32/X64: move .rodata to PE/COFF .text section
  + BaseTools IA32/X64: remove NOP padding from X86/IA32 GCC linker
    scripts
  + MdeModulePkg PeiCore: Add PCD to specify PEIM Shadow
  + ArmVirtPkg: use 'auto' alignment and FIXED placement for XIP
    modules
  + MdeModulePkg: Enhance PciBusDxe to handle high 32bit of MEM64
    BAR returns 0
- Refresh ovmf-gcc5-conf.patch
- Refresh 0001-ArmPlatformPkg-ArmVirtualizationPkg-enable-DEBUG_VER.patch
- Drop upstreamed patch: ovmf-netlib-random-seed.patch
- Drop 0004-ArmPlatformPkg-ArmVirtualizationPkg-auto-detect-boot.patch
  since the ARM BDS was dropped
* Wed Jul 29 2015 glin@suse.com
- Update to R18107
  + NetworkPkg: Fix the issue cannot boot to UEFI Network after
    reset
  + ArmVirtPkg: implement DT-based ArmGicArchLib
  + OvmfPkg: fix conversion specifiers in DEBUG format strings
  + Reduce reserved memory consumption
  + MdeModulePkg: Make boot option description unique
  + NetworkPkg: Fix the issue EfiPxeBcDhcp() may return wrong
    status.
  + ArmVirtPkg/ArmVirtQemu: support SMBIOS
  + ArmVirtPkg: QemuFwCfgToPcdDxe: set SMBIOS entry point version
    dynamically
  + ArmVirtPkg: add QemuFwCfgToPcdDxe
  + OvmfPkg: SmbiosPlatformDxe: restrict current Xen code to
    IA32/X64
  + OvmfPkg: SmbiosPlatformDxe: move IsEntryPointStructureValid()
    to Xen.c
  + OvmfPkg: AcpiS3SaveDxe: drop EFI_ACPI_S3_SAVE_PROTOCOL
  + OvmfPkg: install DxeSmmReadyToLock in PlatformBdsLib
  + IntelFrameworkModulePkg/GenericBdsLib: remove AcpiS3->S3Save()
    call
  + OvmfPkg: PlatformBdsLib: signal End-of-Dxe event group
  + OvmfPkg: AcpiS3SaveDxe: call S3Ready() at End-of-Dxe
  + OvmfPkg: AcpiS3SaveDxe: prepare for End-of-Dxe callback
- Add ovmf-netlib-random-seed.patch to avoid the DHCPv6 IAID
  collision
* Fri Jul 24 2015 glin@suse.com
- Update to R18030
  + ArmVirtPkg: Make terminal type consistent
  + NetworkPkg: Add the unspecified address check for DNS6
    StationIp
  + ShellPkg: Add optional 'tftp' EFI Shell command
  + NetworkPkg: Fix bios bootup hang issue when enable network
  + SecurityPkg: Fix DBX Variable Read Error in
    ImageVerificationLib
  + SecurityPkg: Correct BootOrder/Boot#### measurement behavior
  + ArmVirtPkg/ArmVirtQemu.dsc: Remove Linux specific boot path
  + ArmPkg/BdsLib: Remove Linux loader from BdsLib
  + ArmPlatformPkg: Add the LinuxLoader.efi EFI application
  + ArmPkg/BdsLib: Replaced BdsLoadApplication() by
    LocateEfiApplicationInFv()
  + OvmfPkg: QemuBootOrderLib: recognize extra PCI root buses
  + OvmfPkg: QemuBootOrderLib: introduce ExtraRootBusMap
  + OvmfPkg: PciHostBridgeDxe: shorten search for extra root buses
  + OvmfPkg: PciHostBridgeDxe: look for all root buses
  + OvmfPkg: PciHostBridgeDxe: eliminate
    PCI_HOST_BRIDGE_INSTANCE.RootBridgeNumber
  + OvmfPkg: PciHostBridgeDxe: use private buffer in
    RootBridgeIoConfiguration()
  + OvmfPkg: PciHostBridgeDxe: release resources on driver entry
    failure
  + OvmfPkg: PciHostBridgeDxe: factor out InitRootBridge() function
  + OvmfPkg: PciHostBridgeDxe: embed device path in private root
    bridge struct
  + OvmfPkg: PciHostBridgeDxe: kill RootBridgeNumber and
    RootBridgeAttribute
  + OvmfPkg: PciHostBridgeDxe: eliminate nominal support for
    multiple host bridges
  + OvmfPkg: PlatformBdsLib: connect all PCI root buses
- Refresh patches
  + 0001-ArmPlatformPkg-ArmVirtualizationPkg-enable-DEBUG_VER.patch
  + 0002-ArmPlatformPkg-Bds-generate-ESP-Image-boot-option-if.patch
  + 0003-ArmPlatformPkg-Bds-check-for-other-defaults-too-if-u.patch
  + 0004-ArmPlatformPkg-ArmVirtualizationPkg-auto-detect-boot.patch
  + 0005-ArmPlatformPkg-Bds-initialize-ConIn-ConOut-ErrOut-be.patch
  + 0006-ArmPlatformPkg-Bds-let-FindCandidate-search-all-file.patch
  + 0007-ArmPlatformPkg-Bds-FindCandidateOnHandle-log-full-de.patch
  + 0008-ArmPlatformPkg-Bds-fall-back-to-Boot-Menu-when-no-de.patch
  + 0009-ArmPlatformPkg-Bds-always-connect-drivers-before-loo.patch
  + 0010-avoid-potentially-uninitialized-variable.diff
* Mon Jul 13 2015 glin@suse.com
- Update to R17935
  + CryptoPkg: update OpenSSL dependency to version 1.0.2d
  + OvmfPkg: QemuFwCfgLib: avoid "variable set but not used"
    warning from GCC
  + Remove Ip4ConfigDxe module
  + IntelFrameworkPkg FrameworkUefiLib: Fix ASSERT in CatVSPrint
  + BaseTools: aarch64: add -fno-asynchronous-unwind-tables to gcc
    cflags
  + MdePkg/AArch64: use GCC_ASM_EXPORT to export functions
  + MdeModulePkg/FvSimpleFileSystemDxe: Support file opening with
    no '.efi'
  + OvmfPkg: Fix GCC49 build hang in PeiCore
  + Add "TtyTerm" terminal type to TerminalDxe
  + MdeModulePkg AcpiTableDxe: Install config table at ACPI data
    change
- Remove upstreamed ovmf-remove-old-ip4config.patch
* Wed Jul  8 2015 glin@suse.com
- Update to R17883
  + MdePkg: Add UEFI2.5 Ramdisk device path definition
  + ArmVirtPkg: use correct ASM decoration for non-function global
    symbols
  + NetworkPkg: Add UEFI HTTP boot driver
  + NetworkPkg: Add HTTP Driver
  + NetworkPkg: Add DNS feature support over IPv4 and IPv6
  + MdeModulePkg: Update Ip4Dxe driver to support Ip4Config2
    protocol
  + ArmVirtPkg: adapt ArmVirtXen build to system memory end global
    variable
  + ArmPkg/CpuDxe: Fixed AArch64 MMU
  + ArmPkg/Application: Add new EFI application to boot Linux
  + ArmVirtPkg: build runtime drivers with 64 KB section alignment
  + Restructure AuthVariableLib
  + Conversion of the safe string functions
  + CryptoPkg: Fix the dereferenced pointer issue
  + SecurityPkg: Add MD5 support to Hash2DxeCrypto
  + OvmfPkg: Increase the maximum size of RAM
  + ArmVirtPkg: signal EndOxDxe event in PlatformBsdInit
  + MdeModulePkg: Add Memory Capabilities for MMIO and Reserved
    Range
- Add ovmf-remove-old-ip4config.patch to remove the old Ip4Config
- Refresh patches
  + ovmf-embed-default-keys.patch
  + ovmf-gcc5-conf.patch
  + 0001-ArmPlatformPkg-ArmVirtualizationPkg-enable-DEBUG_VER.patch
  + 0002-ArmPlatformPkg-Bds-generate-ESP-Image-boot-option-if.patch
  + 0003-ArmPlatformPkg-Bds-check-for-other-defaults-too-if-u.patch
  + 0004-ArmPlatformPkg-ArmVirtualizationPkg-auto-detect-boot.patch
  + 0005-ArmPlatformPkg-Bds-initialize-ConIn-ConOut-ErrOut-be.patch
  + 0006-ArmPlatformPkg-Bds-let-FindCandidate-search-all-file.patch
  + 0007-ArmPlatformPkg-Bds-FindCandidateOnHandle-log-full-de.patch
  + 0008-ArmPlatformPkg-Bds-fall-back-to-Boot-Menu-when-no-de.patch
  + 0009-ArmPlatformPkg-Bds-always-connect-drivers-before-loo.patch
- Add the source-level debugging to README
* Wed Jun 24 2015 glin@suse.com
- Update to R17700
  + OvmfPkg/PlatformDxe: Convert Platform.uni to UTF-8
  + OvmfPkg: QemuVideoDxe: add virtio-vga support
  + CryptoPkg: OpensslLib: reintroduce EFIAPI for
    ERR_add_error_data()
  + SecurityPkg: Provide correct file GUID for Pkcs7VerifyDxe
  + SecurityPkg: Fix wrong calculation of ImageExeInfoEntrySize
  + OvmfPkg: PlatformPei: set SMBIOS entry point version
    dynamically
  + SecurityPkg: Add UEFI-2.5 PKCS7 Verification Protocol Support
  + CryptoPkg: Add one new API for PKCS7 Verification Protocol
    Support
  + MdeModulePkg PiSmmCore: Introduce SMM Exit Boot Services and
    Legacy Boot
  + MdePkg/DxeServicesLib: Return NULL GetFileBufferByFilePath
    reads directory
  + MdeModulePkg: Fix DHCP4 driver hang issue in some case
  + MdeModulePkg: Remove DHCP4.TransmitReceive()and DORA process
    dependency
  + MdeModulePkg:System hangs in setup menu
  + ArmVirtPkg: increase memory preallocations for secure build
  + Update openssl to 1.0.2c
  + Add code to protect the whole BIOS region on SPI flash, except
    UEFI Variable region
  + SecurityPkg/MdeModulePkg: Add PcdMaxAuthVariableSize
    declaration
  + MdePkg: Add EFI REST Protocol definitions
  + OvmfPkg/PlatformPei: Initialise RCBA (B0:D31:F0 0xf0) register
  + OvmfPkg/PlatformPei: Query Host Bridge DID only once
  + ArmPkg: reduce sysreg access count in GIC revision probe
  + SecurityPkg: Fix wrong cert data measurement in DBX path
  + MdeModulePkg/UhciDxe: Update async polling interval to 1ms
  + MdeModulePkg/EhciDxe: Update async polling interval to 1ms
  + MdeModulePkg/XhciDxe: Update async polling interval to 1ms
  + ShellPkg\Application\Shell: Clean start row information after
    the console has been Reset or SetMode
  + Add SysPrepOrder and SysPrep#### to global list
  + MdePkg: Add EFI Capsule Report data structure and GUID
  + Add UEFI 2.5 Properties table definition
  + MdePkg:Add UEFI 2.5 PKCS7 Verification Protocol Definition
  + ShellPkg: Handle escape characters properly for parse command
  + ShellPkg: Add pipe support for parse command
  + ArmVirtPkg: increase memory preallocations to reduce region
    count
- Add ovmf-gcc5-conf.patch for GCC5 and adjust the spec file for
  gcc5
* Wed Jun  3 2015 glin@suse.com
- Update to R17553
  + MdeModulePkg/AtaAtapiPassThru: ensure PRDT of IDE is in 64K
    boundary
  + ArmPkg/BdsLib: Fixed TFTP when there are directories in the
    name
  + Renamed ArmPlatformPkg/ArmVirtualizationPkg into ArmVirtPkg
  + ArmPkg: Expand AArch64 address width to 48 bits
  + MdeModulePkg:Support delete key
  + MdeModulePkg/AtaAtapiPassThruDxe: Support 4K bytes block size
    HDDs
  + MdeModulePkg: Fix potential buffer overflow issues
  + Update for OEM reserved memory type
- Update ArmPlatformPkg patches
  + 0001-ArmPlatformPkg-ArmVirtualizationPkg-enable-DEBUG_VER.patch
  + 0002-ArmPlatformPkg-Bds-generate-ESP-Image-boot-option-if.patch
  + 0003-ArmPlatformPkg-Bds-check-for-other-defaults-too-if-u.patch
  + 0004-ArmPlatformPkg-ArmVirtualizationPkg-auto-detect-boot.patch
  + 0005-ArmPlatformPkg-Bds-initialize-ConIn-ConOut-ErrOut-be.patch
  + 0006-ArmPlatformPkg-Bds-let-FindCandidate-search-all-file.patch
  + 0007-ArmPlatformPkg-Bds-FindCandidateOnHandle-log-full-de.patch
  + 0008-ArmPlatformPkg-Bds-fall-back-to-Boot-Menu-when-no-de.patch
  + 0009-ArmPlatformPkg-Bds-always-connect-drivers-before-loo.patch
  + 0010-avoid-potentially-uninitialized-variable.diff
- Remove the prefix of the arm patches
  + ovmf-0001-ArmPlatformPkg-ArmVirtualizationPkg-enable-DEBUG_VER.patch
  + ovmf-0002-ArmPlatformPkg-Bds-generate-ESP-Image-boot-option-if.patch
  + ovmf-0003-ArmPlatformPkg-Bds-check-for-other-defaults-too-if-u.patch
  + ovmf-0004-ArmPlatformPkg-ArmVirtualizationPkg-auto-detect-boot.patch
  + ovmf-0005-ArmPlatformPkg-Bds-initialize-ConIn-ConOut-ErrOut-be.patch
  + ovmf-0006-ArmPlatformPkg-Bds-let-FindCandidate-search-all-file.patch
  + ovmf-0007-ArmPlatformPkg-Bds-FindCandidateOnHandle-log-full-de.patch
  + ovmf-0008-ArmPlatformPkg-Bds-fall-back-to-Boot-Menu-when-no-de.patch
  + ovmf-0009-ArmPlatformPkg-Bds-always-connect-drivers-before-loo.patch
  + ovmf-0010-avoid-potentially-uninitialized-variable.diff
* Thu May 14 2015 glin@suse.com
- Update to R17446
  + OvmfPkg: AcpiS3SaveDxe: fix protocol usage hint in the INF file
  + OvmfPkg: extract some bits and port offsets common to Q35 and
    I440FX
  + MdeModulePkg: Add ESRT management module.
  + MdeModulePkg: Add ESRT management protocol definition
  + MdePkg: Add Microsoft UX capsule GUID & layout
  + SecurityPkg: Update SecureBootConfigDxe to support ARM image
  + SecurityPkg Variable: Make PK & SecureBootMode consistent
  + MdeModulePkg DxeCore: Add read only memory support
  + OvmfPkg: QemuBootOrderLib: parse OFW device path nodes of PCI
    bridges
  + MdePkg: Add UEFI 2.5 SD (Secure Digital) Device Path Definitions
  + Hash2 driver to [Components.IA32, Components.X64, Components.IPF]
    section
  + ArmVirtualizationPkg: Enable secure boot for ArmVirtualizationQemu
  + ArmPlatformPkg: enable use of authenticated variables in
    NorFlashDxe
- Refresh patch
  + ovmf-0002-ArmPlatformPkg-Bds-generate-ESP-Image-boot-option-if.patch
- Enable Secure Boot for AArch64
- Remove the workaround for SLE11
* Thu May  7 2015 glin@suse.com
- Although ovmf-gdb-symbols.patch has been included for a while,
  it's not mentioned in changelog and legal-auto script is not
  happy with it.
* Thu May  7 2015 glin@suse.com
- Update to R17351
  + BaseTools: Fix build fail issue
  + MdeModluePkg: Enable refresh opcode to refresh the entire form
  + BaseTool: Add refresh form opcode in vfrcompiler
  + MdeModulePkg: Add BootManagerMenuApp
  + MdeModulePkg: Add BdsDxe driver and PlatformBootManagerNull
    library
  + MdeModulePkg: Add UefiBootManagerLib
  + MdePkg: Update the UEFI version to reflect new revision
  + OvmfPkg: Use the new PCDs defined in MdePkg and MdeModulePkg
  + MdePkg: Add UEFI2.5 bluetooth protocol/devicepath definition
  + Add UEFI2.5 HASH protocol implementation
  + MdeModulePkg: Add UEFI2.5 and PI1.4 PersistentMemory feature
  + MdePkg: Add ESRT Interface Definitions
  + Various fixes for Shell
- Drop ovmf-sle-11-gcc47.patch
  + The NASM version in SLE11 is too old to build the newer ovmf
- Rename the ARM patches to make the legal-auto script happy
  + ovmf-0001-ArmPlatformPkg-ArmVirtualizationPkg-enable-DEBUG_VER.patch
  + ovmf-0002-ArmPlatformPkg-Bds-generate-ESP-Image-boot-option-if.patch
  + ovmf-0003-ArmPlatformPkg-Bds-check-for-other-defaults-too-if-u.patch
  + ovmf-0004-ArmPlatformPkg-ArmVirtualizationPkg-auto-detect-boot.patch
  + ovmf-0005-ArmPlatformPkg-Bds-initialize-ConIn-ConOut-ErrOut-be.patch
  + ovmf-0006-ArmPlatformPkg-Bds-let-FindCandidate-search-all-file.patch
  + ovmf-0007-ArmPlatformPkg-Bds-FindCandidateOnHandle-log-full-de.patch
  + ovmf-0008-ArmPlatformPkg-Bds-fall-back-to-Boot-Menu-when-no-de.patch
  + ovmf-0009-ArmPlatformPkg-Bds-always-connect-drivers-before-loo.patch
  + ovmf-0010-avoid-potentially-uninitialized-variable.diff
* Thu Apr 23 2015 glin@suse.com
- Update ovmf-embed-default-keys.patch to embed the default dbx.
  Also add the dbx list from the UEFI website and enable it in the
  MS flavor. A script, strip_authinfo.pl, was added to strip the
  AuthInfo headers from dbxupdate.bin since those are not necessary
  in dbx.
* Mon Apr 20 2015 glin@suse.com
- Update to R17187
  + Save initial TSVal from TCP connection initiation packets
  + BaseTools/Ecc: Add ECC (EFI Code Checker) Binary into BaseTools
    bin directory
  + MdePkg: Add ESRT Interface Definitions
  + OvmfPkg: XenConsoleSerialPortLib: deal with output overflow
  + OvmfPkg: Q35: Use correct ACPI PM control register:bit
  + PXE driver bug fix
  + A failed PXEv6 after a success PXEv4 will cause ASSERT
  + MdePkg: BaseSynchronizationLib: fix Increment/Decrement retvals
    for ARM
  + Updated Memory Error Record Per UEFI Specification 2.4a
  + MdeModulePkg BootScriptExecutorDxe: Use ImageContext.ImageSize
    to allocate memory for PE image to handle the case PE file
    alignment is not same as PE section alignment.
  + Fix GCC hang issue: Point should use directly assignment
    instead of IP4_COPY_ADDRESS.
  + SecurityPkg Variable: Update code in ProcessVariable ()
- Update openssl to 0.9.8zf
* Tue Mar 17 2015 glin@suse.com
- Update to R17055
  + OvmfPkg: include XHCI driver
  + ArmVirtualizationPkg/ArmVirtualizationQemu: include XHCI driver
  + ArmVirtualizationPkg: build UEFI shell from source
  + SecurityPkg Variable: Allow the delete operation of common auth
    variable at user physical presence
  + Set network boot option to the default last priority
  + MdeModulePkg: improve scalability of memory pools
  + MdeModulePkg: use correct granularity when allocating pool
    pages
* Fri Mar  6 2015 glin@suse.com
- Update to R17007
  + ArmVirtualizationPkg: PlatformIntelBdsLib: lack of QEMU kernel
    is no error
  + Improve Xen support in Ovmf
  + ArmVirtualizationPkg: PlatformIntelBdsLib: display TianoCore
    logo
  + ArmVirtualizationPkg/ArmVirtualizationQemu: add USB keyboard
    input
  + ArmVirtualizationPkg/ArmVirtualizationQemu: add VGA console
    output
  + ArmVirtualizationPkg/ArmVirtualizationQemu: enable PCI support
  + OvmfPkg/QemuVideoDxe: enable ARM builds
  + Improve ACPI support in Ovmf
  + OvmfPkg/PlatformBdsLib: Signal ReadyToBoot before booting QEMU
    kernel
  + ArmPkg/ArmLib.h: Add CPU Affinity definitions
  + OvmfPkg/SMBIOS: Provide default Type 0 (BIOS Information)
    structure
  + NetworkPkg: Code refine to avoid NULL pointer dereferenced
  + DHCP6 bug fix
  + BaseTools/GenFw: Set the PE/COFF attribute BaseOfData with the
    address of the first '.data' section
  + OvmfPkg: Update PlatformBaseDebugLibIoPort library
  + Various fixes for shell
- Update ARM patches
* Fri Feb  6 2015 lnussel@suse.de
- update to R16775
- add RH patches for ARM
* Tue Jan  6 2015 glin@suse.com
- Update to R16580
  + MdeModulePkg Variable: Implement VarCheck PROTOCOL and follow
    UEFI spec to check UEFI defined variables
  + ArmVirtualizationPkg: Intel BDS: load EFI-stubbed Linux kernel
    from fw_cfg
  + ArmVirtualizationPkg: identify "new shell" as builtin shell
    for Intel BDS
  + ArmVirtualizationPkg: PlatformIntelBdsLib: adhere to QEMU's
    boot order
  + OvmfPkg: QemuBootOrderLib: OFW-to-UEFI translation for
    virtio-mmio
  + OvmfPkg: QemuBootOrderLib: widen ParseUnitAddressHexList() to
    UINT64
  + ArmVirtualizationPkg: VirtFdtDxe: use dedicated
    VIRTIO_MMIO_TRANSPORT_GUID
  + OvmfPkg: introduce VIRTIO_MMIO_TRANSPORT_GUID
  + OvmfPkg: QemuBootOrderLib: featurize PCI-like device path
    translation
  + OvmfPkg: extract QemuBootOrderLib
  + ArmVirtualizationPkg: PlatformIntelBdsLib: add basic policy
  + ArmVirtualizationPkg: clone PlatformIntelBdsLib from
    ArmPlatformPkg
  + ArmVirtualizationPkg: introduce QemuFwCfgLib instance for DXE
    drivers
  + ArmVirtualizationPkg: VirtFdtDxe: forward FwCfg addresses from
    DTB to PCDs
  + MdeModulePkg/FvSimpleFileSystem:Fix a potential NULL
    dereference issue
  + Correct the Hash Calculation for Revoked X.509 Certificate to
    align with RFC3280 and UEFI 2.4 Spec
  + MdeModulePkg/FvSimpleFileSystem: Add a new module to provide
    access to executable files in FVs
  + OvmfPkg: enable IPv6 support
  + Fix a bug that the gateway is not necessary in a simple PXE
    network
  + ArmPkg/BdsLib: Update the size of the Device Tree before
    booting Linux
  + ArmPkg/BdsLib: Rework TFTP boot
  + MdePkg: UefiScsiLib: do not encode LUN in CDB for SCSI commands
  + Correct the alignment calculation of PE/COFF attribute
    certificate entry
  + OvmfPkg: CsmSupportLib: depend on OvmfPkg.dec explicitly
  + OvmfPkg: AcpiPlatformDxe: make dependency on PCI enumeration
    explicit
  + MdePkg/MdeModulePkg: Implement the missing
    SetMemorySpaceCapabilities function
  + Various fixes for shell
- Set the flag to enable IPv6 support
- Refresh ovmf-embed-default-keys.patch
* Tue Nov 18 2014 glin@suse.com
- Update to R16398
  + OvmfPkg: PlatformBdsLib: Dynamic PCI Interrupt Line register
    setup
  + SecurityPkg: VariableServiceSetVariable(): fix dbt <-> GUID
    association
  + CryptoPkg: OpenSslSupport.h: edk2-ize offsetof() macro for
    gcc-4.8 / X64
  + CryptoPkg: TimestampTokenVerify(): fix gcc-4.8 / Ia32 build
    failure
  + UEFI 2.4 X509 Certificate Hash and RFC3161 Timestamp
    Verification support for Secure Boot
  + OvmfPkg: PlatformBdsLib: Platform dependent
    PCI/IRQ initialization
  + OvmfPkg: AcpiTimerLib: Split into multiple phase-specific
    instances
  + OvmfPkg: PlatformPei: Platform specific ACPI power management
    setup
  + OvmfPkg: Factor out platform detection (q35 vs. piix4)
  + UefiCpuPkg/CpuDxe: install Mp Service protocol
  + UefiCpuPkg/CpuDxe: introduce EFI_MP_SERVICES_PROTOCOL
  + ArmPkg/ArmGicLib: select GICv2 mode if SRE is present but
    unavailable
  + OvmfPkg/XenPvBlkDxe: Don't include system inttypes.h
  + ArmPlatformPkg: fix undefined reference to memcpy
  + CryptoPkg Updates to support RFC3161 timestamp signature
    verification
  + MdeModulePkg DxeCore/PiSmmCore: Add UEFI memory and SMRAM
    profile support
* Tue Nov 11 2014 glin@suse.com
- Update to R16329
  + ArmPkg/ArmArchTimerLib: Promotes 32bit value to prevent
    overflow
  + ArmPkg/CompilerIntrinsicesLib: Fixed memmove() and memset()
  + ArmPkg: Ensured the stack is always quad-word aligned
  + ArmPlatformPkg: Increase more ARM address Pcd entries to 64-bit
  + Fix execution status & DEBUG message level mismatch
  + OvmfPkg: set video resolution of text setup to 640x480
  + OvmfPkg: BDS: drop custom boot timeout, revert to
    IntelFrameworkModulePkg's
  + OvmfPkg: BDS: drop superfluous "connect first boot option"
    logic
  + OvmfPkg: BDS: optimize second argument in
    PlatformBdsEnterFrontPage() call
  + OvmfPkg: BDS: don't overwrite the BDS Front Page timeout
  + OvmfPkg: BDS: drop useless return statement
  + OvmfPkg: BDS: remove dead call to PlatformBdsEnterFrontPage()
  + BaseTools/GenFw: Fixed R_AARCH64_CALL26/R_AARCH64_JUMP26 when
    referring to start of a section
  + Various fixes for ShellPkg
  + Convert the assembly code in OVMF to NASM
  + MdeModulePkg/SecurityPkg Variable: Add boundary check for
    while (IsValidVariableHeader (Variable))
  + Add Xen support for OVMF
  + OvmfPkg: Add the MIT license to License.txt
  + ArmPkg/ArmLib: Removed duplicated invalidate TLB function
  + ArmPlatformPkg/ArmShellCmdRunAxf: Added 'runaxf' cmd to shell
- Amend the spec file to use the system gcc version as the tool
  chain tag
* Wed Oct 22 2014 glin@suse.com
- Update to R16226
  + ArmVirtualizationPkg: FdtPL011SerialPortLib: support
    UEFI_APPLICATION
  + ArmPlatformPkg/ArmVirtualizationPkg: Added support for Intel
    BDS
  + ArmPkg/ArmLib/AArch64: Initialize the new N+1-level page table
    before registering it
  + ArmPkg/UncachedMemoryAllocationLib: Track uncached memory
    allocations
  + ArmPkg/ArmPsciResetSystemLib: Made the library only using SMC
  + ArmPlatformPkg/Bds: Reduce boot device entries
  + Various fixes for ShellPkg
  + OvmfPkg: disable stale fork of SecureBootConfigDxe
- Drop upstreamed ovmf-use-generic-sb-config.patch
* Wed Oct  1 2014 glin@suse.com
- Update to R16190
  + OvmfPkg: AcpiPlatformDxe: implement QEMU's full ACPI table
    loader interface
  + OvmfPkg: AcpiPlatformDxe: actualize QemuLoader.h comments
  + OvmfPkg: resolve OrderedCollectionLib with base red-black tree
    instance
  + Fix X64 native function call prolog
  + Add ArmVirtualizationQemu platform
  + Various fixes for ShellPkg
- Enable AArch32 and AArch64 QEMU rom images
- Drop the rom images for Foundation Model
- Drop upstreamed ovmf-correct-debug-path.patch
- Drop upstreamed edk2-basetools-aarch64.patch
* Tue Sep 16 2014 glin@suse.com
- Update to R16106
  + OvmfPkg: resolve BcfgCommandLib class for
    ShellPkg/.../Shell.inf
  + OvmfPkg: AcpiTimerLib: Access power mgmt regs based on host
    bridge type
  + OvmfPkg: QemuVideoDxe: work around misreported QXL framebuffer
    size
  + OvmfPkg: Build OVMF ResetVector during EDK II build process
  + Update openssl to 0.9.8zb
  + Replace GAS Thunk16 with NASM version
  + Various fixes for ShellPkg
- Add ovmf-*-code.bin and ovmf-*-vars.bin for the better flash
  mode support
- Refresh edk2-basetools-aarch64.patch
* Thu Aug 21 2014 lnussel@suse.de
- also build a firmware with the openSUSE 4096 bit CA embedded
* Thu Aug 14 2014 glin@suse.com
- Amend the spec file to package the debug files and update README
  for the source level debugging
- Add gdb_uefi.py.in: the helper script to load the debug symbols
- Update to R15801
  + OvmfPkg/build.sh: Support IA32+X64 build
  + OvmfPkg/build.sh: Add support for GCC49 toolchain
  + Add ACPI5.1 header file
  + BaseTools: various fixes and add support for GCC49
  + OvmfPkg: build OVMF_VARS.fd, OVMF_CODE.fd, OVMF.fd
  + OvmfPkg: extract varstore-related FD Layout Regions to an
    include file
  + StdLib: various fixes and code cleanup
  + Fix segfault while the pointers passed to WaitForEvent() are
    NULL
  + Update openssl to 0.9.8za
  + Correct the default value for date opcode
  + XhciPei/UsbBusPei: Add XHCI recovery support
  + Fix a bug in IP4 driver when computing the network broadcast
    adress
  + Fix the potential address overflow issue when checking PE
    signature
  + OvmfPkg: add missing braces to aggregate and/or union
    initializers
  + OvmfPkg: AcpiPlatformDxe: don't rely on unstable QEMU interface
  + OvmfPkg: AcpiPlatformDxe: exclude RSD PTR from QEMU's fw_cfg
    payload
  + OvmfPkg: AcpiPlatformDxe: pass FwCfgFile to
    InstallQemuLinkedTables()
  + OvmgPkg: QemuFwCfgLib: export QEMU_FW_CFG_FNAME_SIZE
  + Initialize the PCI device path earlier to avoid the possible
    crash
  + Create boot option for all block IO devices
  + ShellPkg: various fixes
- Refresh OVMF-correct-debug-path.patch
* Wed Aug 13 2014 glin@suse.com
- Rename filenames to match the package name
* Wed May 28 2014 glin@suse.com
- Update to R15547
  + Fix memory corruption after S3
  + QemuVideoDxe: Int10h stub for Windows 7 & 2008 (stdvga, QXL)
  + Add QEMU support to OVMF SMBIOS driver
* Thu Apr  3 2014 glin@suse.com
- Update to R15426
  + AcpiPlatformDxe: download ACPI tables from QEMU
  + PlatformDxe: set preferred video resolution from platform
    config
  + QemuBootOrder: don't leak unreferenced boot options
  + Support S3 suspend
  + Bug fixes for QemuVideoDxe
    prefered resolution
  + Various fixes for ShellPkg
- Refresh OVMF-use-generic-sb-config.patch
* Tue Feb 18 2014 glin@suse.com
- Update to R15245
  + OvmfPkg: Reorganize the memory layout
  + OvmfPkg: unify PcdMaxVariableSize at 0x2000 bytes
  + Fix bug that PXEv4 boot fail if PXEv6 is performed firstly
  + Update PXE driver to support PXE forced mode
  + OvmfPkg: QemuFwCfgLib: implement for SEC
  + OvmfPkg: VirtioBlkInit(): expose virtio-blk topology in BlockIo
  + OvmfPkg: QemuFlashFvbServicesRuntimeDxe: fix out-of-LBA write
    access
  + OvmfPkg/QemuVideoDxe: child handles should have open parent
    protocol BY_CHILD_CONTROLLER
  + UefiCpuPkg: S3Resume2Pei: align return stacks explicitly
  + Virtio drivers: fix incorrect casts in init functions
  + Use the new VIRTIO_DEVICE_PROTOCOL protocol
  + Various fixes for ShellPkg
  + Support Xen better
  + Fixed the system hang on VM with >2GB RAM
  + Fix a bug in Fat driver that it asserts when
    OpenEx/ReadEx/WriteEx is about to return failure
  + Updated OvmfPkg to use suitable CPU Exception Handler Library
    instances
  + Updated CPU Exception Handler Library
  + Add Reserve Interrupt and Exception Vectors definition defined
    in PI 1.2.1.
  + QemuVideoDxe: don't leak descriptors returned by
    GetBarAttributes
- Add OVMF-correct-debug-path.patch to correct the path to the
  debug symbols
- Enable AArch64 UEFI image build against Foundation Model
- Drop OVMF-more-gcc-def.patch: just use the flags for gcc 4.7
* Mon Nov 18 2013 glin@suse.com
- Update to R14854
  + Support --enable-flash switch
  + Use rsp instead of esp to save 64-bit stack pointer
  + Fix the bug that SetTimer () cannot work when Type is
    TimerPeriodic and TriggerTime is 0
  + Several Virtio fixes
  + emulated NV storage must be EfiRuntimeServicesData
  + Fix a bug about the iSCSI DHCP dependency issue
  + correctly align emulated NV storage
  + Update ATA drivers to follow UEFI2.4 new request
  + Restore the correct cursor status after finish creating the
    dialog
  + Fix display engine driver paint some menu error
  + Fix a bug about the “VendorKey” variable update logic
  + Several fixes for shell commands
  + Fix spelling typo in the NIC_IP4_CONFIG_INFO.Permanent variable
    name
  + Added VirtIo Subsystem IDs
  + Add the definition for Timestamp Protocol and a new  driver
    base on TimerLib to produce Timestamp protocol
  + Fix modal form display error
  + Fix form flash issue
  + Fix the BdsExpandPartitionPartialDevicePathToFull() hang issue
- Update README about the flash mode support
* Wed Sep 25 2013 glin@suse.com
- Update to R14721
  + Fix EFI handover flag
  + Build early pagetable for the machines without EPT
  + Enable caching in initial page tables
  + Fix pool allocation in shell
  + Improve QemuBootOrder
- Drop upstreamed OVMF-build-early-pagetable.patch
* Fri Sep  6 2013 glin@suse.com
- Strip CR from the license files
- Update README
* Thu Sep  5 2013 glin@suse.com
- Rename the package name from OVMF to ovmf
- Update to R14609
  + Fixes for virtio disk
  + Build the new shell by default
  + Fix EFI memory mapping in Linux loader
  + Add gcc47 definition
- Refresh OVMF-more-gcc-def.patch and OVMF-sle-11-gcc47.patch
- Add OVMF-build-early-pagetable.patch to fix the black screen
  issue on the CPU without EPT support
- Drop upstreamed OVMF-fix-shell-warning.patch
- Drop patches and use the build parameters instead:
  OVMF-enable-secure-boot.patch and OVMF-add-ovmf-targets.patch
- Install license files
- Add _service to checkout the source code from svn
* Thu Aug 29 2013 lnussel@suse.de
- when built in devel project also create a firmware variant that
  includes the devel project key
- include new 2048 bit openSUSE keys
* Tue Aug 27 2013 glin@suse.com
- Add OVMF-sle-11-gcc47.patch for SLE-11-SP3
- Clean up the spec file
- Only embed keys in the x86_64 roms since openSUSE/SUSE and
  Microsoft only support secure boot on x86_64 machines
* Mon Aug 26 2013 glin@suse.com
- Package OVMF roms in qemu-ovmf-*
- Rename patches
  + 0001-OVMF-Enable-secure-boot-and-expand-X64-rom-size.patch to
    OVMF-enable-secure-boot.patch
  + 0002-edk-targets-for-x86_64.patch to
    OVMF-add-ovmf-targets.patch (also enable IA32)
- Merge 0004-add-GCC47-definition-one-removal-of-melf_x86_64.patch
  and OVMF-gcc48-definition.patch into OVMF-more-gcc-def.patch
- Drop 0003-edk2-add-readme.patch and maintain README outside the
  tarball
- Drop 0005-edk-image-size.patch
- Drop 0006-edk-add-shell.efi-target.patch since we don't build
  shell.efi anymore
* Thu Aug 22 2013 glin@suse.com
- Update to R14547
- Drop upstreamed OVMF-fix-shell-warning.patch
* Mon Jul 15 2013 glin@suse.com
- Update to R14466
- Add OVMF-fix-shell-warning.patch to fix a compilation warning in
  shell
- Drop upstreamed OVMF-adjust-variable-size.patch and
  OVMF-convert-virtual-address.patch
* Mon Jul  8 2013 glin@suse.com
- Add OVMF-gcc48-definition.patch for gcc 4.8
* Mon Jun 10 2013 glin@suse.com
- Add OVMF-convert-virtual-address.patch to convert
  mLockedVariableList to virtual address to fix crash when updating
  variables in Runtime
* Wed Jun  5 2013 glin@suse.com
- Update to R14395
- Add OVMF-use-generic-sb-config.patch to use the generic secure
  boot config menu
- Drop OVMF-multi-signatures.patch
* Wed May 29 2013 glin@suse.com
- Update to R14387
- Add OVMF-adjust-variable-size.patch to adjust the default maximum
  variable size to avoid crash
- Remove upstreamed OVMF-new-shell-error-string.patch
- Disable OVMF-multi-signatures.patch
- Build the image with openSUSE keys
* Tue May 14 2013 glin@suse.com
- Refresh OVMF-embed-default-keys.patch to fix a bug that causd the
  enrolled keys overwritten by the default keys after system reset.
- Add OVMF-new-shell-error-string.patch to add newer error status
  strings
- Enable the new shell
* Fri May 10 2013 glin@suse.com
- Add OVMF-embed-default-keys.patch to embed keys at build time
- Build images with SUSE and MS keys
* Fri Mar 22 2013 glin@suse.com
- Add OVMF-multi-signatures.patch (R14141)
- New package OVMF based on James Bottomley's OVMF package (R14071)
